/*
** Copyright @ 2012-2019, Kingsoft office,All rights reserved.
**
** Redistribution and use in source and binary forms ,without modification and
** selling solely, are permitted provided that the following conditions are
** met:
**
** 1.Redistributions of source code must retain the above copyright notice,
**   this list of conditions and the following disclaimer.
** 2.Redistributions in binary form must reproduce the above copyright notice,
**	 this list of conditions and the following disclaimer in the documentation
**	 and/or other materials provided with the distribution.
** 3.Neither the name of the copyright holder nor the names of its contributors
**	 may be used to endorse or promote products derived from this software
**	 without specific prior written permission.
**
** SPECIAL NOTE:THIS SOFTWARE IS NOT PERMITTED TO BE MODIFIED OR SOLD SOLELY AT
** ANY TIME AND UNDER ANY CIRCUMSTANCES, EXCEPT WITH THE WRITTEN PERMISSION OF
** KINGSOFT OFFICE
**
** THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
** AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
** IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
** ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
** LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
** CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
** SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
** INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
** CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
** ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
** POSSIBILITY OF SUCH DAMAGE.
**/
#ifndef __WPPAPI_PREDEF_H__
#define __WPPAPI_PREDEF_H__

using ksoapi::ThemeColorScheme;
using ksoapi::MsoDebugOptions;
using ksoapi::_IMsoDispObj;
using ksoapi::AnswerWizard;
using ksoapi::Assistant;
using ksoapi::COMAddIns;
using ksoapi::_CommandBars;
using ksoapi::CommandBars;
using ksoapi::Crop;
using ksoapi::CustomXMLNode;
using ksoapi::CustomXMLPart;
using ksoapi::CustomXMLParts;
using ksoapi::DocumentInspectors;
using ksoapi::DocumentLibraryVersions;
using ksoapi::DocumentProperties;
using ksoapi::FileDialog;
using ksoapi::FileSearch;
using ksoapi::GlowFormat;
using ksoapi::GradientStops;
using ksoapi::HTMLProject;
using ksoapi::IAssistance;
using ksoapi::IFind;
using ksoapi::IMsoDiagram;
using ksoapi::LanguageSettings;
using ksoapi::MetaProperties;
using ksoapi::MsoEnvelope;
using ksoapi::NewFile;
using ksoapi::OfficeTheme;
using ksoapi::Permission;
using ksoapi::PickerDialog;
using ksoapi::PictureEffects;
using ksoapi::ReflectionFormat;
using ksoapi::Ruler2;
using ksoapi::Script;
using ksoapi::Scripts;
using ksoapi::ServerPolicy;
using ksoapi::SharedWorkspace;
using ksoapi::Signature;
using ksoapi::SignatureSet;
using ksoapi::SmartArt;
using ksoapi::SmartArtColors;
using ksoapi::SmartArtLayout;
using ksoapi::SmartArtLayouts;
using ksoapi::SmartArtQuickStyles;
using ksoapi::SmartDocument;
using ksoapi::SoftEdgeFormat;
using ksoapi::Sync;
using ksoapi::TextColumn2;
using ksoapi::TextRange2;
using ksoapi::WebPageFonts;
using ksoapi::WorkflowTasks;
using ksoapi::WorkflowTemplates;

class VBProject;
class VBE;
class _VBProject;


#undef __Collection_FWD_DEFINED__
#undef ___Application_FWD_DEFINED__
#undef ___Global_FWD_DEFINED__
#undef __ColorFormat_FWD_DEFINED__
#undef __SlideShowWindow_FWD_DEFINED__
#undef __Selection_FWD_DEFINED__
#undef __DocumentWindows_FWD_DEFINED__
#undef __SlideShowWindows_FWD_DEFINED__
#undef __DocumentWindow_FWD_DEFINED__
#undef __View_FWD_DEFINED__
#undef __SlideShowView_FWD_DEFINED__
#undef __SlideShowSettings_FWD_DEFINED__
#undef __NamedSlideShows_FWD_DEFINED__
#undef __NamedSlideShow_FWD_DEFINED__
#undef __PrintOptions_FWD_DEFINED__
#undef __PrintRanges_FWD_DEFINED__
#undef __PrintRange_FWD_DEFINED__
#undef __AddIns_FWD_DEFINED__
#undef __AddIn_FWD_DEFINED__
#undef __Presentations_FWD_DEFINED__
#undef __PresEvents_FWD_DEFINED__
#undef __Hyperlinks_FWD_DEFINED__
#undef __Hyperlink_FWD_DEFINED__
#undef __PageSetup_FWD_DEFINED__
#undef __Fonts_FWD_DEFINED__
#undef __ExtraColors_FWD_DEFINED__
#undef __TextRange_FWD_DEFINED__
#undef __TextFrame_FWD_DEFINED__
#undef __Shape_FWD_DEFINED__
#undef __Shapes_FWD_DEFINED__
#undef __Slides_FWD_DEFINED__
#undef ___Slide_FWD_DEFINED__
#undef __SlideRange_FWD_DEFINED__
#undef ___Master_FWD_DEFINED__
#undef __SldEvents_FWD_DEFINED__
#undef __ColorSchemes_FWD_DEFINED__
#undef __ColorScheme_FWD_DEFINED__
#undef __RGBColor_FWD_DEFINED__
#undef __SlideShowTransition_FWD_DEFINED__
#undef __SoundEffect_FWD_DEFINED__
#undef __SoundFormat_FWD_DEFINED__
#undef __HeadersFooters_FWD_DEFINED__
#undef __Placeholders_FWD_DEFINED__
#undef __PlaceholderFormat_FWD_DEFINED__
#undef __FreeformBuilder_FWD_DEFINED__
#undef __ShapeRange_FWD_DEFINED__
#undef __GroupShapes_FWD_DEFINED__
#undef __Adjustments_FWD_DEFINED__
#undef __PictureFormat_FWD_DEFINED__
#undef __FillFormat_FWD_DEFINED__
#undef __LineFormat_FWD_DEFINED__
#undef __ShadowFormat_FWD_DEFINED__
#undef __ConnectorFormat_FWD_DEFINED__
#undef __TextEffectFormat_FWD_DEFINED__
#undef __ThreeDFormat_FWD_DEFINED__
#undef __CalloutFormat_FWD_DEFINED__
#undef __ShapeNodes_FWD_DEFINED__
#undef __ShapeNode_FWD_DEFINED__
#undef __OLEFormat_FWD_DEFINED__
#undef __LinkFormat_FWD_DEFINED__
#undef __ObjectVerbs_FWD_DEFINED__
#undef __AnimationSettings_FWD_DEFINED__
#undef __ActionSettings_FWD_DEFINED__
#undef __ActionSetting_FWD_DEFINED__
#undef __PlaySettings_FWD_DEFINED__
#undef __Ruler_FWD_DEFINED__
#undef __RulerLevels_FWD_DEFINED__
#undef __RulerLevel_FWD_DEFINED__
#undef __TabStops_FWD_DEFINED__
#undef __TabStop_FWD_DEFINED__
#undef __Font_FWD_DEFINED__
#undef __ParagraphFormat_FWD_DEFINED__
#undef __BulletFormat_FWD_DEFINED__
#undef __TextStyles_FWD_DEFINED__
#undef __TextStyle_FWD_DEFINED__
#undef __TextStyleLevels_FWD_DEFINED__
#undef __TextStyleLevel_FWD_DEFINED__
#undef __HeaderFooter_FWD_DEFINED__
#undef ___Presentation_FWD_DEFINED__
#undef __Tags_FWD_DEFINED__
#undef __MouseTracker_FWD_DEFINED__
#undef __MouseDownHandler_FWD_DEFINED__
#undef __OCXExtender_FWD_DEFINED__
#undef __OCXExtenderEvents_FWD_DEFINED__
#undef __EApplication_FWD_DEFINED__
#undef __Table_FWD_DEFINED__
#undef __Columns_FWD_DEFINED__
#undef __Column_FWD_DEFINED__
#undef __Rows_FWD_DEFINED__
#undef __Row_FWD_DEFINED__
#undef __CellRange_FWD_DEFINED__
#undef __Cell_FWD_DEFINED__
#undef __Borders_FWD_DEFINED__
#undef __Panes_FWD_DEFINED__
#undef __Pane_FWD_DEFINED__
#undef __DefaultWebOptions_FWD_DEFINED__
#undef __WebOptions_FWD_DEFINED__
#undef __PublishObjects_FWD_DEFINED__
#undef __PublishObject_FWD_DEFINED__
#undef __MasterEvents_FWD_DEFINED__
#undef ___PowerRex_FWD_DEFINED__
#undef __Comments_FWD_DEFINED__
#undef __Comment_FWD_DEFINED__
#undef __Designs_FWD_DEFINED__
#undef __Design_FWD_DEFINED__
#undef __DiagramNode_FWD_DEFINED__
#undef __DiagramNodeChildren_FWD_DEFINED__
#undef __DiagramNodes_FWD_DEFINED__
#undef __Diagram_FWD_DEFINED__
#undef __TimeLine_FWD_DEFINED__
#undef __Sequences_FWD_DEFINED__
#undef __Sequence_FWD_DEFINED__
#undef __Effect_FWD_DEFINED__
#undef __Timing_FWD_DEFINED__
#undef __EffectParameters_FWD_DEFINED__
#undef __EffectInformation_FWD_DEFINED__
#undef __AnimationBehaviors_FWD_DEFINED__
#undef __AnimationBehavior_FWD_DEFINED__
#undef __MotionEffect_FWD_DEFINED__
#undef __ColorEffect_FWD_DEFINED__
#undef __ScaleEffect_FWD_DEFINED__
#undef __RotationEffect_FWD_DEFINED__
#undef __PropertyEffect_FWD_DEFINED__
#undef __AnimationPoints_FWD_DEFINED__
#undef __AnimationPoint_FWD_DEFINED__
#undef __CanvasShapes_FWD_DEFINED__
#undef __AutoCorrect_FWD_DEFINED__
#undef __Options_FWD_DEFINED__
#undef __CommandEffect_FWD_DEFINED__
#undef __FilterEffect_FWD_DEFINED__
#undef __SetEffect_FWD_DEFINED__
#undef __CustomLayouts_FWD_DEFINED__
#undef __CustomLayout_FWD_DEFINED__
#undef __TableStyle_FWD_DEFINED__
#undef __CustomerData_FWD_DEFINED__
#undef __Research_FWD_DEFINED__
#undef __TableBackground_FWD_DEFINED__
#undef __TextFrame2_FWD_DEFINED__
#undef __FileConverters_FWD_DEFINED__
#undef __FileConverter_FWD_DEFINED__
#undef __Axes_FWD_DEFINED__
#undef __Axis_FWD_DEFINED__
#undef __AxisTitle_FWD_DEFINED__
#undef __Chart_FWD_DEFINED__
#undef __ChartBorder_FWD_DEFINED__
#undef __ChartCharacters_FWD_DEFINED__
#undef __ChartArea_FWD_DEFINED__
#undef __ChartColorFormat_FWD_DEFINED__
#undef __ChartData_FWD_DEFINED__
#undef __ChartFillFormat_FWD_DEFINED__
#undef __ChartFormat_FWD_DEFINED__
#undef __ChartGroup_FWD_DEFINED__
#undef __ChartGroups_FWD_DEFINED__
#undef __ChartTitle_FWD_DEFINED__
#undef __Corners_FWD_DEFINED__
#undef __DataLabel_FWD_DEFINED__
#undef __DataLabels_FWD_DEFINED__
#undef __DataTable_FWD_DEFINED__
#undef __DisplayUnitLabel_FWD_DEFINED__
#undef __DownBars_FWD_DEFINED__
#undef __DropLines_FWD_DEFINED__
#undef __ErrorBars_FWD_DEFINED__
#undef __Floor_FWD_DEFINED__
#undef __ChartFont_FWD_DEFINED__
#undef __Gridlines_FWD_DEFINED__
#undef __HiLoLines_FWD_DEFINED__
#undef __Interior_FWD_DEFINED__
#undef __LeaderLines_FWD_DEFINED__
#undef __Legend_FWD_DEFINED__
#undef __LegendEntries_FWD_DEFINED__
#undef __LegendEntry_FWD_DEFINED__
#undef __LegendKey_FWD_DEFINED__
#undef __PlotArea_FWD_DEFINED__
#undef __Point_FWD_DEFINED__
#undef __Points_FWD_DEFINED__
#undef __Series_FWD_DEFINED__
#undef __SeriesCollection_FWD_DEFINED__
#undef __SeriesLines_FWD_DEFINED__
#undef __TickLabels_FWD_DEFINED__
#undef __Trendline_FWD_DEFINED__
#undef __Trendlines_FWD_DEFINED__
#undef __UpBars_FWD_DEFINED__
#undef __Walls_FWD_DEFINED__
#undef __MediaFormat_FWD_DEFINED__
#undef __SectionProperties_FWD_DEFINED__
#undef __Player_FWD_DEFINED__
#undef __ResampleMediaTask_FWD_DEFINED__
#undef __ResampleMediaTasks_FWD_DEFINED__
#undef __MediaBookmark_FWD_DEFINED__
#undef __MediaBookmarks_FWD_DEFINED__
#undef __Coauthoring_FWD_DEFINED__
#undef __Broadcast_FWD_DEFINED__
#undef __ProtectedViewWindows_FWD_DEFINED__
#undef __ProtectedViewWindow_FWD_DEFINED__
#undef __FullSeriesCollection_FWD_DEFINED__
#undef __ChartCategory_FWD_DEFINED__
#undef __CategoryCollection_FWD_DEFINED__
#undef __ThemeVariant_FWD_DEFINED__
#undef __ThemeVariants_FWD_DEFINED__
#undef __Theme_FWD_DEFINED__
#undef __SlideNavigation_FWD_DEFINED__
#undef __Guides_FWD_DEFINED__
#undef __Guide_FWD_DEFINED__
#undef __Application_FWD_DEFINED__
#undef __Global_FWD_DEFINED__
#undef __Presentation_FWD_DEFINED__
#undef __Slide_FWD_DEFINED__
#undef __OLEControl_FWD_DEFINED__
#undef __Master_FWD_DEFINED__
#undef __PowerRex_FWD_DEFINED__
#undef __IPPTCtrlExtender_FWD_DEFINED__
#undef __KPPTCtrlExtender_FWD_DEFINED__
#undef __PowerPoint_LIBRARY_DEFINED__
#undef __Collection_INTERFACE_DEFINED__
#undef ___Application_INTERFACE_DEFINED__
#undef ___Global_INTERFACE_DEFINED__
#undef __ColorFormat_INTERFACE_DEFINED__
#undef __SlideShowWindow_INTERFACE_DEFINED__
#undef __Selection_INTERFACE_DEFINED__
#undef __DocumentWindows_INTERFACE_DEFINED__
#undef __SlideShowWindows_INTERFACE_DEFINED__
#undef __DocumentWindow_INTERFACE_DEFINED__
#undef __View_INTERFACE_DEFINED__
#undef __SlideShowView_INTERFACE_DEFINED__
#undef __SlideShowSettings_INTERFACE_DEFINED__
#undef __NamedSlideShows_INTERFACE_DEFINED__
#undef __NamedSlideShow_INTERFACE_DEFINED__
#undef __PrintOptions_INTERFACE_DEFINED__
#undef __PrintRanges_INTERFACE_DEFINED__
#undef __PrintRange_INTERFACE_DEFINED__
#undef __AddIns_INTERFACE_DEFINED__
#undef __AddIn_INTERFACE_DEFINED__
#undef __Presentations_INTERFACE_DEFINED__
#undef __PresEvents_INTERFACE_DEFINED__
#undef __Hyperlinks_INTERFACE_DEFINED__
#undef __Hyperlink_INTERFACE_DEFINED__
#undef __PageSetup_INTERFACE_DEFINED__
#undef __Fonts_INTERFACE_DEFINED__
#undef __ExtraColors_INTERFACE_DEFINED__
#undef __TextRange_INTERFACE_DEFINED__
#undef __TextFrame_INTERFACE_DEFINED__
#undef __Shape_INTERFACE_DEFINED__
#undef __Shapes_INTERFACE_DEFINED__
#undef __Slides_INTERFACE_DEFINED__
#undef ___Slide_INTERFACE_DEFINED__
#undef __SlideRange_INTERFACE_DEFINED__
#undef ___Master_INTERFACE_DEFINED__
#undef __SldEvents_INTERFACE_DEFINED__
#undef __ColorSchemes_INTERFACE_DEFINED__
#undef __ColorScheme_INTERFACE_DEFINED__
#undef __RGBColor_INTERFACE_DEFINED__
#undef __SlideShowTransition_INTERFACE_DEFINED__
#undef __SoundEffect_INTERFACE_DEFINED__
#undef __SoundFormat_INTERFACE_DEFINED__
#undef __HeadersFooters_INTERFACE_DEFINED__
#undef __Placeholders_INTERFACE_DEFINED__
#undef __PlaceholderFormat_INTERFACE_DEFINED__
#undef __FreeformBuilder_INTERFACE_DEFINED__
#undef __ShapeRange_INTERFACE_DEFINED__
#undef __GroupShapes_INTERFACE_DEFINED__
#undef __Adjustments_INTERFACE_DEFINED__
#undef __PictureFormat_INTERFACE_DEFINED__
#undef __FillFormat_INTERFACE_DEFINED__
#undef __LineFormat_INTERFACE_DEFINED__
#undef __ShadowFormat_INTERFACE_DEFINED__
#undef __ConnectorFormat_INTERFACE_DEFINED__
#undef __TextEffectFormat_INTERFACE_DEFINED__
#undef __ThreeDFormat_INTERFACE_DEFINED__
#undef __CalloutFormat_INTERFACE_DEFINED__
#undef __ShapeNodes_INTERFACE_DEFINED__
#undef __ShapeNode_INTERFACE_DEFINED__
#undef __OLEFormat_INTERFACE_DEFINED__
#undef __LinkFormat_INTERFACE_DEFINED__
#undef __ObjectVerbs_INTERFACE_DEFINED__
#undef __AnimationSettings_INTERFACE_DEFINED__
#undef __ActionSettings_INTERFACE_DEFINED__
#undef __ActionSetting_INTERFACE_DEFINED__
#undef __PlaySettings_INTERFACE_DEFINED__
#undef __Ruler_INTERFACE_DEFINED__
#undef __RulerLevels_INTERFACE_DEFINED__
#undef __RulerLevel_INTERFACE_DEFINED__
#undef __TabStops_INTERFACE_DEFINED__
#undef __TabStop_INTERFACE_DEFINED__
#undef __Font_INTERFACE_DEFINED__
#undef __ParagraphFormat_INTERFACE_DEFINED__
#undef __BulletFormat_INTERFACE_DEFINED__
#undef __TextStyles_INTERFACE_DEFINED__
#undef __TextStyle_INTERFACE_DEFINED__
#undef __TextStyleLevels_INTERFACE_DEFINED__
#undef __TextStyleLevel_INTERFACE_DEFINED__
#undef __HeaderFooter_INTERFACE_DEFINED__
#undef ___Presentation_INTERFACE_DEFINED__
#undef __Tags_INTERFACE_DEFINED__
#undef __MouseTracker_INTERFACE_DEFINED__
#undef __MouseDownHandler_INTERFACE_DEFINED__
#undef __OCXExtender_INTERFACE_DEFINED__
#undef __OCXExtenderEvents_INTERFACE_DEFINED__
#undef __EApplication_INTERFACE_DEFINED__
#undef __Table_INTERFACE_DEFINED__
#undef __Columns_INTERFACE_DEFINED__
#undef __Column_INTERFACE_DEFINED__
#undef __Rows_INTERFACE_DEFINED__
#undef __Row_INTERFACE_DEFINED__
#undef __CellRange_INTERFACE_DEFINED__
#undef __Cell_INTERFACE_DEFINED__
#undef __Borders_INTERFACE_DEFINED__
#undef __Panes_INTERFACE_DEFINED__
#undef __Pane_INTERFACE_DEFINED__
#undef __DefaultWebOptions_INTERFACE_DEFINED__
#undef __WebOptions_INTERFACE_DEFINED__
#undef __PublishObjects_INTERFACE_DEFINED__
#undef __PublishObject_INTERFACE_DEFINED__
#undef __MasterEvents_INTERFACE_DEFINED__
#undef ___PowerRex_INTERFACE_DEFINED__
#undef __Comments_INTERFACE_DEFINED__
#undef __Comment_INTERFACE_DEFINED__
#undef __Designs_INTERFACE_DEFINED__
#undef __Design_INTERFACE_DEFINED__
#undef __DiagramNode_INTERFACE_DEFINED__
#undef __DiagramNodeChildren_INTERFACE_DEFINED__
#undef __DiagramNodes_INTERFACE_DEFINED__
#undef __Diagram_INTERFACE_DEFINED__
#undef __TimeLine_INTERFACE_DEFINED__
#undef __Sequences_INTERFACE_DEFINED__
#undef __Sequence_INTERFACE_DEFINED__
#undef __Effect_INTERFACE_DEFINED__
#undef __Timing_INTERFACE_DEFINED__
#undef __EffectParameters_INTERFACE_DEFINED__
#undef __EffectInformation_INTERFACE_DEFINED__
#undef __AnimationBehaviors_INTERFACE_DEFINED__
#undef __AnimationBehavior_INTERFACE_DEFINED__
#undef __MotionEffect_INTERFACE_DEFINED__
#undef __ColorEffect_INTERFACE_DEFINED__
#undef __ScaleEffect_INTERFACE_DEFINED__
#undef __RotationEffect_INTERFACE_DEFINED__
#undef __PropertyEffect_INTERFACE_DEFINED__
#undef __AnimationPoints_INTERFACE_DEFINED__
#undef __AnimationPoint_INTERFACE_DEFINED__
#undef __CanvasShapes_INTERFACE_DEFINED__
#undef __AutoCorrect_INTERFACE_DEFINED__
#undef __Options_INTERFACE_DEFINED__
#undef __CommandEffect_INTERFACE_DEFINED__
#undef __FilterEffect_INTERFACE_DEFINED__
#undef __SetEffect_INTERFACE_DEFINED__
#undef __CustomLayouts_INTERFACE_DEFINED__
#undef __CustomLayout_INTERFACE_DEFINED__
#undef __TableStyle_INTERFACE_DEFINED__
#undef __CustomerData_INTERFACE_DEFINED__
#undef __Research_INTERFACE_DEFINED__
#undef __TableBackground_INTERFACE_DEFINED__
#undef __TextFrame2_INTERFACE_DEFINED__
#undef __FileConverters_INTERFACE_DEFINED__
#undef __FileConverter_INTERFACE_DEFINED__
#undef __Axes_INTERFACE_DEFINED__
#undef __Axis_INTERFACE_DEFINED__
#undef __AxisTitle_INTERFACE_DEFINED__
#undef __Chart_INTERFACE_DEFINED__
#undef __ChartBorder_INTERFACE_DEFINED__
#undef __ChartCharacters_INTERFACE_DEFINED__
#undef __ChartArea_INTERFACE_DEFINED__
#undef __ChartColorFormat_INTERFACE_DEFINED__
#undef __ChartData_INTERFACE_DEFINED__
#undef __ChartFillFormat_INTERFACE_DEFINED__
#undef __ChartFormat_INTERFACE_DEFINED__
#undef __ChartGroup_INTERFACE_DEFINED__
#undef __ChartGroups_INTERFACE_DEFINED__
#undef __ChartTitle_INTERFACE_DEFINED__
#undef __Corners_INTERFACE_DEFINED__
#undef __DataLabel_INTERFACE_DEFINED__
#undef __DataLabels_INTERFACE_DEFINED__
#undef __DataTable_INTERFACE_DEFINED__
#undef __DisplayUnitLabel_INTERFACE_DEFINED__
#undef __DownBars_INTERFACE_DEFINED__
#undef __DropLines_INTERFACE_DEFINED__
#undef __ErrorBars_INTERFACE_DEFINED__
#undef __Floor_INTERFACE_DEFINED__
#undef __ChartFont_INTERFACE_DEFINED__
#undef __Gridlines_INTERFACE_DEFINED__
#undef __HiLoLines_INTERFACE_DEFINED__
#undef __Interior_INTERFACE_DEFINED__
#undef __LeaderLines_INTERFACE_DEFINED__
#undef __Legend_INTERFACE_DEFINED__
#undef __LegendEntries_INTERFACE_DEFINED__
#undef __LegendEntry_INTERFACE_DEFINED__
#undef __LegendKey_INTERFACE_DEFINED__
#undef __PlotArea_INTERFACE_DEFINED__
#undef __Point_INTERFACE_DEFINED__
#undef __Points_INTERFACE_DEFINED__
#undef __Series_INTERFACE_DEFINED__
#undef __SeriesCollection_INTERFACE_DEFINED__
#undef __SeriesLines_INTERFACE_DEFINED__
#undef __TickLabels_INTERFACE_DEFINED__
#undef __Trendline_INTERFACE_DEFINED__
#undef __Trendlines_INTERFACE_DEFINED__
#undef __UpBars_INTERFACE_DEFINED__
#undef __Walls_INTERFACE_DEFINED__
#undef __MediaFormat_INTERFACE_DEFINED__
#undef __SectionProperties_INTERFACE_DEFINED__
#undef __Player_INTERFACE_DEFINED__
#undef __ResampleMediaTask_INTERFACE_DEFINED__
#undef __ResampleMediaTasks_INTERFACE_DEFINED__
#undef __MediaBookmark_INTERFACE_DEFINED__
#undef __MediaBookmarks_INTERFACE_DEFINED__
#undef __Coauthoring_INTERFACE_DEFINED__
#undef __Broadcast_INTERFACE_DEFINED__
#undef __ProtectedViewWindows_INTERFACE_DEFINED__
#undef __ProtectedViewWindow_INTERFACE_DEFINED__
#undef __FullSeriesCollection_INTERFACE_DEFINED__
#undef __ChartCategory_INTERFACE_DEFINED__
#undef __CategoryCollection_INTERFACE_DEFINED__
#undef __ThemeVariant_INTERFACE_DEFINED__
#undef __ThemeVariants_INTERFACE_DEFINED__
#undef __Theme_INTERFACE_DEFINED__
#undef __SlideNavigation_INTERFACE_DEFINED__
#undef __Guides_INTERFACE_DEFINED__
#undef __Guide_INTERFACE_DEFINED__
#undef __IPPTCtrlExtender_INTERFACE_DEFINED__

#endif

