/*
** Copyright @ 2012-2019, Kingsoft office,All rights reserved.
**
** Redistribution and use in source and binary forms ,without modification and
** selling solely, are permitted provided that the following conditions are
** met:
**
** 1.Redistributions of source code must retain the above copyright notice,
**   this list of conditions and the following disclaimer.
** 2.Redistributions in binary form must reproduce the above copyright notice,
**	 this list of conditions and the following disclaimer in the documentation
**	 and/or other materials provided with the distribution.
** 3.Neither the name of the copyright holder nor the names of its contributors
**	 may be used to endorse or promote products derived from this software
**	 without specific prior written permission.
**
** SPECIAL NOTE:THIS SOFTWARE IS NOT PERMITTED TO BE MODIFIED OR SOLD SOLELY AT
** ANY TIME AND UNDER ANY CIRCUMSTANCES, EXCEPT WITH THE WRITTEN PERMISSION OF
** KINGSOFT OFFICE
**
** THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
** AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
** IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
** ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
** LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
** CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
** SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
** INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
** CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
** ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
** POSSIBILITY OF SUCH DAMAGE.
**/
/**
 * \file etapi_predef.h <Fri, 18 Jan 2013 14:52:23 +0000 (kic)>
 * \brief 
 */

#ifndef __ETAPI_PREDEF_H__
#define __ETAPI_PREDEF_H__

using ksoapi::_IMsoDispObj;
using ksoapi::AnswerWizard;
using ksoapi::Assistant;
using ksoapi::CanvasShapes;
using ksoapi::COMAddIns;
using ksoapi::CommandBars;
using ksoapi::_CommandBars;
using ksoapi::Crop;
using ksoapi::CustomXMLParts;
using ksoapi::DocumentProperties;
using ksoapi::DocumentLibraryVersions;
using ksoapi::DocumentInspectors;
using ksoapi::FileDialog;
using ksoapi::FileSearch;
using ksoapi::GlowFormat;
using ksoapi::GradientStops;
using ksoapi::HTMLProject;
using ksoapi::IAssistance;
using ksoapi::IFind;
using ksoapi::IMsoDiagram;
using ksoapi::LanguageSettings;
using ksoapi::MetaProperties;
using ksoapi::MsoEnvelope;
using ksoapi::NewFile;
using ksoapi::OfficeTheme;
using ksoapi::Permission;
using ksoapi::PictureEffects;
using ksoapi::ReflectionFormat;
using ksoapi::Ruler2;
using ksoapi::Script;
using ksoapi::Scripts;
using ksoapi::ServerPolicy;
using ksoapi::SharedWorkspace;
using ksoapi::Signature;
using ksoapi::SignatureSet;
using ksoapi::SmartArt;
using ksoapi::SmartArtColors;
using ksoapi::SmartArtLayout;
using ksoapi::SmartArtLayouts;
using ksoapi::SmartArtQuickStyles;
using ksoapi::SmartDocument;
using ksoapi::SoftEdgeFormat;
using ksoapi::Sync;
using ksoapi::TextColumn2;
using ksoapi::TextRange2;
using ksoapi::WorkflowTasks;
using ksoapi::WorkflowTemplates;
using ksoapi::WebPageFonts;

class VBProject;
class VBE;
class _VBProject;

#undef __Adjustments_FWD_DEFINED__
#undef __CalloutFormat_FWD_DEFINED__
#undef __ColorFormat_FWD_DEFINED__
#undef __LineFormat_FWD_DEFINED__
#undef __ShapeNode_FWD_DEFINED__
#undef __ShapeNodes_FWD_DEFINED__
#undef __PictureFormat_FWD_DEFINED__
#undef __ShadowFormat_FWD_DEFINED__
#undef __TextEffectFormat_FWD_DEFINED__
#undef __ThreeDFormat_FWD_DEFINED__
#undef __FillFormat_FWD_DEFINED__
#undef __DiagramNodes_FWD_DEFINED__
#undef __DiagramNodeChildren_FWD_DEFINED__
#undef __DiagramNode_FWD_DEFINED__
#undef __IRTDUpdateEvent_FWD_DEFINED__
#undef __IRtdServer_FWD_DEFINED__
#undef __TextFrame2_FWD_DEFINED__
#undef __IFont_FWD_DEFINED__
#undef __IWindow_FWD_DEFINED__
#undef __IWindows_FWD_DEFINED__
#undef __IAppEvents_FWD_DEFINED__
#undef ___Application_FWD_DEFINED__
#undef __IWorksheetFunction_FWD_DEFINED__
#undef __IRange_FWD_DEFINED__
#undef __IChartEvents_FWD_DEFINED__
#undef ___Chart_FWD_DEFINED__
#undef __Sheets_FWD_DEFINED__
#undef __IVPageBreak_FWD_DEFINED__
#undef __IHPageBreak_FWD_DEFINED__
#undef __IHPageBreaks_FWD_DEFINED__
#undef __IVPageBreaks_FWD_DEFINED__
#undef __IRecentFile_FWD_DEFINED__
#undef __IRecentFiles_FWD_DEFINED__
#undef __IDocEvents_FWD_DEFINED__
#undef ___Worksheet_FWD_DEFINED__
#undef __IStyle_FWD_DEFINED__
#undef __IStyles_FWD_DEFINED__
#undef __IBorders_FWD_DEFINED__
#undef ___Global_FWD_DEFINED__
#undef __IAddIn_FWD_DEFINED__
#undef __IAddIns_FWD_DEFINED__
#undef __IToolbar_FWD_DEFINED__
#undef __IToolbars_FWD_DEFINED__
#undef __IToolbarButton_FWD_DEFINED__
#undef __IToolbarButtons_FWD_DEFINED__
#undef __IAreas_FWD_DEFINED__
#undef __IWorkbookEvents_FWD_DEFINED__
#undef ___Workbook_FWD_DEFINED__
#undef __Workbooks_FWD_DEFINED__
#undef __IMenuBars_FWD_DEFINED__
#undef __IMenuBar_FWD_DEFINED__
#undef __IMenus_FWD_DEFINED__
#undef __IMenu_FWD_DEFINED__
#undef __IMenuItems_FWD_DEFINED__
#undef __IMenuItem_FWD_DEFINED__
#undef __ICharts_FWD_DEFINED__
#undef __IDrawingObjects_FWD_DEFINED__
#undef __IPivotCache_FWD_DEFINED__
#undef __IPivotCaches_FWD_DEFINED__
#undef __IPivotFormula_FWD_DEFINED__
#undef __IPivotFormulas_FWD_DEFINED__
#undef __IPivotTable_FWD_DEFINED__
#undef __IPivotTables_FWD_DEFINED__
#undef __IPivotField_FWD_DEFINED__
#undef __IPivotFields_FWD_DEFINED__
#undef __ICalculatedFields_FWD_DEFINED__
#undef __IPivotItem_FWD_DEFINED__
#undef __IPivotItems_FWD_DEFINED__
#undef __ICalculatedItems_FWD_DEFINED__
#undef __ICharacters_FWD_DEFINED__
#undef __IDialogs_FWD_DEFINED__
#undef __IDialog_FWD_DEFINED__
#undef __ISoundNote_FWD_DEFINED__
#undef __IButton_FWD_DEFINED__
#undef __IButtons_FWD_DEFINED__
#undef __ICheckBox_FWD_DEFINED__
#undef __ICheckBoxes_FWD_DEFINED__
#undef __IOptionButton_FWD_DEFINED__
#undef __IOptionButtons_FWD_DEFINED__
#undef __IEditBox_FWD_DEFINED__
#undef __IEditBoxes_FWD_DEFINED__
#undef __IScrollBar_FWD_DEFINED__
#undef __IScrollBars_FWD_DEFINED__
#undef __IListBox_FWD_DEFINED__
#undef __IListBoxes_FWD_DEFINED__
#undef __IGroupBox_FWD_DEFINED__
#undef __IGroupBoxes_FWD_DEFINED__
#undef __IDropDown_FWD_DEFINED__
#undef __IDropDowns_FWD_DEFINED__
#undef __ISpinner_FWD_DEFINED__
#undef __ISpinners_FWD_DEFINED__
#undef __IDialogFrame_FWD_DEFINED__
#undef __ILabel_FWD_DEFINED__
#undef __ILabels_FWD_DEFINED__
#undef __IPanes_FWD_DEFINED__
#undef __IPane_FWD_DEFINED__
#undef __IScenarios_FWD_DEFINED__
#undef __IScenario_FWD_DEFINED__
#undef __IGroupObject_FWD_DEFINED__
#undef __IGroupObjects_FWD_DEFINED__
#undef __ILine_FWD_DEFINED__
#undef __ILines_FWD_DEFINED__
#undef __IRectangle_FWD_DEFINED__
#undef __IRectangles_FWD_DEFINED__
#undef __IOval_FWD_DEFINED__
#undef __IOvals_FWD_DEFINED__
#undef __IArc_FWD_DEFINED__
#undef __IArcs_FWD_DEFINED__
#undef __IOLEObjectEvents_FWD_DEFINED__
#undef ___IOLEObject_FWD_DEFINED__
#undef __IOLEObjects_FWD_DEFINED__
#undef __ITextBox_FWD_DEFINED__
#undef __ITextBoxes_FWD_DEFINED__
#undef __IPicture_FWD_DEFINED__
#undef __IPictures_FWD_DEFINED__
#undef __IDrawing_FWD_DEFINED__
#undef __IDrawings_FWD_DEFINED__
#undef __IRoutingSlip_FWD_DEFINED__
#undef __IOutline_FWD_DEFINED__
#undef __IModule_FWD_DEFINED__
#undef __IModules_FWD_DEFINED__
#undef __IDialogSheet_FWD_DEFINED__
#undef __IDialogSheets_FWD_DEFINED__
#undef __IWorksheets_FWD_DEFINED__
#undef __IPageSetup_FWD_DEFINED__
#undef __INames_FWD_DEFINED__
#undef __IName_FWD_DEFINED__
#undef __IChartObject_FWD_DEFINED__
#undef __IChartObjects_FWD_DEFINED__
#undef __IMailer_FWD_DEFINED__
#undef __ICustomViews_FWD_DEFINED__
#undef __ICustomView_FWD_DEFINED__
#undef __IFormatConditions_FWD_DEFINED__
#undef __IFormatCondition_FWD_DEFINED__
#undef __IComments_FWD_DEFINED__
#undef __IComment_FWD_DEFINED__
#undef __IRefreshEvents_FWD_DEFINED__
#undef ___IQueryTable_FWD_DEFINED__
#undef __IQueryTables_FWD_DEFINED__
#undef __IParameter_FWD_DEFINED__
#undef __IParameters_FWD_DEFINED__
#undef __IODBCError_FWD_DEFINED__
#undef __IODBCErrors_FWD_DEFINED__
#undef __IValidation_FWD_DEFINED__
#undef __IHyperlinks_FWD_DEFINED__
#undef __IHyperlink_FWD_DEFINED__
#undef __IAutoFilter_FWD_DEFINED__
#undef __IFilters_FWD_DEFINED__
#undef __IFilter_FWD_DEFINED__
#undef __IAutoCorrect_FWD_DEFINED__
#undef __IBorder_FWD_DEFINED__
#undef __IInterior_FWD_DEFINED__
#undef __IChartFillFormat_FWD_DEFINED__
#undef __IChartColorFormat_FWD_DEFINED__
#undef __IAxis_FWD_DEFINED__
#undef __IChartTitle_FWD_DEFINED__
#undef __IAxisTitle_FWD_DEFINED__
#undef __IChartGroup_FWD_DEFINED__
#undef __IChartGroups_FWD_DEFINED__
#undef __IAxes_FWD_DEFINED__
#undef __IPoints_FWD_DEFINED__
#undef __IPoint_FWD_DEFINED__
#undef __ISeries_FWD_DEFINED__
#undef __ISeriesCollection_FWD_DEFINED__
#undef __IDataLabel_FWD_DEFINED__
#undef __IDataLabels_FWD_DEFINED__
#undef __ILegendEntry_FWD_DEFINED__
#undef __ILegendEntries_FWD_DEFINED__
#undef __ILegendKey_FWD_DEFINED__
#undef __ITrendlines_FWD_DEFINED__
#undef __ITrendline_FWD_DEFINED__
#undef __ICorners_FWD_DEFINED__
#undef __ISeriesLines_FWD_DEFINED__
#undef __IHiLoLines_FWD_DEFINED__
#undef __IGridlines_FWD_DEFINED__
#undef __IDropLines_FWD_DEFINED__
#undef __ILeaderLines_FWD_DEFINED__
#undef __IUpBars_FWD_DEFINED__
#undef __IDownBars_FWD_DEFINED__
#undef __IFloor_FWD_DEFINED__
#undef __IWalls_FWD_DEFINED__
#undef __ITickLabels_FWD_DEFINED__
#undef __IPlotArea_FWD_DEFINED__
#undef __IChartArea_FWD_DEFINED__
#undef __ILegend_FWD_DEFINED__
#undef __IErrorBars_FWD_DEFINED__
#undef __IDataTable_FWD_DEFINED__
#undef __IPhonetic_FWD_DEFINED__
#undef __IShape_FWD_DEFINED__
#undef __IShapes_FWD_DEFINED__
#undef __IShapeRange_FWD_DEFINED__
#undef __IGroupShapes_FWD_DEFINED__
#undef __ITextFrame_FWD_DEFINED__
#undef __IConnectorFormat_FWD_DEFINED__
#undef __IFreeformBuilder_FWD_DEFINED__
#undef __IControlFormat_FWD_DEFINED__
#undef __IOLEFormat_FWD_DEFINED__
#undef __ILinkFormat_FWD_DEFINED__
#undef __IPublishObjects_FWD_DEFINED__
#undef __PublishObject_FWD_DEFINED__
#undef __IOLEDBError_FWD_DEFINED__
#undef __IOLEDBErrors_FWD_DEFINED__
#undef __IPhonetics_FWD_DEFINED__
#undef __DefaultWebOptions_FWD_DEFINED__
#undef __WebOptions_FWD_DEFINED__
#undef __IPivotLayout_FWD_DEFINED__
#undef __TreeviewControl_FWD_DEFINED__
#undef __CubeField_FWD_DEFINED__
#undef __CubeFields_FWD_DEFINED__
#undef __IDisplayUnitLabel_FWD_DEFINED__
#undef __ICellFormat_FWD_DEFINED__
#undef __IUsedObjects_FWD_DEFINED__
#undef __ICustomProperties_FWD_DEFINED__
#undef __ICustomProperty_FWD_DEFINED__
#undef __ICalculatedMembers_FWD_DEFINED__
#undef __ICalculatedMember_FWD_DEFINED__
#undef __IWatches_FWD_DEFINED__
#undef __IWatch_FWD_DEFINED__
#undef __IPivotCell_FWD_DEFINED__
#undef __IGraphic_FWD_DEFINED__
#undef __IAutoRecover_FWD_DEFINED__
#undef __IErrorCheckingOptions_FWD_DEFINED__
#undef __IErrors_FWD_DEFINED__
#undef __IError_FWD_DEFINED__
#undef __ISmartTagAction_FWD_DEFINED__
#undef __ISmartTagActions_FWD_DEFINED__
#undef __ISmartTag_FWD_DEFINED__
#undef __ISmartTags_FWD_DEFINED__
#undef __ISmartTagRecognizer_FWD_DEFINED__
#undef __ISmartTagRecognizers_FWD_DEFINED__
#undef __ISmartTagOptions_FWD_DEFINED__
#undef __ISpellingOptions_FWD_DEFINED__
#undef __ISpeech_FWD_DEFINED__
#undef __IProtection_FWD_DEFINED__
#undef __IPivotItemList_FWD_DEFINED__
#undef __ITab_FWD_DEFINED__
#undef __IAllowEditRanges_FWD_DEFINED__
#undef __IAllowEditRange_FWD_DEFINED__
#undef __IUserAccessList_FWD_DEFINED__
#undef __IUserAccess_FWD_DEFINED__
#undef __IRTD_FWD_DEFINED__
#undef __IDiagram_FWD_DEFINED__
#undef __IListObjects_FWD_DEFINED__
#undef __IListObject_FWD_DEFINED__
#undef __IListColumns_FWD_DEFINED__
#undef __IListColumn_FWD_DEFINED__
#undef __IListRows_FWD_DEFINED__
#undef __IListRow_FWD_DEFINED__
#undef __IXmlNamespace_FWD_DEFINED__
#undef __IXmlNamespaces_FWD_DEFINED__
#undef __IXmlDataBinding_FWD_DEFINED__
#undef __IXmlSchema_FWD_DEFINED__
#undef __IXmlSchemas_FWD_DEFINED__
#undef __IXmlMap_FWD_DEFINED__
#undef __IXmlMaps_FWD_DEFINED__
#undef __IListDataFormat_FWD_DEFINED__
#undef __IXPath_FWD_DEFINED__
#undef __IPivotLineCells_FWD_DEFINED__
#undef __IPivotLine_FWD_DEFINED__
#undef __IPivotLines_FWD_DEFINED__
#undef __IPivotAxis_FWD_DEFINED__
#undef __IPivotFilter_FWD_DEFINED__
#undef __IPivotFilters_FWD_DEFINED__
#undef __IWorkbookConnection_FWD_DEFINED__
#undef __IConnections_FWD_DEFINED__
#undef __IWorksheetView_FWD_DEFINED__
#undef __IChartView_FWD_DEFINED__
#undef __IModuleView_FWD_DEFINED__
#undef __IDialogSheetView_FWD_DEFINED__
#undef __ISheetViews_FWD_DEFINED__
#undef __IOLEDBConnection_FWD_DEFINED__
#undef __IODBCConnection_FWD_DEFINED__
#undef __IAction_FWD_DEFINED__
#undef __IActions_FWD_DEFINED__
#undef __IFormatColor_FWD_DEFINED__
#undef __IConditionValue_FWD_DEFINED__
#undef __IColorScale_FWD_DEFINED__
#undef __IColorScaleCriteria_FWD_DEFINED__
#undef __IColorScaleCriterion_FWD_DEFINED__
#undef __IDatabar_FWD_DEFINED__
#undef __IIconSetCondition_FWD_DEFINED__
#undef __IIconCriteria_FWD_DEFINED__
#undef __IIconCriterion_FWD_DEFINED__
#undef __IIcon_FWD_DEFINED__
#undef __IIconSet_FWD_DEFINED__
#undef __IIconSets_FWD_DEFINED__
#undef __ITop10_FWD_DEFINED__
#undef __IAboveAverage_FWD_DEFINED__
#undef __IUniqueValues_FWD_DEFINED__
#undef __IRanges_FWD_DEFINED__
#undef __IHeaderFooter_FWD_DEFINED__
#undef __IPage_FWD_DEFINED__
#undef __IPages_FWD_DEFINED__
#undef __IServerViewableItems_FWD_DEFINED__
#undef __ITableStyleElement_FWD_DEFINED__
#undef __ITableStyleElements_FWD_DEFINED__
#undef __ITableStyle_FWD_DEFINED__
#undef __ITableStyles_FWD_DEFINED__
#undef __ISortField_FWD_DEFINED__
#undef __ISortFields_FWD_DEFINED__
#undef __ISort_FWD_DEFINED__
#undef __IResearch_FWD_DEFINED__
#undef __IColorStop_FWD_DEFINED__
#undef __IColorStops_FWD_DEFINED__
#undef __ILinearGradient_FWD_DEFINED__
#undef __IRectangularGradient_FWD_DEFINED__
#undef __IMultiThreadedCalculation_FWD_DEFINED__
#undef __IChartFormat_FWD_DEFINED__
#undef __IFileExportConverter_FWD_DEFINED__
#undef __IFileExportConverters_FWD_DEFINED__
#undef __IAddIns2_FWD_DEFINED__
#undef __ISparklineGroups_FWD_DEFINED__
#undef __ISparklineGroup_FWD_DEFINED__
#undef __ISparkPoints_FWD_DEFINED__
#undef __ISparkline_FWD_DEFINED__
#undef __ISparkAxes_FWD_DEFINED__
#undef __ISparkHorizontalAxis_FWD_DEFINED__
#undef __ISparkVerticalAxis_FWD_DEFINED__
#undef __ISparkColor_FWD_DEFINED__
#undef __IDataBarBorder_FWD_DEFINED__
#undef __INegativeBarFormat_FWD_DEFINED__
#undef __IValueChange_FWD_DEFINED__
#undef __IPivotTableChangeList_FWD_DEFINED__
#undef __IDisplayFormat_FWD_DEFINED__
#undef __ISlicerCaches_FWD_DEFINED__
#undef __ISlicerCache_FWD_DEFINED__
#undef __ISlicerCacheLevels_FWD_DEFINED__
#undef __ISlicerCacheLevel_FWD_DEFINED__
#undef __ISlicers_FWD_DEFINED__
#undef __ISlicer_FWD_DEFINED__
#undef __ISlicerItem_FWD_DEFINED__
#undef __ISlicerItems_FWD_DEFINED__
#undef __ISlicerPivotTables_FWD_DEFINED__
#undef __IProtectedViewWindows_FWD_DEFINED__
#undef __IProtectedViewWindow_FWD_DEFINED__
#undef __ITableObject_FWD_DEFINED__
#undef __IPivotValueCell_FWD_DEFINED__
#undef __IQuickAnalysis_FWD_DEFINED__
#undef __IModelConnection_FWD_DEFINED__
#undef __IWorksheetDataConnection_FWD_DEFINED__
#undef __ITextConnection_FWD_DEFINED__
#undef __IDataFeedConnection_FWD_DEFINED__
#undef __IModelTableColumn_FWD_DEFINED__
#undef __IModelTableColumns_FWD_DEFINED__
#undef __IModelTable_FWD_DEFINED__
#undef __IModelTables_FWD_DEFINED__
#undef __IModelRelationship_FWD_DEFINED__
#undef __IModelRelationships_FWD_DEFINED__
#undef __IModel_FWD_DEFINED__
#undef __IFullSeriesCollection_FWD_DEFINED__
#undef __IChartCategory_FWD_DEFINED__
#undef __ICategoryCollection_FWD_DEFINED__
#undef __ITimelineState_FWD_DEFINED__
#undef __ITimelineViewState_FWD_DEFINED__
#undef __IModelTableNames_FWD_DEFINED__
#undef __IModelTableNameChange_FWD_DEFINED__
#undef __IModelTableNameChanges_FWD_DEFINED__
#undef __IModelChanges_FWD_DEFINED__
#undef __IModelColumnName_FWD_DEFINED__
#undef __IModelColumnNames_FWD_DEFINED__
#undef __IModelColumnChange_FWD_DEFINED__
#undef __IModelColumnChanges_FWD_DEFINED__
#undef __IModelMeasureName_FWD_DEFINED__
#undef __IModelMeasureNames_FWD_DEFINED__
#undef __Font_FWD_DEFINED__
#undef __Window_FWD_DEFINED__
#undef __Windows_FWD_DEFINED__
#undef __AppEvents_FWD_DEFINED__
#undef __WorksheetFunction_FWD_DEFINED__
#undef __Range_FWD_DEFINED__
#undef __ChartEvents_FWD_DEFINED__
#undef __VPageBreak_FWD_DEFINED__
#undef __HPageBreak_FWD_DEFINED__
#undef __HPageBreaks_FWD_DEFINED__
#undef __VPageBreaks_FWD_DEFINED__
#undef __RecentFile_FWD_DEFINED__
#undef __RecentFiles_FWD_DEFINED__
#undef __DocEvents_FWD_DEFINED__
#undef __Style_FWD_DEFINED__
#undef __Styles_FWD_DEFINED__
#undef __Borders_FWD_DEFINED__
#undef __AddIn_FWD_DEFINED__
#undef __AddIns_FWD_DEFINED__
#undef __Toolbar_FWD_DEFINED__
#undef __Toolbars_FWD_DEFINED__
#undef __ToolbarButton_FWD_DEFINED__
#undef __ToolbarButtons_FWD_DEFINED__
#undef __Areas_FWD_DEFINED__
#undef __WorkbookEvents_FWD_DEFINED__
#undef __MenuBars_FWD_DEFINED__
#undef __MenuBar_FWD_DEFINED__
#undef __Menus_FWD_DEFINED__
#undef __Menu_FWD_DEFINED__
#undef __MenuItems_FWD_DEFINED__
#undef __MenuItem_FWD_DEFINED__
#undef __Charts_FWD_DEFINED__
#undef __DrawingObjects_FWD_DEFINED__
#undef __PivotCache_FWD_DEFINED__
#undef __PivotCaches_FWD_DEFINED__
#undef __PivotFormula_FWD_DEFINED__
#undef __PivotFormulas_FWD_DEFINED__
#undef __PivotTable_FWD_DEFINED__
#undef __PivotTables_FWD_DEFINED__
#undef __PivotField_FWD_DEFINED__
#undef __PivotFields_FWD_DEFINED__
#undef __CalculatedFields_FWD_DEFINED__
#undef __PivotItem_FWD_DEFINED__
#undef __PivotItems_FWD_DEFINED__
#undef __CalculatedItems_FWD_DEFINED__
#undef __Characters_FWD_DEFINED__
#undef __Dialogs_FWD_DEFINED__
#undef __Dialog_FWD_DEFINED__
#undef __SoundNote_FWD_DEFINED__
#undef __Button_FWD_DEFINED__
#undef __Buttons_FWD_DEFINED__
#undef __CheckBox_FWD_DEFINED__
#undef __CheckBoxes_FWD_DEFINED__
#undef __OptionButton_FWD_DEFINED__
#undef __OptionButtons_FWD_DEFINED__
#undef __EditBox_FWD_DEFINED__
#undef __EditBoxes_FWD_DEFINED__
#undef __ScrollBar_FWD_DEFINED__
#undef __ScrollBars_FWD_DEFINED__
#undef __ListBox_FWD_DEFINED__
#undef __ListBoxes_FWD_DEFINED__
#undef __GroupBox_FWD_DEFINED__
#undef __GroupBoxes_FWD_DEFINED__
#undef __DropDown_FWD_DEFINED__
#undef __DropDowns_FWD_DEFINED__
#undef __Spinner_FWD_DEFINED__
#undef __Spinners_FWD_DEFINED__
#undef __DialogFrame_FWD_DEFINED__
#undef __Label_FWD_DEFINED__
#undef __Labels_FWD_DEFINED__
#undef __Panes_FWD_DEFINED__
#undef __Pane_FWD_DEFINED__
#undef __Scenarios_FWD_DEFINED__
#undef __Scenario_FWD_DEFINED__
#undef __GroupObject_FWD_DEFINED__
#undef __GroupObjects_FWD_DEFINED__
#undef __Line_FWD_DEFINED__
#undef __Lines_FWD_DEFINED__
#undef __Rectangle_FWD_DEFINED__
#undef __Rectangles_FWD_DEFINED__
#undef __Oval_FWD_DEFINED__
#undef __Ovals_FWD_DEFINED__
#undef __Arc_FWD_DEFINED__
#undef __Arcs_FWD_DEFINED__
#undef __OLEObjectEvents_FWD_DEFINED__
#undef ___OLEObject_FWD_DEFINED__
#undef __OLEObjects_FWD_DEFINED__
#undef __TextBox_FWD_DEFINED__
#undef __TextBoxes_FWD_DEFINED__
#undef __Picture_FWD_DEFINED__
#undef __Pictures_FWD_DEFINED__
#undef __Drawing_FWD_DEFINED__
#undef __Drawings_FWD_DEFINED__
#undef __RoutingSlip_FWD_DEFINED__
#undef __Outline_FWD_DEFINED__
#undef __Module_FWD_DEFINED__
#undef __Modules_FWD_DEFINED__
#undef __DialogSheet_FWD_DEFINED__
#undef __DialogSheets_FWD_DEFINED__
#undef __Worksheets_FWD_DEFINED__
#undef __PageSetup_FWD_DEFINED__
#undef __Names_FWD_DEFINED__
#undef __Name_FWD_DEFINED__
#undef __ChartObject_FWD_DEFINED__
#undef __ChartObjects_FWD_DEFINED__
#undef __Mailer_FWD_DEFINED__
#undef __CustomViews_FWD_DEFINED__
#undef __CustomView_FWD_DEFINED__
#undef __FormatConditions_FWD_DEFINED__
#undef __FormatCondition_FWD_DEFINED__
#undef __Comments_FWD_DEFINED__
#undef __Comment_FWD_DEFINED__
#undef __RefreshEvents_FWD_DEFINED__
#undef ___QueryTable_FWD_DEFINED__
#undef __QueryTables_FWD_DEFINED__
#undef __Parameter_FWD_DEFINED__
#undef __Parameters_FWD_DEFINED__
#undef __ODBCError_FWD_DEFINED__
#undef __ODBCErrors_FWD_DEFINED__
#undef __Validation_FWD_DEFINED__
#undef __Hyperlinks_FWD_DEFINED__
#undef __Hyperlink_FWD_DEFINED__
#undef __AutoFilter_FWD_DEFINED__
#undef __Filters_FWD_DEFINED__
#undef __Filter_FWD_DEFINED__
#undef __AutoCorrect_FWD_DEFINED__
#undef __Border_FWD_DEFINED__
#undef __Interior_FWD_DEFINED__
#undef __ChartFillFormat_FWD_DEFINED__
#undef __ChartColorFormat_FWD_DEFINED__
#undef __Axis_FWD_DEFINED__
#undef __ChartTitle_FWD_DEFINED__
#undef __AxisTitle_FWD_DEFINED__
#undef __ChartGroup_FWD_DEFINED__
#undef __ChartGroups_FWD_DEFINED__
#undef __Axes_FWD_DEFINED__
#undef __Points_FWD_DEFINED__
#undef __Point_FWD_DEFINED__
#undef __Series_FWD_DEFINED__
#undef __SeriesCollection_FWD_DEFINED__
#undef __DataLabel_FWD_DEFINED__
#undef __DataLabels_FWD_DEFINED__
#undef __LegendEntry_FWD_DEFINED__
#undef __LegendEntries_FWD_DEFINED__
#undef __LegendKey_FWD_DEFINED__
#undef __Trendlines_FWD_DEFINED__
#undef __Trendline_FWD_DEFINED__
#undef __Corners_FWD_DEFINED__
#undef __SeriesLines_FWD_DEFINED__
#undef __HiLoLines_FWD_DEFINED__
#undef __Gridlines_FWD_DEFINED__
#undef __DropLines_FWD_DEFINED__
#undef __LeaderLines_FWD_DEFINED__
#undef __UpBars_FWD_DEFINED__
#undef __DownBars_FWD_DEFINED__
#undef __Floor_FWD_DEFINED__
#undef __Walls_FWD_DEFINED__
#undef __TickLabels_FWD_DEFINED__
#undef __PlotArea_FWD_DEFINED__
#undef __ChartArea_FWD_DEFINED__
#undef __Legend_FWD_DEFINED__
#undef __ErrorBars_FWD_DEFINED__
#undef __DataTable_FWD_DEFINED__
#undef __Phonetic_FWD_DEFINED__
#undef __Shape_FWD_DEFINED__
#undef __Shapes_FWD_DEFINED__
#undef __ShapeRange_FWD_DEFINED__
#undef __GroupShapes_FWD_DEFINED__
#undef __TextFrame_FWD_DEFINED__
#undef __ConnectorFormat_FWD_DEFINED__
#undef __FreeformBuilder_FWD_DEFINED__
#undef __ControlFormat_FWD_DEFINED__
#undef __OLEFormat_FWD_DEFINED__
#undef __LinkFormat_FWD_DEFINED__
#undef __PublishObjects_FWD_DEFINED__
#undef __OLEDBError_FWD_DEFINED__
#undef __OLEDBErrors_FWD_DEFINED__
#undef __Phonetics_FWD_DEFINED__
#undef __PivotLayout_FWD_DEFINED__
#undef __DisplayUnitLabel_FWD_DEFINED__
#undef __CellFormat_FWD_DEFINED__
#undef __UsedObjects_FWD_DEFINED__
#undef __CustomProperties_FWD_DEFINED__
#undef __CustomProperty_FWD_DEFINED__
#undef __CalculatedMembers_FWD_DEFINED__
#undef __CalculatedMember_FWD_DEFINED__
#undef __Watches_FWD_DEFINED__
#undef __Watch_FWD_DEFINED__
#undef __PivotCell_FWD_DEFINED__
#undef __Graphic_FWD_DEFINED__
#undef __AutoRecover_FWD_DEFINED__
#undef __ErrorCheckingOptions_FWD_DEFINED__
#undef __Errors_FWD_DEFINED__
#undef __Error_FWD_DEFINED__
#undef __SmartTagAction_FWD_DEFINED__
#undef __SmartTagActions_FWD_DEFINED__
#undef __SmartTag_FWD_DEFINED__
#undef __SmartTags_FWD_DEFINED__
#undef __SmartTagRecognizer_FWD_DEFINED__
#undef __SmartTagRecognizers_FWD_DEFINED__
#undef __SmartTagOptions_FWD_DEFINED__
#undef __SpellingOptions_FWD_DEFINED__
#undef __Speech_FWD_DEFINED__
#undef __Protection_FWD_DEFINED__
#undef __PivotItemList_FWD_DEFINED__
#undef __Tab_FWD_DEFINED__
#undef __AllowEditRanges_FWD_DEFINED__
#undef __AllowEditRange_FWD_DEFINED__
#undef __UserAccessList_FWD_DEFINED__
#undef __UserAccess_FWD_DEFINED__
#undef __RTD_FWD_DEFINED__
#undef __Diagram_FWD_DEFINED__
#undef __ListObjects_FWD_DEFINED__
#undef __ListObject_FWD_DEFINED__
#undef __ListColumns_FWD_DEFINED__
#undef __ListColumn_FWD_DEFINED__
#undef __ListRows_FWD_DEFINED__
#undef __ListRow_FWD_DEFINED__
#undef __XmlNamespace_FWD_DEFINED__
#undef __XmlNamespaces_FWD_DEFINED__
#undef __XmlDataBinding_FWD_DEFINED__
#undef __XmlSchema_FWD_DEFINED__
#undef __XmlSchemas_FWD_DEFINED__
#undef __XmlMap_FWD_DEFINED__
#undef __XmlMaps_FWD_DEFINED__
#undef __ListDataFormat_FWD_DEFINED__
#undef __XPath_FWD_DEFINED__
#undef __PivotLineCells_FWD_DEFINED__
#undef __PivotLine_FWD_DEFINED__
#undef __PivotLines_FWD_DEFINED__
#undef __PivotAxis_FWD_DEFINED__
#undef __PivotFilter_FWD_DEFINED__
#undef __PivotFilters_FWD_DEFINED__
#undef __WorkbookConnection_FWD_DEFINED__
#undef __Connections_FWD_DEFINED__
#undef __WorksheetView_FWD_DEFINED__
#undef __ChartView_FWD_DEFINED__
#undef __ModuleView_FWD_DEFINED__
#undef __DialogSheetView_FWD_DEFINED__
#undef __SheetViews_FWD_DEFINED__
#undef __OLEDBConnection_FWD_DEFINED__
#undef __ODBCConnection_FWD_DEFINED__
#undef __Action_FWD_DEFINED__
#undef __Actions_FWD_DEFINED__
#undef __FormatColor_FWD_DEFINED__
#undef __ConditionValue_FWD_DEFINED__
#undef __ColorScale_FWD_DEFINED__
#undef __ColorScaleCriteria_FWD_DEFINED__
#undef __ColorScaleCriterion_FWD_DEFINED__
#undef __Databar_FWD_DEFINED__
#undef __IconSetCondition_FWD_DEFINED__
#undef __IconCriteria_FWD_DEFINED__
#undef __IconCriterion_FWD_DEFINED__
#undef __Icon_FWD_DEFINED__
#undef __IconSet_FWD_DEFINED__
#undef __IconSets_FWD_DEFINED__
#undef __Top10_FWD_DEFINED__
#undef __AboveAverage_FWD_DEFINED__
#undef __UniqueValues_FWD_DEFINED__
#undef __Ranges_FWD_DEFINED__
#undef __HeaderFooter_FWD_DEFINED__
#undef __Page_FWD_DEFINED__
#undef __Pages_FWD_DEFINED__
#undef __ServerViewableItems_FWD_DEFINED__
#undef __TableStyleElement_FWD_DEFINED__
#undef __TableStyleElements_FWD_DEFINED__
#undef __TableStyle_FWD_DEFINED__
#undef __TableStyles_FWD_DEFINED__
#undef __SortField_FWD_DEFINED__
#undef __SortFields_FWD_DEFINED__
#undef __Sort_FWD_DEFINED__
#undef __Research_FWD_DEFINED__
#undef __ColorStop_FWD_DEFINED__
#undef __ColorStops_FWD_DEFINED__
#undef __LinearGradient_FWD_DEFINED__
#undef __RectangularGradient_FWD_DEFINED__
#undef __MultiThreadedCalculation_FWD_DEFINED__
#undef __ChartFormat_FWD_DEFINED__
#undef __FileExportConverter_FWD_DEFINED__
#undef __FileExportConverters_FWD_DEFINED__
#undef __AddIns2_FWD_DEFINED__
#undef __SparklineGroups_FWD_DEFINED__
#undef __SparklineGroup_FWD_DEFINED__
#undef __SparkPoints_FWD_DEFINED__
#undef __Sparkline_FWD_DEFINED__
#undef __SparkAxes_FWD_DEFINED__
#undef __SparkHorizontalAxis_FWD_DEFINED__
#undef __SparkVerticalAxis_FWD_DEFINED__
#undef __SparkColor_FWD_DEFINED__
#undef __DataBarBorder_FWD_DEFINED__
#undef __NegativeBarFormat_FWD_DEFINED__
#undef __ValueChange_FWD_DEFINED__
#undef __PivotTableChangeList_FWD_DEFINED__
#undef __DisplayFormat_FWD_DEFINED__
#undef __SlicerCaches_FWD_DEFINED__
#undef __SlicerCache_FWD_DEFINED__
#undef __SlicerCacheLevels_FWD_DEFINED__
#undef __SlicerCacheLevel_FWD_DEFINED__
#undef __Slicers_FWD_DEFINED__
#undef __Slicer_FWD_DEFINED__
#undef __SlicerItem_FWD_DEFINED__
#undef __SlicerItems_FWD_DEFINED__
#undef __SlicerPivotTables_FWD_DEFINED__
#undef __ProtectedViewWindows_FWD_DEFINED__
#undef __ProtectedViewWindow_FWD_DEFINED__
#undef __TableObject_FWD_DEFINED__
#undef __PivotValueCell_FWD_DEFINED__
#undef __QuickAnalysis_FWD_DEFINED__
#undef __ModelConnection_FWD_DEFINED__
#undef __WorksheetDataConnection_FWD_DEFINED__
#undef __TextConnection_FWD_DEFINED__
#undef __DataFeedConnection_FWD_DEFINED__
#undef __ModelTableColumn_FWD_DEFINED__
#undef __ModelTableColumns_FWD_DEFINED__
#undef __ModelTable_FWD_DEFINED__
#undef __ModelTables_FWD_DEFINED__
#undef __ModelRelationship_FWD_DEFINED__
#undef __ModelRelationships_FWD_DEFINED__
#undef __Model_FWD_DEFINED__
#undef __FullSeriesCollection_FWD_DEFINED__
#undef __ChartCategory_FWD_DEFINED__
#undef __CategoryCollection_FWD_DEFINED__
#undef __TimelineState_FWD_DEFINED__
#undef __TimelineViewState_FWD_DEFINED__
#undef __ModelTableNames_FWD_DEFINED__
#undef __ModelTableNameChange_FWD_DEFINED__
#undef __ModelTableNameChanges_FWD_DEFINED__
#undef __ModelChanges_FWD_DEFINED__
#undef __ModelColumnName_FWD_DEFINED__
#undef __ModelColumnNames_FWD_DEFINED__
#undef __ModelColumnChange_FWD_DEFINED__
#undef __ModelColumnChanges_FWD_DEFINED__
#undef __ModelMeasureName_FWD_DEFINED__
#undef __ModelMeasureNames_FWD_DEFINED__
#undef __IDummy_FWD_DEFINED__
#undef __ICanvasShapes_FWD_DEFINED__
#undef ___DebugTools_FWD_DEFINED__
#undef __Solver_FWD_DEFINED__
#undef __Application_FWD_DEFINED__
#undef __Global_FWD_DEFINED__
#undef __Chart_FWD_DEFINED__
#undef __Workbook_FWD_DEFINED__
#undef __QueryTable_FWD_DEFINED__
#undef __Worksheet_FWD_DEFINED__
#undef __OLEObject_FWD_DEFINED__
#undef __DebugTools_FWD_DEFINED__
#undef __IEXCELCtrlExtender_FWD_DEFINED__
#undef __KEXCELCtrlExtender_FWD_DEFINED__
#undef __Excel_LIBRARY_DEFINED__
#undef __Adjustments_INTERFACE_DEFINED__
#undef __CalloutFormat_INTERFACE_DEFINED__
#undef __ColorFormat_INTERFACE_DEFINED__
#undef __LineFormat_INTERFACE_DEFINED__
#undef __ShapeNode_INTERFACE_DEFINED__
#undef __ShapeNodes_INTERFACE_DEFINED__
#undef __PictureFormat_INTERFACE_DEFINED__
#undef __ShadowFormat_INTERFACE_DEFINED__
#undef __TextEffectFormat_INTERFACE_DEFINED__
#undef __ThreeDFormat_INTERFACE_DEFINED__
#undef __FillFormat_INTERFACE_DEFINED__
#undef __DiagramNodes_INTERFACE_DEFINED__
#undef __DiagramNodeChildren_INTERFACE_DEFINED__
#undef __DiagramNode_INTERFACE_DEFINED__
#undef __IRTDUpdateEvent_INTERFACE_DEFINED__
#undef __IRtdServer_INTERFACE_DEFINED__
#undef __TextFrame2_INTERFACE_DEFINED__
#undef __IFont_INTERFACE_DEFINED__
#undef __IWindow_INTERFACE_DEFINED__
#undef __IWindows_INTERFACE_DEFINED__
#undef __IAppEvents_INTERFACE_DEFINED__
#undef ___Application_INTERFACE_DEFINED__
#undef __IWorksheetFunction_INTERFACE_DEFINED__
#undef __IRange_INTERFACE_DEFINED__
#undef __IChartEvents_INTERFACE_DEFINED__
#undef ___Chart_INTERFACE_DEFINED__
#undef __Sheets_INTERFACE_DEFINED__
#undef __IVPageBreak_INTERFACE_DEFINED__
#undef __IHPageBreak_INTERFACE_DEFINED__
#undef __IHPageBreaks_INTERFACE_DEFINED__
#undef __IVPageBreaks_INTERFACE_DEFINED__
#undef __IRecentFile_INTERFACE_DEFINED__
#undef __IRecentFiles_INTERFACE_DEFINED__
#undef __IDocEvents_INTERFACE_DEFINED__
#undef ___Worksheet_INTERFACE_DEFINED__
#undef __IStyle_INTERFACE_DEFINED__
#undef __IStyles_INTERFACE_DEFINED__
#undef __IBorders_INTERFACE_DEFINED__
#undef ___Global_INTERFACE_DEFINED__
#undef __IAddIn_INTERFACE_DEFINED__
#undef __IAddIns_INTERFACE_DEFINED__
#undef __IToolbar_INTERFACE_DEFINED__
#undef __IToolbars_INTERFACE_DEFINED__
#undef __IToolbarButton_INTERFACE_DEFINED__
#undef __IToolbarButtons_INTERFACE_DEFINED__
#undef __IAreas_INTERFACE_DEFINED__
#undef __IWorkbookEvents_INTERFACE_DEFINED__
#undef ___Workbook_INTERFACE_DEFINED__
#undef __Workbooks_INTERFACE_DEFINED__
#undef __IMenuBars_INTERFACE_DEFINED__
#undef __IMenuBar_INTERFACE_DEFINED__
#undef __IMenus_INTERFACE_DEFINED__
#undef __IMenu_INTERFACE_DEFINED__
#undef __IMenuItems_INTERFACE_DEFINED__
#undef __IMenuItem_INTERFACE_DEFINED__
#undef __ICharts_INTERFACE_DEFINED__
#undef __IDrawingObjects_INTERFACE_DEFINED__
#undef __IPivotCache_INTERFACE_DEFINED__
#undef __IPivotCaches_INTERFACE_DEFINED__
#undef __IPivotFormula_INTERFACE_DEFINED__
#undef __IPivotFormulas_INTERFACE_DEFINED__
#undef __IPivotTable_INTERFACE_DEFINED__
#undef __IPivotTables_INTERFACE_DEFINED__
#undef __IPivotField_INTERFACE_DEFINED__
#undef __IPivotFields_INTERFACE_DEFINED__
#undef __ICalculatedFields_INTERFACE_DEFINED__
#undef __IPivotItem_INTERFACE_DEFINED__
#undef __IPivotItems_INTERFACE_DEFINED__
#undef __ICalculatedItems_INTERFACE_DEFINED__
#undef __ICharacters_INTERFACE_DEFINED__
#undef __IDialogs_INTERFACE_DEFINED__
#undef __IDialog_INTERFACE_DEFINED__
#undef __ISoundNote_INTERFACE_DEFINED__
#undef __IButton_INTERFACE_DEFINED__
#undef __IButtons_INTERFACE_DEFINED__
#undef __ICheckBox_INTERFACE_DEFINED__
#undef __ICheckBoxes_INTERFACE_DEFINED__
#undef __IOptionButton_INTERFACE_DEFINED__
#undef __IOptionButtons_INTERFACE_DEFINED__
#undef __IEditBox_INTERFACE_DEFINED__
#undef __IEditBoxes_INTERFACE_DEFINED__
#undef __IScrollBar_INTERFACE_DEFINED__
#undef __IScrollBars_INTERFACE_DEFINED__
#undef __IListBox_INTERFACE_DEFINED__
#undef __IListBoxes_INTERFACE_DEFINED__
#undef __IGroupBox_INTERFACE_DEFINED__
#undef __IGroupBoxes_INTERFACE_DEFINED__
#undef __IDropDown_INTERFACE_DEFINED__
#undef __IDropDowns_INTERFACE_DEFINED__
#undef __ISpinner_INTERFACE_DEFINED__
#undef __ISpinners_INTERFACE_DEFINED__
#undef __IDialogFrame_INTERFACE_DEFINED__
#undef __ILabel_INTERFACE_DEFINED__
#undef __ILabels_INTERFACE_DEFINED__
#undef __IPanes_INTERFACE_DEFINED__
#undef __IPane_INTERFACE_DEFINED__
#undef __IScenarios_INTERFACE_DEFINED__
#undef __IScenario_INTERFACE_DEFINED__
#undef __IGroupObject_INTERFACE_DEFINED__
#undef __IGroupObjects_INTERFACE_DEFINED__
#undef __ILine_INTERFACE_DEFINED__
#undef __ILines_INTERFACE_DEFINED__
#undef __IRectangle_INTERFACE_DEFINED__
#undef __IRectangles_INTERFACE_DEFINED__
#undef __IOval_INTERFACE_DEFINED__
#undef __IOvals_INTERFACE_DEFINED__
#undef __IArc_INTERFACE_DEFINED__
#undef __IArcs_INTERFACE_DEFINED__
#undef __IOLEObjectEvents_INTERFACE_DEFINED__
#undef ___IOLEObject_INTERFACE_DEFINED__
#undef __IOLEObjects_INTERFACE_DEFINED__
#undef __ITextBox_INTERFACE_DEFINED__
#undef __ITextBoxes_INTERFACE_DEFINED__
#undef __IPicture_INTERFACE_DEFINED__
#undef __IPictures_INTERFACE_DEFINED__
#undef __IDrawing_INTERFACE_DEFINED__
#undef __IDrawings_INTERFACE_DEFINED__
#undef __IRoutingSlip_INTERFACE_DEFINED__
#undef __IOutline_INTERFACE_DEFINED__
#undef __IModule_INTERFACE_DEFINED__
#undef __IModules_INTERFACE_DEFINED__
#undef __IDialogSheet_INTERFACE_DEFINED__
#undef __IDialogSheets_INTERFACE_DEFINED__
#undef __IWorksheets_INTERFACE_DEFINED__
#undef __IPageSetup_INTERFACE_DEFINED__
#undef __INames_INTERFACE_DEFINED__
#undef __IName_INTERFACE_DEFINED__
#undef __IChartObject_INTERFACE_DEFINED__
#undef __IChartObjects_INTERFACE_DEFINED__
#undef __IMailer_INTERFACE_DEFINED__
#undef __ICustomViews_INTERFACE_DEFINED__
#undef __ICustomView_INTERFACE_DEFINED__
#undef __IFormatConditions_INTERFACE_DEFINED__
#undef __IFormatCondition_INTERFACE_DEFINED__
#undef __IComments_INTERFACE_DEFINED__
#undef __IComment_INTERFACE_DEFINED__
#undef __IRefreshEvents_INTERFACE_DEFINED__
#undef ___IQueryTable_INTERFACE_DEFINED__
#undef __IQueryTables_INTERFACE_DEFINED__
#undef __IParameter_INTERFACE_DEFINED__
#undef __IParameters_INTERFACE_DEFINED__
#undef __IODBCError_INTERFACE_DEFINED__
#undef __IODBCErrors_INTERFACE_DEFINED__
#undef __IValidation_INTERFACE_DEFINED__
#undef __IHyperlinks_INTERFACE_DEFINED__
#undef __IHyperlink_INTERFACE_DEFINED__
#undef __IAutoFilter_INTERFACE_DEFINED__
#undef __IFilters_INTERFACE_DEFINED__
#undef __IFilter_INTERFACE_DEFINED__
#undef __IAutoCorrect_INTERFACE_DEFINED__
#undef __IBorder_INTERFACE_DEFINED__
#undef __IInterior_INTERFACE_DEFINED__
#undef __IChartFillFormat_INTERFACE_DEFINED__
#undef __IChartColorFormat_INTERFACE_DEFINED__
#undef __IAxis_INTERFACE_DEFINED__
#undef __IChartTitle_INTERFACE_DEFINED__
#undef __IAxisTitle_INTERFACE_DEFINED__
#undef __IChartGroup_INTERFACE_DEFINED__
#undef __IChartGroups_INTERFACE_DEFINED__
#undef __IAxes_INTERFACE_DEFINED__
#undef __IPoints_INTERFACE_DEFINED__
#undef __IPoint_INTERFACE_DEFINED__
#undef __ISeries_INTERFACE_DEFINED__
#undef __ISeriesCollection_INTERFACE_DEFINED__
#undef __IDataLabel_INTERFACE_DEFINED__
#undef __IDataLabels_INTERFACE_DEFINED__
#undef __ILegendEntry_INTERFACE_DEFINED__
#undef __ILegendEntries_INTERFACE_DEFINED__
#undef __ILegendKey_INTERFACE_DEFINED__
#undef __ITrendlines_INTERFACE_DEFINED__
#undef __ITrendline_INTERFACE_DEFINED__
#undef __ICorners_INTERFACE_DEFINED__
#undef __ISeriesLines_INTERFACE_DEFINED__
#undef __IHiLoLines_INTERFACE_DEFINED__
#undef __IGridlines_INTERFACE_DEFINED__
#undef __IDropLines_INTERFACE_DEFINED__
#undef __ILeaderLines_INTERFACE_DEFINED__
#undef __IUpBars_INTERFACE_DEFINED__
#undef __IDownBars_INTERFACE_DEFINED__
#undef __IFloor_INTERFACE_DEFINED__
#undef __IWalls_INTERFACE_DEFINED__
#undef __ITickLabels_INTERFACE_DEFINED__
#undef __IPlotArea_INTERFACE_DEFINED__
#undef __IChartArea_INTERFACE_DEFINED__
#undef __ILegend_INTERFACE_DEFINED__
#undef __IErrorBars_INTERFACE_DEFINED__
#undef __IDataTable_INTERFACE_DEFINED__
#undef __IPhonetic_INTERFACE_DEFINED__
#undef __IShape_INTERFACE_DEFINED__
#undef __IShapes_INTERFACE_DEFINED__
#undef __IShapeRange_INTERFACE_DEFINED__
#undef __IGroupShapes_INTERFACE_DEFINED__
#undef __ITextFrame_INTERFACE_DEFINED__
#undef __IConnectorFormat_INTERFACE_DEFINED__
#undef __IFreeformBuilder_INTERFACE_DEFINED__
#undef __IControlFormat_INTERFACE_DEFINED__
#undef __IOLEFormat_INTERFACE_DEFINED__
#undef __ILinkFormat_INTERFACE_DEFINED__
#undef __IPublishObjects_INTERFACE_DEFINED__
#undef __PublishObject_INTERFACE_DEFINED__
#undef __IOLEDBError_INTERFACE_DEFINED__
#undef __IOLEDBErrors_INTERFACE_DEFINED__
#undef __IPhonetics_INTERFACE_DEFINED__
#undef __DefaultWebOptions_INTERFACE_DEFINED__
#undef __WebOptions_INTERFACE_DEFINED__
#undef __IPivotLayout_INTERFACE_DEFINED__
#undef __TreeviewControl_INTERFACE_DEFINED__
#undef __CubeField_INTERFACE_DEFINED__
#undef __CubeFields_INTERFACE_DEFINED__
#undef __IDisplayUnitLabel_INTERFACE_DEFINED__
#undef __ICellFormat_INTERFACE_DEFINED__
#undef __IUsedObjects_INTERFACE_DEFINED__
#undef __ICustomProperties_INTERFACE_DEFINED__
#undef __ICustomProperty_INTERFACE_DEFINED__
#undef __ICalculatedMembers_INTERFACE_DEFINED__
#undef __ICalculatedMember_INTERFACE_DEFINED__
#undef __IWatches_INTERFACE_DEFINED__
#undef __IWatch_INTERFACE_DEFINED__
#undef __IPivotCell_INTERFACE_DEFINED__
#undef __IGraphic_INTERFACE_DEFINED__
#undef __IAutoRecover_INTERFACE_DEFINED__
#undef __IErrorCheckingOptions_INTERFACE_DEFINED__
#undef __IErrors_INTERFACE_DEFINED__
#undef __IError_INTERFACE_DEFINED__
#undef __ISmartTagAction_INTERFACE_DEFINED__
#undef __ISmartTagActions_INTERFACE_DEFINED__
#undef __ISmartTag_INTERFACE_DEFINED__
#undef __ISmartTags_INTERFACE_DEFINED__
#undef __ISmartTagRecognizer_INTERFACE_DEFINED__
#undef __ISmartTagRecognizers_INTERFACE_DEFINED__
#undef __ISmartTagOptions_INTERFACE_DEFINED__
#undef __ISpellingOptions_INTERFACE_DEFINED__
#undef __ISpeech_INTERFACE_DEFINED__
#undef __IProtection_INTERFACE_DEFINED__
#undef __IPivotItemList_INTERFACE_DEFINED__
#undef __ITab_INTERFACE_DEFINED__
#undef __IAllowEditRanges_INTERFACE_DEFINED__
#undef __IAllowEditRange_INTERFACE_DEFINED__
#undef __IUserAccessList_INTERFACE_DEFINED__
#undef __IUserAccess_INTERFACE_DEFINED__
#undef __IRTD_INTERFACE_DEFINED__
#undef __IDiagram_INTERFACE_DEFINED__
#undef __IListObjects_INTERFACE_DEFINED__
#undef __IListObject_INTERFACE_DEFINED__
#undef __IListColumns_INTERFACE_DEFINED__
#undef __IListColumn_INTERFACE_DEFINED__
#undef __IListRows_INTERFACE_DEFINED__
#undef __IListRow_INTERFACE_DEFINED__
#undef __IXmlNamespace_INTERFACE_DEFINED__
#undef __IXmlNamespaces_INTERFACE_DEFINED__
#undef __IXmlDataBinding_INTERFACE_DEFINED__
#undef __IXmlSchema_INTERFACE_DEFINED__
#undef __IXmlSchemas_INTERFACE_DEFINED__
#undef __IXmlMap_INTERFACE_DEFINED__
#undef __IXmlMaps_INTERFACE_DEFINED__
#undef __IListDataFormat_INTERFACE_DEFINED__
#undef __IXPath_INTERFACE_DEFINED__
#undef __IPivotLineCells_INTERFACE_DEFINED__
#undef __IPivotLine_INTERFACE_DEFINED__
#undef __IPivotLines_INTERFACE_DEFINED__
#undef __IPivotAxis_INTERFACE_DEFINED__
#undef __IPivotFilter_INTERFACE_DEFINED__
#undef __IPivotFilters_INTERFACE_DEFINED__
#undef __IWorkbookConnection_INTERFACE_DEFINED__
#undef __IConnections_INTERFACE_DEFINED__
#undef __IWorksheetView_INTERFACE_DEFINED__
#undef __IChartView_INTERFACE_DEFINED__
#undef __IModuleView_INTERFACE_DEFINED__
#undef __IDialogSheetView_INTERFACE_DEFINED__
#undef __ISheetViews_INTERFACE_DEFINED__
#undef __IOLEDBConnection_INTERFACE_DEFINED__
#undef __IODBCConnection_INTERFACE_DEFINED__
#undef __IAction_INTERFACE_DEFINED__
#undef __IActions_INTERFACE_DEFINED__
#undef __IFormatColor_INTERFACE_DEFINED__
#undef __IConditionValue_INTERFACE_DEFINED__
#undef __IColorScale_INTERFACE_DEFINED__
#undef __IColorScaleCriteria_INTERFACE_DEFINED__
#undef __IColorScaleCriterion_INTERFACE_DEFINED__
#undef __IDatabar_INTERFACE_DEFINED__
#undef __IIconSetCondition_INTERFACE_DEFINED__
#undef __IIconCriteria_INTERFACE_DEFINED__
#undef __IIconCriterion_INTERFACE_DEFINED__
#undef __IIcon_INTERFACE_DEFINED__
#undef __IIconSet_INTERFACE_DEFINED__
#undef __IIconSets_INTERFACE_DEFINED__
#undef __ITop10_INTERFACE_DEFINED__
#undef __IAboveAverage_INTERFACE_DEFINED__
#undef __IUniqueValues_INTERFACE_DEFINED__
#undef __IRanges_INTERFACE_DEFINED__
#undef __IHeaderFooter_INTERFACE_DEFINED__
#undef __IPage_INTERFACE_DEFINED__
#undef __IPages_INTERFACE_DEFINED__
#undef __IServerViewableItems_INTERFACE_DEFINED__
#undef __ITableStyleElement_INTERFACE_DEFINED__
#undef __ITableStyleElements_INTERFACE_DEFINED__
#undef __ITableStyle_INTERFACE_DEFINED__
#undef __ITableStyles_INTERFACE_DEFINED__
#undef __ISortField_INTERFACE_DEFINED__
#undef __ISortFields_INTERFACE_DEFINED__
#undef __ISort_INTERFACE_DEFINED__
#undef __IResearch_INTERFACE_DEFINED__
#undef __IColorStop_INTERFACE_DEFINED__
#undef __IColorStops_INTERFACE_DEFINED__
#undef __ILinearGradient_INTERFACE_DEFINED__
#undef __IRectangularGradient_INTERFACE_DEFINED__
#undef __IMultiThreadedCalculation_INTERFACE_DEFINED__
#undef __IChartFormat_INTERFACE_DEFINED__
#undef __IFileExportConverter_INTERFACE_DEFINED__
#undef __IFileExportConverters_INTERFACE_DEFINED__
#undef __IAddIns2_INTERFACE_DEFINED__
#undef __ISparklineGroups_INTERFACE_DEFINED__
#undef __ISparklineGroup_INTERFACE_DEFINED__
#undef __ISparkPoints_INTERFACE_DEFINED__
#undef __ISparkline_INTERFACE_DEFINED__
#undef __ISparkAxes_INTERFACE_DEFINED__
#undef __ISparkHorizontalAxis_INTERFACE_DEFINED__
#undef __ISparkVerticalAxis_INTERFACE_DEFINED__
#undef __ISparkColor_INTERFACE_DEFINED__
#undef __IDataBarBorder_INTERFACE_DEFINED__
#undef __INegativeBarFormat_INTERFACE_DEFINED__
#undef __IValueChange_INTERFACE_DEFINED__
#undef __IPivotTableChangeList_INTERFACE_DEFINED__
#undef __IDisplayFormat_INTERFACE_DEFINED__
#undef __ISlicerCaches_INTERFACE_DEFINED__
#undef __ISlicerCache_INTERFACE_DEFINED__
#undef __ISlicerCacheLevels_INTERFACE_DEFINED__
#undef __ISlicerCacheLevel_INTERFACE_DEFINED__
#undef __ISlicers_INTERFACE_DEFINED__
#undef __ISlicer_INTERFACE_DEFINED__
#undef __ISlicerItem_INTERFACE_DEFINED__
#undef __ISlicerItems_INTERFACE_DEFINED__
#undef __ISlicerPivotTables_INTERFACE_DEFINED__
#undef __IProtectedViewWindows_INTERFACE_DEFINED__
#undef __IProtectedViewWindow_INTERFACE_DEFINED__
#undef __ITableObject_INTERFACE_DEFINED__
#undef __IPivotValueCell_INTERFACE_DEFINED__
#undef __IQuickAnalysis_INTERFACE_DEFINED__
#undef __IModelConnection_INTERFACE_DEFINED__
#undef __IWorksheetDataConnection_INTERFACE_DEFINED__
#undef __ITextConnection_INTERFACE_DEFINED__
#undef __IDataFeedConnection_INTERFACE_DEFINED__
#undef __IModelTableColumn_INTERFACE_DEFINED__
#undef __IModelTableColumns_INTERFACE_DEFINED__
#undef __IModelTable_INTERFACE_DEFINED__
#undef __IModelTables_INTERFACE_DEFINED__
#undef __IModelRelationship_INTERFACE_DEFINED__
#undef __IModelRelationships_INTERFACE_DEFINED__
#undef __IModel_INTERFACE_DEFINED__
#undef __IFullSeriesCollection_INTERFACE_DEFINED__
#undef __IChartCategory_INTERFACE_DEFINED__
#undef __ICategoryCollection_INTERFACE_DEFINED__
#undef __ITimelineState_INTERFACE_DEFINED__
#undef __ITimelineViewState_INTERFACE_DEFINED__
#undef __IModelTableNames_INTERFACE_DEFINED__
#undef __IModelTableNameChange_INTERFACE_DEFINED__
#undef __IModelTableNameChanges_INTERFACE_DEFINED__
#undef __IModelChanges_INTERFACE_DEFINED__
#undef __IModelColumnName_INTERFACE_DEFINED__
#undef __IModelColumnNames_INTERFACE_DEFINED__
#undef __IModelColumnChange_INTERFACE_DEFINED__
#undef __IModelColumnChanges_INTERFACE_DEFINED__
#undef __IModelMeasureName_INTERFACE_DEFINED__
#undef __IModelMeasureNames_INTERFACE_DEFINED__
#undef __Font_DISPINTERFACE_DEFINED__
#undef __Window_DISPINTERFACE_DEFINED__
#undef __Windows_DISPINTERFACE_DEFINED__
#undef __AppEvents_DISPINTERFACE_DEFINED__
#undef __WorksheetFunction_DISPINTERFACE_DEFINED__
#undef __Range_DISPINTERFACE_DEFINED__
#undef __ChartEvents_DISPINTERFACE_DEFINED__
#undef __VPageBreak_DISPINTERFACE_DEFINED__
#undef __HPageBreak_DISPINTERFACE_DEFINED__
#undef __HPageBreaks_DISPINTERFACE_DEFINED__
#undef __VPageBreaks_DISPINTERFACE_DEFINED__
#undef __RecentFile_DISPINTERFACE_DEFINED__
#undef __RecentFiles_DISPINTERFACE_DEFINED__
#undef __DocEvents_DISPINTERFACE_DEFINED__
#undef __Style_DISPINTERFACE_DEFINED__
#undef __Styles_DISPINTERFACE_DEFINED__
#undef __Borders_DISPINTERFACE_DEFINED__
#undef __AddIn_DISPINTERFACE_DEFINED__
#undef __AddIns_DISPINTERFACE_DEFINED__
#undef __Toolbar_DISPINTERFACE_DEFINED__
#undef __Toolbars_DISPINTERFACE_DEFINED__
#undef __ToolbarButton_DISPINTERFACE_DEFINED__
#undef __ToolbarButtons_DISPINTERFACE_DEFINED__
#undef __Areas_DISPINTERFACE_DEFINED__
#undef __WorkbookEvents_DISPINTERFACE_DEFINED__
#undef __MenuBars_DISPINTERFACE_DEFINED__
#undef __MenuBar_DISPINTERFACE_DEFINED__
#undef __Menus_DISPINTERFACE_DEFINED__
#undef __Menu_DISPINTERFACE_DEFINED__
#undef __MenuItems_DISPINTERFACE_DEFINED__
#undef __MenuItem_DISPINTERFACE_DEFINED__
#undef __Charts_DISPINTERFACE_DEFINED__
#undef __DrawingObjects_DISPINTERFACE_DEFINED__
#undef __PivotCache_DISPINTERFACE_DEFINED__
#undef __PivotCaches_DISPINTERFACE_DEFINED__
#undef __PivotFormula_DISPINTERFACE_DEFINED__
#undef __PivotFormulas_DISPINTERFACE_DEFINED__
#undef __PivotTable_DISPINTERFACE_DEFINED__
#undef __PivotTables_DISPINTERFACE_DEFINED__
#undef __PivotField_DISPINTERFACE_DEFINED__
#undef __PivotFields_DISPINTERFACE_DEFINED__
#undef __CalculatedFields_DISPINTERFACE_DEFINED__
#undef __PivotItem_DISPINTERFACE_DEFINED__
#undef __PivotItems_DISPINTERFACE_DEFINED__
#undef __CalculatedItems_DISPINTERFACE_DEFINED__
#undef __Characters_DISPINTERFACE_DEFINED__
#undef __Dialogs_DISPINTERFACE_DEFINED__
#undef __Dialog_DISPINTERFACE_DEFINED__
#undef __SoundNote_DISPINTERFACE_DEFINED__
#undef __Button_DISPINTERFACE_DEFINED__
#undef __Buttons_DISPINTERFACE_DEFINED__
#undef __CheckBox_DISPINTERFACE_DEFINED__
#undef __CheckBoxes_DISPINTERFACE_DEFINED__
#undef __OptionButton_DISPINTERFACE_DEFINED__
#undef __OptionButtons_DISPINTERFACE_DEFINED__
#undef __EditBox_DISPINTERFACE_DEFINED__
#undef __EditBoxes_DISPINTERFACE_DEFINED__
#undef __ScrollBar_DISPINTERFACE_DEFINED__
#undef __ScrollBars_DISPINTERFACE_DEFINED__
#undef __ListBox_DISPINTERFACE_DEFINED__
#undef __ListBoxes_DISPINTERFACE_DEFINED__
#undef __GroupBox_DISPINTERFACE_DEFINED__
#undef __GroupBoxes_DISPINTERFACE_DEFINED__
#undef __DropDown_DISPINTERFACE_DEFINED__
#undef __DropDowns_DISPINTERFACE_DEFINED__
#undef __Spinner_DISPINTERFACE_DEFINED__
#undef __Spinners_DISPINTERFACE_DEFINED__
#undef __DialogFrame_DISPINTERFACE_DEFINED__
#undef __Label_DISPINTERFACE_DEFINED__
#undef __Labels_DISPINTERFACE_DEFINED__
#undef __Panes_DISPINTERFACE_DEFINED__
#undef __Pane_DISPINTERFACE_DEFINED__
#undef __Scenarios_DISPINTERFACE_DEFINED__
#undef __Scenario_DISPINTERFACE_DEFINED__
#undef __GroupObject_DISPINTERFACE_DEFINED__
#undef __GroupObjects_DISPINTERFACE_DEFINED__
#undef __Line_DISPINTERFACE_DEFINED__
#undef __Lines_DISPINTERFACE_DEFINED__
#undef __Rectangle_DISPINTERFACE_DEFINED__
#undef __Rectangles_DISPINTERFACE_DEFINED__
#undef __Oval_DISPINTERFACE_DEFINED__
#undef __Ovals_DISPINTERFACE_DEFINED__
#undef __Arc_DISPINTERFACE_DEFINED__
#undef __Arcs_DISPINTERFACE_DEFINED__
#undef __OLEObjectEvents_DISPINTERFACE_DEFINED__
#undef ___OLEObject_DISPINTERFACE_DEFINED__
#undef __OLEObjects_DISPINTERFACE_DEFINED__
#undef __TextBox_DISPINTERFACE_DEFINED__
#undef __TextBoxes_DISPINTERFACE_DEFINED__
#undef __Picture_DISPINTERFACE_DEFINED__
#undef __Pictures_DISPINTERFACE_DEFINED__
#undef __Drawing_DISPINTERFACE_DEFINED__
#undef __Drawings_DISPINTERFACE_DEFINED__
#undef __RoutingSlip_DISPINTERFACE_DEFINED__
#undef __Outline_DISPINTERFACE_DEFINED__
#undef __Module_DISPINTERFACE_DEFINED__
#undef __Modules_DISPINTERFACE_DEFINED__
#undef __DialogSheet_DISPINTERFACE_DEFINED__
#undef __DialogSheets_DISPINTERFACE_DEFINED__
#undef __Worksheets_DISPINTERFACE_DEFINED__
#undef __PageSetup_DISPINTERFACE_DEFINED__
#undef __Names_DISPINTERFACE_DEFINED__
#undef __Name_DISPINTERFACE_DEFINED__
#undef __ChartObject_DISPINTERFACE_DEFINED__
#undef __ChartObjects_DISPINTERFACE_DEFINED__
#undef __Mailer_DISPINTERFACE_DEFINED__
#undef __CustomViews_DISPINTERFACE_DEFINED__
#undef __CustomView_DISPINTERFACE_DEFINED__
#undef __FormatConditions_DISPINTERFACE_DEFINED__
#undef __FormatCondition_DISPINTERFACE_DEFINED__
#undef __Comments_DISPINTERFACE_DEFINED__
#undef __Comment_DISPINTERFACE_DEFINED__
#undef __RefreshEvents_DISPINTERFACE_DEFINED__
#undef ___QueryTable_DISPINTERFACE_DEFINED__
#undef __QueryTables_DISPINTERFACE_DEFINED__
#undef __Parameter_DISPINTERFACE_DEFINED__
#undef __Parameters_DISPINTERFACE_DEFINED__
#undef __ODBCError_DISPINTERFACE_DEFINED__
#undef __ODBCErrors_DISPINTERFACE_DEFINED__
#undef __Validation_DISPINTERFACE_DEFINED__
#undef __Hyperlinks_DISPINTERFACE_DEFINED__
#undef __Hyperlink_DISPINTERFACE_DEFINED__
#undef __AutoFilter_DISPINTERFACE_DEFINED__
#undef __Filters_DISPINTERFACE_DEFINED__
#undef __Filter_DISPINTERFACE_DEFINED__
#undef __AutoCorrect_DISPINTERFACE_DEFINED__
#undef __Border_DISPINTERFACE_DEFINED__
#undef __Interior_DISPINTERFACE_DEFINED__
#undef __ChartFillFormat_DISPINTERFACE_DEFINED__
#undef __ChartColorFormat_DISPINTERFACE_DEFINED__
#undef __Axis_DISPINTERFACE_DEFINED__
#undef __ChartTitle_DISPINTERFACE_DEFINED__
#undef __AxisTitle_DISPINTERFACE_DEFINED__
#undef __ChartGroup_DISPINTERFACE_DEFINED__
#undef __ChartGroups_DISPINTERFACE_DEFINED__
#undef __Axes_DISPINTERFACE_DEFINED__
#undef __Points_DISPINTERFACE_DEFINED__
#undef __Point_DISPINTERFACE_DEFINED__
#undef __Series_DISPINTERFACE_DEFINED__
#undef __SeriesCollection_DISPINTERFACE_DEFINED__
#undef __DataLabel_DISPINTERFACE_DEFINED__
#undef __DataLabels_DISPINTERFACE_DEFINED__
#undef __LegendEntry_DISPINTERFACE_DEFINED__
#undef __LegendEntries_DISPINTERFACE_DEFINED__
#undef __LegendKey_DISPINTERFACE_DEFINED__
#undef __Trendlines_DISPINTERFACE_DEFINED__
#undef __Trendline_DISPINTERFACE_DEFINED__
#undef __Corners_DISPINTERFACE_DEFINED__
#undef __SeriesLines_DISPINTERFACE_DEFINED__
#undef __HiLoLines_DISPINTERFACE_DEFINED__
#undef __Gridlines_DISPINTERFACE_DEFINED__
#undef __DropLines_DISPINTERFACE_DEFINED__
#undef __LeaderLines_DISPINTERFACE_DEFINED__
#undef __UpBars_DISPINTERFACE_DEFINED__
#undef __DownBars_DISPINTERFACE_DEFINED__
#undef __Floor_DISPINTERFACE_DEFINED__
#undef __Walls_DISPINTERFACE_DEFINED__
#undef __TickLabels_DISPINTERFACE_DEFINED__
#undef __PlotArea_DISPINTERFACE_DEFINED__
#undef __ChartArea_DISPINTERFACE_DEFINED__
#undef __Legend_DISPINTERFACE_DEFINED__
#undef __ErrorBars_DISPINTERFACE_DEFINED__
#undef __DataTable_DISPINTERFACE_DEFINED__
#undef __Phonetic_DISPINTERFACE_DEFINED__
#undef __Shape_DISPINTERFACE_DEFINED__
#undef __Shapes_DISPINTERFACE_DEFINED__
#undef __ShapeRange_DISPINTERFACE_DEFINED__
#undef __GroupShapes_DISPINTERFACE_DEFINED__
#undef __TextFrame_DISPINTERFACE_DEFINED__
#undef __ConnectorFormat_DISPINTERFACE_DEFINED__
#undef __FreeformBuilder_DISPINTERFACE_DEFINED__
#undef __ControlFormat_DISPINTERFACE_DEFINED__
#undef __OLEFormat_DISPINTERFACE_DEFINED__
#undef __LinkFormat_DISPINTERFACE_DEFINED__
#undef __PublishObjects_DISPINTERFACE_DEFINED__
#undef __OLEDBError_DISPINTERFACE_DEFINED__
#undef __OLEDBErrors_DISPINTERFACE_DEFINED__
#undef __Phonetics_DISPINTERFACE_DEFINED__
#undef __PivotLayout_DISPINTERFACE_DEFINED__
#undef __DisplayUnitLabel_DISPINTERFACE_DEFINED__
#undef __CellFormat_DISPINTERFACE_DEFINED__
#undef __UsedObjects_DISPINTERFACE_DEFINED__
#undef __CustomProperties_DISPINTERFACE_DEFINED__
#undef __CustomProperty_DISPINTERFACE_DEFINED__
#undef __CalculatedMembers_DISPINTERFACE_DEFINED__
#undef __CalculatedMember_DISPINTERFACE_DEFINED__
#undef __Watches_DISPINTERFACE_DEFINED__
#undef __Watch_DISPINTERFACE_DEFINED__
#undef __PivotCell_DISPINTERFACE_DEFINED__
#undef __Graphic_DISPINTERFACE_DEFINED__
#undef __AutoRecover_DISPINTERFACE_DEFINED__
#undef __ErrorCheckingOptions_DISPINTERFACE_DEFINED__
#undef __Errors_DISPINTERFACE_DEFINED__
#undef __Error_DISPINTERFACE_DEFINED__
#undef __SmartTagAction_DISPINTERFACE_DEFINED__
#undef __SmartTagActions_DISPINTERFACE_DEFINED__
#undef __SmartTag_DISPINTERFACE_DEFINED__
#undef __SmartTags_DISPINTERFACE_DEFINED__
#undef __SmartTagRecognizer_DISPINTERFACE_DEFINED__
#undef __SmartTagRecognizers_DISPINTERFACE_DEFINED__
#undef __SmartTagOptions_DISPINTERFACE_DEFINED__
#undef __SpellingOptions_DISPINTERFACE_DEFINED__
#undef __Speech_DISPINTERFACE_DEFINED__
#undef __Protection_DISPINTERFACE_DEFINED__
#undef __PivotItemList_DISPINTERFACE_DEFINED__
#undef __Tab_DISPINTERFACE_DEFINED__
#undef __AllowEditRanges_DISPINTERFACE_DEFINED__
#undef __AllowEditRange_DISPINTERFACE_DEFINED__
#undef __UserAccessList_DISPINTERFACE_DEFINED__
#undef __UserAccess_DISPINTERFACE_DEFINED__
#undef __RTD_DISPINTERFACE_DEFINED__
#undef __Diagram_DISPINTERFACE_DEFINED__
#undef __ListObjects_DISPINTERFACE_DEFINED__
#undef __ListObject_DISPINTERFACE_DEFINED__
#undef __ListColumns_DISPINTERFACE_DEFINED__
#undef __ListColumn_DISPINTERFACE_DEFINED__
#undef __ListRows_DISPINTERFACE_DEFINED__
#undef __ListRow_DISPINTERFACE_DEFINED__
#undef __XmlNamespace_DISPINTERFACE_DEFINED__
#undef __XmlNamespaces_DISPINTERFACE_DEFINED__
#undef __XmlDataBinding_DISPINTERFACE_DEFINED__
#undef __XmlSchema_DISPINTERFACE_DEFINED__
#undef __XmlSchemas_DISPINTERFACE_DEFINED__
#undef __XmlMap_DISPINTERFACE_DEFINED__
#undef __XmlMaps_DISPINTERFACE_DEFINED__
#undef __ListDataFormat_DISPINTERFACE_DEFINED__
#undef __XPath_DISPINTERFACE_DEFINED__
#undef __PivotLineCells_DISPINTERFACE_DEFINED__
#undef __PivotLine_DISPINTERFACE_DEFINED__
#undef __PivotLines_DISPINTERFACE_DEFINED__
#undef __PivotAxis_DISPINTERFACE_DEFINED__
#undef __PivotFilter_DISPINTERFACE_DEFINED__
#undef __PivotFilters_DISPINTERFACE_DEFINED__
#undef __WorkbookConnection_DISPINTERFACE_DEFINED__
#undef __Connections_DISPINTERFACE_DEFINED__
#undef __WorksheetView_DISPINTERFACE_DEFINED__
#undef __ChartView_DISPINTERFACE_DEFINED__
#undef __ModuleView_DISPINTERFACE_DEFINED__
#undef __DialogSheetView_DISPINTERFACE_DEFINED__
#undef __SheetViews_DISPINTERFACE_DEFINED__
#undef __OLEDBConnection_DISPINTERFACE_DEFINED__
#undef __ODBCConnection_DISPINTERFACE_DEFINED__
#undef __Action_DISPINTERFACE_DEFINED__
#undef __Actions_DISPINTERFACE_DEFINED__
#undef __FormatColor_DISPINTERFACE_DEFINED__
#undef __ConditionValue_DISPINTERFACE_DEFINED__
#undef __ColorScale_DISPINTERFACE_DEFINED__
#undef __ColorScaleCriteria_DISPINTERFACE_DEFINED__
#undef __ColorScaleCriterion_DISPINTERFACE_DEFINED__
#undef __Databar_DISPINTERFACE_DEFINED__
#undef __IconSetCondition_DISPINTERFACE_DEFINED__
#undef __IconCriteria_DISPINTERFACE_DEFINED__
#undef __IconCriterion_DISPINTERFACE_DEFINED__
#undef __Icon_DISPINTERFACE_DEFINED__
#undef __IconSet_DISPINTERFACE_DEFINED__
#undef __IconSets_DISPINTERFACE_DEFINED__
#undef __Top10_DISPINTERFACE_DEFINED__
#undef __AboveAverage_DISPINTERFACE_DEFINED__
#undef __UniqueValues_DISPINTERFACE_DEFINED__
#undef __Ranges_DISPINTERFACE_DEFINED__
#undef __HeaderFooter_DISPINTERFACE_DEFINED__
#undef __Page_DISPINTERFACE_DEFINED__
#undef __Pages_DISPINTERFACE_DEFINED__
#undef __ServerViewableItems_DISPINTERFACE_DEFINED__
#undef __TableStyleElement_DISPINTERFACE_DEFINED__
#undef __TableStyleElements_DISPINTERFACE_DEFINED__
#undef __TableStyle_DISPINTERFACE_DEFINED__
#undef __TableStyles_DISPINTERFACE_DEFINED__
#undef __SortField_DISPINTERFACE_DEFINED__
#undef __SortFields_DISPINTERFACE_DEFINED__
#undef __Sort_DISPINTERFACE_DEFINED__
#undef __Research_DISPINTERFACE_DEFINED__
#undef __ColorStop_DISPINTERFACE_DEFINED__
#undef __ColorStops_DISPINTERFACE_DEFINED__
#undef __LinearGradient_DISPINTERFACE_DEFINED__
#undef __RectangularGradient_DISPINTERFACE_DEFINED__
#undef __MultiThreadedCalculation_DISPINTERFACE_DEFINED__
#undef __ChartFormat_DISPINTERFACE_DEFINED__
#undef __FileExportConverter_DISPINTERFACE_DEFINED__
#undef __FileExportConverters_DISPINTERFACE_DEFINED__
#undef __AddIns2_DISPINTERFACE_DEFINED__
#undef __SparklineGroups_DISPINTERFACE_DEFINED__
#undef __SparklineGroup_DISPINTERFACE_DEFINED__
#undef __SparkPoints_DISPINTERFACE_DEFINED__
#undef __Sparkline_DISPINTERFACE_DEFINED__
#undef __SparkAxes_DISPINTERFACE_DEFINED__
#undef __SparkHorizontalAxis_DISPINTERFACE_DEFINED__
#undef __SparkVerticalAxis_DISPINTERFACE_DEFINED__
#undef __SparkColor_DISPINTERFACE_DEFINED__
#undef __DataBarBorder_DISPINTERFACE_DEFINED__
#undef __NegativeBarFormat_DISPINTERFACE_DEFINED__
#undef __ValueChange_DISPINTERFACE_DEFINED__
#undef __PivotTableChangeList_DISPINTERFACE_DEFINED__
#undef __DisplayFormat_DISPINTERFACE_DEFINED__
#undef __SlicerCaches_DISPINTERFACE_DEFINED__
#undef __SlicerCache_DISPINTERFACE_DEFINED__
#undef __SlicerCacheLevels_DISPINTERFACE_DEFINED__
#undef __SlicerCacheLevel_DISPINTERFACE_DEFINED__
#undef __Slicers_DISPINTERFACE_DEFINED__
#undef __Slicer_DISPINTERFACE_DEFINED__
#undef __SlicerItem_DISPINTERFACE_DEFINED__
#undef __SlicerItems_DISPINTERFACE_DEFINED__
#undef __SlicerPivotTables_DISPINTERFACE_DEFINED__
#undef __ProtectedViewWindows_DISPINTERFACE_DEFINED__
#undef __ProtectedViewWindow_DISPINTERFACE_DEFINED__
#undef __TableObject_DISPINTERFACE_DEFINED__
#undef __PivotValueCell_DISPINTERFACE_DEFINED__
#undef __QuickAnalysis_DISPINTERFACE_DEFINED__
#undef __ModelConnection_DISPINTERFACE_DEFINED__
#undef __WorksheetDataConnection_DISPINTERFACE_DEFINED__
#undef __TextConnection_DISPINTERFACE_DEFINED__
#undef __DataFeedConnection_DISPINTERFACE_DEFINED__
#undef __ModelTableColumn_DISPINTERFACE_DEFINED__
#undef __ModelTableColumns_DISPINTERFACE_DEFINED__
#undef __ModelTable_DISPINTERFACE_DEFINED__
#undef __ModelTables_DISPINTERFACE_DEFINED__
#undef __ModelRelationship_DISPINTERFACE_DEFINED__
#undef __ModelRelationships_DISPINTERFACE_DEFINED__
#undef __Model_DISPINTERFACE_DEFINED__
#undef __FullSeriesCollection_DISPINTERFACE_DEFINED__
#undef __ChartCategory_DISPINTERFACE_DEFINED__
#undef __CategoryCollection_DISPINTERFACE_DEFINED__
#undef __TimelineState_DISPINTERFACE_DEFINED__
#undef __TimelineViewState_DISPINTERFACE_DEFINED__
#undef __ModelTableNames_DISPINTERFACE_DEFINED__
#undef __ModelTableNameChange_DISPINTERFACE_DEFINED__
#undef __ModelTableNameChanges_DISPINTERFACE_DEFINED__
#undef __ModelChanges_DISPINTERFACE_DEFINED__
#undef __ModelColumnName_DISPINTERFACE_DEFINED__
#undef __ModelColumnNames_DISPINTERFACE_DEFINED__
#undef __ModelColumnChange_DISPINTERFACE_DEFINED__
#undef __ModelColumnChanges_DISPINTERFACE_DEFINED__
#undef __ModelMeasureName_DISPINTERFACE_DEFINED__
#undef __ModelMeasureNames_DISPINTERFACE_DEFINED__
#undef __IDummy_INTERFACE_DEFINED__
#undef __ICanvasShapes_INTERFACE_DEFINED__
#undef ___DebugTools_INTERFACE_DEFINED__
#undef __Solver_INTERFACE_DEFINED__
#undef __IEXCELCtrlExtender_INTERFACE_DEFINED__

// INCLUDE MSO ENUM
#undef __INCLUDE_MSO_ENUM_H__

#endif // __ETAPI_PREDEF_H__
