/*
** Copyright @ 2012-2019, Kingsoft office,All rights reserved.
**
** Redistribution and use in source and binary forms ,without modification and
** selling solely, are permitted provided that the following conditions are
** met:
**
** 1.Redistributions of source code must retain the above copyright notice,
**   this list of conditions and the following disclaimer.
** 2.Redistributions in binary form must reproduce the above copyright notice,
**	 this list of conditions and the following disclaimer in the documentation
**	 and/or other materials provided with the distribution.
** 3.Neither the name of the copyright holder nor the names of its contributors
**	 may be used to endorse or promote products derived from this software
**	 without specific prior written permission.
**
** SPECIAL NOTE:THIS SOFTWARE IS NOT PERMITTED TO BE MODIFIED OR SOLD SOLELY AT
** ANY TIME AND UNDER ANY CIRCUMSTANCES, EXCEPT WITH THE WRITTEN PERMISSION OF
** KINGSOFT OFFICE
**
** THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
** AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
** IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
** ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
** LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
** CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
** SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
** INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
** CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
** ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
** POSSIBILITY OF SUCH DAMAGE.
**/
#ifndef __REQUIRED_RPCNDR_H_VERSION__
#define __REQUIRED_RPCNDR_H_VERSION__ 475
#endif


#ifndef __etapi_h__
#define __etapi_h__


namespace etapi {



/* Forward Declarations */ 

#ifndef __Adjustments_FWD_DEFINED__
#define __Adjustments_FWD_DEFINED__
typedef interface Adjustments Adjustments;
#endif 	/* __Adjustments_FWD_DEFINED__ */


#ifndef __CalloutFormat_FWD_DEFINED__
#define __CalloutFormat_FWD_DEFINED__
typedef interface CalloutFormat CalloutFormat;
#endif 	/* __CalloutFormat_FWD_DEFINED__ */


#ifndef __ColorFormat_FWD_DEFINED__
#define __ColorFormat_FWD_DEFINED__
typedef interface ColorFormat ColorFormat;
#endif 	/* __ColorFormat_FWD_DEFINED__ */


#ifndef __LineFormat_FWD_DEFINED__
#define __LineFormat_FWD_DEFINED__
typedef interface LineFormat LineFormat;
#endif 	/* __LineFormat_FWD_DEFINED__ */


#ifndef __ShapeNode_FWD_DEFINED__
#define __ShapeNode_FWD_DEFINED__
typedef interface ShapeNode ShapeNode;
#endif 	/* __ShapeNode_FWD_DEFINED__ */


#ifndef __ShapeNodes_FWD_DEFINED__
#define __ShapeNodes_FWD_DEFINED__
typedef interface ShapeNodes ShapeNodes;
#endif 	/* __ShapeNodes_FWD_DEFINED__ */


#ifndef __PictureFormat_FWD_DEFINED__
#define __PictureFormat_FWD_DEFINED__
typedef interface PictureFormat PictureFormat;
#endif 	/* __PictureFormat_FWD_DEFINED__ */


#ifndef __ShadowFormat_FWD_DEFINED__
#define __ShadowFormat_FWD_DEFINED__
typedef interface ShadowFormat ShadowFormat;
#endif 	/* __ShadowFormat_FWD_DEFINED__ */


#ifndef __TextEffectFormat_FWD_DEFINED__
#define __TextEffectFormat_FWD_DEFINED__
typedef interface TextEffectFormat TextEffectFormat;
#endif 	/* __TextEffectFormat_FWD_DEFINED__ */


#ifndef __ThreeDFormat_FWD_DEFINED__
#define __ThreeDFormat_FWD_DEFINED__
typedef interface ThreeDFormat ThreeDFormat;
#endif 	/* __ThreeDFormat_FWD_DEFINED__ */


#ifndef __FillFormat_FWD_DEFINED__
#define __FillFormat_FWD_DEFINED__
typedef interface FillFormat FillFormat;
#endif 	/* __FillFormat_FWD_DEFINED__ */


#ifndef __DiagramNodes_FWD_DEFINED__
#define __DiagramNodes_FWD_DEFINED__
typedef interface DiagramNodes DiagramNodes;
#endif 	/* __DiagramNodes_FWD_DEFINED__ */


#ifndef __DiagramNodeChildren_FWD_DEFINED__
#define __DiagramNodeChildren_FWD_DEFINED__
typedef interface DiagramNodeChildren DiagramNodeChildren;
#endif 	/* __DiagramNodeChildren_FWD_DEFINED__ */


#ifndef __DiagramNode_FWD_DEFINED__
#define __DiagramNode_FWD_DEFINED__
typedef interface DiagramNode DiagramNode;
#endif 	/* __DiagramNode_FWD_DEFINED__ */


#ifndef __IRTDUpdateEvent_FWD_DEFINED__
#define __IRTDUpdateEvent_FWD_DEFINED__
typedef interface IRTDUpdateEvent IRTDUpdateEvent;
#endif 	/* __IRTDUpdateEvent_FWD_DEFINED__ */


#ifndef __IRtdServer_FWD_DEFINED__
#define __IRtdServer_FWD_DEFINED__
typedef interface IRtdServer IRtdServer;
#endif 	/* __IRtdServer_FWD_DEFINED__ */


#ifndef __TextFrame2_FWD_DEFINED__
#define __TextFrame2_FWD_DEFINED__
typedef interface TextFrame2 TextFrame2;
#endif 	/* __TextFrame2_FWD_DEFINED__ */


#ifndef __IFont_FWD_DEFINED__
#define __IFont_FWD_DEFINED__
typedef interface IFont IFont;
#endif 	/* __IFont_FWD_DEFINED__ */


#ifndef __IWindow_FWD_DEFINED__
#define __IWindow_FWD_DEFINED__
typedef interface IWindow IWindow;
#endif 	/* __IWindow_FWD_DEFINED__ */


#ifndef __IWindows_FWD_DEFINED__
#define __IWindows_FWD_DEFINED__
typedef interface IWindows IWindows;
#endif 	/* __IWindows_FWD_DEFINED__ */


#ifndef __IAppEvents_FWD_DEFINED__
#define __IAppEvents_FWD_DEFINED__
typedef interface IAppEvents IAppEvents;
#endif 	/* __IAppEvents_FWD_DEFINED__ */


#ifndef ___Application_FWD_DEFINED__
#define ___Application_FWD_DEFINED__
typedef interface _Application _Application;
#endif 	/* ___Application_FWD_DEFINED__ */


#ifndef __IWorksheetFunction_FWD_DEFINED__
#define __IWorksheetFunction_FWD_DEFINED__
typedef interface IWorksheetFunction IWorksheetFunction;
#endif 	/* __IWorksheetFunction_FWD_DEFINED__ */


#ifndef __IRange_FWD_DEFINED__
#define __IRange_FWD_DEFINED__
typedef interface IRange IRange;
#endif 	/* __IRange_FWD_DEFINED__ */


#ifndef __IChartEvents_FWD_DEFINED__
#define __IChartEvents_FWD_DEFINED__
typedef interface IChartEvents IChartEvents;
#endif 	/* __IChartEvents_FWD_DEFINED__ */


#ifndef ___Chart_FWD_DEFINED__
#define ___Chart_FWD_DEFINED__
typedef interface _Chart _Chart;
#endif 	/* ___Chart_FWD_DEFINED__ */


#ifndef __Sheets_FWD_DEFINED__
#define __Sheets_FWD_DEFINED__
typedef interface Sheets Sheets;
#endif 	/* __Sheets_FWD_DEFINED__ */


#ifndef __IVPageBreak_FWD_DEFINED__
#define __IVPageBreak_FWD_DEFINED__
typedef interface IVPageBreak IVPageBreak;
#endif 	/* __IVPageBreak_FWD_DEFINED__ */


#ifndef __IHPageBreak_FWD_DEFINED__
#define __IHPageBreak_FWD_DEFINED__
typedef interface IHPageBreak IHPageBreak;
#endif 	/* __IHPageBreak_FWD_DEFINED__ */


#ifndef __IHPageBreaks_FWD_DEFINED__
#define __IHPageBreaks_FWD_DEFINED__
typedef interface IHPageBreaks IHPageBreaks;
#endif 	/* __IHPageBreaks_FWD_DEFINED__ */


#ifndef __IVPageBreaks_FWD_DEFINED__
#define __IVPageBreaks_FWD_DEFINED__
typedef interface IVPageBreaks IVPageBreaks;
#endif 	/* __IVPageBreaks_FWD_DEFINED__ */


#ifndef __IRecentFile_FWD_DEFINED__
#define __IRecentFile_FWD_DEFINED__
typedef interface IRecentFile IRecentFile;
#endif 	/* __IRecentFile_FWD_DEFINED__ */


#ifndef __IRecentFiles_FWD_DEFINED__
#define __IRecentFiles_FWD_DEFINED__
typedef interface IRecentFiles IRecentFiles;
#endif 	/* __IRecentFiles_FWD_DEFINED__ */


#ifndef __IDocEvents_FWD_DEFINED__
#define __IDocEvents_FWD_DEFINED__
typedef interface IDocEvents IDocEvents;
#endif 	/* __IDocEvents_FWD_DEFINED__ */


#ifndef ___Worksheet_FWD_DEFINED__
#define ___Worksheet_FWD_DEFINED__
typedef interface _Worksheet _Worksheet;
#endif 	/* ___Worksheet_FWD_DEFINED__ */


#ifndef __IStyle_FWD_DEFINED__
#define __IStyle_FWD_DEFINED__
typedef interface IStyle IStyle;
#endif 	/* __IStyle_FWD_DEFINED__ */


#ifndef __IStyles_FWD_DEFINED__
#define __IStyles_FWD_DEFINED__
typedef interface IStyles IStyles;
#endif 	/* __IStyles_FWD_DEFINED__ */


#ifndef __IBorders_FWD_DEFINED__
#define __IBorders_FWD_DEFINED__
typedef interface IBorders IBorders;
#endif 	/* __IBorders_FWD_DEFINED__ */


#ifndef ___Global_FWD_DEFINED__
#define ___Global_FWD_DEFINED__
typedef interface _Global _Global;
#endif 	/* ___Global_FWD_DEFINED__ */


#ifndef __IAddIn_FWD_DEFINED__
#define __IAddIn_FWD_DEFINED__
typedef interface IAddIn IAddIn;
#endif 	/* __IAddIn_FWD_DEFINED__ */


#ifndef __IAddIns_FWD_DEFINED__
#define __IAddIns_FWD_DEFINED__
typedef interface IAddIns IAddIns;
#endif 	/* __IAddIns_FWD_DEFINED__ */


#ifndef __IToolbar_FWD_DEFINED__
#define __IToolbar_FWD_DEFINED__
typedef interface IToolbar IToolbar;
#endif 	/* __IToolbar_FWD_DEFINED__ */


#ifndef __IToolbars_FWD_DEFINED__
#define __IToolbars_FWD_DEFINED__
typedef interface IToolbars IToolbars;
#endif 	/* __IToolbars_FWD_DEFINED__ */


#ifndef __IToolbarButton_FWD_DEFINED__
#define __IToolbarButton_FWD_DEFINED__
typedef interface IToolbarButton IToolbarButton;
#endif 	/* __IToolbarButton_FWD_DEFINED__ */


#ifndef __IToolbarButtons_FWD_DEFINED__
#define __IToolbarButtons_FWD_DEFINED__
typedef interface IToolbarButtons IToolbarButtons;
#endif 	/* __IToolbarButtons_FWD_DEFINED__ */


#ifndef __IAreas_FWD_DEFINED__
#define __IAreas_FWD_DEFINED__
typedef interface IAreas IAreas;
#endif 	/* __IAreas_FWD_DEFINED__ */


#ifndef __IWorkbookEvents_FWD_DEFINED__
#define __IWorkbookEvents_FWD_DEFINED__
typedef interface IWorkbookEvents IWorkbookEvents;
#endif 	/* __IWorkbookEvents_FWD_DEFINED__ */


#ifndef ___Workbook_FWD_DEFINED__
#define ___Workbook_FWD_DEFINED__
typedef interface _Workbook _Workbook;
#endif 	/* ___Workbook_FWD_DEFINED__ */


#ifndef __Workbooks_FWD_DEFINED__
#define __Workbooks_FWD_DEFINED__
typedef interface Workbooks Workbooks;
#endif 	/* __Workbooks_FWD_DEFINED__ */


#ifndef __IMenuBars_FWD_DEFINED__
#define __IMenuBars_FWD_DEFINED__
typedef interface IMenuBars IMenuBars;
#endif 	/* __IMenuBars_FWD_DEFINED__ */


#ifndef __IMenuBar_FWD_DEFINED__
#define __IMenuBar_FWD_DEFINED__
typedef interface IMenuBar IMenuBar;
#endif 	/* __IMenuBar_FWD_DEFINED__ */


#ifndef __IMenus_FWD_DEFINED__
#define __IMenus_FWD_DEFINED__
typedef interface IMenus IMenus;
#endif 	/* __IMenus_FWD_DEFINED__ */


#ifndef __IMenu_FWD_DEFINED__
#define __IMenu_FWD_DEFINED__
typedef interface IMenu IMenu;
#endif 	/* __IMenu_FWD_DEFINED__ */


#ifndef __IMenuItems_FWD_DEFINED__
#define __IMenuItems_FWD_DEFINED__
typedef interface IMenuItems IMenuItems;
#endif 	/* __IMenuItems_FWD_DEFINED__ */


#ifndef __IMenuItem_FWD_DEFINED__
#define __IMenuItem_FWD_DEFINED__
typedef interface IMenuItem IMenuItem;
#endif 	/* __IMenuItem_FWD_DEFINED__ */


#ifndef __ICharts_FWD_DEFINED__
#define __ICharts_FWD_DEFINED__
typedef interface ICharts ICharts;
#endif 	/* __ICharts_FWD_DEFINED__ */


#ifndef __IDrawingObjects_FWD_DEFINED__
#define __IDrawingObjects_FWD_DEFINED__
typedef interface IDrawingObjects IDrawingObjects;
#endif 	/* __IDrawingObjects_FWD_DEFINED__ */


#ifndef __IPivotCache_FWD_DEFINED__
#define __IPivotCache_FWD_DEFINED__
typedef interface IPivotCache IPivotCache;
#endif 	/* __IPivotCache_FWD_DEFINED__ */


#ifndef __IPivotCaches_FWD_DEFINED__
#define __IPivotCaches_FWD_DEFINED__
typedef interface IPivotCaches IPivotCaches;
#endif 	/* __IPivotCaches_FWD_DEFINED__ */


#ifndef __IPivotFormula_FWD_DEFINED__
#define __IPivotFormula_FWD_DEFINED__
typedef interface IPivotFormula IPivotFormula;
#endif 	/* __IPivotFormula_FWD_DEFINED__ */


#ifndef __IPivotFormulas_FWD_DEFINED__
#define __IPivotFormulas_FWD_DEFINED__
typedef interface IPivotFormulas IPivotFormulas;
#endif 	/* __IPivotFormulas_FWD_DEFINED__ */


#ifndef __IPivotTable_FWD_DEFINED__
#define __IPivotTable_FWD_DEFINED__
typedef interface IPivotTable IPivotTable;
#endif 	/* __IPivotTable_FWD_DEFINED__ */


#ifndef __IPivotTables_FWD_DEFINED__
#define __IPivotTables_FWD_DEFINED__
typedef interface IPivotTables IPivotTables;
#endif 	/* __IPivotTables_FWD_DEFINED__ */


#ifndef __IPivotField_FWD_DEFINED__
#define __IPivotField_FWD_DEFINED__
typedef interface IPivotField IPivotField;
#endif 	/* __IPivotField_FWD_DEFINED__ */


#ifndef __IPivotFields_FWD_DEFINED__
#define __IPivotFields_FWD_DEFINED__
typedef interface IPivotFields IPivotFields;
#endif 	/* __IPivotFields_FWD_DEFINED__ */


#ifndef __ICalculatedFields_FWD_DEFINED__
#define __ICalculatedFields_FWD_DEFINED__
typedef interface ICalculatedFields ICalculatedFields;
#endif 	/* __ICalculatedFields_FWD_DEFINED__ */


#ifndef __IPivotItem_FWD_DEFINED__
#define __IPivotItem_FWD_DEFINED__
typedef interface IPivotItem IPivotItem;
#endif 	/* __IPivotItem_FWD_DEFINED__ */


#ifndef __IPivotItems_FWD_DEFINED__
#define __IPivotItems_FWD_DEFINED__
typedef interface IPivotItems IPivotItems;
#endif 	/* __IPivotItems_FWD_DEFINED__ */


#ifndef __ICalculatedItems_FWD_DEFINED__
#define __ICalculatedItems_FWD_DEFINED__
typedef interface ICalculatedItems ICalculatedItems;
#endif 	/* __ICalculatedItems_FWD_DEFINED__ */


#ifndef __ICharacters_FWD_DEFINED__
#define __ICharacters_FWD_DEFINED__
typedef interface ICharacters ICharacters;
#endif 	/* __ICharacters_FWD_DEFINED__ */


#ifndef __IDialogs_FWD_DEFINED__
#define __IDialogs_FWD_DEFINED__
typedef interface IDialogs IDialogs;
#endif 	/* __IDialogs_FWD_DEFINED__ */


#ifndef __IDialog_FWD_DEFINED__
#define __IDialog_FWD_DEFINED__
typedef interface IDialog IDialog;
#endif 	/* __IDialog_FWD_DEFINED__ */


#ifndef __ISoundNote_FWD_DEFINED__
#define __ISoundNote_FWD_DEFINED__
typedef interface ISoundNote ISoundNote;
#endif 	/* __ISoundNote_FWD_DEFINED__ */


#ifndef __IButton_FWD_DEFINED__
#define __IButton_FWD_DEFINED__
typedef interface IButton IButton;
#endif 	/* __IButton_FWD_DEFINED__ */


#ifndef __IButtons_FWD_DEFINED__
#define __IButtons_FWD_DEFINED__
typedef interface IButtons IButtons;
#endif 	/* __IButtons_FWD_DEFINED__ */


#ifndef __ICheckBox_FWD_DEFINED__
#define __ICheckBox_FWD_DEFINED__
typedef interface ICheckBox ICheckBox;
#endif 	/* __ICheckBox_FWD_DEFINED__ */


#ifndef __ICheckBoxes_FWD_DEFINED__
#define __ICheckBoxes_FWD_DEFINED__
typedef interface ICheckBoxes ICheckBoxes;
#endif 	/* __ICheckBoxes_FWD_DEFINED__ */


#ifndef __IOptionButton_FWD_DEFINED__
#define __IOptionButton_FWD_DEFINED__
typedef interface IOptionButton IOptionButton;
#endif 	/* __IOptionButton_FWD_DEFINED__ */


#ifndef __IOptionButtons_FWD_DEFINED__
#define __IOptionButtons_FWD_DEFINED__
typedef interface IOptionButtons IOptionButtons;
#endif 	/* __IOptionButtons_FWD_DEFINED__ */


#ifndef __IEditBox_FWD_DEFINED__
#define __IEditBox_FWD_DEFINED__
typedef interface IEditBox IEditBox;
#endif 	/* __IEditBox_FWD_DEFINED__ */


#ifndef __IEditBoxes_FWD_DEFINED__
#define __IEditBoxes_FWD_DEFINED__
typedef interface IEditBoxes IEditBoxes;
#endif 	/* __IEditBoxes_FWD_DEFINED__ */


#ifndef __IScrollBar_FWD_DEFINED__
#define __IScrollBar_FWD_DEFINED__
typedef interface IScrollBar IScrollBar;
#endif 	/* __IScrollBar_FWD_DEFINED__ */


#ifndef __IScrollBars_FWD_DEFINED__
#define __IScrollBars_FWD_DEFINED__
typedef interface IScrollBars IScrollBars;
#endif 	/* __IScrollBars_FWD_DEFINED__ */


#ifndef __IListBox_FWD_DEFINED__
#define __IListBox_FWD_DEFINED__
typedef interface IListBox IListBox;
#endif 	/* __IListBox_FWD_DEFINED__ */


#ifndef __IListBoxes_FWD_DEFINED__
#define __IListBoxes_FWD_DEFINED__
typedef interface IListBoxes IListBoxes;
#endif 	/* __IListBoxes_FWD_DEFINED__ */


#ifndef __IGroupBox_FWD_DEFINED__
#define __IGroupBox_FWD_DEFINED__
typedef interface IGroupBox IGroupBox;
#endif 	/* __IGroupBox_FWD_DEFINED__ */


#ifndef __IGroupBoxes_FWD_DEFINED__
#define __IGroupBoxes_FWD_DEFINED__
typedef interface IGroupBoxes IGroupBoxes;
#endif 	/* __IGroupBoxes_FWD_DEFINED__ */


#ifndef __IDropDown_FWD_DEFINED__
#define __IDropDown_FWD_DEFINED__
typedef interface IDropDown IDropDown;
#endif 	/* __IDropDown_FWD_DEFINED__ */


#ifndef __IDropDowns_FWD_DEFINED__
#define __IDropDowns_FWD_DEFINED__
typedef interface IDropDowns IDropDowns;
#endif 	/* __IDropDowns_FWD_DEFINED__ */


#ifndef __ISpinner_FWD_DEFINED__
#define __ISpinner_FWD_DEFINED__
typedef interface ISpinner ISpinner;
#endif 	/* __ISpinner_FWD_DEFINED__ */


#ifndef __ISpinners_FWD_DEFINED__
#define __ISpinners_FWD_DEFINED__
typedef interface ISpinners ISpinners;
#endif 	/* __ISpinners_FWD_DEFINED__ */


#ifndef __IDialogFrame_FWD_DEFINED__
#define __IDialogFrame_FWD_DEFINED__
typedef interface IDialogFrame IDialogFrame;
#endif 	/* __IDialogFrame_FWD_DEFINED__ */


#ifndef __ILabel_FWD_DEFINED__
#define __ILabel_FWD_DEFINED__
typedef interface ILabel ILabel;
#endif 	/* __ILabel_FWD_DEFINED__ */


#ifndef __ILabels_FWD_DEFINED__
#define __ILabels_FWD_DEFINED__
typedef interface ILabels ILabels;
#endif 	/* __ILabels_FWD_DEFINED__ */


#ifndef __IPanes_FWD_DEFINED__
#define __IPanes_FWD_DEFINED__
typedef interface IPanes IPanes;
#endif 	/* __IPanes_FWD_DEFINED__ */


#ifndef __IPane_FWD_DEFINED__
#define __IPane_FWD_DEFINED__
typedef interface IPane IPane;
#endif 	/* __IPane_FWD_DEFINED__ */


#ifndef __IScenarios_FWD_DEFINED__
#define __IScenarios_FWD_DEFINED__
typedef interface IScenarios IScenarios;
#endif 	/* __IScenarios_FWD_DEFINED__ */


#ifndef __IScenario_FWD_DEFINED__
#define __IScenario_FWD_DEFINED__
typedef interface IScenario IScenario;
#endif 	/* __IScenario_FWD_DEFINED__ */


#ifndef __IGroupObject_FWD_DEFINED__
#define __IGroupObject_FWD_DEFINED__
typedef interface IGroupObject IGroupObject;
#endif 	/* __IGroupObject_FWD_DEFINED__ */


#ifndef __IGroupObjects_FWD_DEFINED__
#define __IGroupObjects_FWD_DEFINED__
typedef interface IGroupObjects IGroupObjects;
#endif 	/* __IGroupObjects_FWD_DEFINED__ */


#ifndef __ILine_FWD_DEFINED__
#define __ILine_FWD_DEFINED__
typedef interface ILine ILine;
#endif 	/* __ILine_FWD_DEFINED__ */


#ifndef __ILines_FWD_DEFINED__
#define __ILines_FWD_DEFINED__
typedef interface ILines ILines;
#endif 	/* __ILines_FWD_DEFINED__ */


#ifndef __IRectangle_FWD_DEFINED__
#define __IRectangle_FWD_DEFINED__
typedef interface IRectangle IRectangle;
#endif 	/* __IRectangle_FWD_DEFINED__ */


#ifndef __IRectangles_FWD_DEFINED__
#define __IRectangles_FWD_DEFINED__
typedef interface IRectangles IRectangles;
#endif 	/* __IRectangles_FWD_DEFINED__ */


#ifndef __IOval_FWD_DEFINED__
#define __IOval_FWD_DEFINED__
typedef interface IOval IOval;
#endif 	/* __IOval_FWD_DEFINED__ */


#ifndef __IOvals_FWD_DEFINED__
#define __IOvals_FWD_DEFINED__
typedef interface IOvals IOvals;
#endif 	/* __IOvals_FWD_DEFINED__ */


#ifndef __IArc_FWD_DEFINED__
#define __IArc_FWD_DEFINED__
typedef interface IArc IArc;
#endif 	/* __IArc_FWD_DEFINED__ */


#ifndef __IArcs_FWD_DEFINED__
#define __IArcs_FWD_DEFINED__
typedef interface IArcs IArcs;
#endif 	/* __IArcs_FWD_DEFINED__ */


#ifndef __IOLEObjectEvents_FWD_DEFINED__
#define __IOLEObjectEvents_FWD_DEFINED__
typedef interface IOLEObjectEvents IOLEObjectEvents;
#endif 	/* __IOLEObjectEvents_FWD_DEFINED__ */


#ifndef ___IOLEObject_FWD_DEFINED__
#define ___IOLEObject_FWD_DEFINED__
typedef interface _IOLEObject _IOLEObject;
#endif 	/* ___IOLEObject_FWD_DEFINED__ */


#ifndef __IOLEObjects_FWD_DEFINED__
#define __IOLEObjects_FWD_DEFINED__
typedef interface IOLEObjects IOLEObjects;
#endif 	/* __IOLEObjects_FWD_DEFINED__ */


#ifndef __ITextBox_FWD_DEFINED__
#define __ITextBox_FWD_DEFINED__
typedef interface ITextBox ITextBox;
#endif 	/* __ITextBox_FWD_DEFINED__ */


#ifndef __ITextBoxes_FWD_DEFINED__
#define __ITextBoxes_FWD_DEFINED__
typedef interface ITextBoxes ITextBoxes;
#endif 	/* __ITextBoxes_FWD_DEFINED__ */


#ifndef __IPicture_FWD_DEFINED__
#define __IPicture_FWD_DEFINED__
typedef interface IPicture IPicture;
#endif 	/* __IPicture_FWD_DEFINED__ */


#ifndef __IPictures_FWD_DEFINED__
#define __IPictures_FWD_DEFINED__
typedef interface IPictures IPictures;
#endif 	/* __IPictures_FWD_DEFINED__ */


#ifndef __IDrawing_FWD_DEFINED__
#define __IDrawing_FWD_DEFINED__
typedef interface IDrawing IDrawing;
#endif 	/* __IDrawing_FWD_DEFINED__ */


#ifndef __IDrawings_FWD_DEFINED__
#define __IDrawings_FWD_DEFINED__
typedef interface IDrawings IDrawings;
#endif 	/* __IDrawings_FWD_DEFINED__ */


#ifndef __IRoutingSlip_FWD_DEFINED__
#define __IRoutingSlip_FWD_DEFINED__
typedef interface IRoutingSlip IRoutingSlip;
#endif 	/* __IRoutingSlip_FWD_DEFINED__ */


#ifndef __IOutline_FWD_DEFINED__
#define __IOutline_FWD_DEFINED__
typedef interface IOutline IOutline;
#endif 	/* __IOutline_FWD_DEFINED__ */


#ifndef __IModule_FWD_DEFINED__
#define __IModule_FWD_DEFINED__
typedef interface IModule IModule;
#endif 	/* __IModule_FWD_DEFINED__ */


#ifndef __IModules_FWD_DEFINED__
#define __IModules_FWD_DEFINED__
typedef interface IModules IModules;
#endif 	/* __IModules_FWD_DEFINED__ */


#ifndef __IDialogSheet_FWD_DEFINED__
#define __IDialogSheet_FWD_DEFINED__
typedef interface IDialogSheet IDialogSheet;
#endif 	/* __IDialogSheet_FWD_DEFINED__ */


#ifndef __IDialogSheets_FWD_DEFINED__
#define __IDialogSheets_FWD_DEFINED__
typedef interface IDialogSheets IDialogSheets;
#endif 	/* __IDialogSheets_FWD_DEFINED__ */


#ifndef __IWorksheets_FWD_DEFINED__
#define __IWorksheets_FWD_DEFINED__
typedef interface IWorksheets IWorksheets;
#endif 	/* __IWorksheets_FWD_DEFINED__ */


#ifndef __IPageSetup_FWD_DEFINED__
#define __IPageSetup_FWD_DEFINED__
typedef interface IPageSetup IPageSetup;
#endif 	/* __IPageSetup_FWD_DEFINED__ */


#ifndef __INames_FWD_DEFINED__
#define __INames_FWD_DEFINED__
typedef interface INames INames;
#endif 	/* __INames_FWD_DEFINED__ */


#ifndef __IName_FWD_DEFINED__
#define __IName_FWD_DEFINED__
typedef interface IName IName;
#endif 	/* __IName_FWD_DEFINED__ */


#ifndef __IChartObject_FWD_DEFINED__
#define __IChartObject_FWD_DEFINED__
typedef interface IChartObject IChartObject;
#endif 	/* __IChartObject_FWD_DEFINED__ */


#ifndef __IChartObjects_FWD_DEFINED__
#define __IChartObjects_FWD_DEFINED__
typedef interface IChartObjects IChartObjects;
#endif 	/* __IChartObjects_FWD_DEFINED__ */


#ifndef __IMailer_FWD_DEFINED__
#define __IMailer_FWD_DEFINED__
typedef interface IMailer IMailer;
#endif 	/* __IMailer_FWD_DEFINED__ */


#ifndef __ICustomViews_FWD_DEFINED__
#define __ICustomViews_FWD_DEFINED__
typedef interface ICustomViews ICustomViews;
#endif 	/* __ICustomViews_FWD_DEFINED__ */


#ifndef __ICustomView_FWD_DEFINED__
#define __ICustomView_FWD_DEFINED__
typedef interface ICustomView ICustomView;
#endif 	/* __ICustomView_FWD_DEFINED__ */


#ifndef __IFormatConditions_FWD_DEFINED__
#define __IFormatConditions_FWD_DEFINED__
typedef interface IFormatConditions IFormatConditions;
#endif 	/* __IFormatConditions_FWD_DEFINED__ */


#ifndef __IFormatCondition_FWD_DEFINED__
#define __IFormatCondition_FWD_DEFINED__
typedef interface IFormatCondition IFormatCondition;
#endif 	/* __IFormatCondition_FWD_DEFINED__ */


#ifndef __IComments_FWD_DEFINED__
#define __IComments_FWD_DEFINED__
typedef interface IComments IComments;
#endif 	/* __IComments_FWD_DEFINED__ */


#ifndef __IComment_FWD_DEFINED__
#define __IComment_FWD_DEFINED__
typedef interface IComment IComment;
#endif 	/* __IComment_FWD_DEFINED__ */


#ifndef __IRefreshEvents_FWD_DEFINED__
#define __IRefreshEvents_FWD_DEFINED__
typedef interface IRefreshEvents IRefreshEvents;
#endif 	/* __IRefreshEvents_FWD_DEFINED__ */


#ifndef ___IQueryTable_FWD_DEFINED__
#define ___IQueryTable_FWD_DEFINED__
typedef interface _IQueryTable _IQueryTable;
#endif 	/* ___IQueryTable_FWD_DEFINED__ */


#ifndef __IQueryTables_FWD_DEFINED__
#define __IQueryTables_FWD_DEFINED__
typedef interface IQueryTables IQueryTables;
#endif 	/* __IQueryTables_FWD_DEFINED__ */


#ifndef __IParameter_FWD_DEFINED__
#define __IParameter_FWD_DEFINED__
typedef interface IParameter IParameter;
#endif 	/* __IParameter_FWD_DEFINED__ */


#ifndef __IParameters_FWD_DEFINED__
#define __IParameters_FWD_DEFINED__
typedef interface IParameters IParameters;
#endif 	/* __IParameters_FWD_DEFINED__ */


#ifndef __IODBCError_FWD_DEFINED__
#define __IODBCError_FWD_DEFINED__
typedef interface IODBCError IODBCError;
#endif 	/* __IODBCError_FWD_DEFINED__ */


#ifndef __IODBCErrors_FWD_DEFINED__
#define __IODBCErrors_FWD_DEFINED__
typedef interface IODBCErrors IODBCErrors;
#endif 	/* __IODBCErrors_FWD_DEFINED__ */


#ifndef __IValidation_FWD_DEFINED__
#define __IValidation_FWD_DEFINED__
typedef interface IValidation IValidation;
#endif 	/* __IValidation_FWD_DEFINED__ */


#ifndef __IHyperlinks_FWD_DEFINED__
#define __IHyperlinks_FWD_DEFINED__
typedef interface IHyperlinks IHyperlinks;
#endif 	/* __IHyperlinks_FWD_DEFINED__ */


#ifndef __IHyperlink_FWD_DEFINED__
#define __IHyperlink_FWD_DEFINED__
typedef interface IHyperlink IHyperlink;
#endif 	/* __IHyperlink_FWD_DEFINED__ */


#ifndef __IAutoFilter_FWD_DEFINED__
#define __IAutoFilter_FWD_DEFINED__
typedef interface IAutoFilter IAutoFilter;
#endif 	/* __IAutoFilter_FWD_DEFINED__ */


#ifndef __IFilters_FWD_DEFINED__
#define __IFilters_FWD_DEFINED__
typedef interface IFilters IFilters;
#endif 	/* __IFilters_FWD_DEFINED__ */


#ifndef __IFilter_FWD_DEFINED__
#define __IFilter_FWD_DEFINED__
typedef interface IFilter IFilter;
#endif 	/* __IFilter_FWD_DEFINED__ */


#ifndef __IAutoCorrect_FWD_DEFINED__
#define __IAutoCorrect_FWD_DEFINED__
typedef interface IAutoCorrect IAutoCorrect;
#endif 	/* __IAutoCorrect_FWD_DEFINED__ */


#ifndef __IBorder_FWD_DEFINED__
#define __IBorder_FWD_DEFINED__
typedef interface IBorder IBorder;
#endif 	/* __IBorder_FWD_DEFINED__ */


#ifndef __IInterior_FWD_DEFINED__
#define __IInterior_FWD_DEFINED__
typedef interface IInterior IInterior;
#endif 	/* __IInterior_FWD_DEFINED__ */


#ifndef __IChartFillFormat_FWD_DEFINED__
#define __IChartFillFormat_FWD_DEFINED__
typedef interface IChartFillFormat IChartFillFormat;
#endif 	/* __IChartFillFormat_FWD_DEFINED__ */


#ifndef __IChartColorFormat_FWD_DEFINED__
#define __IChartColorFormat_FWD_DEFINED__
typedef interface IChartColorFormat IChartColorFormat;
#endif 	/* __IChartColorFormat_FWD_DEFINED__ */


#ifndef __IAxis_FWD_DEFINED__
#define __IAxis_FWD_DEFINED__
typedef interface IAxis IAxis;
#endif 	/* __IAxis_FWD_DEFINED__ */


#ifndef __IChartTitle_FWD_DEFINED__
#define __IChartTitle_FWD_DEFINED__
typedef interface IChartTitle IChartTitle;
#endif 	/* __IChartTitle_FWD_DEFINED__ */


#ifndef __IAxisTitle_FWD_DEFINED__
#define __IAxisTitle_FWD_DEFINED__
typedef interface IAxisTitle IAxisTitle;
#endif 	/* __IAxisTitle_FWD_DEFINED__ */


#ifndef __IChartGroup_FWD_DEFINED__
#define __IChartGroup_FWD_DEFINED__
typedef interface IChartGroup IChartGroup;
#endif 	/* __IChartGroup_FWD_DEFINED__ */


#ifndef __IChartGroups_FWD_DEFINED__
#define __IChartGroups_FWD_DEFINED__
typedef interface IChartGroups IChartGroups;
#endif 	/* __IChartGroups_FWD_DEFINED__ */


#ifndef __IAxes_FWD_DEFINED__
#define __IAxes_FWD_DEFINED__
typedef interface IAxes IAxes;
#endif 	/* __IAxes_FWD_DEFINED__ */


#ifndef __IPoints_FWD_DEFINED__
#define __IPoints_FWD_DEFINED__
typedef interface IPoints IPoints;
#endif 	/* __IPoints_FWD_DEFINED__ */


#ifndef __IPoint_FWD_DEFINED__
#define __IPoint_FWD_DEFINED__
typedef interface IPoint IPoint;
#endif 	/* __IPoint_FWD_DEFINED__ */


#ifndef __ISeries_FWD_DEFINED__
#define __ISeries_FWD_DEFINED__
typedef interface ISeries ISeries;
#endif 	/* __ISeries_FWD_DEFINED__ */


#ifndef __ISeriesCollection_FWD_DEFINED__
#define __ISeriesCollection_FWD_DEFINED__
typedef interface ISeriesCollection ISeriesCollection;
#endif 	/* __ISeriesCollection_FWD_DEFINED__ */


#ifndef __IDataLabel_FWD_DEFINED__
#define __IDataLabel_FWD_DEFINED__
typedef interface IDataLabel IDataLabel;
#endif 	/* __IDataLabel_FWD_DEFINED__ */


#ifndef __IDataLabels_FWD_DEFINED__
#define __IDataLabels_FWD_DEFINED__
typedef interface IDataLabels IDataLabels;
#endif 	/* __IDataLabels_FWD_DEFINED__ */


#ifndef __ILegendEntry_FWD_DEFINED__
#define __ILegendEntry_FWD_DEFINED__
typedef interface ILegendEntry ILegendEntry;
#endif 	/* __ILegendEntry_FWD_DEFINED__ */


#ifndef __ILegendEntries_FWD_DEFINED__
#define __ILegendEntries_FWD_DEFINED__
typedef interface ILegendEntries ILegendEntries;
#endif 	/* __ILegendEntries_FWD_DEFINED__ */


#ifndef __ILegendKey_FWD_DEFINED__
#define __ILegendKey_FWD_DEFINED__
typedef interface ILegendKey ILegendKey;
#endif 	/* __ILegendKey_FWD_DEFINED__ */


#ifndef __ITrendlines_FWD_DEFINED__
#define __ITrendlines_FWD_DEFINED__
typedef interface ITrendlines ITrendlines;
#endif 	/* __ITrendlines_FWD_DEFINED__ */


#ifndef __ITrendline_FWD_DEFINED__
#define __ITrendline_FWD_DEFINED__
typedef interface ITrendline ITrendline;
#endif 	/* __ITrendline_FWD_DEFINED__ */


#ifndef __ICorners_FWD_DEFINED__
#define __ICorners_FWD_DEFINED__
typedef interface ICorners ICorners;
#endif 	/* __ICorners_FWD_DEFINED__ */


#ifndef __ISeriesLines_FWD_DEFINED__
#define __ISeriesLines_FWD_DEFINED__
typedef interface ISeriesLines ISeriesLines;
#endif 	/* __ISeriesLines_FWD_DEFINED__ */


#ifndef __IHiLoLines_FWD_DEFINED__
#define __IHiLoLines_FWD_DEFINED__
typedef interface IHiLoLines IHiLoLines;
#endif 	/* __IHiLoLines_FWD_DEFINED__ */


#ifndef __IGridlines_FWD_DEFINED__
#define __IGridlines_FWD_DEFINED__
typedef interface IGridlines IGridlines;
#endif 	/* __IGridlines_FWD_DEFINED__ */


#ifndef __IDropLines_FWD_DEFINED__
#define __IDropLines_FWD_DEFINED__
typedef interface IDropLines IDropLines;
#endif 	/* __IDropLines_FWD_DEFINED__ */


#ifndef __ILeaderLines_FWD_DEFINED__
#define __ILeaderLines_FWD_DEFINED__
typedef interface ILeaderLines ILeaderLines;
#endif 	/* __ILeaderLines_FWD_DEFINED__ */


#ifndef __IUpBars_FWD_DEFINED__
#define __IUpBars_FWD_DEFINED__
typedef interface IUpBars IUpBars;
#endif 	/* __IUpBars_FWD_DEFINED__ */


#ifndef __IDownBars_FWD_DEFINED__
#define __IDownBars_FWD_DEFINED__
typedef interface IDownBars IDownBars;
#endif 	/* __IDownBars_FWD_DEFINED__ */


#ifndef __IFloor_FWD_DEFINED__
#define __IFloor_FWD_DEFINED__
typedef interface IFloor IFloor;
#endif 	/* __IFloor_FWD_DEFINED__ */


#ifndef __IWalls_FWD_DEFINED__
#define __IWalls_FWD_DEFINED__
typedef interface IWalls IWalls;
#endif 	/* __IWalls_FWD_DEFINED__ */


#ifndef __ITickLabels_FWD_DEFINED__
#define __ITickLabels_FWD_DEFINED__
typedef interface ITickLabels ITickLabels;
#endif 	/* __ITickLabels_FWD_DEFINED__ */


#ifndef __IPlotArea_FWD_DEFINED__
#define __IPlotArea_FWD_DEFINED__
typedef interface IPlotArea IPlotArea;
#endif 	/* __IPlotArea_FWD_DEFINED__ */


#ifndef __IChartArea_FWD_DEFINED__
#define __IChartArea_FWD_DEFINED__
typedef interface IChartArea IChartArea;
#endif 	/* __IChartArea_FWD_DEFINED__ */


#ifndef __ILegend_FWD_DEFINED__
#define __ILegend_FWD_DEFINED__
typedef interface ILegend ILegend;
#endif 	/* __ILegend_FWD_DEFINED__ */


#ifndef __IErrorBars_FWD_DEFINED__
#define __IErrorBars_FWD_DEFINED__
typedef interface IErrorBars IErrorBars;
#endif 	/* __IErrorBars_FWD_DEFINED__ */


#ifndef __IDataTable_FWD_DEFINED__
#define __IDataTable_FWD_DEFINED__
typedef interface IDataTable IDataTable;
#endif 	/* __IDataTable_FWD_DEFINED__ */


#ifndef __IPhonetic_FWD_DEFINED__
#define __IPhonetic_FWD_DEFINED__
typedef interface IPhonetic IPhonetic;
#endif 	/* __IPhonetic_FWD_DEFINED__ */


#ifndef __IShape_FWD_DEFINED__
#define __IShape_FWD_DEFINED__
typedef interface IShape IShape;
#endif 	/* __IShape_FWD_DEFINED__ */


#ifndef __IShapes_FWD_DEFINED__
#define __IShapes_FWD_DEFINED__
typedef interface IShapes IShapes;
#endif 	/* __IShapes_FWD_DEFINED__ */


#ifndef __IShapeRange_FWD_DEFINED__
#define __IShapeRange_FWD_DEFINED__
typedef interface IShapeRange IShapeRange;
#endif 	/* __IShapeRange_FWD_DEFINED__ */


#ifndef __IGroupShapes_FWD_DEFINED__
#define __IGroupShapes_FWD_DEFINED__
typedef interface IGroupShapes IGroupShapes;
#endif 	/* __IGroupShapes_FWD_DEFINED__ */


#ifndef __ITextFrame_FWD_DEFINED__
#define __ITextFrame_FWD_DEFINED__
typedef interface ITextFrame ITextFrame;
#endif 	/* __ITextFrame_FWD_DEFINED__ */


#ifndef __IConnectorFormat_FWD_DEFINED__
#define __IConnectorFormat_FWD_DEFINED__
typedef interface IConnectorFormat IConnectorFormat;
#endif 	/* __IConnectorFormat_FWD_DEFINED__ */


#ifndef __IFreeformBuilder_FWD_DEFINED__
#define __IFreeformBuilder_FWD_DEFINED__
typedef interface IFreeformBuilder IFreeformBuilder;
#endif 	/* __IFreeformBuilder_FWD_DEFINED__ */


#ifndef __IControlFormat_FWD_DEFINED__
#define __IControlFormat_FWD_DEFINED__
typedef interface IControlFormat IControlFormat;
#endif 	/* __IControlFormat_FWD_DEFINED__ */


#ifndef __IOLEFormat_FWD_DEFINED__
#define __IOLEFormat_FWD_DEFINED__
typedef interface IOLEFormat IOLEFormat;
#endif 	/* __IOLEFormat_FWD_DEFINED__ */


#ifndef __ILinkFormat_FWD_DEFINED__
#define __ILinkFormat_FWD_DEFINED__
typedef interface ILinkFormat ILinkFormat;
#endif 	/* __ILinkFormat_FWD_DEFINED__ */


#ifndef __IPublishObjects_FWD_DEFINED__
#define __IPublishObjects_FWD_DEFINED__
typedef interface IPublishObjects IPublishObjects;
#endif 	/* __IPublishObjects_FWD_DEFINED__ */


#ifndef __PublishObject_FWD_DEFINED__
#define __PublishObject_FWD_DEFINED__
typedef interface PublishObject PublishObject;
#endif 	/* __PublishObject_FWD_DEFINED__ */


#ifndef __IOLEDBError_FWD_DEFINED__
#define __IOLEDBError_FWD_DEFINED__
typedef interface IOLEDBError IOLEDBError;
#endif 	/* __IOLEDBError_FWD_DEFINED__ */


#ifndef __IOLEDBErrors_FWD_DEFINED__
#define __IOLEDBErrors_FWD_DEFINED__
typedef interface IOLEDBErrors IOLEDBErrors;
#endif 	/* __IOLEDBErrors_FWD_DEFINED__ */


#ifndef __IPhonetics_FWD_DEFINED__
#define __IPhonetics_FWD_DEFINED__
typedef interface IPhonetics IPhonetics;
#endif 	/* __IPhonetics_FWD_DEFINED__ */


#ifndef __DefaultWebOptions_FWD_DEFINED__
#define __DefaultWebOptions_FWD_DEFINED__
typedef interface DefaultWebOptions DefaultWebOptions;
#endif 	/* __DefaultWebOptions_FWD_DEFINED__ */


#ifndef __WebOptions_FWD_DEFINED__
#define __WebOptions_FWD_DEFINED__
typedef interface WebOptions WebOptions;
#endif 	/* __WebOptions_FWD_DEFINED__ */


#ifndef __IPivotLayout_FWD_DEFINED__
#define __IPivotLayout_FWD_DEFINED__
typedef interface IPivotLayout IPivotLayout;
#endif 	/* __IPivotLayout_FWD_DEFINED__ */


#ifndef __TreeviewControl_FWD_DEFINED__
#define __TreeviewControl_FWD_DEFINED__
typedef interface TreeviewControl TreeviewControl;
#endif 	/* __TreeviewControl_FWD_DEFINED__ */


#ifndef __CubeField_FWD_DEFINED__
#define __CubeField_FWD_DEFINED__
typedef interface CubeField CubeField;
#endif 	/* __CubeField_FWD_DEFINED__ */


#ifndef __CubeFields_FWD_DEFINED__
#define __CubeFields_FWD_DEFINED__
typedef interface CubeFields CubeFields;
#endif 	/* __CubeFields_FWD_DEFINED__ */


#ifndef __IDisplayUnitLabel_FWD_DEFINED__
#define __IDisplayUnitLabel_FWD_DEFINED__
typedef interface IDisplayUnitLabel IDisplayUnitLabel;
#endif 	/* __IDisplayUnitLabel_FWD_DEFINED__ */


#ifndef __ICellFormat_FWD_DEFINED__
#define __ICellFormat_FWD_DEFINED__
typedef interface ICellFormat ICellFormat;
#endif 	/* __ICellFormat_FWD_DEFINED__ */


#ifndef __IUsedObjects_FWD_DEFINED__
#define __IUsedObjects_FWD_DEFINED__
typedef interface IUsedObjects IUsedObjects;
#endif 	/* __IUsedObjects_FWD_DEFINED__ */


#ifndef __ICustomProperties_FWD_DEFINED__
#define __ICustomProperties_FWD_DEFINED__
typedef interface ICustomProperties ICustomProperties;
#endif 	/* __ICustomProperties_FWD_DEFINED__ */


#ifndef __ICustomProperty_FWD_DEFINED__
#define __ICustomProperty_FWD_DEFINED__
typedef interface ICustomProperty ICustomProperty;
#endif 	/* __ICustomProperty_FWD_DEFINED__ */


#ifndef __ICalculatedMembers_FWD_DEFINED__
#define __ICalculatedMembers_FWD_DEFINED__
typedef interface ICalculatedMembers ICalculatedMembers;
#endif 	/* __ICalculatedMembers_FWD_DEFINED__ */


#ifndef __ICalculatedMember_FWD_DEFINED__
#define __ICalculatedMember_FWD_DEFINED__
typedef interface ICalculatedMember ICalculatedMember;
#endif 	/* __ICalculatedMember_FWD_DEFINED__ */


#ifndef __IWatches_FWD_DEFINED__
#define __IWatches_FWD_DEFINED__
typedef interface IWatches IWatches;
#endif 	/* __IWatches_FWD_DEFINED__ */


#ifndef __IWatch_FWD_DEFINED__
#define __IWatch_FWD_DEFINED__
typedef interface IWatch IWatch;
#endif 	/* __IWatch_FWD_DEFINED__ */


#ifndef __IPivotCell_FWD_DEFINED__
#define __IPivotCell_FWD_DEFINED__
typedef interface IPivotCell IPivotCell;
#endif 	/* __IPivotCell_FWD_DEFINED__ */


#ifndef __IGraphic_FWD_DEFINED__
#define __IGraphic_FWD_DEFINED__
typedef interface IGraphic IGraphic;
#endif 	/* __IGraphic_FWD_DEFINED__ */


#ifndef __IAutoRecover_FWD_DEFINED__
#define __IAutoRecover_FWD_DEFINED__
typedef interface IAutoRecover IAutoRecover;
#endif 	/* __IAutoRecover_FWD_DEFINED__ */


#ifndef __IErrorCheckingOptions_FWD_DEFINED__
#define __IErrorCheckingOptions_FWD_DEFINED__
typedef interface IErrorCheckingOptions IErrorCheckingOptions;
#endif 	/* __IErrorCheckingOptions_FWD_DEFINED__ */


#ifndef __IErrors_FWD_DEFINED__
#define __IErrors_FWD_DEFINED__
typedef interface IErrors IErrors;
#endif 	/* __IErrors_FWD_DEFINED__ */


#ifndef __IError_FWD_DEFINED__
#define __IError_FWD_DEFINED__
typedef interface IError IError;
#endif 	/* __IError_FWD_DEFINED__ */


#ifndef __ISmartTagAction_FWD_DEFINED__
#define __ISmartTagAction_FWD_DEFINED__
typedef interface ISmartTagAction ISmartTagAction;
#endif 	/* __ISmartTagAction_FWD_DEFINED__ */


#ifndef __ISmartTagActions_FWD_DEFINED__
#define __ISmartTagActions_FWD_DEFINED__
typedef interface ISmartTagActions ISmartTagActions;
#endif 	/* __ISmartTagActions_FWD_DEFINED__ */


#ifndef __ISmartTag_FWD_DEFINED__
#define __ISmartTag_FWD_DEFINED__
typedef interface ISmartTag ISmartTag;
#endif 	/* __ISmartTag_FWD_DEFINED__ */


#ifndef __ISmartTags_FWD_DEFINED__
#define __ISmartTags_FWD_DEFINED__
typedef interface ISmartTags ISmartTags;
#endif 	/* __ISmartTags_FWD_DEFINED__ */


#ifndef __ISmartTagRecognizer_FWD_DEFINED__
#define __ISmartTagRecognizer_FWD_DEFINED__
typedef interface ISmartTagRecognizer ISmartTagRecognizer;
#endif 	/* __ISmartTagRecognizer_FWD_DEFINED__ */


#ifndef __ISmartTagRecognizers_FWD_DEFINED__
#define __ISmartTagRecognizers_FWD_DEFINED__
typedef interface ISmartTagRecognizers ISmartTagRecognizers;
#endif 	/* __ISmartTagRecognizers_FWD_DEFINED__ */


#ifndef __ISmartTagOptions_FWD_DEFINED__
#define __ISmartTagOptions_FWD_DEFINED__
typedef interface ISmartTagOptions ISmartTagOptions;
#endif 	/* __ISmartTagOptions_FWD_DEFINED__ */


#ifndef __ISpellingOptions_FWD_DEFINED__
#define __ISpellingOptions_FWD_DEFINED__
typedef interface ISpellingOptions ISpellingOptions;
#endif 	/* __ISpellingOptions_FWD_DEFINED__ */


#ifndef __ISpeech_FWD_DEFINED__
#define __ISpeech_FWD_DEFINED__
typedef interface ISpeech ISpeech;
#endif 	/* __ISpeech_FWD_DEFINED__ */


#ifndef __IProtection_FWD_DEFINED__
#define __IProtection_FWD_DEFINED__
typedef interface IProtection IProtection;
#endif 	/* __IProtection_FWD_DEFINED__ */


#ifndef __IPivotItemList_FWD_DEFINED__
#define __IPivotItemList_FWD_DEFINED__
typedef interface IPivotItemList IPivotItemList;
#endif 	/* __IPivotItemList_FWD_DEFINED__ */


#ifndef __ITab_FWD_DEFINED__
#define __ITab_FWD_DEFINED__
typedef interface ITab ITab;
#endif 	/* __ITab_FWD_DEFINED__ */


#ifndef __IAllowEditRanges_FWD_DEFINED__
#define __IAllowEditRanges_FWD_DEFINED__
typedef interface IAllowEditRanges IAllowEditRanges;
#endif 	/* __IAllowEditRanges_FWD_DEFINED__ */


#ifndef __IAllowEditRange_FWD_DEFINED__
#define __IAllowEditRange_FWD_DEFINED__
typedef interface IAllowEditRange IAllowEditRange;
#endif 	/* __IAllowEditRange_FWD_DEFINED__ */


#ifndef __IUserAccessList_FWD_DEFINED__
#define __IUserAccessList_FWD_DEFINED__
typedef interface IUserAccessList IUserAccessList;
#endif 	/* __IUserAccessList_FWD_DEFINED__ */


#ifndef __IUserAccess_FWD_DEFINED__
#define __IUserAccess_FWD_DEFINED__
typedef interface IUserAccess IUserAccess;
#endif 	/* __IUserAccess_FWD_DEFINED__ */


#ifndef __IRTD_FWD_DEFINED__
#define __IRTD_FWD_DEFINED__
typedef interface IRTD IRTD;
#endif 	/* __IRTD_FWD_DEFINED__ */


#ifndef __IDiagram_FWD_DEFINED__
#define __IDiagram_FWD_DEFINED__
typedef interface IDiagram IDiagram;
#endif 	/* __IDiagram_FWD_DEFINED__ */


#ifndef __IListObjects_FWD_DEFINED__
#define __IListObjects_FWD_DEFINED__
typedef interface IListObjects IListObjects;
#endif 	/* __IListObjects_FWD_DEFINED__ */


#ifndef __IListObject_FWD_DEFINED__
#define __IListObject_FWD_DEFINED__
typedef interface IListObject IListObject;
#endif 	/* __IListObject_FWD_DEFINED__ */


#ifndef __IListColumns_FWD_DEFINED__
#define __IListColumns_FWD_DEFINED__
typedef interface IListColumns IListColumns;
#endif 	/* __IListColumns_FWD_DEFINED__ */


#ifndef __IListColumn_FWD_DEFINED__
#define __IListColumn_FWD_DEFINED__
typedef interface IListColumn IListColumn;
#endif 	/* __IListColumn_FWD_DEFINED__ */


#ifndef __IListRows_FWD_DEFINED__
#define __IListRows_FWD_DEFINED__
typedef interface IListRows IListRows;
#endif 	/* __IListRows_FWD_DEFINED__ */


#ifndef __IListRow_FWD_DEFINED__
#define __IListRow_FWD_DEFINED__
typedef interface IListRow IListRow;
#endif 	/* __IListRow_FWD_DEFINED__ */


#ifndef __IXmlNamespace_FWD_DEFINED__
#define __IXmlNamespace_FWD_DEFINED__
typedef interface IXmlNamespace IXmlNamespace;
#endif 	/* __IXmlNamespace_FWD_DEFINED__ */


#ifndef __IXmlNamespaces_FWD_DEFINED__
#define __IXmlNamespaces_FWD_DEFINED__
typedef interface IXmlNamespaces IXmlNamespaces;
#endif 	/* __IXmlNamespaces_FWD_DEFINED__ */


#ifndef __IXmlDataBinding_FWD_DEFINED__
#define __IXmlDataBinding_FWD_DEFINED__
typedef interface IXmlDataBinding IXmlDataBinding;
#endif 	/* __IXmlDataBinding_FWD_DEFINED__ */


#ifndef __IXmlSchema_FWD_DEFINED__
#define __IXmlSchema_FWD_DEFINED__
typedef interface IXmlSchema IXmlSchema;
#endif 	/* __IXmlSchema_FWD_DEFINED__ */


#ifndef __IXmlSchemas_FWD_DEFINED__
#define __IXmlSchemas_FWD_DEFINED__
typedef interface IXmlSchemas IXmlSchemas;
#endif 	/* __IXmlSchemas_FWD_DEFINED__ */


#ifndef __IXmlMap_FWD_DEFINED__
#define __IXmlMap_FWD_DEFINED__
typedef interface IXmlMap IXmlMap;
#endif 	/* __IXmlMap_FWD_DEFINED__ */


#ifndef __IXmlMaps_FWD_DEFINED__
#define __IXmlMaps_FWD_DEFINED__
typedef interface IXmlMaps IXmlMaps;
#endif 	/* __IXmlMaps_FWD_DEFINED__ */


#ifndef __IListDataFormat_FWD_DEFINED__
#define __IListDataFormat_FWD_DEFINED__
typedef interface IListDataFormat IListDataFormat;
#endif 	/* __IListDataFormat_FWD_DEFINED__ */


#ifndef __IXPath_FWD_DEFINED__
#define __IXPath_FWD_DEFINED__
typedef interface IXPath IXPath;
#endif 	/* __IXPath_FWD_DEFINED__ */


#ifndef __IPivotLineCells_FWD_DEFINED__
#define __IPivotLineCells_FWD_DEFINED__
typedef interface IPivotLineCells IPivotLineCells;
#endif 	/* __IPivotLineCells_FWD_DEFINED__ */


#ifndef __IPivotLine_FWD_DEFINED__
#define __IPivotLine_FWD_DEFINED__
typedef interface IPivotLine IPivotLine;
#endif 	/* __IPivotLine_FWD_DEFINED__ */


#ifndef __IPivotLines_FWD_DEFINED__
#define __IPivotLines_FWD_DEFINED__
typedef interface IPivotLines IPivotLines;
#endif 	/* __IPivotLines_FWD_DEFINED__ */


#ifndef __IPivotAxis_FWD_DEFINED__
#define __IPivotAxis_FWD_DEFINED__
typedef interface IPivotAxis IPivotAxis;
#endif 	/* __IPivotAxis_FWD_DEFINED__ */


#ifndef __IPivotFilter_FWD_DEFINED__
#define __IPivotFilter_FWD_DEFINED__
typedef interface IPivotFilter IPivotFilter;
#endif 	/* __IPivotFilter_FWD_DEFINED__ */


#ifndef __IPivotFilters_FWD_DEFINED__
#define __IPivotFilters_FWD_DEFINED__
typedef interface IPivotFilters IPivotFilters;
#endif 	/* __IPivotFilters_FWD_DEFINED__ */


#ifndef __IWorkbookConnection_FWD_DEFINED__
#define __IWorkbookConnection_FWD_DEFINED__
typedef interface IWorkbookConnection IWorkbookConnection;
#endif 	/* __IWorkbookConnection_FWD_DEFINED__ */


#ifndef __IConnections_FWD_DEFINED__
#define __IConnections_FWD_DEFINED__
typedef interface IConnections IConnections;
#endif 	/* __IConnections_FWD_DEFINED__ */


#ifndef __IWorksheetView_FWD_DEFINED__
#define __IWorksheetView_FWD_DEFINED__
typedef interface IWorksheetView IWorksheetView;
#endif 	/* __IWorksheetView_FWD_DEFINED__ */


#ifndef __IChartView_FWD_DEFINED__
#define __IChartView_FWD_DEFINED__
typedef interface IChartView IChartView;
#endif 	/* __IChartView_FWD_DEFINED__ */


#ifndef __IModuleView_FWD_DEFINED__
#define __IModuleView_FWD_DEFINED__
typedef interface IModuleView IModuleView;
#endif 	/* __IModuleView_FWD_DEFINED__ */


#ifndef __IDialogSheetView_FWD_DEFINED__
#define __IDialogSheetView_FWD_DEFINED__
typedef interface IDialogSheetView IDialogSheetView;
#endif 	/* __IDialogSheetView_FWD_DEFINED__ */


#ifndef __ISheetViews_FWD_DEFINED__
#define __ISheetViews_FWD_DEFINED__
typedef interface ISheetViews ISheetViews;
#endif 	/* __ISheetViews_FWD_DEFINED__ */


#ifndef __IOLEDBConnection_FWD_DEFINED__
#define __IOLEDBConnection_FWD_DEFINED__
typedef interface IOLEDBConnection IOLEDBConnection;
#endif 	/* __IOLEDBConnection_FWD_DEFINED__ */


#ifndef __IODBCConnection_FWD_DEFINED__
#define __IODBCConnection_FWD_DEFINED__
typedef interface IODBCConnection IODBCConnection;
#endif 	/* __IODBCConnection_FWD_DEFINED__ */


#ifndef __IAction_FWD_DEFINED__
#define __IAction_FWD_DEFINED__
typedef interface IAction IAction;
#endif 	/* __IAction_FWD_DEFINED__ */


#ifndef __IActions_FWD_DEFINED__
#define __IActions_FWD_DEFINED__
typedef interface IActions IActions;
#endif 	/* __IActions_FWD_DEFINED__ */


#ifndef __IFormatColor_FWD_DEFINED__
#define __IFormatColor_FWD_DEFINED__
typedef interface IFormatColor IFormatColor;
#endif 	/* __IFormatColor_FWD_DEFINED__ */


#ifndef __IConditionValue_FWD_DEFINED__
#define __IConditionValue_FWD_DEFINED__
typedef interface IConditionValue IConditionValue;
#endif 	/* __IConditionValue_FWD_DEFINED__ */


#ifndef __IColorScale_FWD_DEFINED__
#define __IColorScale_FWD_DEFINED__
typedef interface IColorScale IColorScale;
#endif 	/* __IColorScale_FWD_DEFINED__ */


#ifndef __IColorScaleCriteria_FWD_DEFINED__
#define __IColorScaleCriteria_FWD_DEFINED__
typedef interface IColorScaleCriteria IColorScaleCriteria;
#endif 	/* __IColorScaleCriteria_FWD_DEFINED__ */


#ifndef __IColorScaleCriterion_FWD_DEFINED__
#define __IColorScaleCriterion_FWD_DEFINED__
typedef interface IColorScaleCriterion IColorScaleCriterion;
#endif 	/* __IColorScaleCriterion_FWD_DEFINED__ */


#ifndef __IDatabar_FWD_DEFINED__
#define __IDatabar_FWD_DEFINED__
typedef interface IDatabar IDatabar;
#endif 	/* __IDatabar_FWD_DEFINED__ */


#ifndef __IIconSetCondition_FWD_DEFINED__
#define __IIconSetCondition_FWD_DEFINED__
typedef interface IIconSetCondition IIconSetCondition;
#endif 	/* __IIconSetCondition_FWD_DEFINED__ */


#ifndef __IIconCriteria_FWD_DEFINED__
#define __IIconCriteria_FWD_DEFINED__
typedef interface IIconCriteria IIconCriteria;
#endif 	/* __IIconCriteria_FWD_DEFINED__ */


#ifndef __IIconCriterion_FWD_DEFINED__
#define __IIconCriterion_FWD_DEFINED__
typedef interface IIconCriterion IIconCriterion;
#endif 	/* __IIconCriterion_FWD_DEFINED__ */


#ifndef __IIcon_FWD_DEFINED__
#define __IIcon_FWD_DEFINED__
typedef interface IIcon IIcon;
#endif 	/* __IIcon_FWD_DEFINED__ */


#ifndef __IIconSet_FWD_DEFINED__
#define __IIconSet_FWD_DEFINED__
typedef interface IIconSet IIconSet;
#endif 	/* __IIconSet_FWD_DEFINED__ */


#ifndef __IIconSets_FWD_DEFINED__
#define __IIconSets_FWD_DEFINED__
typedef interface IIconSets IIconSets;
#endif 	/* __IIconSets_FWD_DEFINED__ */


#ifndef __ITop10_FWD_DEFINED__
#define __ITop10_FWD_DEFINED__
typedef interface ITop10 ITop10;
#endif 	/* __ITop10_FWD_DEFINED__ */


#ifndef __IAboveAverage_FWD_DEFINED__
#define __IAboveAverage_FWD_DEFINED__
typedef interface IAboveAverage IAboveAverage;
#endif 	/* __IAboveAverage_FWD_DEFINED__ */


#ifndef __IUniqueValues_FWD_DEFINED__
#define __IUniqueValues_FWD_DEFINED__
typedef interface IUniqueValues IUniqueValues;
#endif 	/* __IUniqueValues_FWD_DEFINED__ */


#ifndef __IRanges_FWD_DEFINED__
#define __IRanges_FWD_DEFINED__
typedef interface IRanges IRanges;
#endif 	/* __IRanges_FWD_DEFINED__ */


#ifndef __IHeaderFooter_FWD_DEFINED__
#define __IHeaderFooter_FWD_DEFINED__
typedef interface IHeaderFooter IHeaderFooter;
#endif 	/* __IHeaderFooter_FWD_DEFINED__ */


#ifndef __IPage_FWD_DEFINED__
#define __IPage_FWD_DEFINED__
typedef interface IPage IPage;
#endif 	/* __IPage_FWD_DEFINED__ */


#ifndef __IPages_FWD_DEFINED__
#define __IPages_FWD_DEFINED__
typedef interface IPages IPages;
#endif 	/* __IPages_FWD_DEFINED__ */


#ifndef __IServerViewableItems_FWD_DEFINED__
#define __IServerViewableItems_FWD_DEFINED__
typedef interface IServerViewableItems IServerViewableItems;
#endif 	/* __IServerViewableItems_FWD_DEFINED__ */


#ifndef __ITableStyleElement_FWD_DEFINED__
#define __ITableStyleElement_FWD_DEFINED__
typedef interface ITableStyleElement ITableStyleElement;
#endif 	/* __ITableStyleElement_FWD_DEFINED__ */


#ifndef __ITableStyleElements_FWD_DEFINED__
#define __ITableStyleElements_FWD_DEFINED__
typedef interface ITableStyleElements ITableStyleElements;
#endif 	/* __ITableStyleElements_FWD_DEFINED__ */


#ifndef __ITableStyle_FWD_DEFINED__
#define __ITableStyle_FWD_DEFINED__
typedef interface ITableStyle ITableStyle;
#endif 	/* __ITableStyle_FWD_DEFINED__ */


#ifndef __ITableStyles_FWD_DEFINED__
#define __ITableStyles_FWD_DEFINED__
typedef interface ITableStyles ITableStyles;
#endif 	/* __ITableStyles_FWD_DEFINED__ */


#ifndef __ISortField_FWD_DEFINED__
#define __ISortField_FWD_DEFINED__
typedef interface ISortField ISortField;
#endif 	/* __ISortField_FWD_DEFINED__ */


#ifndef __ISortFields_FWD_DEFINED__
#define __ISortFields_FWD_DEFINED__
typedef interface ISortFields ISortFields;
#endif 	/* __ISortFields_FWD_DEFINED__ */


#ifndef __ISort_FWD_DEFINED__
#define __ISort_FWD_DEFINED__
typedef interface ISort ISort;
#endif 	/* __ISort_FWD_DEFINED__ */


#ifndef __IResearch_FWD_DEFINED__
#define __IResearch_FWD_DEFINED__
typedef interface IResearch IResearch;
#endif 	/* __IResearch_FWD_DEFINED__ */


#ifndef __IColorStop_FWD_DEFINED__
#define __IColorStop_FWD_DEFINED__
typedef interface IColorStop IColorStop;
#endif 	/* __IColorStop_FWD_DEFINED__ */


#ifndef __IColorStops_FWD_DEFINED__
#define __IColorStops_FWD_DEFINED__
typedef interface IColorStops IColorStops;
#endif 	/* __IColorStops_FWD_DEFINED__ */


#ifndef __ILinearGradient_FWD_DEFINED__
#define __ILinearGradient_FWD_DEFINED__
typedef interface ILinearGradient ILinearGradient;
#endif 	/* __ILinearGradient_FWD_DEFINED__ */


#ifndef __IRectangularGradient_FWD_DEFINED__
#define __IRectangularGradient_FWD_DEFINED__
typedef interface IRectangularGradient IRectangularGradient;
#endif 	/* __IRectangularGradient_FWD_DEFINED__ */


#ifndef __IMultiThreadedCalculation_FWD_DEFINED__
#define __IMultiThreadedCalculation_FWD_DEFINED__
typedef interface IMultiThreadedCalculation IMultiThreadedCalculation;
#endif 	/* __IMultiThreadedCalculation_FWD_DEFINED__ */


#ifndef __IChartFormat_FWD_DEFINED__
#define __IChartFormat_FWD_DEFINED__
typedef interface IChartFormat IChartFormat;
#endif 	/* __IChartFormat_FWD_DEFINED__ */


#ifndef __IFileExportConverter_FWD_DEFINED__
#define __IFileExportConverter_FWD_DEFINED__
typedef interface IFileExportConverter IFileExportConverter;
#endif 	/* __IFileExportConverter_FWD_DEFINED__ */


#ifndef __IFileExportConverters_FWD_DEFINED__
#define __IFileExportConverters_FWD_DEFINED__
typedef interface IFileExportConverters IFileExportConverters;
#endif 	/* __IFileExportConverters_FWD_DEFINED__ */


#ifndef __IAddIns2_FWD_DEFINED__
#define __IAddIns2_FWD_DEFINED__
typedef interface IAddIns2 IAddIns2;
#endif 	/* __IAddIns2_FWD_DEFINED__ */


#ifndef __ISparklineGroups_FWD_DEFINED__
#define __ISparklineGroups_FWD_DEFINED__
typedef interface ISparklineGroups ISparklineGroups;
#endif 	/* __ISparklineGroups_FWD_DEFINED__ */


#ifndef __ISparklineGroup_FWD_DEFINED__
#define __ISparklineGroup_FWD_DEFINED__
typedef interface ISparklineGroup ISparklineGroup;
#endif 	/* __ISparklineGroup_FWD_DEFINED__ */


#ifndef __ISparkPoints_FWD_DEFINED__
#define __ISparkPoints_FWD_DEFINED__
typedef interface ISparkPoints ISparkPoints;
#endif 	/* __ISparkPoints_FWD_DEFINED__ */


#ifndef __ISparkline_FWD_DEFINED__
#define __ISparkline_FWD_DEFINED__
typedef interface ISparkline ISparkline;
#endif 	/* __ISparkline_FWD_DEFINED__ */


#ifndef __ISparkAxes_FWD_DEFINED__
#define __ISparkAxes_FWD_DEFINED__
typedef interface ISparkAxes ISparkAxes;
#endif 	/* __ISparkAxes_FWD_DEFINED__ */


#ifndef __ISparkHorizontalAxis_FWD_DEFINED__
#define __ISparkHorizontalAxis_FWD_DEFINED__
typedef interface ISparkHorizontalAxis ISparkHorizontalAxis;
#endif 	/* __ISparkHorizontalAxis_FWD_DEFINED__ */


#ifndef __ISparkVerticalAxis_FWD_DEFINED__
#define __ISparkVerticalAxis_FWD_DEFINED__
typedef interface ISparkVerticalAxis ISparkVerticalAxis;
#endif 	/* __ISparkVerticalAxis_FWD_DEFINED__ */


#ifndef __ISparkColor_FWD_DEFINED__
#define __ISparkColor_FWD_DEFINED__
typedef interface ISparkColor ISparkColor;
#endif 	/* __ISparkColor_FWD_DEFINED__ */


#ifndef __IDataBarBorder_FWD_DEFINED__
#define __IDataBarBorder_FWD_DEFINED__
typedef interface IDataBarBorder IDataBarBorder;
#endif 	/* __IDataBarBorder_FWD_DEFINED__ */


#ifndef __INegativeBarFormat_FWD_DEFINED__
#define __INegativeBarFormat_FWD_DEFINED__
typedef interface INegativeBarFormat INegativeBarFormat;
#endif 	/* __INegativeBarFormat_FWD_DEFINED__ */


#ifndef __IValueChange_FWD_DEFINED__
#define __IValueChange_FWD_DEFINED__
typedef interface IValueChange IValueChange;
#endif 	/* __IValueChange_FWD_DEFINED__ */


#ifndef __IPivotTableChangeList_FWD_DEFINED__
#define __IPivotTableChangeList_FWD_DEFINED__
typedef interface IPivotTableChangeList IPivotTableChangeList;
#endif 	/* __IPivotTableChangeList_FWD_DEFINED__ */


#ifndef __IDisplayFormat_FWD_DEFINED__
#define __IDisplayFormat_FWD_DEFINED__
typedef interface IDisplayFormat IDisplayFormat;
#endif 	/* __IDisplayFormat_FWD_DEFINED__ */


#ifndef __ISlicerCaches_FWD_DEFINED__
#define __ISlicerCaches_FWD_DEFINED__
typedef interface ISlicerCaches ISlicerCaches;
#endif 	/* __ISlicerCaches_FWD_DEFINED__ */


#ifndef __ISlicerCache_FWD_DEFINED__
#define __ISlicerCache_FWD_DEFINED__
typedef interface ISlicerCache ISlicerCache;
#endif 	/* __ISlicerCache_FWD_DEFINED__ */


#ifndef __ISlicerCacheLevels_FWD_DEFINED__
#define __ISlicerCacheLevels_FWD_DEFINED__
typedef interface ISlicerCacheLevels ISlicerCacheLevels;
#endif 	/* __ISlicerCacheLevels_FWD_DEFINED__ */


#ifndef __ISlicerCacheLevel_FWD_DEFINED__
#define __ISlicerCacheLevel_FWD_DEFINED__
typedef interface ISlicerCacheLevel ISlicerCacheLevel;
#endif 	/* __ISlicerCacheLevel_FWD_DEFINED__ */


#ifndef __ISlicers_FWD_DEFINED__
#define __ISlicers_FWD_DEFINED__
typedef interface ISlicers ISlicers;
#endif 	/* __ISlicers_FWD_DEFINED__ */


#ifndef __ISlicer_FWD_DEFINED__
#define __ISlicer_FWD_DEFINED__
typedef interface ISlicer ISlicer;
#endif 	/* __ISlicer_FWD_DEFINED__ */


#ifndef __ISlicerItem_FWD_DEFINED__
#define __ISlicerItem_FWD_DEFINED__
typedef interface ISlicerItem ISlicerItem;
#endif 	/* __ISlicerItem_FWD_DEFINED__ */


#ifndef __ISlicerItems_FWD_DEFINED__
#define __ISlicerItems_FWD_DEFINED__
typedef interface ISlicerItems ISlicerItems;
#endif 	/* __ISlicerItems_FWD_DEFINED__ */


#ifndef __ISlicerPivotTables_FWD_DEFINED__
#define __ISlicerPivotTables_FWD_DEFINED__
typedef interface ISlicerPivotTables ISlicerPivotTables;
#endif 	/* __ISlicerPivotTables_FWD_DEFINED__ */


#ifndef __IProtectedViewWindows_FWD_DEFINED__
#define __IProtectedViewWindows_FWD_DEFINED__
typedef interface IProtectedViewWindows IProtectedViewWindows;
#endif 	/* __IProtectedViewWindows_FWD_DEFINED__ */


#ifndef __IProtectedViewWindow_FWD_DEFINED__
#define __IProtectedViewWindow_FWD_DEFINED__
typedef interface IProtectedViewWindow IProtectedViewWindow;
#endif 	/* __IProtectedViewWindow_FWD_DEFINED__ */


#ifndef __ITableObject_FWD_DEFINED__
#define __ITableObject_FWD_DEFINED__
typedef interface ITableObject ITableObject;
#endif 	/* __ITableObject_FWD_DEFINED__ */


#ifndef __IPivotValueCell_FWD_DEFINED__
#define __IPivotValueCell_FWD_DEFINED__
typedef interface IPivotValueCell IPivotValueCell;
#endif 	/* __IPivotValueCell_FWD_DEFINED__ */


#ifndef __IQuickAnalysis_FWD_DEFINED__
#define __IQuickAnalysis_FWD_DEFINED__
typedef interface IQuickAnalysis IQuickAnalysis;
#endif 	/* __IQuickAnalysis_FWD_DEFINED__ */


#ifndef __IModelConnection_FWD_DEFINED__
#define __IModelConnection_FWD_DEFINED__
typedef interface IModelConnection IModelConnection;
#endif 	/* __IModelConnection_FWD_DEFINED__ */


#ifndef __IWorksheetDataConnection_FWD_DEFINED__
#define __IWorksheetDataConnection_FWD_DEFINED__
typedef interface IWorksheetDataConnection IWorksheetDataConnection;
#endif 	/* __IWorksheetDataConnection_FWD_DEFINED__ */


#ifndef __ITextConnection_FWD_DEFINED__
#define __ITextConnection_FWD_DEFINED__
typedef interface ITextConnection ITextConnection;
#endif 	/* __ITextConnection_FWD_DEFINED__ */


#ifndef __IDataFeedConnection_FWD_DEFINED__
#define __IDataFeedConnection_FWD_DEFINED__
typedef interface IDataFeedConnection IDataFeedConnection;
#endif 	/* __IDataFeedConnection_FWD_DEFINED__ */


#ifndef __IModelTableColumn_FWD_DEFINED__
#define __IModelTableColumn_FWD_DEFINED__
typedef interface IModelTableColumn IModelTableColumn;
#endif 	/* __IModelTableColumn_FWD_DEFINED__ */


#ifndef __IModelTableColumns_FWD_DEFINED__
#define __IModelTableColumns_FWD_DEFINED__
typedef interface IModelTableColumns IModelTableColumns;
#endif 	/* __IModelTableColumns_FWD_DEFINED__ */


#ifndef __IModelTable_FWD_DEFINED__
#define __IModelTable_FWD_DEFINED__
typedef interface IModelTable IModelTable;
#endif 	/* __IModelTable_FWD_DEFINED__ */


#ifndef __IModelTables_FWD_DEFINED__
#define __IModelTables_FWD_DEFINED__
typedef interface IModelTables IModelTables;
#endif 	/* __IModelTables_FWD_DEFINED__ */


#ifndef __IModelRelationship_FWD_DEFINED__
#define __IModelRelationship_FWD_DEFINED__
typedef interface IModelRelationship IModelRelationship;
#endif 	/* __IModelRelationship_FWD_DEFINED__ */


#ifndef __IModelRelationships_FWD_DEFINED__
#define __IModelRelationships_FWD_DEFINED__
typedef interface IModelRelationships IModelRelationships;
#endif 	/* __IModelRelationships_FWD_DEFINED__ */


#ifndef __IModel_FWD_DEFINED__
#define __IModel_FWD_DEFINED__
typedef interface IModel IModel;
#endif 	/* __IModel_FWD_DEFINED__ */


#ifndef __IFullSeriesCollection_FWD_DEFINED__
#define __IFullSeriesCollection_FWD_DEFINED__
typedef interface IFullSeriesCollection IFullSeriesCollection;
#endif 	/* __IFullSeriesCollection_FWD_DEFINED__ */


#ifndef __IChartCategory_FWD_DEFINED__
#define __IChartCategory_FWD_DEFINED__
typedef interface IChartCategory IChartCategory;
#endif 	/* __IChartCategory_FWD_DEFINED__ */


#ifndef __ICategoryCollection_FWD_DEFINED__
#define __ICategoryCollection_FWD_DEFINED__
typedef interface ICategoryCollection ICategoryCollection;
#endif 	/* __ICategoryCollection_FWD_DEFINED__ */


#ifndef __ITimelineState_FWD_DEFINED__
#define __ITimelineState_FWD_DEFINED__
typedef interface ITimelineState ITimelineState;
#endif 	/* __ITimelineState_FWD_DEFINED__ */


#ifndef __ITimelineViewState_FWD_DEFINED__
#define __ITimelineViewState_FWD_DEFINED__
typedef interface ITimelineViewState ITimelineViewState;
#endif 	/* __ITimelineViewState_FWD_DEFINED__ */


#ifndef __IModelTableNames_FWD_DEFINED__
#define __IModelTableNames_FWD_DEFINED__
typedef interface IModelTableNames IModelTableNames;
#endif 	/* __IModelTableNames_FWD_DEFINED__ */


#ifndef __IModelTableNameChange_FWD_DEFINED__
#define __IModelTableNameChange_FWD_DEFINED__
typedef interface IModelTableNameChange IModelTableNameChange;
#endif 	/* __IModelTableNameChange_FWD_DEFINED__ */


#ifndef __IModelTableNameChanges_FWD_DEFINED__
#define __IModelTableNameChanges_FWD_DEFINED__
typedef interface IModelTableNameChanges IModelTableNameChanges;
#endif 	/* __IModelTableNameChanges_FWD_DEFINED__ */


#ifndef __IModelChanges_FWD_DEFINED__
#define __IModelChanges_FWD_DEFINED__
typedef interface IModelChanges IModelChanges;
#endif 	/* __IModelChanges_FWD_DEFINED__ */


#ifndef __IModelColumnName_FWD_DEFINED__
#define __IModelColumnName_FWD_DEFINED__
typedef interface IModelColumnName IModelColumnName;
#endif 	/* __IModelColumnName_FWD_DEFINED__ */


#ifndef __IModelColumnNames_FWD_DEFINED__
#define __IModelColumnNames_FWD_DEFINED__
typedef interface IModelColumnNames IModelColumnNames;
#endif 	/* __IModelColumnNames_FWD_DEFINED__ */


#ifndef __IModelColumnChange_FWD_DEFINED__
#define __IModelColumnChange_FWD_DEFINED__
typedef interface IModelColumnChange IModelColumnChange;
#endif 	/* __IModelColumnChange_FWD_DEFINED__ */


#ifndef __IModelColumnChanges_FWD_DEFINED__
#define __IModelColumnChanges_FWD_DEFINED__
typedef interface IModelColumnChanges IModelColumnChanges;
#endif 	/* __IModelColumnChanges_FWD_DEFINED__ */


#ifndef __IModelMeasureName_FWD_DEFINED__
#define __IModelMeasureName_FWD_DEFINED__
typedef interface IModelMeasureName IModelMeasureName;
#endif 	/* __IModelMeasureName_FWD_DEFINED__ */


#ifndef __IModelMeasureNames_FWD_DEFINED__
#define __IModelMeasureNames_FWD_DEFINED__
typedef interface IModelMeasureNames IModelMeasureNames;
#endif 	/* __IModelMeasureNames_FWD_DEFINED__ */


#ifndef __Font_FWD_DEFINED__
#define __Font_FWD_DEFINED__
typedef interface Font Font;
#endif 	/* __Font_FWD_DEFINED__ */


#ifndef __Window_FWD_DEFINED__
#define __Window_FWD_DEFINED__
typedef interface Window Window;
#endif 	/* __Window_FWD_DEFINED__ */


#ifndef __Windows_FWD_DEFINED__
#define __Windows_FWD_DEFINED__
typedef interface Windows Windows;
#endif 	/* __Windows_FWD_DEFINED__ */


#ifndef __AppEvents_FWD_DEFINED__
#define __AppEvents_FWD_DEFINED__
typedef interface AppEvents AppEvents;
#endif 	/* __AppEvents_FWD_DEFINED__ */


#ifndef __WorksheetFunction_FWD_DEFINED__
#define __WorksheetFunction_FWD_DEFINED__
typedef interface WorksheetFunction WorksheetFunction;
#endif 	/* __WorksheetFunction_FWD_DEFINED__ */


#ifndef __Range_FWD_DEFINED__
#define __Range_FWD_DEFINED__
typedef interface Range Range;
#endif 	/* __Range_FWD_DEFINED__ */


#ifndef __ChartEvents_FWD_DEFINED__
#define __ChartEvents_FWD_DEFINED__
typedef interface ChartEvents ChartEvents;
#endif 	/* __ChartEvents_FWD_DEFINED__ */


#ifndef __VPageBreak_FWD_DEFINED__
#define __VPageBreak_FWD_DEFINED__
typedef interface VPageBreak VPageBreak;
#endif 	/* __VPageBreak_FWD_DEFINED__ */


#ifndef __HPageBreak_FWD_DEFINED__
#define __HPageBreak_FWD_DEFINED__
typedef interface HPageBreak HPageBreak;
#endif 	/* __HPageBreak_FWD_DEFINED__ */


#ifndef __HPageBreaks_FWD_DEFINED__
#define __HPageBreaks_FWD_DEFINED__
typedef interface HPageBreaks HPageBreaks;
#endif 	/* __HPageBreaks_FWD_DEFINED__ */


#ifndef __VPageBreaks_FWD_DEFINED__
#define __VPageBreaks_FWD_DEFINED__
typedef interface VPageBreaks VPageBreaks;
#endif 	/* __VPageBreaks_FWD_DEFINED__ */


#ifndef __RecentFile_FWD_DEFINED__
#define __RecentFile_FWD_DEFINED__
typedef interface RecentFile RecentFile;
#endif 	/* __RecentFile_FWD_DEFINED__ */


#ifndef __RecentFiles_FWD_DEFINED__
#define __RecentFiles_FWD_DEFINED__
typedef interface RecentFiles RecentFiles;
#endif 	/* __RecentFiles_FWD_DEFINED__ */


#ifndef __DocEvents_FWD_DEFINED__
#define __DocEvents_FWD_DEFINED__
typedef interface DocEvents DocEvents;
#endif 	/* __DocEvents_FWD_DEFINED__ */


#ifndef __Style_FWD_DEFINED__
#define __Style_FWD_DEFINED__
typedef interface Style Style;
#endif 	/* __Style_FWD_DEFINED__ */


#ifndef __Styles_FWD_DEFINED__
#define __Styles_FWD_DEFINED__
typedef interface Styles Styles;
#endif 	/* __Styles_FWD_DEFINED__ */


#ifndef __Borders_FWD_DEFINED__
#define __Borders_FWD_DEFINED__
typedef interface Borders Borders;
#endif 	/* __Borders_FWD_DEFINED__ */


#ifndef __AddIn_FWD_DEFINED__
#define __AddIn_FWD_DEFINED__
typedef interface AddIn AddIn;
#endif 	/* __AddIn_FWD_DEFINED__ */


#ifndef __AddIns_FWD_DEFINED__
#define __AddIns_FWD_DEFINED__
typedef interface AddIns AddIns;
#endif 	/* __AddIns_FWD_DEFINED__ */


#ifndef __Toolbar_FWD_DEFINED__
#define __Toolbar_FWD_DEFINED__
typedef interface Toolbar Toolbar;
#endif 	/* __Toolbar_FWD_DEFINED__ */


#ifndef __Toolbars_FWD_DEFINED__
#define __Toolbars_FWD_DEFINED__
typedef interface Toolbars Toolbars;
#endif 	/* __Toolbars_FWD_DEFINED__ */


#ifndef __ToolbarButton_FWD_DEFINED__
#define __ToolbarButton_FWD_DEFINED__
typedef interface ToolbarButton ToolbarButton;
#endif 	/* __ToolbarButton_FWD_DEFINED__ */


#ifndef __ToolbarButtons_FWD_DEFINED__
#define __ToolbarButtons_FWD_DEFINED__
typedef interface ToolbarButtons ToolbarButtons;
#endif 	/* __ToolbarButtons_FWD_DEFINED__ */


#ifndef __Areas_FWD_DEFINED__
#define __Areas_FWD_DEFINED__
typedef interface Areas Areas;
#endif 	/* __Areas_FWD_DEFINED__ */


#ifndef __WorkbookEvents_FWD_DEFINED__
#define __WorkbookEvents_FWD_DEFINED__
typedef interface WorkbookEvents WorkbookEvents;
#endif 	/* __WorkbookEvents_FWD_DEFINED__ */


#ifndef __MenuBars_FWD_DEFINED__
#define __MenuBars_FWD_DEFINED__
typedef interface MenuBars MenuBars;
#endif 	/* __MenuBars_FWD_DEFINED__ */


#ifndef __MenuBar_FWD_DEFINED__
#define __MenuBar_FWD_DEFINED__
typedef interface MenuBar MenuBar;
#endif 	/* __MenuBar_FWD_DEFINED__ */


#ifndef __Menus_FWD_DEFINED__
#define __Menus_FWD_DEFINED__
typedef interface Menus Menus;
#endif 	/* __Menus_FWD_DEFINED__ */


#ifndef __Menu_FWD_DEFINED__
#define __Menu_FWD_DEFINED__
typedef interface Menu Menu;
#endif 	/* __Menu_FWD_DEFINED__ */


#ifndef __MenuItems_FWD_DEFINED__
#define __MenuItems_FWD_DEFINED__
typedef interface MenuItems MenuItems;
#endif 	/* __MenuItems_FWD_DEFINED__ */


#ifndef __MenuItem_FWD_DEFINED__
#define __MenuItem_FWD_DEFINED__
typedef interface MenuItem MenuItem;
#endif 	/* __MenuItem_FWD_DEFINED__ */


#ifndef __Charts_FWD_DEFINED__
#define __Charts_FWD_DEFINED__
typedef interface Charts Charts;
#endif 	/* __Charts_FWD_DEFINED__ */


#ifndef __DrawingObjects_FWD_DEFINED__
#define __DrawingObjects_FWD_DEFINED__
typedef interface DrawingObjects DrawingObjects;
#endif 	/* __DrawingObjects_FWD_DEFINED__ */


#ifndef __PivotCache_FWD_DEFINED__
#define __PivotCache_FWD_DEFINED__
typedef interface PivotCache PivotCache;
#endif 	/* __PivotCache_FWD_DEFINED__ */


#ifndef __PivotCaches_FWD_DEFINED__
#define __PivotCaches_FWD_DEFINED__
typedef interface PivotCaches PivotCaches;
#endif 	/* __PivotCaches_FWD_DEFINED__ */


#ifndef __PivotFormula_FWD_DEFINED__
#define __PivotFormula_FWD_DEFINED__
typedef interface PivotFormula PivotFormula;
#endif 	/* __PivotFormula_FWD_DEFINED__ */


#ifndef __PivotFormulas_FWD_DEFINED__
#define __PivotFormulas_FWD_DEFINED__
typedef interface PivotFormulas PivotFormulas;
#endif 	/* __PivotFormulas_FWD_DEFINED__ */


#ifndef __PivotTable_FWD_DEFINED__
#define __PivotTable_FWD_DEFINED__
typedef interface PivotTable PivotTable;
#endif 	/* __PivotTable_FWD_DEFINED__ */


#ifndef __PivotTables_FWD_DEFINED__
#define __PivotTables_FWD_DEFINED__
typedef interface PivotTables PivotTables;
#endif 	/* __PivotTables_FWD_DEFINED__ */


#ifndef __PivotField_FWD_DEFINED__
#define __PivotField_FWD_DEFINED__
typedef interface PivotField PivotField;
#endif 	/* __PivotField_FWD_DEFINED__ */


#ifndef __PivotFields_FWD_DEFINED__
#define __PivotFields_FWD_DEFINED__
typedef interface PivotFields PivotFields;
#endif 	/* __PivotFields_FWD_DEFINED__ */


#ifndef __CalculatedFields_FWD_DEFINED__
#define __CalculatedFields_FWD_DEFINED__
typedef interface CalculatedFields CalculatedFields;
#endif 	/* __CalculatedFields_FWD_DEFINED__ */


#ifndef __PivotItem_FWD_DEFINED__
#define __PivotItem_FWD_DEFINED__
typedef interface PivotItem PivotItem;
#endif 	/* __PivotItem_FWD_DEFINED__ */


#ifndef __PivotItems_FWD_DEFINED__
#define __PivotItems_FWD_DEFINED__
typedef interface PivotItems PivotItems;
#endif 	/* __PivotItems_FWD_DEFINED__ */


#ifndef __CalculatedItems_FWD_DEFINED__
#define __CalculatedItems_FWD_DEFINED__
typedef interface CalculatedItems CalculatedItems;
#endif 	/* __CalculatedItems_FWD_DEFINED__ */


#ifndef __Characters_FWD_DEFINED__
#define __Characters_FWD_DEFINED__
typedef interface Characters Characters;
#endif 	/* __Characters_FWD_DEFINED__ */


#ifndef __Dialogs_FWD_DEFINED__
#define __Dialogs_FWD_DEFINED__
typedef interface Dialogs Dialogs;
#endif 	/* __Dialogs_FWD_DEFINED__ */


#ifndef __Dialog_FWD_DEFINED__
#define __Dialog_FWD_DEFINED__
typedef interface Dialog Dialog;
#endif 	/* __Dialog_FWD_DEFINED__ */


#ifndef __SoundNote_FWD_DEFINED__
#define __SoundNote_FWD_DEFINED__
typedef interface SoundNote SoundNote;
#endif 	/* __SoundNote_FWD_DEFINED__ */


#ifndef __Button_FWD_DEFINED__
#define __Button_FWD_DEFINED__
typedef interface Button Button;
#endif 	/* __Button_FWD_DEFINED__ */


#ifndef __Buttons_FWD_DEFINED__
#define __Buttons_FWD_DEFINED__
typedef interface Buttons Buttons;
#endif 	/* __Buttons_FWD_DEFINED__ */


#ifndef __CheckBox_FWD_DEFINED__
#define __CheckBox_FWD_DEFINED__
typedef interface CheckBox CheckBox;
#endif 	/* __CheckBox_FWD_DEFINED__ */


#ifndef __CheckBoxes_FWD_DEFINED__
#define __CheckBoxes_FWD_DEFINED__
typedef interface CheckBoxes CheckBoxes;
#endif 	/* __CheckBoxes_FWD_DEFINED__ */


#ifndef __OptionButton_FWD_DEFINED__
#define __OptionButton_FWD_DEFINED__
typedef interface OptionButton OptionButton;
#endif 	/* __OptionButton_FWD_DEFINED__ */


#ifndef __OptionButtons_FWD_DEFINED__
#define __OptionButtons_FWD_DEFINED__
typedef interface OptionButtons OptionButtons;
#endif 	/* __OptionButtons_FWD_DEFINED__ */


#ifndef __EditBox_FWD_DEFINED__
#define __EditBox_FWD_DEFINED__
typedef interface EditBox EditBox;
#endif 	/* __EditBox_FWD_DEFINED__ */


#ifndef __EditBoxes_FWD_DEFINED__
#define __EditBoxes_FWD_DEFINED__
typedef interface EditBoxes EditBoxes;
#endif 	/* __EditBoxes_FWD_DEFINED__ */


#ifndef __ScrollBar_FWD_DEFINED__
#define __ScrollBar_FWD_DEFINED__
typedef interface ScrollBar ScrollBar;
#endif 	/* __ScrollBar_FWD_DEFINED__ */


#ifndef __ScrollBars_FWD_DEFINED__
#define __ScrollBars_FWD_DEFINED__
typedef interface ScrollBars ScrollBars;
#endif 	/* __ScrollBars_FWD_DEFINED__ */


#ifndef __ListBox_FWD_DEFINED__
#define __ListBox_FWD_DEFINED__
typedef interface ListBox ListBox;
#endif 	/* __ListBox_FWD_DEFINED__ */


#ifndef __ListBoxes_FWD_DEFINED__
#define __ListBoxes_FWD_DEFINED__
typedef interface ListBoxes ListBoxes;
#endif 	/* __ListBoxes_FWD_DEFINED__ */


#ifndef __GroupBox_FWD_DEFINED__
#define __GroupBox_FWD_DEFINED__
typedef interface GroupBox GroupBox;
#endif 	/* __GroupBox_FWD_DEFINED__ */


#ifndef __GroupBoxes_FWD_DEFINED__
#define __GroupBoxes_FWD_DEFINED__
typedef interface GroupBoxes GroupBoxes;
#endif 	/* __GroupBoxes_FWD_DEFINED__ */


#ifndef __DropDown_FWD_DEFINED__
#define __DropDown_FWD_DEFINED__
typedef interface DropDown DropDown;
#endif 	/* __DropDown_FWD_DEFINED__ */


#ifndef __DropDowns_FWD_DEFINED__
#define __DropDowns_FWD_DEFINED__
typedef interface DropDowns DropDowns;
#endif 	/* __DropDowns_FWD_DEFINED__ */


#ifndef __Spinner_FWD_DEFINED__
#define __Spinner_FWD_DEFINED__
typedef interface Spinner Spinner;
#endif 	/* __Spinner_FWD_DEFINED__ */


#ifndef __Spinners_FWD_DEFINED__
#define __Spinners_FWD_DEFINED__
typedef interface Spinners Spinners;
#endif 	/* __Spinners_FWD_DEFINED__ */


#ifndef __DialogFrame_FWD_DEFINED__
#define __DialogFrame_FWD_DEFINED__
typedef interface DialogFrame DialogFrame;
#endif 	/* __DialogFrame_FWD_DEFINED__ */


#ifndef __Label_FWD_DEFINED__
#define __Label_FWD_DEFINED__
typedef interface Label Label;
#endif 	/* __Label_FWD_DEFINED__ */


#ifndef __Labels_FWD_DEFINED__
#define __Labels_FWD_DEFINED__
typedef interface Labels Labels;
#endif 	/* __Labels_FWD_DEFINED__ */


#ifndef __Panes_FWD_DEFINED__
#define __Panes_FWD_DEFINED__
typedef interface Panes Panes;
#endif 	/* __Panes_FWD_DEFINED__ */


#ifndef __Pane_FWD_DEFINED__
#define __Pane_FWD_DEFINED__
typedef interface Pane Pane;
#endif 	/* __Pane_FWD_DEFINED__ */


#ifndef __Scenarios_FWD_DEFINED__
#define __Scenarios_FWD_DEFINED__
typedef interface Scenarios Scenarios;
#endif 	/* __Scenarios_FWD_DEFINED__ */


#ifndef __Scenario_FWD_DEFINED__
#define __Scenario_FWD_DEFINED__
typedef interface Scenario Scenario;
#endif 	/* __Scenario_FWD_DEFINED__ */


#ifndef __GroupObject_FWD_DEFINED__
#define __GroupObject_FWD_DEFINED__
typedef interface GroupObject GroupObject;
#endif 	/* __GroupObject_FWD_DEFINED__ */


#ifndef __GroupObjects_FWD_DEFINED__
#define __GroupObjects_FWD_DEFINED__
typedef interface GroupObjects GroupObjects;
#endif 	/* __GroupObjects_FWD_DEFINED__ */


#ifndef __Line_FWD_DEFINED__
#define __Line_FWD_DEFINED__
typedef interface Line Line;
#endif 	/* __Line_FWD_DEFINED__ */


#ifndef __Lines_FWD_DEFINED__
#define __Lines_FWD_DEFINED__
typedef interface Lines Lines;
#endif 	/* __Lines_FWD_DEFINED__ */


#ifndef __Rectangle_FWD_DEFINED__
#define __Rectangle_FWD_DEFINED__
typedef interface Rectangle Rectangle;
#endif 	/* __Rectangle_FWD_DEFINED__ */


#ifndef __Rectangles_FWD_DEFINED__
#define __Rectangles_FWD_DEFINED__
typedef interface Rectangles Rectangles;
#endif 	/* __Rectangles_FWD_DEFINED__ */


#ifndef __Oval_FWD_DEFINED__
#define __Oval_FWD_DEFINED__
typedef interface Oval Oval;
#endif 	/* __Oval_FWD_DEFINED__ */


#ifndef __Ovals_FWD_DEFINED__
#define __Ovals_FWD_DEFINED__
typedef interface Ovals Ovals;
#endif 	/* __Ovals_FWD_DEFINED__ */


#ifndef __Arc_FWD_DEFINED__
#define __Arc_FWD_DEFINED__
typedef interface Arc Arc;
#endif 	/* __Arc_FWD_DEFINED__ */


#ifndef __Arcs_FWD_DEFINED__
#define __Arcs_FWD_DEFINED__
typedef interface Arcs Arcs;
#endif 	/* __Arcs_FWD_DEFINED__ */


#ifndef __OLEObjectEvents_FWD_DEFINED__
#define __OLEObjectEvents_FWD_DEFINED__
typedef interface OLEObjectEvents OLEObjectEvents;
#endif 	/* __OLEObjectEvents_FWD_DEFINED__ */


#ifndef ___OLEObject_FWD_DEFINED__
#define ___OLEObject_FWD_DEFINED__
typedef interface _OLEObject _OLEObject;
#endif 	/* ___OLEObject_FWD_DEFINED__ */


#ifndef __OLEObjects_FWD_DEFINED__
#define __OLEObjects_FWD_DEFINED__
typedef interface OLEObjects OLEObjects;
#endif 	/* __OLEObjects_FWD_DEFINED__ */


#ifndef __TextBox_FWD_DEFINED__
#define __TextBox_FWD_DEFINED__
typedef interface TextBox TextBox;
#endif 	/* __TextBox_FWD_DEFINED__ */


#ifndef __TextBoxes_FWD_DEFINED__
#define __TextBoxes_FWD_DEFINED__
typedef interface TextBoxes TextBoxes;
#endif 	/* __TextBoxes_FWD_DEFINED__ */


#ifndef __Picture_FWD_DEFINED__
#define __Picture_FWD_DEFINED__
typedef interface Picture Picture;
#endif 	/* __Picture_FWD_DEFINED__ */


#ifndef __Pictures_FWD_DEFINED__
#define __Pictures_FWD_DEFINED__
typedef interface Pictures Pictures;
#endif 	/* __Pictures_FWD_DEFINED__ */


#ifndef __Drawing_FWD_DEFINED__
#define __Drawing_FWD_DEFINED__
typedef interface Drawing Drawing;
#endif 	/* __Drawing_FWD_DEFINED__ */


#ifndef __Drawings_FWD_DEFINED__
#define __Drawings_FWD_DEFINED__
typedef interface Drawings Drawings;
#endif 	/* __Drawings_FWD_DEFINED__ */


#ifndef __RoutingSlip_FWD_DEFINED__
#define __RoutingSlip_FWD_DEFINED__
typedef interface RoutingSlip RoutingSlip;
#endif 	/* __RoutingSlip_FWD_DEFINED__ */


#ifndef __Outline_FWD_DEFINED__
#define __Outline_FWD_DEFINED__
typedef interface Outline Outline;
#endif 	/* __Outline_FWD_DEFINED__ */


#ifndef __Module_FWD_DEFINED__
#define __Module_FWD_DEFINED__
typedef interface Module Module;
#endif 	/* __Module_FWD_DEFINED__ */


#ifndef __Modules_FWD_DEFINED__
#define __Modules_FWD_DEFINED__
typedef interface Modules Modules;
#endif 	/* __Modules_FWD_DEFINED__ */


#ifndef __DialogSheet_FWD_DEFINED__
#define __DialogSheet_FWD_DEFINED__
typedef interface DialogSheet DialogSheet;
#endif 	/* __DialogSheet_FWD_DEFINED__ */


#ifndef __DialogSheets_FWD_DEFINED__
#define __DialogSheets_FWD_DEFINED__
typedef interface DialogSheets DialogSheets;
#endif 	/* __DialogSheets_FWD_DEFINED__ */


#ifndef __Worksheets_FWD_DEFINED__
#define __Worksheets_FWD_DEFINED__
typedef interface Worksheets Worksheets;
#endif 	/* __Worksheets_FWD_DEFINED__ */


#ifndef __PageSetup_FWD_DEFINED__
#define __PageSetup_FWD_DEFINED__
typedef interface PageSetup PageSetup;
#endif 	/* __PageSetup_FWD_DEFINED__ */


#ifndef __Names_FWD_DEFINED__
#define __Names_FWD_DEFINED__
typedef interface Names Names;
#endif 	/* __Names_FWD_DEFINED__ */


#ifndef __Name_FWD_DEFINED__
#define __Name_FWD_DEFINED__
typedef interface Name Name;
#endif 	/* __Name_FWD_DEFINED__ */


#ifndef __ChartObject_FWD_DEFINED__
#define __ChartObject_FWD_DEFINED__
typedef interface ChartObject ChartObject;
#endif 	/* __ChartObject_FWD_DEFINED__ */


#ifndef __ChartObjects_FWD_DEFINED__
#define __ChartObjects_FWD_DEFINED__
typedef interface ChartObjects ChartObjects;
#endif 	/* __ChartObjects_FWD_DEFINED__ */


#ifndef __Mailer_FWD_DEFINED__
#define __Mailer_FWD_DEFINED__
typedef interface Mailer Mailer;
#endif 	/* __Mailer_FWD_DEFINED__ */


#ifndef __CustomViews_FWD_DEFINED__
#define __CustomViews_FWD_DEFINED__
typedef interface CustomViews CustomViews;
#endif 	/* __CustomViews_FWD_DEFINED__ */


#ifndef __CustomView_FWD_DEFINED__
#define __CustomView_FWD_DEFINED__
typedef interface CustomView CustomView;
#endif 	/* __CustomView_FWD_DEFINED__ */


#ifndef __FormatConditions_FWD_DEFINED__
#define __FormatConditions_FWD_DEFINED__
typedef interface FormatConditions FormatConditions;
#endif 	/* __FormatConditions_FWD_DEFINED__ */


#ifndef __FormatCondition_FWD_DEFINED__
#define __FormatCondition_FWD_DEFINED__
typedef interface FormatCondition FormatCondition;
#endif 	/* __FormatCondition_FWD_DEFINED__ */


#ifndef __Comments_FWD_DEFINED__
#define __Comments_FWD_DEFINED__
typedef interface Comments Comments;
#endif 	/* __Comments_FWD_DEFINED__ */


#ifndef __Comment_FWD_DEFINED__
#define __Comment_FWD_DEFINED__
typedef interface Comment Comment;
#endif 	/* __Comment_FWD_DEFINED__ */


#ifndef __RefreshEvents_FWD_DEFINED__
#define __RefreshEvents_FWD_DEFINED__
typedef interface RefreshEvents RefreshEvents;
#endif 	/* __RefreshEvents_FWD_DEFINED__ */


#ifndef ___QueryTable_FWD_DEFINED__
#define ___QueryTable_FWD_DEFINED__
typedef interface _QueryTable _QueryTable;
#endif 	/* ___QueryTable_FWD_DEFINED__ */


#ifndef __QueryTables_FWD_DEFINED__
#define __QueryTables_FWD_DEFINED__
typedef interface QueryTables QueryTables;
#endif 	/* __QueryTables_FWD_DEFINED__ */


#ifndef __Parameter_FWD_DEFINED__
#define __Parameter_FWD_DEFINED__
typedef interface Parameter Parameter;
#endif 	/* __Parameter_FWD_DEFINED__ */


#ifndef __Parameters_FWD_DEFINED__
#define __Parameters_FWD_DEFINED__
typedef interface Parameters Parameters;
#endif 	/* __Parameters_FWD_DEFINED__ */


#ifndef __ODBCError_FWD_DEFINED__
#define __ODBCError_FWD_DEFINED__
typedef interface ODBCError ODBCError;
#endif 	/* __ODBCError_FWD_DEFINED__ */


#ifndef __ODBCErrors_FWD_DEFINED__
#define __ODBCErrors_FWD_DEFINED__
typedef interface ODBCErrors ODBCErrors;
#endif 	/* __ODBCErrors_FWD_DEFINED__ */


#ifndef __Validation_FWD_DEFINED__
#define __Validation_FWD_DEFINED__
typedef interface Validation Validation;
#endif 	/* __Validation_FWD_DEFINED__ */


#ifndef __Hyperlinks_FWD_DEFINED__
#define __Hyperlinks_FWD_DEFINED__
typedef interface Hyperlinks Hyperlinks;
#endif 	/* __Hyperlinks_FWD_DEFINED__ */


#ifndef __Hyperlink_FWD_DEFINED__
#define __Hyperlink_FWD_DEFINED__
typedef interface Hyperlink Hyperlink;
#endif 	/* __Hyperlink_FWD_DEFINED__ */


#ifndef __AutoFilter_FWD_DEFINED__
#define __AutoFilter_FWD_DEFINED__
typedef interface AutoFilter AutoFilter;
#endif 	/* __AutoFilter_FWD_DEFINED__ */


#ifndef __Filters_FWD_DEFINED__
#define __Filters_FWD_DEFINED__
typedef interface Filters Filters;
#endif 	/* __Filters_FWD_DEFINED__ */


#ifndef __Filter_FWD_DEFINED__
#define __Filter_FWD_DEFINED__
typedef interface Filter Filter;
#endif 	/* __Filter_FWD_DEFINED__ */


#ifndef __AutoCorrect_FWD_DEFINED__
#define __AutoCorrect_FWD_DEFINED__
typedef interface AutoCorrect AutoCorrect;
#endif 	/* __AutoCorrect_FWD_DEFINED__ */


#ifndef __Border_FWD_DEFINED__
#define __Border_FWD_DEFINED__
typedef interface Border Border;
#endif 	/* __Border_FWD_DEFINED__ */


#ifndef __Interior_FWD_DEFINED__
#define __Interior_FWD_DEFINED__
typedef interface Interior Interior;
#endif 	/* __Interior_FWD_DEFINED__ */


#ifndef __ChartFillFormat_FWD_DEFINED__
#define __ChartFillFormat_FWD_DEFINED__
typedef interface ChartFillFormat ChartFillFormat;
#endif 	/* __ChartFillFormat_FWD_DEFINED__ */


#ifndef __ChartColorFormat_FWD_DEFINED__
#define __ChartColorFormat_FWD_DEFINED__
typedef interface ChartColorFormat ChartColorFormat;
#endif 	/* __ChartColorFormat_FWD_DEFINED__ */


#ifndef __Axis_FWD_DEFINED__
#define __Axis_FWD_DEFINED__
typedef interface Axis Axis;
#endif 	/* __Axis_FWD_DEFINED__ */


#ifndef __ChartTitle_FWD_DEFINED__
#define __ChartTitle_FWD_DEFINED__
typedef interface ChartTitle ChartTitle;
#endif 	/* __ChartTitle_FWD_DEFINED__ */


#ifndef __AxisTitle_FWD_DEFINED__
#define __AxisTitle_FWD_DEFINED__
typedef interface AxisTitle AxisTitle;
#endif 	/* __AxisTitle_FWD_DEFINED__ */


#ifndef __ChartGroup_FWD_DEFINED__
#define __ChartGroup_FWD_DEFINED__
typedef interface ChartGroup ChartGroup;
#endif 	/* __ChartGroup_FWD_DEFINED__ */


#ifndef __ChartGroups_FWD_DEFINED__
#define __ChartGroups_FWD_DEFINED__
typedef interface ChartGroups ChartGroups;
#endif 	/* __ChartGroups_FWD_DEFINED__ */


#ifndef __Axes_FWD_DEFINED__
#define __Axes_FWD_DEFINED__
typedef interface Axes Axes;
#endif 	/* __Axes_FWD_DEFINED__ */


#ifndef __Points_FWD_DEFINED__
#define __Points_FWD_DEFINED__
typedef interface Points Points;
#endif 	/* __Points_FWD_DEFINED__ */


#ifndef __Point_FWD_DEFINED__
#define __Point_FWD_DEFINED__
typedef interface Point Point;
#endif 	/* __Point_FWD_DEFINED__ */


#ifndef __Series_FWD_DEFINED__
#define __Series_FWD_DEFINED__
typedef interface Series Series;
#endif 	/* __Series_FWD_DEFINED__ */


#ifndef __SeriesCollection_FWD_DEFINED__
#define __SeriesCollection_FWD_DEFINED__
typedef interface SeriesCollection SeriesCollection;
#endif 	/* __SeriesCollection_FWD_DEFINED__ */


#ifndef __DataLabel_FWD_DEFINED__
#define __DataLabel_FWD_DEFINED__
typedef interface DataLabel DataLabel;
#endif 	/* __DataLabel_FWD_DEFINED__ */


#ifndef __DataLabels_FWD_DEFINED__
#define __DataLabels_FWD_DEFINED__
typedef interface DataLabels DataLabels;
#endif 	/* __DataLabels_FWD_DEFINED__ */


#ifndef __LegendEntry_FWD_DEFINED__
#define __LegendEntry_FWD_DEFINED__
typedef interface LegendEntry LegendEntry;
#endif 	/* __LegendEntry_FWD_DEFINED__ */


#ifndef __LegendEntries_FWD_DEFINED__
#define __LegendEntries_FWD_DEFINED__
typedef interface LegendEntries LegendEntries;
#endif 	/* __LegendEntries_FWD_DEFINED__ */


#ifndef __LegendKey_FWD_DEFINED__
#define __LegendKey_FWD_DEFINED__
typedef interface LegendKey LegendKey;
#endif 	/* __LegendKey_FWD_DEFINED__ */


#ifndef __Trendlines_FWD_DEFINED__
#define __Trendlines_FWD_DEFINED__
typedef interface Trendlines Trendlines;
#endif 	/* __Trendlines_FWD_DEFINED__ */


#ifndef __Trendline_FWD_DEFINED__
#define __Trendline_FWD_DEFINED__
typedef interface Trendline Trendline;
#endif 	/* __Trendline_FWD_DEFINED__ */


#ifndef __Corners_FWD_DEFINED__
#define __Corners_FWD_DEFINED__
typedef interface Corners Corners;
#endif 	/* __Corners_FWD_DEFINED__ */


#ifndef __SeriesLines_FWD_DEFINED__
#define __SeriesLines_FWD_DEFINED__
typedef interface SeriesLines SeriesLines;
#endif 	/* __SeriesLines_FWD_DEFINED__ */


#ifndef __HiLoLines_FWD_DEFINED__
#define __HiLoLines_FWD_DEFINED__
typedef interface HiLoLines HiLoLines;
#endif 	/* __HiLoLines_FWD_DEFINED__ */


#ifndef __Gridlines_FWD_DEFINED__
#define __Gridlines_FWD_DEFINED__
typedef interface Gridlines Gridlines;
#endif 	/* __Gridlines_FWD_DEFINED__ */


#ifndef __DropLines_FWD_DEFINED__
#define __DropLines_FWD_DEFINED__
typedef interface DropLines DropLines;
#endif 	/* __DropLines_FWD_DEFINED__ */


#ifndef __LeaderLines_FWD_DEFINED__
#define __LeaderLines_FWD_DEFINED__
typedef interface LeaderLines LeaderLines;
#endif 	/* __LeaderLines_FWD_DEFINED__ */


#ifndef __UpBars_FWD_DEFINED__
#define __UpBars_FWD_DEFINED__
typedef interface UpBars UpBars;
#endif 	/* __UpBars_FWD_DEFINED__ */


#ifndef __DownBars_FWD_DEFINED__
#define __DownBars_FWD_DEFINED__
typedef interface DownBars DownBars;
#endif 	/* __DownBars_FWD_DEFINED__ */


#ifndef __Floor_FWD_DEFINED__
#define __Floor_FWD_DEFINED__
typedef interface Floor Floor;
#endif 	/* __Floor_FWD_DEFINED__ */


#ifndef __Walls_FWD_DEFINED__
#define __Walls_FWD_DEFINED__
typedef interface Walls Walls;
#endif 	/* __Walls_FWD_DEFINED__ */


#ifndef __TickLabels_FWD_DEFINED__
#define __TickLabels_FWD_DEFINED__
typedef interface TickLabels TickLabels;
#endif 	/* __TickLabels_FWD_DEFINED__ */


#ifndef __PlotArea_FWD_DEFINED__
#define __PlotArea_FWD_DEFINED__
typedef interface PlotArea PlotArea;
#endif 	/* __PlotArea_FWD_DEFINED__ */


#ifndef __ChartArea_FWD_DEFINED__
#define __ChartArea_FWD_DEFINED__
typedef interface ChartArea ChartArea;
#endif 	/* __ChartArea_FWD_DEFINED__ */


#ifndef __Legend_FWD_DEFINED__
#define __Legend_FWD_DEFINED__
typedef interface Legend Legend;
#endif 	/* __Legend_FWD_DEFINED__ */


#ifndef __ErrorBars_FWD_DEFINED__
#define __ErrorBars_FWD_DEFINED__
typedef interface ErrorBars ErrorBars;
#endif 	/* __ErrorBars_FWD_DEFINED__ */


#ifndef __DataTable_FWD_DEFINED__
#define __DataTable_FWD_DEFINED__
typedef interface DataTable DataTable;
#endif 	/* __DataTable_FWD_DEFINED__ */


#ifndef __Phonetic_FWD_DEFINED__
#define __Phonetic_FWD_DEFINED__
typedef interface Phonetic Phonetic;
#endif 	/* __Phonetic_FWD_DEFINED__ */


#ifndef __Shape_FWD_DEFINED__
#define __Shape_FWD_DEFINED__
typedef interface Shape Shape;
#endif 	/* __Shape_FWD_DEFINED__ */


#ifndef __Shapes_FWD_DEFINED__
#define __Shapes_FWD_DEFINED__
typedef interface Shapes Shapes;
#endif 	/* __Shapes_FWD_DEFINED__ */


#ifndef __ShapeRange_FWD_DEFINED__
#define __ShapeRange_FWD_DEFINED__
typedef interface ShapeRange ShapeRange;
#endif 	/* __ShapeRange_FWD_DEFINED__ */


#ifndef __GroupShapes_FWD_DEFINED__
#define __GroupShapes_FWD_DEFINED__
typedef interface GroupShapes GroupShapes;
#endif 	/* __GroupShapes_FWD_DEFINED__ */


#ifndef __TextFrame_FWD_DEFINED__
#define __TextFrame_FWD_DEFINED__
typedef interface TextFrame TextFrame;
#endif 	/* __TextFrame_FWD_DEFINED__ */


#ifndef __ConnectorFormat_FWD_DEFINED__
#define __ConnectorFormat_FWD_DEFINED__
typedef interface ConnectorFormat ConnectorFormat;
#endif 	/* __ConnectorFormat_FWD_DEFINED__ */


#ifndef __FreeformBuilder_FWD_DEFINED__
#define __FreeformBuilder_FWD_DEFINED__
typedef interface FreeformBuilder FreeformBuilder;
#endif 	/* __FreeformBuilder_FWD_DEFINED__ */


#ifndef __ControlFormat_FWD_DEFINED__
#define __ControlFormat_FWD_DEFINED__
typedef interface ControlFormat ControlFormat;
#endif 	/* __ControlFormat_FWD_DEFINED__ */


#ifndef __OLEFormat_FWD_DEFINED__
#define __OLEFormat_FWD_DEFINED__
typedef interface OLEFormat OLEFormat;
#endif 	/* __OLEFormat_FWD_DEFINED__ */


#ifndef __LinkFormat_FWD_DEFINED__
#define __LinkFormat_FWD_DEFINED__
typedef interface LinkFormat LinkFormat;
#endif 	/* __LinkFormat_FWD_DEFINED__ */


#ifndef __PublishObjects_FWD_DEFINED__
#define __PublishObjects_FWD_DEFINED__
typedef interface PublishObjects PublishObjects;
#endif 	/* __PublishObjects_FWD_DEFINED__ */


#ifndef __OLEDBError_FWD_DEFINED__
#define __OLEDBError_FWD_DEFINED__
typedef interface OLEDBError OLEDBError;
#endif 	/* __OLEDBError_FWD_DEFINED__ */


#ifndef __OLEDBErrors_FWD_DEFINED__
#define __OLEDBErrors_FWD_DEFINED__
typedef interface OLEDBErrors OLEDBErrors;
#endif 	/* __OLEDBErrors_FWD_DEFINED__ */


#ifndef __Phonetics_FWD_DEFINED__
#define __Phonetics_FWD_DEFINED__
typedef interface Phonetics Phonetics;
#endif 	/* __Phonetics_FWD_DEFINED__ */


#ifndef __PivotLayout_FWD_DEFINED__
#define __PivotLayout_FWD_DEFINED__
typedef interface PivotLayout PivotLayout;
#endif 	/* __PivotLayout_FWD_DEFINED__ */


#ifndef __DisplayUnitLabel_FWD_DEFINED__
#define __DisplayUnitLabel_FWD_DEFINED__
typedef interface DisplayUnitLabel DisplayUnitLabel;
#endif 	/* __DisplayUnitLabel_FWD_DEFINED__ */


#ifndef __CellFormat_FWD_DEFINED__
#define __CellFormat_FWD_DEFINED__
typedef interface CellFormat CellFormat;
#endif 	/* __CellFormat_FWD_DEFINED__ */


#ifndef __UsedObjects_FWD_DEFINED__
#define __UsedObjects_FWD_DEFINED__
typedef interface UsedObjects UsedObjects;
#endif 	/* __UsedObjects_FWD_DEFINED__ */


#ifndef __CustomProperties_FWD_DEFINED__
#define __CustomProperties_FWD_DEFINED__
typedef interface CustomProperties CustomProperties;
#endif 	/* __CustomProperties_FWD_DEFINED__ */


#ifndef __CustomProperty_FWD_DEFINED__
#define __CustomProperty_FWD_DEFINED__
typedef interface CustomProperty CustomProperty;
#endif 	/* __CustomProperty_FWD_DEFINED__ */


#ifndef __CalculatedMembers_FWD_DEFINED__
#define __CalculatedMembers_FWD_DEFINED__
typedef interface CalculatedMembers CalculatedMembers;
#endif 	/* __CalculatedMembers_FWD_DEFINED__ */


#ifndef __CalculatedMember_FWD_DEFINED__
#define __CalculatedMember_FWD_DEFINED__
typedef interface CalculatedMember CalculatedMember;
#endif 	/* __CalculatedMember_FWD_DEFINED__ */


#ifndef __Watches_FWD_DEFINED__
#define __Watches_FWD_DEFINED__
typedef interface Watches Watches;
#endif 	/* __Watches_FWD_DEFINED__ */


#ifndef __Watch_FWD_DEFINED__
#define __Watch_FWD_DEFINED__
typedef interface Watch Watch;
#endif 	/* __Watch_FWD_DEFINED__ */


#ifndef __PivotCell_FWD_DEFINED__
#define __PivotCell_FWD_DEFINED__
typedef interface PivotCell PivotCell;
#endif 	/* __PivotCell_FWD_DEFINED__ */


#ifndef __Graphic_FWD_DEFINED__
#define __Graphic_FWD_DEFINED__
typedef interface Graphic Graphic;
#endif 	/* __Graphic_FWD_DEFINED__ */


#ifndef __AutoRecover_FWD_DEFINED__
#define __AutoRecover_FWD_DEFINED__
typedef interface AutoRecover AutoRecover;
#endif 	/* __AutoRecover_FWD_DEFINED__ */


#ifndef __ErrorCheckingOptions_FWD_DEFINED__
#define __ErrorCheckingOptions_FWD_DEFINED__
typedef interface ErrorCheckingOptions ErrorCheckingOptions;
#endif 	/* __ErrorCheckingOptions_FWD_DEFINED__ */


#ifndef __Errors_FWD_DEFINED__
#define __Errors_FWD_DEFINED__
typedef interface Errors Errors;
#endif 	/* __Errors_FWD_DEFINED__ */


#ifndef __Error_FWD_DEFINED__
#define __Error_FWD_DEFINED__
typedef interface Error Error;
#endif 	/* __Error_FWD_DEFINED__ */


#ifndef __SmartTagAction_FWD_DEFINED__
#define __SmartTagAction_FWD_DEFINED__
typedef interface SmartTagAction SmartTagAction;
#endif 	/* __SmartTagAction_FWD_DEFINED__ */


#ifndef __SmartTagActions_FWD_DEFINED__
#define __SmartTagActions_FWD_DEFINED__
typedef interface SmartTagActions SmartTagActions;
#endif 	/* __SmartTagActions_FWD_DEFINED__ */


#ifndef __SmartTag_FWD_DEFINED__
#define __SmartTag_FWD_DEFINED__
typedef interface SmartTag SmartTag;
#endif 	/* __SmartTag_FWD_DEFINED__ */


#ifndef __SmartTags_FWD_DEFINED__
#define __SmartTags_FWD_DEFINED__
typedef interface SmartTags SmartTags;
#endif 	/* __SmartTags_FWD_DEFINED__ */


#ifndef __SmartTagRecognizer_FWD_DEFINED__
#define __SmartTagRecognizer_FWD_DEFINED__
typedef interface SmartTagRecognizer SmartTagRecognizer;
#endif 	/* __SmartTagRecognizer_FWD_DEFINED__ */


#ifndef __SmartTagRecognizers_FWD_DEFINED__
#define __SmartTagRecognizers_FWD_DEFINED__
typedef interface SmartTagRecognizers SmartTagRecognizers;
#endif 	/* __SmartTagRecognizers_FWD_DEFINED__ */


#ifndef __SmartTagOptions_FWD_DEFINED__
#define __SmartTagOptions_FWD_DEFINED__
typedef interface SmartTagOptions SmartTagOptions;
#endif 	/* __SmartTagOptions_FWD_DEFINED__ */


#ifndef __SpellingOptions_FWD_DEFINED__
#define __SpellingOptions_FWD_DEFINED__
typedef interface SpellingOptions SpellingOptions;
#endif 	/* __SpellingOptions_FWD_DEFINED__ */


#ifndef __Speech_FWD_DEFINED__
#define __Speech_FWD_DEFINED__
typedef interface Speech Speech;
#endif 	/* __Speech_FWD_DEFINED__ */


#ifndef __Protection_FWD_DEFINED__
#define __Protection_FWD_DEFINED__
typedef interface Protection Protection;
#endif 	/* __Protection_FWD_DEFINED__ */


#ifndef __PivotItemList_FWD_DEFINED__
#define __PivotItemList_FWD_DEFINED__
typedef interface PivotItemList PivotItemList;
#endif 	/* __PivotItemList_FWD_DEFINED__ */


#ifndef __Tab_FWD_DEFINED__
#define __Tab_FWD_DEFINED__
typedef interface Tab Tab;
#endif 	/* __Tab_FWD_DEFINED__ */


#ifndef __AllowEditRanges_FWD_DEFINED__
#define __AllowEditRanges_FWD_DEFINED__
typedef interface AllowEditRanges AllowEditRanges;
#endif 	/* __AllowEditRanges_FWD_DEFINED__ */


#ifndef __AllowEditRange_FWD_DEFINED__
#define __AllowEditRange_FWD_DEFINED__
typedef interface AllowEditRange AllowEditRange;
#endif 	/* __AllowEditRange_FWD_DEFINED__ */


#ifndef __UserAccessList_FWD_DEFINED__
#define __UserAccessList_FWD_DEFINED__
typedef interface UserAccessList UserAccessList;
#endif 	/* __UserAccessList_FWD_DEFINED__ */


#ifndef __UserAccess_FWD_DEFINED__
#define __UserAccess_FWD_DEFINED__
typedef interface UserAccess UserAccess;
#endif 	/* __UserAccess_FWD_DEFINED__ */


#ifndef __RTD_FWD_DEFINED__
#define __RTD_FWD_DEFINED__
typedef interface RTD RTD;
#endif 	/* __RTD_FWD_DEFINED__ */


#ifndef __Diagram_FWD_DEFINED__
#define __Diagram_FWD_DEFINED__
typedef interface Diagram Diagram;
#endif 	/* __Diagram_FWD_DEFINED__ */


#ifndef __ListObjects_FWD_DEFINED__
#define __ListObjects_FWD_DEFINED__
typedef interface ListObjects ListObjects;
#endif 	/* __ListObjects_FWD_DEFINED__ */


#ifndef __ListObject_FWD_DEFINED__
#define __ListObject_FWD_DEFINED__
typedef interface ListObject ListObject;
#endif 	/* __ListObject_FWD_DEFINED__ */


#ifndef __ListColumns_FWD_DEFINED__
#define __ListColumns_FWD_DEFINED__
typedef interface ListColumns ListColumns;
#endif 	/* __ListColumns_FWD_DEFINED__ */


#ifndef __ListColumn_FWD_DEFINED__
#define __ListColumn_FWD_DEFINED__
typedef interface ListColumn ListColumn;
#endif 	/* __ListColumn_FWD_DEFINED__ */


#ifndef __ListRows_FWD_DEFINED__
#define __ListRows_FWD_DEFINED__
typedef interface ListRows ListRows;
#endif 	/* __ListRows_FWD_DEFINED__ */


#ifndef __ListRow_FWD_DEFINED__
#define __ListRow_FWD_DEFINED__
typedef interface ListRow ListRow;
#endif 	/* __ListRow_FWD_DEFINED__ */


#ifndef __XmlNamespace_FWD_DEFINED__
#define __XmlNamespace_FWD_DEFINED__
typedef interface XmlNamespace XmlNamespace;
#endif 	/* __XmlNamespace_FWD_DEFINED__ */


#ifndef __XmlNamespaces_FWD_DEFINED__
#define __XmlNamespaces_FWD_DEFINED__
typedef interface XmlNamespaces XmlNamespaces;
#endif 	/* __XmlNamespaces_FWD_DEFINED__ */


#ifndef __XmlDataBinding_FWD_DEFINED__
#define __XmlDataBinding_FWD_DEFINED__
typedef interface XmlDataBinding XmlDataBinding;
#endif 	/* __XmlDataBinding_FWD_DEFINED__ */


#ifndef __XmlSchema_FWD_DEFINED__
#define __XmlSchema_FWD_DEFINED__
typedef interface XmlSchema XmlSchema;
#endif 	/* __XmlSchema_FWD_DEFINED__ */


#ifndef __XmlSchemas_FWD_DEFINED__
#define __XmlSchemas_FWD_DEFINED__
typedef interface XmlSchemas XmlSchemas;
#endif 	/* __XmlSchemas_FWD_DEFINED__ */


#ifndef __XmlMap_FWD_DEFINED__
#define __XmlMap_FWD_DEFINED__
typedef interface XmlMap XmlMap;
#endif 	/* __XmlMap_FWD_DEFINED__ */


#ifndef __XmlMaps_FWD_DEFINED__
#define __XmlMaps_FWD_DEFINED__
typedef interface XmlMaps XmlMaps;
#endif 	/* __XmlMaps_FWD_DEFINED__ */


#ifndef __ListDataFormat_FWD_DEFINED__
#define __ListDataFormat_FWD_DEFINED__
typedef interface ListDataFormat ListDataFormat;
#endif 	/* __ListDataFormat_FWD_DEFINED__ */


#ifndef __XPath_FWD_DEFINED__
#define __XPath_FWD_DEFINED__
typedef interface XPath XPath;
#endif 	/* __XPath_FWD_DEFINED__ */


#ifndef __PivotLineCells_FWD_DEFINED__
#define __PivotLineCells_FWD_DEFINED__
typedef interface PivotLineCells PivotLineCells;
#endif 	/* __PivotLineCells_FWD_DEFINED__ */


#ifndef __PivotLine_FWD_DEFINED__
#define __PivotLine_FWD_DEFINED__
typedef interface PivotLine PivotLine;
#endif 	/* __PivotLine_FWD_DEFINED__ */


#ifndef __PivotLines_FWD_DEFINED__
#define __PivotLines_FWD_DEFINED__
typedef interface PivotLines PivotLines;
#endif 	/* __PivotLines_FWD_DEFINED__ */


#ifndef __PivotAxis_FWD_DEFINED__
#define __PivotAxis_FWD_DEFINED__
typedef interface PivotAxis PivotAxis;
#endif 	/* __PivotAxis_FWD_DEFINED__ */


#ifndef __PivotFilter_FWD_DEFINED__
#define __PivotFilter_FWD_DEFINED__
typedef interface PivotFilter PivotFilter;
#endif 	/* __PivotFilter_FWD_DEFINED__ */


#ifndef __PivotFilters_FWD_DEFINED__
#define __PivotFilters_FWD_DEFINED__
typedef interface PivotFilters PivotFilters;
#endif 	/* __PivotFilters_FWD_DEFINED__ */


#ifndef __WorkbookConnection_FWD_DEFINED__
#define __WorkbookConnection_FWD_DEFINED__
typedef interface WorkbookConnection WorkbookConnection;
#endif 	/* __WorkbookConnection_FWD_DEFINED__ */


#ifndef __Connections_FWD_DEFINED__
#define __Connections_FWD_DEFINED__
typedef interface Connections Connections;
#endif 	/* __Connections_FWD_DEFINED__ */


#ifndef __WorksheetView_FWD_DEFINED__
#define __WorksheetView_FWD_DEFINED__
typedef interface WorksheetView WorksheetView;
#endif 	/* __WorksheetView_FWD_DEFINED__ */


#ifndef __ChartView_FWD_DEFINED__
#define __ChartView_FWD_DEFINED__
typedef interface ChartView ChartView;
#endif 	/* __ChartView_FWD_DEFINED__ */


#ifndef __ModuleView_FWD_DEFINED__
#define __ModuleView_FWD_DEFINED__
typedef interface ModuleView ModuleView;
#endif 	/* __ModuleView_FWD_DEFINED__ */


#ifndef __DialogSheetView_FWD_DEFINED__
#define __DialogSheetView_FWD_DEFINED__
typedef interface DialogSheetView DialogSheetView;
#endif 	/* __DialogSheetView_FWD_DEFINED__ */


#ifndef __SheetViews_FWD_DEFINED__
#define __SheetViews_FWD_DEFINED__
typedef interface SheetViews SheetViews;
#endif 	/* __SheetViews_FWD_DEFINED__ */


#ifndef __OLEDBConnection_FWD_DEFINED__
#define __OLEDBConnection_FWD_DEFINED__
typedef interface OLEDBConnection OLEDBConnection;
#endif 	/* __OLEDBConnection_FWD_DEFINED__ */


#ifndef __ODBCConnection_FWD_DEFINED__
#define __ODBCConnection_FWD_DEFINED__
typedef interface ODBCConnection ODBCConnection;
#endif 	/* __ODBCConnection_FWD_DEFINED__ */


#ifndef __Action_FWD_DEFINED__
#define __Action_FWD_DEFINED__
typedef interface Action Action;
#endif 	/* __Action_FWD_DEFINED__ */


#ifndef __Actions_FWD_DEFINED__
#define __Actions_FWD_DEFINED__
typedef interface Actions Actions;
#endif 	/* __Actions_FWD_DEFINED__ */


#ifndef __FormatColor_FWD_DEFINED__
#define __FormatColor_FWD_DEFINED__
typedef interface FormatColor FormatColor;
#endif 	/* __FormatColor_FWD_DEFINED__ */


#ifndef __ConditionValue_FWD_DEFINED__
#define __ConditionValue_FWD_DEFINED__
typedef interface ConditionValue ConditionValue;
#endif 	/* __ConditionValue_FWD_DEFINED__ */


#ifndef __ColorScale_FWD_DEFINED__
#define __ColorScale_FWD_DEFINED__
typedef interface ColorScale ColorScale;
#endif 	/* __ColorScale_FWD_DEFINED__ */


#ifndef __ColorScaleCriteria_FWD_DEFINED__
#define __ColorScaleCriteria_FWD_DEFINED__
typedef interface ColorScaleCriteria ColorScaleCriteria;
#endif 	/* __ColorScaleCriteria_FWD_DEFINED__ */


#ifndef __ColorScaleCriterion_FWD_DEFINED__
#define __ColorScaleCriterion_FWD_DEFINED__
typedef interface ColorScaleCriterion ColorScaleCriterion;
#endif 	/* __ColorScaleCriterion_FWD_DEFINED__ */


#ifndef __Databar_FWD_DEFINED__
#define __Databar_FWD_DEFINED__
typedef interface Databar Databar;
#endif 	/* __Databar_FWD_DEFINED__ */


#ifndef __IconSetCondition_FWD_DEFINED__
#define __IconSetCondition_FWD_DEFINED__
typedef interface IconSetCondition IconSetCondition;
#endif 	/* __IconSetCondition_FWD_DEFINED__ */


#ifndef __IconCriteria_FWD_DEFINED__
#define __IconCriteria_FWD_DEFINED__
typedef interface IconCriteria IconCriteria;
#endif 	/* __IconCriteria_FWD_DEFINED__ */


#ifndef __IconCriterion_FWD_DEFINED__
#define __IconCriterion_FWD_DEFINED__
typedef interface IconCriterion IconCriterion;
#endif 	/* __IconCriterion_FWD_DEFINED__ */


#ifndef __Icon_FWD_DEFINED__
#define __Icon_FWD_DEFINED__
typedef interface Icon Icon;
#endif 	/* __Icon_FWD_DEFINED__ */


#ifndef __IconSet_FWD_DEFINED__
#define __IconSet_FWD_DEFINED__
typedef interface IconSet IconSet;
#endif 	/* __IconSet_FWD_DEFINED__ */


#ifndef __IconSets_FWD_DEFINED__
#define __IconSets_FWD_DEFINED__
typedef interface IconSets IconSets;
#endif 	/* __IconSets_FWD_DEFINED__ */


#ifndef __Top10_FWD_DEFINED__
#define __Top10_FWD_DEFINED__
typedef interface Top10 Top10;
#endif 	/* __Top10_FWD_DEFINED__ */


#ifndef __AboveAverage_FWD_DEFINED__
#define __AboveAverage_FWD_DEFINED__
typedef interface AboveAverage AboveAverage;
#endif 	/* __AboveAverage_FWD_DEFINED__ */


#ifndef __UniqueValues_FWD_DEFINED__
#define __UniqueValues_FWD_DEFINED__
typedef interface UniqueValues UniqueValues;
#endif 	/* __UniqueValues_FWD_DEFINED__ */


#ifndef __Ranges_FWD_DEFINED__
#define __Ranges_FWD_DEFINED__
typedef interface Ranges Ranges;
#endif 	/* __Ranges_FWD_DEFINED__ */


#ifndef __HeaderFooter_FWD_DEFINED__
#define __HeaderFooter_FWD_DEFINED__
typedef interface HeaderFooter HeaderFooter;
#endif 	/* __HeaderFooter_FWD_DEFINED__ */


#ifndef __Page_FWD_DEFINED__
#define __Page_FWD_DEFINED__
typedef interface Page Page;
#endif 	/* __Page_FWD_DEFINED__ */


#ifndef __Pages_FWD_DEFINED__
#define __Pages_FWD_DEFINED__
typedef interface Pages Pages;
#endif 	/* __Pages_FWD_DEFINED__ */


#ifndef __ServerViewableItems_FWD_DEFINED__
#define __ServerViewableItems_FWD_DEFINED__
typedef interface ServerViewableItems ServerViewableItems;
#endif 	/* __ServerViewableItems_FWD_DEFINED__ */


#ifndef __TableStyleElement_FWD_DEFINED__
#define __TableStyleElement_FWD_DEFINED__
typedef interface TableStyleElement TableStyleElement;
#endif 	/* __TableStyleElement_FWD_DEFINED__ */


#ifndef __TableStyleElements_FWD_DEFINED__
#define __TableStyleElements_FWD_DEFINED__
typedef interface TableStyleElements TableStyleElements;
#endif 	/* __TableStyleElements_FWD_DEFINED__ */


#ifndef __TableStyle_FWD_DEFINED__
#define __TableStyle_FWD_DEFINED__
typedef interface TableStyle TableStyle;
#endif 	/* __TableStyle_FWD_DEFINED__ */


#ifndef __TableStyles_FWD_DEFINED__
#define __TableStyles_FWD_DEFINED__
typedef interface TableStyles TableStyles;
#endif 	/* __TableStyles_FWD_DEFINED__ */


#ifndef __SortField_FWD_DEFINED__
#define __SortField_FWD_DEFINED__
typedef interface SortField SortField;
#endif 	/* __SortField_FWD_DEFINED__ */


#ifndef __SortFields_FWD_DEFINED__
#define __SortFields_FWD_DEFINED__
typedef interface SortFields SortFields;
#endif 	/* __SortFields_FWD_DEFINED__ */


#ifndef __Sort_FWD_DEFINED__
#define __Sort_FWD_DEFINED__
typedef interface Sort Sort;
#endif 	/* __Sort_FWD_DEFINED__ */


#ifndef __Research_FWD_DEFINED__
#define __Research_FWD_DEFINED__
typedef interface Research Research;
#endif 	/* __Research_FWD_DEFINED__ */


#ifndef __ColorStop_FWD_DEFINED__
#define __ColorStop_FWD_DEFINED__
typedef interface ColorStop ColorStop;
#endif 	/* __ColorStop_FWD_DEFINED__ */


#ifndef __ColorStops_FWD_DEFINED__
#define __ColorStops_FWD_DEFINED__
typedef interface ColorStops ColorStops;
#endif 	/* __ColorStops_FWD_DEFINED__ */


#ifndef __LinearGradient_FWD_DEFINED__
#define __LinearGradient_FWD_DEFINED__
typedef interface LinearGradient LinearGradient;
#endif 	/* __LinearGradient_FWD_DEFINED__ */


#ifndef __RectangularGradient_FWD_DEFINED__
#define __RectangularGradient_FWD_DEFINED__
typedef interface RectangularGradient RectangularGradient;
#endif 	/* __RectangularGradient_FWD_DEFINED__ */


#ifndef __MultiThreadedCalculation_FWD_DEFINED__
#define __MultiThreadedCalculation_FWD_DEFINED__
typedef interface MultiThreadedCalculation MultiThreadedCalculation;
#endif 	/* __MultiThreadedCalculation_FWD_DEFINED__ */


#ifndef __ChartFormat_FWD_DEFINED__
#define __ChartFormat_FWD_DEFINED__
typedef interface ChartFormat ChartFormat;
#endif 	/* __ChartFormat_FWD_DEFINED__ */


#ifndef __FileExportConverter_FWD_DEFINED__
#define __FileExportConverter_FWD_DEFINED__
typedef interface FileExportConverter FileExportConverter;
#endif 	/* __FileExportConverter_FWD_DEFINED__ */


#ifndef __FileExportConverters_FWD_DEFINED__
#define __FileExportConverters_FWD_DEFINED__
typedef interface FileExportConverters FileExportConverters;
#endif 	/* __FileExportConverters_FWD_DEFINED__ */


#ifndef __AddIns2_FWD_DEFINED__
#define __AddIns2_FWD_DEFINED__
typedef interface AddIns2 AddIns2;
#endif 	/* __AddIns2_FWD_DEFINED__ */


#ifndef __SparklineGroups_FWD_DEFINED__
#define __SparklineGroups_FWD_DEFINED__
typedef interface SparklineGroups SparklineGroups;
#endif 	/* __SparklineGroups_FWD_DEFINED__ */


#ifndef __SparklineGroup_FWD_DEFINED__
#define __SparklineGroup_FWD_DEFINED__
typedef interface SparklineGroup SparklineGroup;
#endif 	/* __SparklineGroup_FWD_DEFINED__ */


#ifndef __SparkPoints_FWD_DEFINED__
#define __SparkPoints_FWD_DEFINED__
typedef interface SparkPoints SparkPoints;
#endif 	/* __SparkPoints_FWD_DEFINED__ */


#ifndef __Sparkline_FWD_DEFINED__
#define __Sparkline_FWD_DEFINED__
typedef interface Sparkline Sparkline;
#endif 	/* __Sparkline_FWD_DEFINED__ */


#ifndef __SparkAxes_FWD_DEFINED__
#define __SparkAxes_FWD_DEFINED__
typedef interface SparkAxes SparkAxes;
#endif 	/* __SparkAxes_FWD_DEFINED__ */


#ifndef __SparkHorizontalAxis_FWD_DEFINED__
#define __SparkHorizontalAxis_FWD_DEFINED__
typedef interface SparkHorizontalAxis SparkHorizontalAxis;
#endif 	/* __SparkHorizontalAxis_FWD_DEFINED__ */


#ifndef __SparkVerticalAxis_FWD_DEFINED__
#define __SparkVerticalAxis_FWD_DEFINED__
typedef interface SparkVerticalAxis SparkVerticalAxis;
#endif 	/* __SparkVerticalAxis_FWD_DEFINED__ */


#ifndef __SparkColor_FWD_DEFINED__
#define __SparkColor_FWD_DEFINED__
typedef interface SparkColor SparkColor;
#endif 	/* __SparkColor_FWD_DEFINED__ */


#ifndef __DataBarBorder_FWD_DEFINED__
#define __DataBarBorder_FWD_DEFINED__
typedef interface DataBarBorder DataBarBorder;
#endif 	/* __DataBarBorder_FWD_DEFINED__ */


#ifndef __NegativeBarFormat_FWD_DEFINED__
#define __NegativeBarFormat_FWD_DEFINED__
typedef interface NegativeBarFormat NegativeBarFormat;
#endif 	/* __NegativeBarFormat_FWD_DEFINED__ */


#ifndef __ValueChange_FWD_DEFINED__
#define __ValueChange_FWD_DEFINED__
typedef interface ValueChange ValueChange;
#endif 	/* __ValueChange_FWD_DEFINED__ */


#ifndef __PivotTableChangeList_FWD_DEFINED__
#define __PivotTableChangeList_FWD_DEFINED__
typedef interface PivotTableChangeList PivotTableChangeList;
#endif 	/* __PivotTableChangeList_FWD_DEFINED__ */


#ifndef __DisplayFormat_FWD_DEFINED__
#define __DisplayFormat_FWD_DEFINED__
typedef interface DisplayFormat DisplayFormat;
#endif 	/* __DisplayFormat_FWD_DEFINED__ */


#ifndef __SlicerCaches_FWD_DEFINED__
#define __SlicerCaches_FWD_DEFINED__
typedef interface SlicerCaches SlicerCaches;
#endif 	/* __SlicerCaches_FWD_DEFINED__ */


#ifndef __SlicerCache_FWD_DEFINED__
#define __SlicerCache_FWD_DEFINED__
typedef interface SlicerCache SlicerCache;
#endif 	/* __SlicerCache_FWD_DEFINED__ */


#ifndef __SlicerCacheLevels_FWD_DEFINED__
#define __SlicerCacheLevels_FWD_DEFINED__
typedef interface SlicerCacheLevels SlicerCacheLevels;
#endif 	/* __SlicerCacheLevels_FWD_DEFINED__ */


#ifndef __SlicerCacheLevel_FWD_DEFINED__
#define __SlicerCacheLevel_FWD_DEFINED__
typedef interface SlicerCacheLevel SlicerCacheLevel;
#endif 	/* __SlicerCacheLevel_FWD_DEFINED__ */


#ifndef __Slicers_FWD_DEFINED__
#define __Slicers_FWD_DEFINED__
typedef interface Slicers Slicers;
#endif 	/* __Slicers_FWD_DEFINED__ */


#ifndef __Slicer_FWD_DEFINED__
#define __Slicer_FWD_DEFINED__
typedef interface Slicer Slicer;
#endif 	/* __Slicer_FWD_DEFINED__ */


#ifndef __SlicerItem_FWD_DEFINED__
#define __SlicerItem_FWD_DEFINED__
typedef interface SlicerItem SlicerItem;
#endif 	/* __SlicerItem_FWD_DEFINED__ */


#ifndef __SlicerItems_FWD_DEFINED__
#define __SlicerItems_FWD_DEFINED__
typedef interface SlicerItems SlicerItems;
#endif 	/* __SlicerItems_FWD_DEFINED__ */


#ifndef __SlicerPivotTables_FWD_DEFINED__
#define __SlicerPivotTables_FWD_DEFINED__
typedef interface SlicerPivotTables SlicerPivotTables;
#endif 	/* __SlicerPivotTables_FWD_DEFINED__ */


#ifndef __ProtectedViewWindows_FWD_DEFINED__
#define __ProtectedViewWindows_FWD_DEFINED__
typedef interface ProtectedViewWindows ProtectedViewWindows;
#endif 	/* __ProtectedViewWindows_FWD_DEFINED__ */


#ifndef __ProtectedViewWindow_FWD_DEFINED__
#define __ProtectedViewWindow_FWD_DEFINED__
typedef interface ProtectedViewWindow ProtectedViewWindow;
#endif 	/* __ProtectedViewWindow_FWD_DEFINED__ */


#ifndef __TableObject_FWD_DEFINED__
#define __TableObject_FWD_DEFINED__
typedef interface TableObject TableObject;
#endif 	/* __TableObject_FWD_DEFINED__ */


#ifndef __PivotValueCell_FWD_DEFINED__
#define __PivotValueCell_FWD_DEFINED__
typedef interface PivotValueCell PivotValueCell;
#endif 	/* __PivotValueCell_FWD_DEFINED__ */


#ifndef __QuickAnalysis_FWD_DEFINED__
#define __QuickAnalysis_FWD_DEFINED__
typedef interface QuickAnalysis QuickAnalysis;
#endif 	/* __QuickAnalysis_FWD_DEFINED__ */


#ifndef __ModelConnection_FWD_DEFINED__
#define __ModelConnection_FWD_DEFINED__
typedef interface ModelConnection ModelConnection;
#endif 	/* __ModelConnection_FWD_DEFINED__ */


#ifndef __WorksheetDataConnection_FWD_DEFINED__
#define __WorksheetDataConnection_FWD_DEFINED__
typedef interface WorksheetDataConnection WorksheetDataConnection;
#endif 	/* __WorksheetDataConnection_FWD_DEFINED__ */


#ifndef __TextConnection_FWD_DEFINED__
#define __TextConnection_FWD_DEFINED__
typedef interface TextConnection TextConnection;
#endif 	/* __TextConnection_FWD_DEFINED__ */


#ifndef __DataFeedConnection_FWD_DEFINED__
#define __DataFeedConnection_FWD_DEFINED__
typedef interface DataFeedConnection DataFeedConnection;
#endif 	/* __DataFeedConnection_FWD_DEFINED__ */


#ifndef __ModelTableColumn_FWD_DEFINED__
#define __ModelTableColumn_FWD_DEFINED__
typedef interface ModelTableColumn ModelTableColumn;
#endif 	/* __ModelTableColumn_FWD_DEFINED__ */


#ifndef __ModelTableColumns_FWD_DEFINED__
#define __ModelTableColumns_FWD_DEFINED__
typedef interface ModelTableColumns ModelTableColumns;
#endif 	/* __ModelTableColumns_FWD_DEFINED__ */


#ifndef __ModelTable_FWD_DEFINED__
#define __ModelTable_FWD_DEFINED__
typedef interface ModelTable ModelTable;
#endif 	/* __ModelTable_FWD_DEFINED__ */


#ifndef __ModelTables_FWD_DEFINED__
#define __ModelTables_FWD_DEFINED__
typedef interface ModelTables ModelTables;
#endif 	/* __ModelTables_FWD_DEFINED__ */


#ifndef __ModelRelationship_FWD_DEFINED__
#define __ModelRelationship_FWD_DEFINED__
typedef interface ModelRelationship ModelRelationship;
#endif 	/* __ModelRelationship_FWD_DEFINED__ */


#ifndef __ModelRelationships_FWD_DEFINED__
#define __ModelRelationships_FWD_DEFINED__
typedef interface ModelRelationships ModelRelationships;
#endif 	/* __ModelRelationships_FWD_DEFINED__ */


#ifndef __Model_FWD_DEFINED__
#define __Model_FWD_DEFINED__
typedef interface Model Model;
#endif 	/* __Model_FWD_DEFINED__ */


#ifndef __FullSeriesCollection_FWD_DEFINED__
#define __FullSeriesCollection_FWD_DEFINED__
typedef interface FullSeriesCollection FullSeriesCollection;
#endif 	/* __FullSeriesCollection_FWD_DEFINED__ */


#ifndef __ChartCategory_FWD_DEFINED__
#define __ChartCategory_FWD_DEFINED__
typedef interface ChartCategory ChartCategory;
#endif 	/* __ChartCategory_FWD_DEFINED__ */


#ifndef __CategoryCollection_FWD_DEFINED__
#define __CategoryCollection_FWD_DEFINED__
typedef interface CategoryCollection CategoryCollection;
#endif 	/* __CategoryCollection_FWD_DEFINED__ */


#ifndef __TimelineState_FWD_DEFINED__
#define __TimelineState_FWD_DEFINED__
typedef interface TimelineState TimelineState;
#endif 	/* __TimelineState_FWD_DEFINED__ */


#ifndef __TimelineViewState_FWD_DEFINED__
#define __TimelineViewState_FWD_DEFINED__
typedef interface TimelineViewState TimelineViewState;
#endif 	/* __TimelineViewState_FWD_DEFINED__ */


#ifndef __ModelTableNames_FWD_DEFINED__
#define __ModelTableNames_FWD_DEFINED__
typedef interface ModelTableNames ModelTableNames;
#endif 	/* __ModelTableNames_FWD_DEFINED__ */


#ifndef __ModelTableNameChange_FWD_DEFINED__
#define __ModelTableNameChange_FWD_DEFINED__
typedef interface ModelTableNameChange ModelTableNameChange;
#endif 	/* __ModelTableNameChange_FWD_DEFINED__ */


#ifndef __ModelTableNameChanges_FWD_DEFINED__
#define __ModelTableNameChanges_FWD_DEFINED__
typedef interface ModelTableNameChanges ModelTableNameChanges;
#endif 	/* __ModelTableNameChanges_FWD_DEFINED__ */


#ifndef __ModelChanges_FWD_DEFINED__
#define __ModelChanges_FWD_DEFINED__
typedef interface ModelChanges ModelChanges;
#endif 	/* __ModelChanges_FWD_DEFINED__ */


#ifndef __ModelColumnName_FWD_DEFINED__
#define __ModelColumnName_FWD_DEFINED__
typedef interface ModelColumnName ModelColumnName;
#endif 	/* __ModelColumnName_FWD_DEFINED__ */


#ifndef __ModelColumnNames_FWD_DEFINED__
#define __ModelColumnNames_FWD_DEFINED__
typedef interface ModelColumnNames ModelColumnNames;
#endif 	/* __ModelColumnNames_FWD_DEFINED__ */


#ifndef __ModelColumnChange_FWD_DEFINED__
#define __ModelColumnChange_FWD_DEFINED__
typedef interface ModelColumnChange ModelColumnChange;
#endif 	/* __ModelColumnChange_FWD_DEFINED__ */


#ifndef __ModelColumnChanges_FWD_DEFINED__
#define __ModelColumnChanges_FWD_DEFINED__
typedef interface ModelColumnChanges ModelColumnChanges;
#endif 	/* __ModelColumnChanges_FWD_DEFINED__ */


#ifndef __ModelMeasureName_FWD_DEFINED__
#define __ModelMeasureName_FWD_DEFINED__
typedef interface ModelMeasureName ModelMeasureName;
#endif 	/* __ModelMeasureName_FWD_DEFINED__ */


#ifndef __ModelMeasureNames_FWD_DEFINED__
#define __ModelMeasureNames_FWD_DEFINED__
typedef interface ModelMeasureNames ModelMeasureNames;
#endif 	/* __ModelMeasureNames_FWD_DEFINED__ */


#ifndef __IDummy_FWD_DEFINED__
#define __IDummy_FWD_DEFINED__
typedef interface IDummy IDummy;
#endif 	/* __IDummy_FWD_DEFINED__ */


#ifndef __ICanvasShapes_FWD_DEFINED__
#define __ICanvasShapes_FWD_DEFINED__
typedef interface ICanvasShapes ICanvasShapes;
#endif 	/* __ICanvasShapes_FWD_DEFINED__ */


#ifndef ___DebugTools_FWD_DEFINED__
#define ___DebugTools_FWD_DEFINED__
typedef interface _DebugTools _DebugTools;
#endif 	/* ___DebugTools_FWD_DEFINED__ */


#ifndef __Solver_FWD_DEFINED__
#define __Solver_FWD_DEFINED__
typedef interface Solver Solver;
#endif 	/* __Solver_FWD_DEFINED__ */


#ifndef __Application_FWD_DEFINED__
#define __Application_FWD_DEFINED__

#ifdef __cplusplus
typedef class Application Application;
#else
typedef struct Application Application;
#endif /* __cplusplus */

#endif 	/* __Application_FWD_DEFINED__ */


#ifndef __Global_FWD_DEFINED__
#define __Global_FWD_DEFINED__

#ifdef __cplusplus
typedef class Global Global;
#else
typedef struct Global Global;
#endif /* __cplusplus */

#endif 	/* __Global_FWD_DEFINED__ */


#ifndef __Chart_FWD_DEFINED__
#define __Chart_FWD_DEFINED__

#ifdef __cplusplus
typedef class Chart Chart;
#else
typedef struct Chart Chart;
#endif /* __cplusplus */

#endif 	/* __Chart_FWD_DEFINED__ */


#ifndef __Workbook_FWD_DEFINED__
#define __Workbook_FWD_DEFINED__

#ifdef __cplusplus
typedef class Workbook Workbook;
#else
typedef struct Workbook Workbook;
#endif /* __cplusplus */

#endif 	/* __Workbook_FWD_DEFINED__ */


#ifndef __QueryTable_FWD_DEFINED__
#define __QueryTable_FWD_DEFINED__

#ifdef __cplusplus
typedef class QueryTable QueryTable;
#else
typedef struct QueryTable QueryTable;
#endif /* __cplusplus */

#endif 	/* __QueryTable_FWD_DEFINED__ */


#ifndef __Worksheet_FWD_DEFINED__
#define __Worksheet_FWD_DEFINED__

#ifdef __cplusplus
typedef class Worksheet Worksheet;
#else
typedef struct Worksheet Worksheet;
#endif /* __cplusplus */

#endif 	/* __Worksheet_FWD_DEFINED__ */


#ifndef __OLEObject_FWD_DEFINED__
#define __OLEObject_FWD_DEFINED__

#ifdef __cplusplus
typedef class OLEObject OLEObject;
#else
typedef struct OLEObject OLEObject;
#endif /* __cplusplus */

#endif 	/* __OLEObject_FWD_DEFINED__ */


#ifndef __DebugTools_FWD_DEFINED__
#define __DebugTools_FWD_DEFINED__

#ifdef __cplusplus
typedef class DebugTools DebugTools;
#else
typedef struct DebugTools DebugTools;
#endif /* __cplusplus */

#endif 	/* __DebugTools_FWD_DEFINED__ */


#ifndef __IEXCELCtrlExtender_FWD_DEFINED__
#define __IEXCELCtrlExtender_FWD_DEFINED__
typedef interface IEXCELCtrlExtender IEXCELCtrlExtender;
#endif 	/* __IEXCELCtrlExtender_FWD_DEFINED__ */


#ifndef __KEXCELCtrlExtender_FWD_DEFINED__
#define __KEXCELCtrlExtender_FWD_DEFINED__

#ifdef __cplusplus
typedef class KEXCELCtrlExtender KEXCELCtrlExtender;
#else
typedef struct KEXCELCtrlExtender KEXCELCtrlExtender;
#endif /* __cplusplus */

#endif 	/* __KEXCELCtrlExtender_FWD_DEFINED__ */


/* header files for imported files */
#include "mso_enum.h"

#ifdef __cplusplus
extern "C"{
#endif 



#ifndef __Excel_LIBRARY_DEFINED__
#define __Excel_LIBRARY_DEFINED__

/* library Excel */
/* [helpcontext][helpfile][helpstring][version][uuid] */ 

typedef float single;

typedef 
enum Constants
    {	xlAll	= -4104,
	xlAutomatic	= -4105,
	xlBoth	= 1,
	xlCenter	= -4108,
	xlChecker	= 9,
	xlCircle	= 8,
	xlCorner	= 2,
	xlCrissCross	= 16,
	xlCross	= 4,
	xlDiamond	= 2,
	xlDistributed	= -4117,
	xlDoubleAccounting	= 5,
	xlFixedValue	= 1,
	xlFormats	= -4122,
	xlGray16	= 17,
	xlGray8	= 18,
	xlGrid	= 15,
	xlHigh	= -4127,
	xlInside	= 2,
	xlJustify	= -4130,
	xlLightDown	= 13,
	xlLightHorizontal	= 11,
	xlLightUp	= 14,
	xlLightVertical	= 12,
	xlLow	= -4134,
	xlManual	= -4135,
	xlMinusValues	= 3,
	xlModule	= -4141,
	xlNextToAxis	= 4,
	xlNone	= -4142,
	xlNotes	= -4144,
	xlOff	= -4146,
	xlOn	= 1,
	xlPercent	= 2,
	xlPlus	= 9,
	xlPlusValues	= 2,
	xlSemiGray75	= 10,
	xlShowLabel	= 4,
	xlShowLabelAndPercent	= 5,
	xlShowPercent	= 3,
	xlShowValue	= 2,
	xlSimple	= -4154,
	xlSingle	= 2,
	xlSingleAccounting	= 4,
	xlSolid	= 1,
	xlSquare	= 1,
	xlStar	= 5,
	xlStError	= 4,
	xlToolbarButton	= 2,
	xlTriangle	= 3,
	xlGray25	= -4124,
	xlGray50	= -4125,
	xlGray75	= -4126,
	xlBottom	= -4107,
	xlLeft	= -4131,
	xlRight	= -4152,
	xlTop	= -4160,
	xl3DBar	= -4099,
	xl3DSurface	= -4103,
	xlBar	= 2,
	xlColumn	= 3,
	xlCombination	= -4111,
	xlCustom	= -4114,
	xlDefaultAutoFormat	= -1,
	xlMaximum	= 2,
	xlMinimum	= 4,
	xlOpaque	= 3,
	xlTransparent	= 2,
	xlBidi	= -5000,
	xlLatin	= -5001,
	xlContext	= -5002,
	xlLTR	= -5003,
	xlRTL	= -5004,
	xlFullScript	= 1,
	xlPartialScript	= 2,
	xlMixedScript	= 3,
	xlMixedAuthorizedScript	= 4,
	xlVisualCursor	= 2,
	xlLogicalCursor	= 1,
	xlSystem	= 1,
	xlPartial	= 3,
	xlHindiNumerals	= 3,
	xlBidiCalendar	= 3,
	xlGregorian	= 2,
	xlComplete	= 4,
	xlScale	= 3,
	xlClosed	= 3,
	xlColor1	= 7,
	xlColor2	= 8,
	xlColor3	= 9,
	xlConstants	= 2,
	xlContents	= 2,
	xlBelow	= 1,
	xlCascade	= 7,
	xlCenterAcrossSelection	= 7,
	xlChart4	= 2,
	xlChartSeries	= 17,
	xlChartShort	= 6,
	xlChartTitles	= 18,
	xlClassic1	= 1,
	xlClassic2	= 2,
	xlClassic3	= 3,
	xl3DEffects1	= 13,
	xl3DEffects2	= 14,
	xlAbove	= 0,
	xlAccounting1	= 4,
	xlAccounting2	= 5,
	xlAccounting3	= 6,
	xlAccounting4	= 17,
	xlAdd	= 2,
	xlDebugCodePane	= 13,
	xlDesktop	= 9,
	xlDirect	= 1,
	xlDivide	= 5,
	xlDoubleClosed	= 5,
	xlDoubleOpen	= 4,
	xlDoubleQuote	= 1,
	xlEntireChart	= 20,
	xlExcelMenus	= 1,
	xlExtended	= 3,
	xlFill	= 5,
	xlFirst	= 0,
	xlFloating	= 5,
	xlFormula	= 5,
	xlGeneral	= 1,
	xlGridline	= 22,
	xlIcons	= 1,
	xlImmediatePane	= 12,
	xlInteger	= 2,
	xlLast	= 1,
	xlLastCell	= 11,
	xlList1	= 10,
	xlList2	= 11,
	xlList3	= 12,
	xlLocalFormat1	= 15,
	xlLocalFormat2	= 16,
	xlLong	= 3,
	xlLotusHelp	= 2,
	xlMacrosheetCell	= 7,
	xlMixed	= 2,
	xlMultiply	= 4,
	xlNarrow	= 1,
	xlNoDocuments	= 3,
	xlOpen	= 2,
	xlOutside	= 3,
	xlReference	= 4,
	xlSemiautomatic	= 2,
	xlShort	= 1,
	xlSingleQuote	= 2,
	xlStrict	= 2,
	xlSubtract	= 3,
	xlTextBox	= 16,
	xlTiled	= 1,
	xlTitleBar	= 8,
	xlToolbar	= 1,
	xlVisible	= 12,
	xlWatchPane	= 11,
	xlWide	= 3,
	xlWorkbookTab	= 6,
	xlWorksheet4	= 1,
	xlWorksheetCell	= 3,
	xlWorksheetShort	= 5,
	xlAllExceptBorders	= 7,
	xlLeftToRight	= 2,
	xlTopToBottom	= 1,
	xlVeryHidden	= 2,
	xlDrawingObject	= 14
    } 	Constants;

typedef 
enum XlCreator
    {	xlCreatorCode	= 1480803660
    } 	XlCreator;

typedef 
enum XlChartGallery
    {	xlBuiltIn	= 21,
	xlUserDefined	= 22,
	xlAnyGallery	= 23
    } 	XlChartGallery;

typedef 
enum XlColorIndex
    {	xlColorIndexAutomatic	= -4105,
	xlColorIndexNone	= -4142
    } 	XlColorIndex;

typedef 
enum XlEndStyleCap
    {	xlCap	= 1,
	xlNoCap	= 2
    } 	XlEndStyleCap;

typedef 
enum XlRowCol
    {	xlColumns	= 2,
	xlRows	= 1
    } 	XlRowCol;

typedef 
enum XlScaleType
    {	xlScaleLinear	= -4132,
	xlScaleLogarithmic	= -4133
    } 	XlScaleType;

typedef 
enum XlDataSeriesType
    {	xlAutoFill	= 4,
	xlChronological	= 3,
	xlGrowth	= 2,
	xlDataSeriesLinear	= -4132
    } 	XlDataSeriesType;

typedef 
enum XlAxisCrosses
    {	xlAxisCrossesAutomatic	= -4105,
	xlAxisCrossesCustom	= -4114,
	xlAxisCrossesMaximum	= 2,
	xlAxisCrossesMinimum	= 4
    } 	XlAxisCrosses;

typedef 
enum XlAxisGroup
    {	xlPrimary	= 1,
	xlSecondary	= 2
    } 	XlAxisGroup;

typedef 
enum XlBackground
    {	xlBackgroundAutomatic	= -4105,
	xlBackgroundOpaque	= 3,
	xlBackgroundTransparent	= 2
    } 	XlBackground;

typedef 
enum XlWindowState
    {	xlMaximized	= -4137,
	xlMinimized	= -4140,
	xlNormal	= -4143
    } 	XlWindowState;

typedef 
enum XlAxisType
    {	xlCategory	= 1,
	xlSeriesAxis	= 3,
	xlValue	= 2
    } 	XlAxisType;

typedef 
enum XlArrowHeadLength
    {	xlArrowHeadLengthLong	= 3,
	xlArrowHeadLengthMedium	= -4138,
	xlArrowHeadLengthShort	= 1
    } 	XlArrowHeadLength;

typedef 
enum XlVAlign
    {	xlVAlignBottom	= -4107,
	xlVAlignCenter	= -4108,
	xlVAlignDistributed	= -4117,
	xlVAlignJustify	= -4130,
	xlVAlignTop	= -4160
    } 	XlVAlign;

typedef 
enum XlTickMark
    {	xlTickMarkCross	= 4,
	xlTickMarkInside	= 2,
	xlTickMarkNone	= -4142,
	xlTickMarkOutside	= 3
    } 	XlTickMark;

typedef 
enum XlErrorBarDirection
    {	xlX	= -4168,
	xlY	= 1
    } 	XlErrorBarDirection;

typedef 
enum XlErrorBarInclude
    {	xlErrorBarIncludeBoth	= 1,
	xlErrorBarIncludeMinusValues	= 3,
	xlErrorBarIncludeNone	= -4142,
	xlErrorBarIncludePlusValues	= 2
    } 	XlErrorBarInclude;

typedef 
enum XlDisplayBlanksAs
    {	xlInterpolated	= 3,
	xlNotPlotted	= 1,
	xlZero	= 2
    } 	XlDisplayBlanksAs;

typedef 
enum XlArrowHeadStyle
    {	xlArrowHeadStyleClosed	= 3,
	xlArrowHeadStyleDoubleClosed	= 5,
	xlArrowHeadStyleDoubleOpen	= 4,
	xlArrowHeadStyleNone	= -4142,
	xlArrowHeadStyleOpen	= 2
    } 	XlArrowHeadStyle;

typedef 
enum XlArrowHeadWidth
    {	xlArrowHeadWidthMedium	= -4138,
	xlArrowHeadWidthNarrow	= 1,
	xlArrowHeadWidthWide	= 3
    } 	XlArrowHeadWidth;

typedef 
enum XlHAlign
    {	xlHAlignCenter	= -4108,
	xlHAlignCenterAcrossSelection	= 7,
	xlHAlignDistributed	= -4117,
	xlHAlignFill	= 5,
	xlHAlignGeneral	= 1,
	xlHAlignJustify	= -4130,
	xlHAlignLeft	= -4131,
	xlHAlignRight	= -4152
    } 	XlHAlign;

typedef 
enum XlTickLabelPosition
    {	xlTickLabelPositionHigh	= -4127,
	xlTickLabelPositionLow	= -4134,
	xlTickLabelPositionNextToAxis	= 4,
	xlTickLabelPositionNone	= -4142
    } 	XlTickLabelPosition;

typedef 
enum XlLegendPosition
    {	xlLegendPositionBottom	= -4107,
	xlLegendPositionCorner	= 2,
	xlLegendPositionLeft	= -4131,
	xlLegendPositionRight	= -4152,
	xlLegendPositionTop	= -4160,
	xlLegendPositionCustom	= -4161
    } 	XlLegendPosition;

typedef 
enum XlChartPictureType
    {	xlStackScale	= 3,
	xlStack	= 2,
	xlStretch	= 1
    } 	XlChartPictureType;

typedef 
enum XlChartPicturePlacement
    {	xlSides	= 1,
	xlEnd	= 2,
	xlEndSides	= 3,
	xlFront	= 4,
	xlFrontSides	= 5,
	xlFrontEnd	= 6,
	xlAllFaces	= 7
    } 	XlChartPicturePlacement;

typedef 
enum XlOrientation
    {	xlDownward	= -4170,
	xlHorizontal	= -4128,
	xlUpward	= -4171,
	xlVertical	= -4166
    } 	XlOrientation;

typedef 
enum XlTickLabelOrientation
    {	xlTickLabelOrientationAutomatic	= -4105,
	xlTickLabelOrientationDownward	= -4170,
	xlTickLabelOrientationHorizontal	= -4128,
	xlTickLabelOrientationUpward	= -4171,
	xlTickLabelOrientationVertical	= -4166
    } 	XlTickLabelOrientation;

typedef 
enum XlBorderWeight
    {	xlHairline	= 1,
	xlMedium	= -4138,
	xlThick	= 4,
	xlThin	= 2
    } 	XlBorderWeight;

typedef 
enum XlDataSeriesDate
    {	xlDay	= 1,
	xlMonth	= 3,
	xlWeekday	= 2,
	xlYear	= 4
    } 	XlDataSeriesDate;

typedef 
enum XlUnderlineStyle
    {	xlUnderlineStyleDouble	= -4119,
	xlUnderlineStyleDoubleAccounting	= 5,
	xlUnderlineStyleNone	= -4142,
	xlUnderlineStyleSingle	= 2,
	xlUnderlineStyleSingleAccounting	= 4
    } 	XlUnderlineStyle;

typedef 
enum XlErrorBarType
    {	xlErrorBarTypeCustom	= -4114,
	xlErrorBarTypeFixedValue	= 1,
	xlErrorBarTypePercent	= 2,
	xlErrorBarTypeStDev	= -4155,
	xlErrorBarTypeStError	= 4
    } 	XlErrorBarType;

typedef 
enum XlTrendlineType
    {	xlExponential	= 5,
	xlLinear	= -4132,
	xlLogarithmic	= -4133,
	xlMovingAvg	= 6,
	xlPolynomial	= 3,
	xlPower	= 4
    } 	XlTrendlineType;

typedef 
enum XlLineStyle
    {	xlContinuous	= 1,
	xlDash	= -4115,
	xlDashDot	= 4,
	xlDashDotDot	= 5,
	xlDot	= -4118,
	xlDouble	= -4119,
	xlSlantDashDot	= 13,
	xlLineStyleNone	= -4142
    } 	XlLineStyle;

typedef 
enum XlDataLabelsType
    {	xlDataLabelsShowNone	= -4142,
	xlDataLabelsShowValue	= 2,
	xlDataLabelsShowPercent	= 3,
	xlDataLabelsShowLabel	= 4,
	xlDataLabelsShowLabelAndPercent	= 5,
	xlDataLabelsShowBubbleSizes	= 6
    } 	XlDataLabelsType;

typedef 
enum XlMarkerStyle
    {	xlMarkerStyleAutomatic	= -4105,
	xlMarkerStyleCircle	= 8,
	xlMarkerStyleDash	= -4115,
	xlMarkerStyleDiamond	= 2,
	xlMarkerStyleDot	= -4118,
	xlMarkerStyleNone	= -4142,
	xlMarkerStylePicture	= -4147,
	xlMarkerStylePlus	= 9,
	xlMarkerStyleSquare	= 1,
	xlMarkerStyleStar	= 5,
	xlMarkerStyleTriangle	= 3,
	xlMarkerStyleX	= -4168
    } 	XlMarkerStyle;

typedef 
enum XlPictureConvertorType
    {	xlBMP	= 1,
	xlCGM	= 7,
	xlDRW	= 4,
	xlDXF	= 5,
	xlEPS	= 8,
	xlHGL	= 6,
	xlPCT	= 13,
	xlPCX	= 10,
	xlPIC	= 11,
	xlPLT	= 12,
	xlTIF	= 9,
	xlWMF	= 2,
	xlWPG	= 3
    } 	XlPictureConvertorType;

typedef 
enum XlPattern
    {	xlPatternAutomatic	= -4105,
	xlPatternChecker	= 9,
	xlPatternCrissCross	= 16,
	xlPatternDown	= -4121,
	xlPatternGray16	= 17,
	xlPatternGray25	= -4124,
	xlPatternGray50	= -4125,
	xlPatternGray75	= -4126,
	xlPatternGray8	= 18,
	xlPatternGrid	= 15,
	xlPatternHorizontal	= -4128,
	xlPatternLightDown	= 13,
	xlPatternLightHorizontal	= 11,
	xlPatternLightUp	= 14,
	xlPatternLightVertical	= 12,
	xlPatternNone	= -4142,
	xlPatternSemiGray75	= 10,
	xlPatternSolid	= 1,
	xlPatternUp	= -4162,
	xlPatternVertical	= -4166,
	xlPatternLinearGradient	= 4000,
	xlPatternRectangularGradient	= 4001
    } 	XlPattern;

typedef 
enum XlChartSplitType
    {	xlSplitByPosition	= 1,
	xlSplitByPercentValue	= 3,
	xlSplitByCustomSplit	= 4,
	xlSplitByValue	= 2
    } 	XlChartSplitType;

typedef 
enum XlDisplayUnit
    {	xlHundreds	= -2,
	xlThousands	= -3,
	xlTenThousands	= -4,
	xlHundredThousands	= -5,
	xlMillions	= -6,
	xlTenMillions	= -7,
	xlHundredMillions	= -8,
	xlThousandMillions	= -9,
	xlMillionMillions	= -10
    } 	XlDisplayUnit;

typedef 
enum XlDataLabelPosition
    {	xlLabelPositionCenter	= -4108,
	xlLabelPositionAbove	= 0,
	xlLabelPositionBelow	= 1,
	xlLabelPositionLeft	= -4131,
	xlLabelPositionRight	= -4152,
	xlLabelPositionOutsideEnd	= 2,
	xlLabelPositionInsideEnd	= 3,
	xlLabelPositionInsideBase	= 4,
	xlLabelPositionBestFit	= 5,
	xlLabelPositionMixed	= 6,
	xlLabelPositionCustom	= 7
    } 	XlDataLabelPosition;

typedef 
enum XlTimeUnit
    {	xlDays	= 0,
	xlMonths	= 1,
	xlYears	= 2
    } 	XlTimeUnit;

typedef 
enum XlCategoryType
    {	xlCategoryScale	= 2,
	xlTimeScale	= 3,
	xlAutomaticScale	= -4105
    } 	XlCategoryType;

typedef 
enum XlBarShape
    {	xlBox	= 0,
	xlPyramidToPoint	= 1,
	xlPyramidToMax	= 2,
	xlCylinder	= 3,
	xlConeToPoint	= 4,
	xlConeToMax	= 5
    } 	XlBarShape;

typedef 
enum XlChartType
    {	xlColumnClustered	= 51,
	xlColumnStacked	= 52,
	xlColumnStacked100	= 53,
	xl3DColumnClustered	= 54,
	xl3DColumnStacked	= 55,
	xl3DColumnStacked100	= 56,
	xlBarClustered	= 57,
	xlBarStacked	= 58,
	xlBarStacked100	= 59,
	xl3DBarClustered	= 60,
	xl3DBarStacked	= 61,
	xl3DBarStacked100	= 62,
	xlLineStacked	= 63,
	xlLineStacked100	= 64,
	xlLineMarkers	= 65,
	xlLineMarkersStacked	= 66,
	xlLineMarkersStacked100	= 67,
	xlPieOfPie	= 68,
	xlPieExploded	= 69,
	xl3DPieExploded	= 70,
	xlBarOfPie	= 71,
	xlXYScatterSmooth	= 72,
	xlXYScatterSmoothNoMarkers	= 73,
	xlXYScatterLines	= 74,
	xlXYScatterLinesNoMarkers	= 75,
	xlAreaStacked	= 76,
	xlAreaStacked100	= 77,
	xl3DAreaStacked	= 78,
	xl3DAreaStacked100	= 79,
	xlDoughnutExploded	= 80,
	xlRadarMarkers	= 81,
	xlRadarFilled	= 82,
	xlSurface	= 83,
	xlSurfaceWireframe	= 84,
	xlSurfaceTopView	= 85,
	xlSurfaceTopViewWireframe	= 86,
	xlBubble	= 15,
	xlBubble3DEffect	= 87,
	xlStockHLC	= 88,
	xlStockOHLC	= 89,
	xlStockVHLC	= 90,
	xlStockVOHLC	= 91,
	xlCylinderColClustered	= 92,
	xlCylinderColStacked	= 93,
	xlCylinderColStacked100	= 94,
	xlCylinderBarClustered	= 95,
	xlCylinderBarStacked	= 96,
	xlCylinderBarStacked100	= 97,
	xlCylinderCol	= 98,
	xlConeColClustered	= 99,
	xlConeColStacked	= 100,
	xlConeColStacked100	= 101,
	xlConeBarClustered	= 102,
	xlConeBarStacked	= 103,
	xlConeBarStacked100	= 104,
	xlConeCol	= 105,
	xlPyramidColClustered	= 106,
	xlPyramidColStacked	= 107,
	xlPyramidColStacked100	= 108,
	xlPyramidBarClustered	= 109,
	xlPyramidBarStacked	= 110,
	xlPyramidBarStacked100	= 111,
	xlPyramidCol	= 112,
	xl3DColumn	= -4100,
	xlLine	= 4,
	xl3DLine	= -4101,
	xl3DPie	= -4102,
	xlPie	= 5,
	xlXYScatter	= -4169,
	xl3DArea	= -4098,
	xlArea	= 1,
	xlDoughnut	= -4120,
	xlRadar	= -4151
    } 	XlChartType;

typedef 
enum XlChartItem
    {	xlDataLabel	= 0,
	xlChartArea	= 2,
	xlSeries	= 3,
	xlChartTitle	= 4,
	xlWalls	= 5,
	xlCorners	= 6,
	xlDataTable	= 7,
	xlTrendline	= 8,
	xlErrorBars	= 9,
	xlXErrorBars	= 10,
	xlYErrorBars	= 11,
	xlLegendEntry	= 12,
	xlLegendKey	= 13,
	xlShape	= 14,
	xlMajorGridlines	= 15,
	xlMinorGridlines	= 16,
	xlAxisTitle	= 17,
	xlUpBars	= 18,
	xlPlotArea	= 19,
	xlDownBars	= 20,
	xlAxis	= 21,
	xlSeriesLines	= 22,
	xlFloor	= 23,
	xlLegend	= 24,
	xlHiLoLines	= 25,
	xlDropLines	= 26,
	xlRadarAxisLabels	= 27,
	xlNothing	= 28,
	xlLeaderLines	= 29,
	xlDisplayUnitLabel	= 30,
	xlPivotChartFieldButton	= 31,
	xlPivotChartDropZone	= 32
    } 	XlChartItem;

typedef 
enum XlSizeRepresents
    {	xlSizeIsWidth	= 2,
	xlSizeIsArea	= 1
    } 	XlSizeRepresents;

typedef 
enum XlInsertShiftDirection
    {	xlShiftDown	= -4121,
	xlShiftToRight	= -4161
    } 	XlInsertShiftDirection;

typedef 
enum XlDeleteShiftDirection
    {	xlShiftToLeft	= -4159,
	xlShiftUp	= -4162
    } 	XlDeleteShiftDirection;

typedef 
enum XlDirection
    {	xlDown	= -4121,
	xlToLeft	= -4159,
	xlToRight	= -4161,
	xlUp	= -4162
    } 	XlDirection;

typedef 
enum XlConsolidationFunction
    {	xlAverage	= -4106,
	xlCount	= -4112,
	xlCountNums	= -4113,
	xlMax	= -4136,
	xlMin	= -4139,
	xlProduct	= -4149,
	xlStDev	= -4155,
	xlStDevP	= -4156,
	xlSum	= -4157,
	xlVar	= -4164,
	xlVarP	= -4165,
	xlUnknown	= 1000,
	xlDistinctCount	= 11
    } 	XlConsolidationFunction;

typedef 
enum XlSheetType
    {	xlChart	= -4109,
	xlDialogSheet	= -4116,
	xlExcel4IntlMacroSheet	= 4,
	xlExcel4MacroSheet	= 3,
	xlWorksheet	= -4167
    } 	XlSheetType;

typedef 
enum XlLocationInTable
    {	xlColumnHeader	= -4110,
	xlColumnItem	= 5,
	xlDataHeader	= 3,
	xlDataItem	= 7,
	xlPageHeader	= 2,
	xlPageItem	= 6,
	xlRowHeader	= -4153,
	xlRowItem	= 4,
	xlTableBody	= 8
    } 	XlLocationInTable;

typedef 
enum XlFindLookIn
    {	xlFormulas	= -4123,
	xlComments	= -4144,
	xlValues	= -4163
    } 	XlFindLookIn;

typedef 
enum XlWindowType
    {	xlChartAsWindow	= 5,
	xlChartInPlace	= 4,
	xlClipboard	= 3,
	xlInfo	= -4129,
	xlWorkbook	= 1
    } 	XlWindowType;

typedef 
enum XlPivotFieldDataType
    {	xlDate	= 2,
	xlNumber	= -4145,
	xlText	= -4158
    } 	XlPivotFieldDataType;

typedef 
enum XlCopyPictureFormat
    {	xlBitmap	= 2,
	xlPicture	= -4147
    } 	XlCopyPictureFormat;

typedef 
enum XlPivotTableSourceType
    {	xlScenario	= 4,
	xlConsolidation	= 3,
	xlDatabase	= 1,
	xlExternal	= 2,
	xlPivotTable	= -4148
    } 	XlPivotTableSourceType;

typedef 
enum XlReferenceStyle
    {	xlA1	= 1,
	xlR1C1	= -4150
    } 	XlReferenceStyle;

typedef 
enum XlMSApplication
    {	xlMicrosoftAccess	= 4,
	xlMicrosoftFoxPro	= 5,
	xlMicrosoftMail	= 3,
	xlMicrosoftPowerPoint	= 2,
	xlMicrosoftProject	= 6,
	xlMicrosoftSchedulePlus	= 7,
	xlMicrosoftWord	= 1
    } 	XlMSApplication;

typedef 
enum XlMouseButton
    {	xlNoButton	= 0,
	xlPrimaryButton	= 1,
	xlSecondaryButton	= 2
    } 	XlMouseButton;

typedef 
enum XlCutCopyMode
    {	xlCopy	= 1,
	xlCut	= 2
    } 	XlCutCopyMode;

typedef 
enum XlFillWith
    {	xlFillWithAll	= -4104,
	xlFillWithContents	= 2,
	xlFillWithFormats	= -4122
    } 	XlFillWith;

typedef 
enum XlFilterAction
    {	xlFilterCopy	= 2,
	xlFilterInPlace	= 1
    } 	XlFilterAction;

typedef 
enum XlOrder
    {	xlDownThenOver	= 1,
	xlOverThenDown	= 2
    } 	XlOrder;

typedef 
enum XlLinkType
    {	xlLinkTypeExcelLinks	= 1,
	xlLinkTypeOLELinks	= 2
    } 	XlLinkType;

typedef 
enum XlApplyNamesOrder
    {	xlColumnThenRow	= 2,
	xlRowThenColumn	= 1
    } 	XlApplyNamesOrder;

typedef 
enum XlEnableCancelKey
    {	xlDisabled	= 0,
	xlErrorHandler	= 2,
	xlInterrupt	= 1
    } 	XlEnableCancelKey;

typedef 
enum XlPageBreak
    {	xlPageBreakAutomatic	= -4105,
	xlPageBreakManual	= -4135,
	xlPageBreakNone	= -4142
    } 	XlPageBreak;

typedef 
enum XlOLEType
    {	xlOLEControl	= 2,
	xlOLEEmbed	= 1,
	xlOLELink	= 0
    } 	XlOLEType;

typedef 
enum XlPageOrientation
    {	xlLandscape	= 2,
	xlPortrait	= 1
    } 	XlPageOrientation;

typedef 
enum XlLinkInfo
    {	xlEditionDate	= 2,
	xlUpdateState	= 1,
	xlLinkInfoStatus	= 3
    } 	XlLinkInfo;

typedef 
enum XlCommandUnderlines
    {	xlCommandUnderlinesAutomatic	= -4105,
	xlCommandUnderlinesOff	= -4146,
	xlCommandUnderlinesOn	= 1
    } 	XlCommandUnderlines;

typedef 
enum XlOLEVerb
    {	xlVerbOpen	= 2,
	xlVerbPrimary	= 1
    } 	XlOLEVerb;

typedef 
enum XlCalculation
    {	xlCalculationAutomatic	= -4105,
	xlCalculationManual	= -4135,
	xlCalculationSemiautomatic	= 2
    } 	XlCalculation;

typedef 
enum XlFileAccess
    {	xlReadOnly	= 3,
	xlReadWrite	= 2
    } 	XlFileAccess;

typedef 
enum XlEditionType
    {	xlPublisher	= 1,
	xlSubscriber	= 2
    } 	XlEditionType;

typedef 
enum XlObjectSize
    {	xlFitToPage	= 2,
	xlFullPage	= 3,
	xlScreenSize	= 1
    } 	XlObjectSize;

typedef 
enum XlLookAt
    {	xlPart	= 2,
	xlWhole	= 1
    } 	XlLookAt;

typedef 
enum XlMailSystem
    {	xlMAPI	= 1,
	xlNoMailSystem	= 0,
	xlPowerTalk	= 2
    } 	XlMailSystem;

typedef 
enum XlLinkInfoType
    {	xlLinkInfoOLELinks	= 2,
	xlLinkInfoPublishers	= 5,
	xlLinkInfoSubscribers	= 6
    } 	XlLinkInfoType;

typedef 
enum XlCVError
    {	xlErrDiv0	= 2007,
	xlErrNA	= 2042,
	xlErrName	= 2029,
	xlErrNull	= 2000,
	xlErrNum	= 2036,
	xlErrRef	= 2023,
	xlErrValue	= 2015
    } 	XlCVError;

typedef 
enum XlEditionFormat
    {	xlBIFF	= 2,
	xlPICT	= 1,
	xlRTF	= 4,
	xlVALU	= 8
    } 	XlEditionFormat;

typedef 
enum XlLink
    {	xlExcelLinks	= 1,
	xlOLELinks	= 2,
	xlPublishers	= 5,
	xlSubscribers	= 6
    } 	XlLink;

typedef 
enum XlCellType
    {	xlCellTypeBlanks	= 4,
	xlCellTypeConstants	= 2,
	xlCellTypeFormulas	= -4123,
	xlCellTypeLastCell	= 11,
	xlCellTypeComments	= -4144,
	xlCellTypeVisible	= 12,
	xlCellTypeAllFormatConditions	= -4172,
	xlCellTypeSameFormatConditions	= -4173,
	xlCellTypeAllValidation	= -4174,
	xlCellTypeSameValidation	= -4175
    } 	XlCellType;

typedef 
enum XlArrangeStyle
    {	xlArrangeStyleCascade	= 7,
	xlArrangeStyleHorizontal	= -4128,
	xlArrangeStyleTiled	= 1,
	xlArrangeStyleVertical	= -4166
    } 	XlArrangeStyle;

typedef 
enum XlMousePointer
    {	xlIBeam	= 3,
	xlDefault	= -4143,
	xlNorthwestArrow	= 1,
	xlWait	= 2
    } 	XlMousePointer;

typedef 
enum XlEditionOptionsOption
    {	xlAutomaticUpdate	= 4,
	xlCancel	= 1,
	xlChangeAttributes	= 6,
	xlManualUpdate	= 5,
	xlOpenSource	= 3,
	xlSelect	= 3,
	xlSendPublisher	= 2,
	xlUpdateSubscriber	= 2
    } 	XlEditionOptionsOption;

typedef 
enum XlAutoFillType
    {	xlFillCopy	= 1,
	xlFillDays	= 5,
	xlFillDefault	= 0,
	xlFillFormats	= 3,
	xlFillMonths	= 7,
	xlFillSeries	= 2,
	xlFillValues	= 4,
	xlFillWeekdays	= 6,
	xlFillYears	= 8,
	xlGrowthTrend	= 10,
	xlLinearTrend	= 9,
	xlFlashFill	= 11
    } 	XlAutoFillType;

typedef 
enum XlAutoFilterOperator
    {	xlAnd	= 1,
	xlBottom10Items	= 4,
	xlBottom10Percent	= 6,
	xlOr	= 2,
	xlTop10Items	= 3,
	xlTop10Percent	= 5,
	xlFilterValues	= 7,
	xlFilterCellColor	= 8,
	xlFilterFontColor	= 9,
	xlFilterIcon	= 10,
	xlFilterDynamic	= 11,
	xlFilterNoFill	= 12,
	xlFilterAutomaticFontColor	= 13,
	xlFilterNoIcon	= 14
    } 	XlAutoFilterOperator;

typedef 
enum XlClipboardFormat
    {	xlClipboardFormatBIFF12	= 63,
	xlClipboardFormatBIFF	= 8,
	xlClipboardFormatBIFF2	= 18,
	xlClipboardFormatBIFF3	= 20,
	xlClipboardFormatBIFF4	= 30,
	xlClipboardFormatBinary	= 15,
	xlClipboardFormatBitmap	= 9,
	xlClipboardFormatCGM	= 13,
	xlClipboardFormatCSV	= 5,
	xlClipboardFormatDIF	= 4,
	xlClipboardFormatDspText	= 12,
	xlClipboardFormatEmbeddedObject	= 21,
	xlClipboardFormatEmbedSource	= 22,
	xlClipboardFormatLink	= 11,
	xlClipboardFormatLinkSource	= 23,
	xlClipboardFormatLinkSourceDesc	= 32,
	xlClipboardFormatMovie	= 24,
	xlClipboardFormatNative	= 14,
	xlClipboardFormatObjectDesc	= 31,
	xlClipboardFormatObjectLink	= 19,
	xlClipboardFormatOwnerLink	= 17,
	xlClipboardFormatPICT	= 2,
	xlClipboardFormatPrintPICT	= 3,
	xlClipboardFormatRTF	= 7,
	xlClipboardFormatScreenPICT	= 29,
	xlClipboardFormatStandardFont	= 28,
	xlClipboardFormatStandardScale	= 27,
	xlClipboardFormatSYLK	= 6,
	xlClipboardFormatTable	= 16,
	xlClipboardFormatText	= 0,
	xlClipboardFormatToolFace	= 25,
	xlClipboardFormatToolFacePICT	= 26,
	xlClipboardFormatVALU	= 1,
	xlClipboardFormatWK1	= 10
    } 	XlClipboardFormat;

typedef 
enum XlFileFormat
    {	xlAddIn	= 18,
	xlCSV	= 6,
	xlCSVMac	= 22,
	xlCSVMSDOS	= 24,
	xlCSVWindows	= 23,
	xlDBF2	= 7,
	xlDBF3	= 8,
	xlDBF4	= 11,
	xlDIF	= 9,
	xlExcel2	= 16,
	xlExcel2FarEast	= 27,
	xlExcel3	= 29,
	xlExcel4	= 33,
	xlExcel5	= 39,
	xlExcel7	= 39,
	xlExcel9795	= 43,
	xlExcel4Workbook	= 35,
	xlIntlAddIn	= 26,
	xlIntlMacro	= 25,
	xlWorkbookNormal	= -4143,
	xlSYLK	= 2,
	xlTemplate	= 17,
	xlCurrentPlatformText	= -4158,
	xlTextMac	= 19,
	xlTextMSDOS	= 21,
	xlTextPrinter	= 36,
	xlTextWindows	= 20,
	xlWJ2WD1	= 14,
	xlWK1	= 5,
	xlWK1ALL	= 31,
	xlWK1FMT	= 30,
	xlWK3	= 15,
	xlWK4	= 38,
	xlWK3FM3	= 32,
	xlWKS	= 4,
	xlWorks2FarEast	= 28,
	xlWQ1	= 34,
	xlWJ3	= 40,
	xlWJ3FJ3	= 41,
	xlUnicodeText	= 42,
	xlHtml	= 44,
	xlWebArchive	= 45,
	xlXMLSpreadsheet	= 46,
	xlExcel12	= 50,
	xlOpenXMLWorkbook	= 51,
	xlOpenXMLWorkbookMacroEnabled	= 52,
	xlOpenXMLTemplateMacroEnabled	= 53,
	xlTemplate8	= 17,
	xlOpenXMLTemplate	= 54,
	xlAddIn8	= 18,
	xlOpenXMLAddIn	= 55,
	xlExcel8	= 56,
	xlOpenDocumentSpreadsheet	= 60,
	xlOpenXMLStrictWorkbook	= 61,
        xlWorkbookDefault	= 51,
        xlOFD = 102
    } 	XlFileFormat;

typedef 
enum XlApplicationInternational
    {	xl24HourClock	= 33,
	xl4DigitYears	= 43,
	xlAlternateArraySeparator	= 16,
	xlColumnSeparator	= 14,
	xlCountryCode	= 1,
	xlCountrySetting	= 2,
	xlCurrencyBefore	= 37,
	xlCurrencyCode	= 25,
	xlCurrencyDigits	= 27,
	xlCurrencyLeadingZeros	= 40,
	xlCurrencyMinusSign	= 38,
	xlCurrencyNegative	= 28,
	xlCurrencySpaceBefore	= 36,
	xlCurrencyTrailingZeros	= 39,
	xlDateOrder	= 32,
	xlDateSeparator	= 17,
	xlDayCode	= 21,
	xlDayLeadingZero	= 42,
	xlDecimalSeparator	= 3,
	xlGeneralFormatName	= 26,
	xlHourCode	= 22,
	xlLeftBrace	= 12,
	xlLeftBracket	= 10,
	xlListSeparator	= 5,
	xlLowerCaseColumnLetter	= 9,
	xlLowerCaseRowLetter	= 8,
	xlMDY	= 44,
	xlMetric	= 35,
	xlMinuteCode	= 23,
	xlMonthCode	= 20,
	xlMonthLeadingZero	= 41,
	xlMonthNameChars	= 30,
	xlNoncurrencyDigits	= 29,
	xlNonEnglishFunctions	= 34,
	xlRightBrace	= 13,
	xlRightBracket	= 11,
	xlRowSeparator	= 15,
	xlSecondCode	= 24,
	xlThousandsSeparator	= 4,
	xlTimeLeadingZero	= 45,
	xlTimeSeparator	= 18,
	xlUpperCaseColumnLetter	= 7,
	xlUpperCaseRowLetter	= 6,
	xlWeekdayNameChars	= 31,
	xlYearCode	= 19
    } 	XlApplicationInternational;

typedef 
enum XlPageBreakExtent
    {	xlPageBreakFull	= 1,
	xlPageBreakPartial	= 2
    } 	XlPageBreakExtent;

typedef 
enum XlCellInsertionMode
    {	xlOverwriteCells	= 0,
	xlInsertDeleteCells	= 1,
	xlInsertEntireRows	= 2
    } 	XlCellInsertionMode;

typedef 
enum XlFormulaLabel
    {	xlNoLabels	= -4142,
	xlRowLabels	= 1,
	xlColumnLabels	= 2,
	xlMixedLabels	= 3
    } 	XlFormulaLabel;

typedef 
enum XlHighlightChangesTime
    {	xlSinceMyLastSave	= 1,
	xlAllChanges	= 2,
	xlNotYetReviewed	= 3
    } 	XlHighlightChangesTime;

typedef 
enum XlCommentDisplayMode
    {	xlNoIndicator	= 0,
	xlCommentIndicatorOnly	= -1,
	xlCommentAndIndicator	= 1
    } 	XlCommentDisplayMode;

typedef 
enum XlFormatConditionType
    {	xlCellValue	= 1,
	xlExpression	= 2,
	xlColorScale	= 3,
	xlDatabar	= 4,
	xlTop10	= 5,
	xlIconSets	= 6,
	xlUniqueValues	= 8,
	xlTextString	= 9,
	xlBlanksCondition	= 10,
	xlTimePeriod	= 11,
	xlAboveAverageCondition	= 12,
	xlNoBlanksCondition	= 13,
	xlErrorsCondition	= 16,
	xlNoErrorsCondition	= 17
    } 	XlFormatConditionType;

typedef 
enum XlFormatConditionOperator
    {	xlBetween	= 1,
	xlNotBetween	= 2,
	xlEqual	= 3,
	xlNotEqual	= 4,
	xlGreater	= 5,
	xlLess	= 6,
	xlGreaterEqual	= 7,
	xlLessEqual	= 8
    } 	XlFormatConditionOperator;

typedef 
enum XlEnableSelection
    {	xlNoRestrictions	= 0,
	xlUnlockedCells	= 1,
	xlNoSelection	= -4142
    } 	XlEnableSelection;

typedef 
enum XlDVType
    {	xlValidateInputOnly	= 0,
	xlValidateWholeNumber	= 1,
	xlValidateDecimal	= 2,
	xlValidateList	= 3,
	xlValidateDate	= 4,
	xlValidateTime	= 5,
	xlValidateTextLength	= 6,
	xlValidateCustom	= 7
    } 	XlDVType;

typedef 
enum XlIMEMode
    {	xlIMEModeNoControl	= 0,
	xlIMEModeOn	= 1,
	xlIMEModeOff	= 2,
	xlIMEModeDisable	= 3,
	xlIMEModeHiragana	= 4,
	xlIMEModeKatakana	= 5,
	xlIMEModeKatakanaHalf	= 6,
	xlIMEModeAlphaFull	= 7,
	xlIMEModeAlpha	= 8,
	xlIMEModeHangulFull	= 9,
	xlIMEModeHangul	= 10
    } 	XlIMEMode;

typedef 
enum XlDVAlertStyle
    {	xlValidAlertStop	= 1,
	xlValidAlertWarning	= 2,
	xlValidAlertInformation	= 3
    } 	XlDVAlertStyle;

typedef 
enum XlChartLocation
    {	xlLocationAsNewSheet	= 1,
	xlLocationAsObject	= 2,
	xlLocationAutomatic	= 3
    } 	XlChartLocation;

typedef 
enum XlPaperSize
    {	xlPaper10x14	= 16,
	xlPaper11x17	= 17,
	xlPaperA3	= 8,
	xlPaperA4	= 9,
	xlPaperA4Small	= 10,
	xlPaperA5	= 11,
	xlPaperB4	= 12,
	xlPaperB5	= 13,
	xlPaperCsheet	= 24,
	xlPaperDsheet	= 25,
	xlPaperEnvelope10	= 20,
	xlPaperEnvelope11	= 21,
	xlPaperEnvelope12	= 22,
	xlPaperEnvelope14	= 23,
	xlPaperEnvelope9	= 19,
	xlPaperEnvelopeB4	= 33,
	xlPaperEnvelopeB5	= 34,
	xlPaperEnvelopeB6	= 35,
	xlPaperEnvelopeC3	= 29,
	xlPaperEnvelopeC4	= 30,
	xlPaperEnvelopeC5	= 28,
	xlPaperEnvelopeC6	= 31,
	xlPaperEnvelopeC65	= 32,
	xlPaperEnvelopeDL	= 27,
	xlPaperEnvelopeItaly	= 36,
	xlPaperEnvelopeMonarch	= 37,
	xlPaperEnvelopePersonal	= 38,
	xlPaperEsheet	= 26,
	xlPaperExecutive	= 7,
	xlPaperFanfoldLegalGerman	= 41,
	xlPaperFanfoldStdGerman	= 40,
	xlPaperFanfoldUS	= 39,
	xlPaperFolio	= 14,
	xlPaperLedger	= 4,
	xlPaperLegal	= 5,
	xlPaperLetter	= 1,
	xlPaperLetterSmall	= 2,
	xlPaperNote	= 18,
	xlPaperQuarto	= 15,
	xlPaperStatement	= 6,
	xlPaperTabloid	= 3,
	xlPaperUser	= 256
    } 	XlPaperSize;

typedef 
enum XlPasteSpecialOperation
    {	xlPasteSpecialOperationAdd	= 2,
	xlPasteSpecialOperationDivide	= 5,
	xlPasteSpecialOperationMultiply	= 4,
	xlPasteSpecialOperationNone	= -4142,
	xlPasteSpecialOperationSubtract	= 3
    } 	XlPasteSpecialOperation;

typedef 
enum XlPasteType
    {	xlPasteAll	= -4104,
	xlPasteAllUsingSourceTheme	= 13,
	xlPasteAllMergingConditionalFormats	= 14,
	xlPasteAllExceptBorders	= 7,
	xlPasteFormats	= -4122,
	xlPasteFormulas	= -4123,
	xlPasteComments	= -4144,
	xlPasteValues	= -4163,
	xlPasteColumnWidths	= 8,
	xlPasteValidation	= 6,
	xlPasteFormulasAndNumberFormats	= 11,
	xlPasteValuesAndNumberFormats	= 12
    } 	XlPasteType;

typedef 
enum XlPhoneticCharacterType
    {	xlKatakanaHalf	= 0,
	xlKatakana	= 1,
	xlHiragana	= 2,
	xlNoConversion	= 3
    } 	XlPhoneticCharacterType;

typedef 
enum XlPhoneticAlignment
    {	xlPhoneticAlignNoControl	= 0,
	xlPhoneticAlignLeft	= 1,
	xlPhoneticAlignCenter	= 2,
	xlPhoneticAlignDistributed	= 3
    } 	XlPhoneticAlignment;

typedef 
enum XlPictureAppearance
    {	xlPrinter	= 2,
	xlScreen	= 1
    } 	XlPictureAppearance;

typedef 
enum XlPivotFieldOrientation
    {	xlColumnField	= 2,
	xlDataField	= 4,
	xlHidden	= 0,
	xlPageField	= 3,
	xlRowField	= 1
    } 	XlPivotFieldOrientation;

typedef 
enum XlPivotFieldCalculation
    {	xlDifferenceFrom	= 2,
	xlIndex	= 9,
	xlNoAdditionalCalculation	= -4143,
	xlPercentDifferenceFrom	= 4,
	xlPercentOf	= 3,
	xlPercentOfColumn	= 7,
	xlPercentOfRow	= 6,
	xlPercentOfTotal	= 8,
	xlRunningTotal	= 5,
	xlPercentOfParentRow	= 10,
	xlPercentOfParentColumn	= 11,
	xlPercentOfParent	= 12,
	xlPercentRunningTotal	= 13,
	xlRankAscending	= 14,
	xlRankDecending	= 15
    } 	XlPivotFieldCalculation;

typedef 
enum XlPlacement
    {	xlFreeFloating	= 3,
	xlMove	= 2,
	xlMoveAndSize	= 1
    } 	XlPlacement;

typedef 
enum XlPlatform
    {	xlMacintosh	= 1,
	xlMSDOS	= 3,
	xlWindows	= 2
    } 	XlPlatform;

typedef 
enum XlPrintLocation
    {	xlPrintSheetEnd	= 1,
	xlPrintInPlace	= 16,
	xlPrintNoComments	= -4142
    } 	XlPrintLocation;

typedef 
enum XlPriority
    {	xlPriorityHigh	= -4127,
	xlPriorityLow	= -4134,
	xlPriorityNormal	= -4143
    } 	XlPriority;

typedef 
enum XlPTSelectionMode
    {	xlLabelOnly	= 1,
	xlDataAndLabel	= 0,
	xlDataOnly	= 2,
	xlOrigin	= 3,
	xlButton	= 15,
	xlBlanks	= 4,
	xlFirstRow	= 256
    } 	XlPTSelectionMode;

typedef 
enum XlRangeAutoFormat
    {	xlRangeAutoFormat3DEffects1	= 13,
	xlRangeAutoFormat3DEffects2	= 14,
	xlRangeAutoFormatAccounting1	= 4,
	xlRangeAutoFormatAccounting2	= 5,
	xlRangeAutoFormatAccounting3	= 6,
	xlRangeAutoFormatAccounting4	= 17,
	xlRangeAutoFormatClassic1	= 1,
	xlRangeAutoFormatClassic2	= 2,
	xlRangeAutoFormatClassic3	= 3,
	xlRangeAutoFormatColor1	= 7,
	xlRangeAutoFormatColor2	= 8,
	xlRangeAutoFormatColor3	= 9,
	xlRangeAutoFormatList1	= 10,
	xlRangeAutoFormatList2	= 11,
	xlRangeAutoFormatList3	= 12,
	xlRangeAutoFormatLocalFormat1	= 15,
	xlRangeAutoFormatLocalFormat2	= 16,
	xlRangeAutoFormatLocalFormat3	= 19,
	xlRangeAutoFormatLocalFormat4	= 20,
	xlRangeAutoFormatReport1	= 21,
	xlRangeAutoFormatReport2	= 22,
	xlRangeAutoFormatReport3	= 23,
	xlRangeAutoFormatReport4	= 24,
	xlRangeAutoFormatReport5	= 25,
	xlRangeAutoFormatReport6	= 26,
	xlRangeAutoFormatReport7	= 27,
	xlRangeAutoFormatReport8	= 28,
	xlRangeAutoFormatReport9	= 29,
	xlRangeAutoFormatReport10	= 30,
	xlRangeAutoFormatClassicPivotTable	= 31,
	xlRangeAutoFormatTable1	= 32,
	xlRangeAutoFormatTable2	= 33,
	xlRangeAutoFormatTable3	= 34,
	xlRangeAutoFormatTable4	= 35,
	xlRangeAutoFormatTable5	= 36,
	xlRangeAutoFormatTable6	= 37,
	xlRangeAutoFormatTable7	= 38,
	xlRangeAutoFormatTable8	= 39,
	xlRangeAutoFormatTable9	= 40,
	xlRangeAutoFormatTable10	= 41,
	xlRangeAutoFormatPTNone	= 42,
	xlRangeAutoFormatNone	= -4142,
	xlRangeAutoFormatSimple	= -4154
    } 	XlRangeAutoFormat;

typedef 
enum XlReferenceType
    {	xlAbsolute	= 1,
	xlAbsRowRelColumn	= 2,
	xlRelative	= 4,
	xlRelRowAbsColumn	= 3
    } 	XlReferenceType;

typedef 
enum XlLayoutFormType
    {	xlTabular	= 0,
	xlOutline	= 1
    } 	XlLayoutFormType;

typedef 
enum XlRoutingSlipDelivery
    {	xlAllAtOnce	= 2,
	xlOneAfterAnother	= 1
    } 	XlRoutingSlipDelivery;

typedef 
enum XlRoutingSlipStatus
    {	xlNotYetRouted	= 0,
	xlRoutingComplete	= 2,
	xlRoutingInProgress	= 1
    } 	XlRoutingSlipStatus;

typedef 
enum XlRunAutoMacro
    {	xlAutoActivate	= 3,
	xlAutoClose	= 2,
	xlAutoDeactivate	= 4,
	xlAutoOpen	= 1
    } 	XlRunAutoMacro;

typedef 
enum XlSaveAction
    {	xlDoNotSaveChanges	= 2,
	xlSaveChanges	= 1
    } 	XlSaveAction;

typedef 
enum XlSaveAsAccessMode
    {	xlExclusive	= 3,
	xlNoChange	= 1,
	xlShared	= 2
    } 	XlSaveAsAccessMode;

typedef 
enum XlSaveConflictResolution
    {	xlLocalSessionChanges	= 2,
	xlOtherSessionChanges	= 3,
	xlUserResolution	= 1
    } 	XlSaveConflictResolution;

typedef 
enum XlSearchDirection
    {	xlNext	= 1,
	xlPrevious	= 2
    } 	XlSearchDirection;

typedef 
enum XlSearchOrder
    {	xlByColumns	= 2,
	xlByRows	= 1
    } 	XlSearchOrder;

typedef 
enum XlSheetVisibility
    {	xlSheetVisible	= -1,
	xlSheetHidden	= 0,
	xlSheetVeryHidden	= 2
    } 	XlSheetVisibility;

typedef 
enum XlSortMethod
    {	xlPinYin	= 1,
	xlStroke	= 2
    } 	XlSortMethod;

typedef 
enum XlSortMethodOld
    {	xlCodePage	= 2,
	xlSyllabary	= 1
    } 	XlSortMethodOld;

typedef 
enum XlSortOrder
    {	xlAscending	= 1,
	xlDescending	= 2
    } 	XlSortOrder;

typedef 
enum XlSortOrientation
    {	xlSortRows	= 2,
	xlSortColumns	= 1
    } 	XlSortOrientation;

typedef 
enum XlSortType
    {	xlSortLabels	= 2,
	xlSortValues	= 1
    } 	XlSortType;

typedef 
enum XlSpecialCellsValue
    {	xlErrors	= 16,
	xlLogical	= 4,
	xlNumbers	= 1,
	xlTextValues	= 2
    } 	XlSpecialCellsValue;

typedef 
enum XlSubscribeToFormat
    {	xlSubscribeToPicture	= -4147,
	xlSubscribeToText	= -4158
    } 	XlSubscribeToFormat;

typedef 
enum XlSummaryRow
    {	xlSummaryAbove	= 0,
	xlSummaryBelow	= 1
    } 	XlSummaryRow;

typedef 
enum XlSummaryColumn
    {	xlSummaryOnLeft	= -4131,
	xlSummaryOnRight	= -4152
    } 	XlSummaryColumn;

typedef 
enum XlSummaryReportType
    {	xlSummaryPivotTable	= -4148,
	xlStandardSummary	= 1
    } 	XlSummaryReportType;

typedef 
enum XlTabPosition
    {	xlTabPositionFirst	= 0,
	xlTabPositionLast	= 1
    } 	XlTabPosition;

typedef 
enum XlTextParsingType
    {	xlDelimited	= 1,
	xlFixedWidth	= 2
    } 	XlTextParsingType;

typedef 
enum XlTextQualifier
    {	xlTextQualifierDoubleQuote	= 1,
	xlTextQualifierNone	= -4142,
	xlTextQualifierSingleQuote	= 2
    } 	XlTextQualifier;

typedef 
enum XlWBATemplate
    {	xlWBATChart	= -4109,
	xlWBATExcel4IntlMacroSheet	= 4,
	xlWBATExcel4MacroSheet	= 3,
	xlWBATWorksheet	= -4167
    } 	XlWBATemplate;

typedef 
enum XlWindowView
    {	xlNormalView	= 1,
	xlPageBreakPreview	= 2,
	xlPageLayoutView	= 3
    } 	XlWindowView;

typedef 
enum XlXLMMacroType
    {	xlCommand	= 2,
	xlFunction	= 1,
	xlNotXLM	= 3
    } 	XlXLMMacroType;

typedef 
enum XlYesNoGuess
    {	xlGuess	= 0,
	xlNo	= 2,
	xlYes	= 1
    } 	XlYesNoGuess;

typedef 
enum XlBordersIndex
    {	xlInsideHorizontal	= 12,
	xlInsideVertical	= 11,
	xlDiagonalDown	= 5,
	xlDiagonalUp	= 6,
	xlEdgeBottom	= 9,
	xlEdgeLeft	= 7,
	xlEdgeRight	= 10,
	xlEdgeTop	= 8
    } 	XlBordersIndex;

typedef 
enum XlToolbarProtection
    {	xlNoButtonChanges	= 1,
	xlNoChanges	= 4,
	xlNoDockingChanges	= 3,
	xlToolbarProtectionNone	= -4143,
	xlNoShapeChanges	= 2
    } 	XlToolbarProtection;

typedef 
enum XlBuiltInDialog
    {	xlDialogOpen	= 1,
	xlDialogOpenLinks	= 2,
	xlDialogSaveAs	= 5,
	xlDialogFileDelete	= 6,
	xlDialogPageSetup	= 7,
	xlDialogPrint	= 8,
	xlDialogPrinterSetup	= 9,
	xlDialogArrangeAll	= 12,
	xlDialogWindowSize	= 13,
	xlDialogWindowMove	= 14,
	xlDialogRun	= 17,
	xlDialogSetPrintTitles	= 23,
	xlDialogFont	= 26,
	xlDialogDisplay	= 27,
	xlDialogProtectDocument	= 28,
	xlDialogCalculation	= 32,
	xlDialogExtract	= 35,
	xlDialogDataDelete	= 36,
	xlDialogSort	= 39,
	xlDialogDataSeries	= 40,
	xlDialogTable	= 41,
	xlDialogFormatNumber	= 42,
	xlDialogAlignment	= 43,
	xlDialogStyle	= 44,
	xlDialogBorder	= 45,
	xlDialogCellProtection	= 46,
	xlDialogColumnWidth	= 47,
	xlDialogClear	= 52,
	xlDialogPasteSpecial	= 53,
	xlDialogEditDelete	= 54,
	xlDialogInsert	= 55,
	xlDialogPasteNames	= 58,
	xlDialogDefineName	= 61,
	xlDialogCreateNames	= 62,
	xlDialogFormulaGoto	= 63,
	xlDialogFormulaFind	= 64,
	xlDialogGalleryArea	= 67,
	xlDialogGalleryBar	= 68,
	xlDialogGalleryColumn	= 69,
	xlDialogGalleryLine	= 70,
	xlDialogGalleryPie	= 71,
	xlDialogGalleryScatter	= 72,
	xlDialogCombination	= 73,
	xlDialogGridlines	= 76,
	xlDialogAxes	= 78,
	xlDialogAttachText	= 80,
	xlDialogPatterns	= 84,
	xlDialogMainChart	= 85,
	xlDialogOverlay	= 86,
	xlDialogScale	= 87,
	xlDialogFormatLegend	= 88,
	xlDialogFormatText	= 89,
	xlDialogParse	= 91,
	xlDialogUnhide	= 94,
	xlDialogWorkspace	= 95,
	xlDialogActivate	= 103,
	xlDialogCopyPicture	= 108,
	xlDialogDeleteName	= 110,
	xlDialogDeleteFormat	= 111,
	xlDialogNew	= 119,
	xlDialogRowHeight	= 127,
	xlDialogFormatMove	= 128,
	xlDialogFormatSize	= 129,
	xlDialogFormulaReplace	= 130,
	xlDialogSelectSpecial	= 132,
	xlDialogApplyNames	= 133,
	xlDialogReplaceFont	= 134,
	xlDialogSplit	= 137,
	xlDialogOutline	= 142,
	xlDialogSaveWorkbook	= 145,
	xlDialogCopyChart	= 147,
	xlDialogFormatFont	= 150,
	xlDialogNote	= 154,
	xlDialogSetUpdateStatus	= 159,
	xlDialogColorPalette	= 161,
	xlDialogChangeLink	= 166,
	xlDialogAppMove	= 170,
	xlDialogAppSize	= 171,
	xlDialogMainChartType	= 185,
	xlDialogOverlayChartType	= 186,
	xlDialogOpenMail	= 188,
	xlDialogSendMail	= 189,
	xlDialogStandardFont	= 190,
	xlDialogConsolidate	= 191,
	xlDialogSortSpecial	= 192,
	xlDialogGallery3dArea	= 193,
	xlDialogGallery3dColumn	= 194,
	xlDialogGallery3dLine	= 195,
	xlDialogGallery3dPie	= 196,
	xlDialogView3d	= 197,
	xlDialogGoalSeek	= 198,
	xlDialogWorkgroup	= 199,
	xlDialogFillGroup	= 200,
	xlDialogUpdateLink	= 201,
	xlDialogPromote	= 202,
	xlDialogDemote	= 203,
	xlDialogShowDetail	= 204,
	xlDialogObjectProperties	= 207,
	xlDialogSaveNewObject	= 208,
	xlDialogApplyStyle	= 212,
	xlDialogAssignToObject	= 213,
	xlDialogObjectProtection	= 214,
	xlDialogCreatePublisher	= 217,
	xlDialogSubscribeTo	= 218,
	xlDialogShowToolbar	= 220,
	xlDialogPrintPreview	= 222,
	xlDialogEditColor	= 223,
	xlDialogFormatMain	= 225,
	xlDialogFormatOverlay	= 226,
	xlDialogEditSeries	= 228,
	xlDialogDefineStyle	= 229,
	xlDialogGalleryRadar	= 249,
	xlDialogEditionOptions	= 251,
	xlDialogZoom	= 256,
	xlDialogInsertObject	= 259,
	xlDialogSize	= 261,
	xlDialogMove	= 262,
	xlDialogFormatAuto	= 269,
	xlDialogGallery3dBar	= 272,
	xlDialogGallery3dSurface	= 273,
	xlDialogCustomizeToolbar	= 276,
	xlDialogWorkbookAdd	= 281,
	xlDialogWorkbookMove	= 282,
	xlDialogWorkbookCopy	= 283,
	xlDialogWorkbookOptions	= 284,
	xlDialogSaveWorkspace	= 285,
	xlDialogChartWizard	= 288,
	xlDialogAssignToTool	= 293,
	xlDialogPlacement	= 300,
	xlDialogFillWorkgroup	= 301,
	xlDialogWorkbookNew	= 302,
	xlDialogScenarioCells	= 305,
	xlDialogScenarioAdd	= 307,
	xlDialogScenarioEdit	= 308,
	xlDialogScenarioSummary	= 311,
	xlDialogPivotTableWizard	= 312,
	xlDialogPivotFieldProperties	= 313,
	xlDialogOptionsCalculation	= 318,
	xlDialogOptionsEdit	= 319,
	xlDialogOptionsView	= 320,
	xlDialogAddinManager	= 321,
	xlDialogMenuEditor	= 322,
	xlDialogAttachToolbars	= 323,
	xlDialogOptionsChart	= 325,
	xlDialogVbaInsertFile	= 328,
	xlDialogVbaProcedureDefinition	= 330,
	xlDialogRoutingSlip	= 336,
	xlDialogMailLogon	= 339,
	xlDialogInsertPicture	= 342,
	xlDialogGalleryDoughnut	= 344,
	xlDialogChartTrend	= 350,
	xlDialogWorkbookInsert	= 354,
	xlDialogOptionsTransition	= 355,
	xlDialogOptionsGeneral	= 356,
	xlDialogFilterAdvanced	= 370,
	xlDialogMailNextLetter	= 378,
	xlDialogDataLabel	= 379,
	xlDialogInsertTitle	= 380,
	xlDialogFontProperties	= 381,
	xlDialogMacroOptions	= 382,
	xlDialogWorkbookUnhide	= 384,
	xlDialogWorkbookName	= 386,
	xlDialogGalleryCustom	= 388,
	xlDialogAddChartAutoformat	= 390,
	xlDialogChartAddData	= 392,
	xlDialogTabOrder	= 394,
	xlDialogSubtotalCreate	= 398,
	xlDialogWorkbookTabSplit	= 415,
	xlDialogWorkbookProtect	= 417,
	xlDialogScrollbarProperties	= 420,
	xlDialogPivotShowPages	= 421,
	xlDialogTextToColumns	= 422,
	xlDialogFormatCharttype	= 423,
	xlDialogPivotFieldGroup	= 433,
	xlDialogPivotFieldUngroup	= 434,
	xlDialogCheckboxProperties	= 435,
	xlDialogLabelProperties	= 436,
	xlDialogListboxProperties	= 437,
	xlDialogEditboxProperties	= 438,
	xlDialogOpenText	= 441,
	xlDialogPushbuttonProperties	= 445,
	xlDialogFilter	= 447,
	xlDialogFunctionWizard	= 450,
	xlDialogSaveCopyAs	= 456,
	xlDialogOptionsListsAdd	= 458,
	xlDialogSeriesAxes	= 460,
	xlDialogSeriesX	= 461,
	xlDialogSeriesY	= 462,
	xlDialogErrorbarX	= 463,
	xlDialogErrorbarY	= 464,
	xlDialogFormatChart	= 465,
	xlDialogSeriesOrder	= 466,
	xlDialogMailEditMailer	= 470,
	xlDialogStandardWidth	= 472,
	xlDialogScenarioMerge	= 473,
	xlDialogProperties	= 474,
	xlDialogSummaryInfo	= 474,
	xlDialogFindFile	= 475,
	xlDialogActiveCellFont	= 476,
	xlDialogVbaMakeAddin	= 478,
	xlDialogFileSharing	= 481,
	xlDialogAutoCorrect	= 485,
	xlDialogCustomViews	= 493,
	xlDialogInsertNameLabel	= 496,
	xlDialogSeriesShape	= 504,
	xlDialogChartOptionsDataLabels	= 505,
	xlDialogChartOptionsDataTable	= 506,
	xlDialogSetBackgroundPicture	= 509,
	xlDialogDataValidation	= 525,
	xlDialogChartType	= 526,
	xlDialogChartLocation	= 527,
	_xlDialogPhonetic	= 538,
	xlDialogChartSourceData	= 540,
	_xlDialogChartSourceData	= 541,
	xlDialogSeriesOptions	= 557,
	xlDialogPivotTableOptions	= 567,
	xlDialogPivotSolveOrder	= 568,
	xlDialogPivotCalculatedField	= 570,
	xlDialogPivotCalculatedItem	= 572,
	xlDialogConditionalFormatting	= 583,
	xlDialogInsertHyperlink	= 596,
	xlDialogProtectSharing	= 620,
	xlDialogOptionsME	= 647,
	xlDialogPublishAsWebPage	= 653,
	xlDialogPhonetic	= 656,
	xlDialogNewWebQuery	= 667,
	xlDialogImportTextFile	= 666,
	xlDialogExternalDataProperties	= 530,
	xlDialogWebOptionsGeneral	= 683,
	xlDialogWebOptionsFiles	= 684,
	xlDialogWebOptionsPictures	= 685,
	xlDialogWebOptionsEncoding	= 686,
	xlDialogWebOptionsFonts	= 687,
	xlDialogPivotClientServerSet	= 689,
	xlDialogPropertyFields	= 754,
	xlDialogSearch	= 731,
	xlDialogEvaluateFormula	= 709,
	xlDialogDataLabelMultiple	= 723,
	xlDialogChartOptionsDataLabelMultiple	= 724,
	xlDialogErrorChecking	= 732,
	xlDialogWebOptionsBrowsers	= 773,
	xlDialogCreateList	= 796,
	xlDialogPermission	= 832,
	xlDialogMyPermission	= 834,
	xlDialogDocumentInspector	= 862,
	xlDialogNameManager	= 977,
	xlDialogNewName	= 978,
	xlDialogSparklineInsertLine	= 1133,
	xlDialogSparklineInsertColumn	= 1134,
	xlDialogSparklineInsertWinLoss	= 1135,
	xlDialogSlicerSettings	= 1179,
	xlDialogSlicerCreation	= 1182,
	xlDialogSlicerPivotTableConnections	= 1184,
	xlDialogPivotTableSlicerConnections	= 1183,
	xlDialogPivotTableWhatIfAnalysisSettings	= 1153,
	xlDialogSetManager	= 1109,
	xlDialogSetMDXEditor	= 1208,
	xlDialogSetTupleEditorOnRows	= 1107,
	xlDialogSetTupleEditorOnColumns	= 1108,
	xlDialogManageRelationships	= 1271,
	xlDialogCreateRelationship	= 1272,
	xlDialogRecommendedPivotTables	= 1258
    } 	XlBuiltInDialog;

typedef 
enum XlParameterType
    {	xlPrompt	= 0,
	xlConstant	= 1,
	xlRange	= 2
    } 	XlParameterType;

typedef 
enum XlParameterDataType
    {	xlParamTypeUnknown	= 0,
	xlParamTypeChar	= 1,
	xlParamTypeNumeric	= 2,
	xlParamTypeDecimal	= 3,
	xlParamTypeInteger	= 4,
	xlParamTypeSmallInt	= 5,
	xlParamTypeFloat	= 6,
	xlParamTypeReal	= 7,
	xlParamTypeDouble	= 8,
	xlParamTypeVarChar	= 12,
	xlParamTypeDate	= 9,
	xlParamTypeTime	= 10,
	xlParamTypeTimestamp	= 11,
	xlParamTypeLongVarChar	= -1,
	xlParamTypeBinary	= -2,
	xlParamTypeVarBinary	= -3,
	xlParamTypeLongVarBinary	= -4,
	xlParamTypeBigInt	= -5,
	xlParamTypeTinyInt	= -6,
	xlParamTypeBit	= -7,
	xlParamTypeWChar	= -8
    } 	XlParameterDataType;

typedef 
enum XlFormControl
    {	xlButtonControl	= 0,
	xlCheckBox	= 1,
	xlDropDown	= 2,
	xlEditBox	= 3,
	xlGroupBox	= 4,
	xlLabel	= 5,
	xlListBox	= 6,
	xlOptionButton	= 7,
	xlScrollBar	= 8,
	xlSpinner	= 9
    } 	XlFormControl;

typedef 
enum XlSourceType
    {	xlSourceWorkbook	= 0,
	xlSourceSheet	= 1,
	xlSourcePrintArea	= 2,
	xlSourceAutoFilter	= 3,
	xlSourceRange	= 4,
	xlSourceChart	= 5,
	xlSourcePivotTable	= 6,
	xlSourceQuery	= 7
    } 	XlSourceType;

typedef 
enum XlHtmlType
    {	xlHtmlStatic	= 0,
	xlHtmlCalc	= 1,
	xlHtmlList	= 2,
	xlHtmlChart	= 3
    } 	XlHtmlType;

typedef 
enum XlPivotFormatType
    {	xlReport1	= 0,
	xlReport2	= 1,
	xlReport3	= 2,
	xlReport4	= 3,
	xlReport5	= 4,
	xlReport6	= 5,
	xlReport7	= 6,
	xlReport8	= 7,
	xlReport9	= 8,
	xlReport10	= 9,
	xlTable1	= 10,
	xlTable2	= 11,
	xlTable3	= 12,
	xlTable4	= 13,
	xlTable5	= 14,
	xlTable6	= 15,
	xlTable7	= 16,
	xlTable8	= 17,
	xlTable9	= 18,
	xlTable10	= 19,
	xlPTClassic	= 20,
	xlPTNone	= 21
    } 	XlPivotFormatType;

typedef 
enum XlCmdType
    {	xlCmdCube	= 1,
	xlCmdSql	= 2,
	xlCmdTable	= 3,
	xlCmdDefault	= 4,
	xlCmdList	= 5,
	xlCmdTableCollection	= 6,
	xlCmdExcel	= 7,
	xlCmdDAX	= 8
    } 	XlCmdType;

typedef 
enum XlColumnDataType
    {	xlGeneralFormat	= 1,
	xlTextFormat	= 2,
	xlMDYFormat	= 3,
	xlDMYFormat	= 4,
	xlYMDFormat	= 5,
	xlMYDFormat	= 6,
	xlDYMFormat	= 7,
	xlYDMFormat	= 8,
	xlSkipColumn	= 9,
	xlEMDFormat	= 10
    } 	XlColumnDataType;

typedef 
enum XlQueryType
    {	xlODBCQuery	= 1,
	xlDAORecordset	= 2,
	xlWebQuery	= 4,
	xlOLEDBQuery	= 5,
	xlTextImport	= 6,
	xlADORecordset	= 7
    } 	XlQueryType;

typedef 
enum XlWebSelectionType
    {	xlEntirePage	= 1,
	xlAllTables	= 2,
	xlSpecifiedTables	= 3
    } 	XlWebSelectionType;

typedef 
enum XlCubeFieldType
    {	xlHierarchy	= 1,
	xlMeasure	= 2,
	xlSet	= 3
    } 	XlCubeFieldType;

typedef 
enum XlWebFormatting
    {	xlWebFormattingAll	= 1,
	xlWebFormattingRTF	= 2,
	xlWebFormattingNone	= 3
    } 	XlWebFormatting;

typedef 
enum XlDisplayDrawingObjects
    {	xlDisplayShapes	= -4104,
	xlHide	= 3,
	xlPlaceholders	= 2
    } 	XlDisplayDrawingObjects;

typedef 
enum XlSubtototalLocationType
    {	xlAtTop	= 1,
	xlAtBottom	= 2
    } 	XlSubtototalLocationType;

typedef 
enum XlPivotTableVersionList
    {	xlPivotTableVersion2000	= 0,
	xlPivotTableVersion10	= 1,
	xlPivotTableVersion11	= 2,
	xlPivotTableVersion12	= 3,
	xlPivotTableVersion14	= 4,
	xlPivotTableVersion15	= 5,
	xlPivotTableVersionCurrent	= -1
    } 	XlPivotTableVersionList;

typedef 
enum XlPrintErrors
    {	xlPrintErrorsDisplayed	= 0,
	xlPrintErrorsBlank	= 1,
	xlPrintErrorsDash	= 2,
	xlPrintErrorsNA	= 3
    } 	XlPrintErrors;

typedef 
enum XlPivotCellType
    {	xlPivotCellValue	= 0,
	xlPivotCellPivotItem	= 1,
	xlPivotCellSubtotal	= 2,
	xlPivotCellGrandTotal	= 3,
	xlPivotCellDataField	= 4,
	xlPivotCellPivotField	= 5,
	xlPivotCellPageFieldItem	= 6,
	xlPivotCellCustomSubtotal	= 7,
	xlPivotCellDataPivotField	= 8,
	xlPivotCellBlankCell	= 9
    } 	XlPivotCellType;

typedef 
enum XlPivotTableMissingItems
    {	xlMissingItemsDefault	= -1,
	xlMissingItemsNone	= 0,
	xlMissingItemsMax	= 32500,
	xlMissingItemsMax2	= 1048576
    } 	XlPivotTableMissingItems;

typedef 
enum XlCalculationState
    {	xlDone	= 0,
	xlCalculating	= 1,
	xlPending	= 2
    } 	XlCalculationState;

typedef 
enum XlCalculationInterruptKey
    {	xlNoKey	= 0,
	xlEscKey	= 1,
	xlAnyKey	= 2
    } 	XlCalculationInterruptKey;

typedef 
enum XlSortDataOption
    {	xlSortNormal	= 0,
	xlSortTextAsNumbers	= 1
    } 	XlSortDataOption;

typedef 
enum XlUpdateLinks
    {	xlUpdateLinksUserSetting	= 1,
	xlUpdateLinksNever	= 2,
	xlUpdateLinksAlways	= 3
    } 	XlUpdateLinks;

typedef 
enum XlLinkStatus
    {	xlLinkStatusOK	= 0,
	xlLinkStatusMissingFile	= 1,
	xlLinkStatusMissingSheet	= 2,
	xlLinkStatusOld	= 3,
	xlLinkStatusSourceNotCalculated	= 4,
	xlLinkStatusIndeterminate	= 5,
	xlLinkStatusNotStarted	= 6,
	xlLinkStatusInvalidName	= 7,
	xlLinkStatusSourceNotOpen	= 8,
	xlLinkStatusSourceOpen	= 9,
	xlLinkStatusCopiedValues	= 10
    } 	XlLinkStatus;

typedef 
enum XlSearchWithin
    {	xlWithinSheet	= 1,
	xlWithinWorkbook	= 2
    } 	XlSearchWithin;

typedef 
enum XlCorruptLoad
    {	xlNormalLoad	= 0,
	xlRepairFile	= 1,
	xlExtractData	= 2
    } 	XlCorruptLoad;

typedef 
enum XlRobustConnect
    {	xlAsRequired	= 0,
	xlAlways	= 1,
	xlNever	= 2
    } 	XlRobustConnect;

typedef 
enum XlErrorChecks
    {	xlEvaluateToError	= 1,
	xlTextDate	= 2,
	xlNumberAsText	= 3,
	xlInconsistentFormula	= 4,
	xlOmittedCells	= 5,
	xlUnlockedFormulaCells	= 6,
	xlEmptyCellReferences	= 7,
	xlListDataValidation	= 8,
	xlInconsistentListFormula	= 9
    } 	XlErrorChecks;

typedef 
enum XlDataLabelSeparator
    {	xlDataLabelSeparatorDefault	= 1
    } 	XlDataLabelSeparator;

typedef 
enum XlSmartTagDisplayMode
    {	xlIndicatorAndButton	= 0,
	xlDisplayNone	= 1,
	xlButtonOnly	= 2
    } 	XlSmartTagDisplayMode;

typedef 
enum XlRangeValueDataType
    {	xlRangeValueDefault	= 10,
	xlRangeValueXMLSpreadsheet	= 11,
	xlRangeValueMSPersistXML	= 12
    } 	XlRangeValueDataType;

typedef 
enum XlSpeakDirection
    {	xlSpeakByRows	= 0,
	xlSpeakByColumns	= 1
    } 	XlSpeakDirection;

typedef 
enum XlInsertFormatOrigin
    {	xlFormatFromLeftOrAbove	= 0,
	xlFormatFromRightOrBelow	= 1
    } 	XlInsertFormatOrigin;

typedef 
enum XlArabicModes
    {	xlArabicNone	= 0,
	xlArabicStrictAlefHamza	= 1,
	xlArabicStrictFinalYaa	= 2,
	xlArabicBothStrict	= 3
    } 	XlArabicModes;

typedef 
enum XlImportDataAs
    {	xlQueryTable	= 0,
	xlPivotTableReport	= 1,
	xlTable	= 2
    } 	XlImportDataAs;

typedef 
enum XlCalculatedMemberType
    {	xlCalculatedMember	= 0,
	xlCalculatedSet	= 1,
	xlCalculatedMeasure	= 2
    } 	XlCalculatedMemberType;

typedef 
enum XlHebrewModes
    {	xlHebrewFullScript	= 0,
	xlHebrewPartialScript	= 1,
	xlHebrewMixedScript	= 2,
	xlHebrewMixedAuthorizedScript	= 3
    } 	XlHebrewModes;

typedef 
enum XlListObjectSourceType
    {	xlSrcExternal	= 0,
	xlSrcRange	= 1,
	xlSrcXml	= 2,
	xlSrcQuery	= 3,
	xlSrcModel	= 4
    } 	XlListObjectSourceType;

typedef 
enum XlTextVisualLayoutType
    {	xlTextVisualLTR	= 1,
	xlTextVisualRTL	= 2
    } 	XlTextVisualLayoutType;

typedef 
enum XlListDataType
    {	xlListDataTypeNone	= 0,
	xlListDataTypeText	= 1,
	xlListDataTypeMultiLineText	= 2,
	xlListDataTypeNumber	= 3,
	xlListDataTypeCurrency	= 4,
	xlListDataTypeDateTime	= 5,
	xlListDataTypeChoice	= 6,
	xlListDataTypeChoiceMulti	= 7,
	xlListDataTypeListLookup	= 8,
	xlListDataTypeCheckbox	= 9,
	xlListDataTypeHyperLink	= 10,
	xlListDataTypeCounter	= 11,
	xlListDataTypeMultiLineRichText	= 12
    } 	XlListDataType;

typedef 
enum XlTotalsCalculation
    {	xlTotalsCalculationNone	= 0,
	xlTotalsCalculationSum	= 1,
	xlTotalsCalculationAverage	= 2,
	xlTotalsCalculationCount	= 3,
	xlTotalsCalculationCountNums	= 4,
	xlTotalsCalculationMin	= 5,
	xlTotalsCalculationMax	= 6,
	xlTotalsCalculationStdDev	= 7,
	xlTotalsCalculationVar	= 8,
	xlTotalsCalculationCustom	= 9
    } 	XlTotalsCalculation;

typedef 
enum XlXmlLoadOption
    {	xlXmlLoadPromptUser	= 0,
	xlXmlLoadOpenXml	= 1,
	xlXmlLoadImportToList	= 2,
	xlXmlLoadMapXml	= 3
    } 	XlXmlLoadOption;

typedef 
enum XlSmartTagControlType
    {	xlSmartTagControlSmartTag	= 1,
	xlSmartTagControlLink	= 2,
	xlSmartTagControlHelp	= 3,
	xlSmartTagControlHelpURL	= 4,
	xlSmartTagControlSeparator	= 5,
	xlSmartTagControlButton	= 6,
	xlSmartTagControlLabel	= 7,
	xlSmartTagControlImage	= 8,
	xlSmartTagControlCheckbox	= 9,
	xlSmartTagControlTextbox	= 10,
	xlSmartTagControlListbox	= 11,
	xlSmartTagControlCombo	= 12,
	xlSmartTagControlActiveX	= 13,
	xlSmartTagControlRadioGroup	= 14
    } 	XlSmartTagControlType;

typedef 
enum XlListConflict
    {	xlListConflictDialog	= 0,
	xlListConflictRetryAllConflicts	= 1,
	xlListConflictDiscardAllConflicts	= 2,
	xlListConflictError	= 3
    } 	XlListConflict;

typedef 
enum XlXmlExportResult
    {	xlXmlExportSuccess	= 0,
	xlXmlExportValidationFailed	= 1
    } 	XlXmlExportResult;

typedef 
enum XlXmlImportResult
    {	xlXmlImportSuccess	= 0,
	xlXmlImportElementsTruncated	= 1,
	xlXmlImportValidationFailed	= 2
    } 	XlXmlImportResult;

typedef 
enum XlRemoveDocInfoType
    {	xlRDIComments	= 1,
	xlRDIRemovePersonalInformation	= 4,
	xlRDIEmailHeader	= 5,
	xlRDIRoutingSlip	= 6,
	xlRDISendForReview	= 7,
	xlRDIDocumentProperties	= 8,
	xlRDIDocumentWorkspace	= 10,
	xlRDIInkAnnotations	= 11,
	xlRDIScenarioComments	= 12,
	xlRDIPublishInfo	= 13,
	xlRDIDocumentServerProperties	= 14,
	xlRDIDocumentManagementPolicy	= 15,
	xlRDIContentType	= 16,
	xlRDIDefinedNameComments	= 18,
	xlRDIInactiveDataConnections	= 19,
	xlRDIPrinterPath	= 20,
	xlRDIInlineWebExtensions	= 21,
	xlRDITaskpaneWebExtensions	= 22,
	xlRDIExcelDataModel	= 23,
	xlRDIAll	= 99
    } 	XlRemoveDocInfoType;

typedef 
enum XlRgbColor
    {	rgbAliceBlue	= 16775408,
	rgbAntiqueWhite	= 14150650,
	rgbAqua	= 16776960,
	rgbAquamarine	= 13959039,
	rgbAzure	= 16777200,
	rgbBeige	= 14480885,
	rgbBisque	= 12903679,
	rgbBlack	= 0,
	rgbBlanchedAlmond	= 13495295,
	rgbBlue	= 16711680,
	rgbBlueViolet	= 14822282,
	rgbBrown	= 2763429,
	rgbBurlyWood	= 8894686,
	rgbCadetBlue	= 10526303,
	rgbChartreuse	= 65407,
	rgbCoral	= 5275647,
	rgbCornflowerBlue	= 15570276,
	rgbCornsilk	= 14481663,
	rgbCrimson	= 3937500,
	rgbDarkBlue	= 9109504,
	rgbDarkCyan	= 9145088,
	rgbDarkGoldenrod	= 755384,
	rgbDarkGreen	= 25600,
	rgbDarkGray	= 11119017,
	rgbDarkGrey	= 11119017,
	rgbDarkKhaki	= 7059389,
	rgbDarkMagenta	= 9109643,
	rgbDarkOliveGreen	= 3107669,
	rgbDarkOrange	= 36095,
	rgbDarkOrchid	= 13382297,
	rgbDarkRed	= 139,
	rgbDarkSalmon	= 8034025,
	rgbDarkSeaGreen	= 9419919,
	rgbDarkSlateBlue	= 9125192,
	rgbDarkSlateGray	= 5197615,
	rgbDarkSlateGrey	= 5197615,
	rgbDarkTurquoise	= 13749760,
	rgbDarkViolet	= 13828244,
	rgbDeepPink	= 9639167,
	rgbDeepSkyBlue	= 16760576,
	rgbDimGray	= 6908265,
	rgbDimGrey	= 6908265,
	rgbDodgerBlue	= 16748574,
	rgbFireBrick	= 2237106,
	rgbFloralWhite	= 15792895,
	rgbForestGreen	= 2263842,
	rgbFuchsia	= 16711935,
	rgbGainsboro	= 14474460,
	rgbGhostWhite	= 16775416,
	rgbGold	= 55295,
	rgbGoldenrod	= 2139610,
	rgbGray	= 8421504,
	rgbGreen	= 32768,
	rgbGrey	= 8421504,
	rgbGreenYellow	= 3145645,
	rgbHoneydew	= 15794160,
	rgbHotPink	= 11823615,
	rgbIndianRed	= 6053069,
	rgbIndigo	= 8519755,
	rgbIvory	= 15794175,
	rgbKhaki	= 9234160,
	rgbLavender	= 16443110,
	rgbLavenderBlush	= 16118015,
	rgbLawnGreen	= 64636,
	rgbLemonChiffon	= 13499135,
	rgbLightBlue	= 15128749,
	rgbLightCoral	= 8421616,
	rgbLightCyan	= 9145088,
	rgbLightGoldenrodYellow	= 13826810,
	rgbLightGray	= 13882323,
	rgbLightGreen	= 9498256,
	rgbLightGrey	= 13882323,
	rgbLightPink	= 12695295,
	rgbLightSalmon	= 8036607,
	rgbLightSeaGreen	= 11186720,
	rgbLightSkyBlue	= 16436871,
	rgbLightSlateGray	= 10061943,
	rgbLightSlateGrey	= 10061943,
	rgbLightSteelBlue	= 14599344,
	rgbLightYellow	= 14745599,
	rgbLime	= 65280,
	rgbLimeGreen	= 3329330,
	rgbLinen	= 15134970,
	rgbMaroon	= 128,
	rgbMediumAquamarine	= 11206502,
	rgbMediumBlue	= 13434880,
	rgbMediumOrchid	= 13850042,
	rgbMediumPurple	= 14381203,
	rgbMediumSeaGreen	= 7451452,
	rgbMediumSlateBlue	= 15624315,
	rgbMediumSpringGreen	= 10156544,
	rgbMediumTurquoise	= 13422920,
	rgbMediumVioletRed	= 8721863,
	rgbMidnightBlue	= 7346457,
	rgbMintCream	= 16449525,
	rgbMistyRose	= 14804223,
	rgbMoccasin	= 11920639,
	rgbNavajoWhite	= 11394815,
	rgbNavy	= 8388608,
	rgbNavyBlue	= 8388608,
	rgbOldLace	= 15136253,
	rgbOlive	= 32896,
	rgbOliveDrab	= 2330219,
	rgbOrange	= 42495,
	rgbOrangeRed	= 17919,
	rgbOrchid	= 14053594,
	rgbPaleGoldenrod	= 7071982,
	rgbPaleGreen	= 10025880,
	rgbPaleTurquoise	= 15658671,
	rgbPaleVioletRed	= 9662683,
	rgbPapayaWhip	= 14020607,
	rgbPeachPuff	= 12180223,
	rgbPeru	= 4163021,
	rgbPink	= 13353215,
	rgbPlum	= 14524637,
	rgbPowderBlue	= 15130800,
	rgbPurple	= 8388736,
	rgbRed	= 255,
	rgbRosyBrown	= 9408444,
	rgbRoyalBlue	= 14772545,
	rgbSalmon	= 7504122,
	rgbSandyBrown	= 6333684,
	rgbSeaGreen	= 5737262,
	rgbSeashell	= 15660543,
	rgbSienna	= 2970272,
	rgbSilver	= 12632256,
	rgbSkyBlue	= 15453831,
	rgbSlateBlue	= 13458026,
	rgbSlateGray	= 9470064,
	rgbSlateGrey	= 9470064,
	rgbSnow	= 16448255,
	rgbSpringGreen	= 8388352,
	rgbSteelBlue	= 11829830,
	rgbTan	= 9221330,
	rgbTeal	= 8421376,
	rgbThistle	= 14204888,
	rgbTomato	= 4678655,
	rgbTurquoise	= 13688896,
	rgbYellow	= 65535,
	rgbYellowGreen	= 3329434,
	rgbViolet	= 15631086,
	rgbWheat	= 11788021,
	rgbWhite	= 16777215,
	rgbWhiteSmoke	= 16119285
    } 	XlRgbColor;

typedef 
enum XlStdColorScale
    {	xlColorScaleRYG	= 1,
	xlColorScaleGYR	= 2,
	xlColorScaleBlackWhite	= 3,
	xlColorScaleWhiteBlack	= 4
    } 	XlStdColorScale;

typedef 
enum XlConditionValueTypes
    {	xlConditionValueNone	= -1,
	xlConditionValueNumber	= 0,
	xlConditionValueLowestValue	= 1,
	xlConditionValueHighestValue	= 2,
	xlConditionValuePercent	= 3,
	xlConditionValueFormula	= 4,
	xlConditionValuePercentile	= 5,
	xlConditionValueAutomaticMin	= 6,
	xlConditionValueAutomaticMax	= 7
    } 	XlConditionValueTypes;

typedef 
enum XlFormatFilterTypes
    {	xlFilterBottom	= 0,
	xlFilterTop	= 1,
	xlFilterBottomPercent	= 2,
	xlFilterTopPercent	= 3
    } 	XlFormatFilterTypes;

typedef 
enum XlContainsOperator
    {	xlContains	= 0,
	xlDoesNotContain	= 1,
	xlBeginsWith	= 2,
	xlEndsWith	= 3
    } 	XlContainsOperator;

typedef 
enum XlAboveBelow
    {	xlAboveAverage	= 0,
	xlBelowAverage	= 1,
	xlEqualAboveAverage	= 2,
	xlEqualBelowAverage	= 3,
	xlAboveStdDev	= 4,
	xlBelowStdDev	= 5
    } 	XlAboveBelow;

typedef 
enum XlLookFor
    {	xlLookForBlanks	= 0,
	xlLookForErrors	= 1,
	xlLookForFormulas	= 2
    } 	XlLookFor;

typedef 
enum XlTimePeriods
    {	xlToday	= 0,
	xlYesterday	= 1,
	xlLast7Days	= 2,
	xlThisWeek	= 3,
	xlLastWeek	= 4,
	xlLastMonth	= 5,
	xlTomorrow	= 6,
	xlNextWeek	= 7,
	xlNextMonth	= 8,
	xlThisMonth	= 9
    } 	XlTimePeriods;

typedef 
enum XlDupeUnique
    {	xlUnique	= 0,
	xlDuplicate	= 1
    } 	XlDupeUnique;

typedef 
enum XlTopBottom
    {	xlTop10Top	= 1,
	xlTop10Bottom	= 0
    } 	XlTopBottom;

typedef 
enum XlIconSet
    {	xlCustomSet	= -1,
	xl3Arrows	= 1,
	xl3ArrowsGray	= 2,
	xl3Flags	= 3,
	xl3TrafficLights1	= 4,
	xl3TrafficLights2	= 5,
	xl3Signs	= 6,
	xl3Symbols	= 7,
	xl3Symbols2	= 8,
	xl4Arrows	= 9,
	xl4ArrowsGray	= 10,
	xl4RedToBlack	= 11,
	xl4CRV	= 12,
	xl4TrafficLights	= 13,
	xl5Arrows	= 14,
	xl5ArrowsGray	= 15,
	xl5CRV	= 16,
	xl5Quarters	= 17,
	xl3Stars	= 18,
	xl3Triangles	= 19,
	xl5Boxes	= 20
    } 	XlIconSet;

typedef 
enum XlThemeFont
    {	xlThemeFontNone	= 0,
	xlThemeFontMajor	= 1,
	xlThemeFontMinor	= 2
    } 	XlThemeFont;

typedef 
enum XlPivotLineType
    {	xlPivotLineRegular	= 0,
	xlPivotLineSubtotal	= 1,
	xlPivotLineGrandTotal	= 2,
	xlPivotLineBlank	= 3
    } 	XlPivotLineType;

typedef 
enum XlCheckInVersionType
    {	xlCheckInMinorVersion	= 0,
	xlCheckInMajorVersion	= 1,
	xlCheckInOverwriteVersion	= 2
    } 	XlCheckInVersionType;

typedef 
enum XlPropertyDisplayedIn
    {	xlDisplayPropertyInPivotTable	= 1,
	xlDisplayPropertyInTooltip	= 2,
	xlDisplayPropertyInPivotTableAndTooltip	= 3
    } 	XlPropertyDisplayedIn;

typedef 
enum XlConnectionType
    {	xlConnectionTypeOLEDB	= 1,
	xlConnectionTypeODBC	= 2,
	xlConnectionTypeXMLMAP	= 3,
	xlConnectionTypeTEXT	= 4,
	xlConnectionTypeWEB	= 5,
	xlConnectionTypeDATAFEED	= 6,
	xlConnectionTypeMODEL	= 7,
	xlConnectionTypeWORKSHEET	= 8,
	xlConnectionTypeNOSOURCE	= 9
    } 	XlConnectionType;

typedef 
enum XlActionType
    {	xlActionTypeUrl	= 1,
	xlActionTypeRowset	= 16,
	xlActionTypeReport	= 128,
	xlActionTypeDrillthrough	= 256
    } 	XlActionType;

typedef 
enum XlLayoutRowType
    {	xlCompactRow	= 0,
	xlTabularRow	= 1,
	xlOutlineRow	= 2
    } 	XlLayoutRowType;

typedef 
enum XlMeasurementUnits
    {	xlInches	= 0,
	xlCentimeters	= 1,
	xlMillimeters	= 2
    } 	XlMeasurementUnits;

typedef 
enum XlPivotFilterType
    {	xlTopCount	= 1,
	xlBottomCount	= 2,
	xlTopPercent	= 3,
	xlBottomPercent	= 4,
	xlTopSum	= 5,
	xlBottomSum	= 6,
	xlValueEquals	= 7,
	xlValueDoesNotEqual	= 8,
	xlValueIsGreaterThan	= 9,
	xlValueIsGreaterThanOrEqualTo	= 10,
	xlValueIsLessThan	= 11,
	xlValueIsLessThanOrEqualTo	= 12,
	xlValueIsBetween	= 13,
	xlValueIsNotBetween	= 14,
	xlCaptionEquals	= 15,
	xlCaptionDoesNotEqual	= 16,
	xlCaptionBeginsWith	= 17,
	xlCaptionDoesNotBeginWith	= 18,
	xlCaptionEndsWith	= 19,
	xlCaptionDoesNotEndWith	= 20,
	xlCaptionContains	= 21,
	xlCaptionDoesNotContain	= 22,
	xlCaptionIsGreaterThan	= 23,
	xlCaptionIsGreaterThanOrEqualTo	= 24,
	xlCaptionIsLessThan	= 25,
	xlCaptionIsLessThanOrEqualTo	= 26,
	xlCaptionIsBetween	= 27,
	xlCaptionIsNotBetween	= 28,
	xlSpecificDate	= 29,
	xlNotSpecificDate	= 30,
	xlBefore	= 31,
	xlBeforeOrEqualTo	= 32,
	xlAfter	= 33,
	xlAfterOrEqualTo	= 34,
	xlDateBetween	= 35,
	xlDateNotBetween	= 36,
	xlDateTomorrow	= 37,
	xlDateToday	= 38,
	xlDateYesterday	= 39,
	xlDateNextWeek	= 40,
	xlDateThisWeek	= 41,
	xlDateLastWeek	= 42,
	xlDateNextMonth	= 43,
	xlDateThisMonth	= 44,
	xlDateLastMonth	= 45,
	xlDateNextQuarter	= 46,
	xlDateThisQuarter	= 47,
	xlDateLastQuarter	= 48,
	xlDateNextYear	= 49,
	xlDateThisYear	= 50,
	xlDateLastYear	= 51,
	xlYearToDate	= 52,
	xlAllDatesInPeriodQuarter1	= 53,
	xlAllDatesInPeriodQuarter2	= 54,
	xlAllDatesInPeriodQuarter3	= 55,
	xlAllDatesInPeriodQuarter4	= 56,
	xlAllDatesInPeriodJanuary	= 57,
	xlAllDatesInPeriodFebruary	= 58,
	xlAllDatesInPeriodMarch	= 59,
	xlAllDatesInPeriodApril	= 60,
	xlAllDatesInPeriodMay	= 61,
	xlAllDatesInPeriodJune	= 62,
	xlAllDatesInPeriodJuly	= 63,
	xlAllDatesInPeriodAugust	= 64,
	xlAllDatesInPeriodSeptember	= 65,
	xlAllDatesInPeriodOctober	= 66,
	xlAllDatesInPeriodNovember	= 67,
	xlAllDatesInPeriodDecember	= 68
    } 	XlPivotFilterType;

typedef 
enum XlCredentialsMethod
    {	xlCredentialsMethodIntegrated	= 0,
	xlCredentialsMethodNone	= 1,
	xlCredentialsMethodStored	= 2
    } 	XlCredentialsMethod;

typedef 
enum XlCubeFieldSubType
    {	xlCubeHierarchy	= 1,
	xlCubeMeasure	= 2,
	xlCubeSet	= 3,
	xlCubeAttribute	= 4,
	xlCubeCalculatedMeasure	= 5,
	xlCubeKPIValue	= 6,
	xlCubeKPIGoal	= 7,
	xlCubeKPIStatus	= 8,
	xlCubeKPITrend	= 9,
	xlCubeKPIWeight	= 10,
	xlCubeImplicitMeasure	= 11
    } 	XlCubeFieldSubType;

typedef 
enum XlSortOn
    {	xlSortOnValues	= 0,
	xlSortOnCellColor	= 1,
	xlSortOnFontColor	= 2,
	xlSortOnIcon	= 3
    } 	XlSortOn;

typedef 
enum XlDynamicFilterCriteria
    {	xlFilterToday	= 1,
	xlFilterYesterday	= 2,
	xlFilterTomorrow	= 3,
	xlFilterThisWeek	= 4,
	xlFilterLastWeek	= 5,
	xlFilterNextWeek	= 6,
	xlFilterThisMonth	= 7,
	xlFilterLastMonth	= 8,
	xlFilterNextMonth	= 9,
	xlFilterThisQuarter	= 10,
	xlFilterLastQuarter	= 11,
	xlFilterNextQuarter	= 12,
	xlFilterThisYear	= 13,
	xlFilterLastYear	= 14,
	xlFilterNextYear	= 15,
	xlFilterYearToDate	= 16,
	xlFilterAllDatesInPeriodQuarter1	= 17,
	xlFilterAllDatesInPeriodQuarter2	= 18,
	xlFilterAllDatesInPeriodQuarter3	= 19,
	xlFilterAllDatesInPeriodQuarter4	= 20,
	xlFilterAllDatesInPeriodJanuary	= 21,
	xlFilterAllDatesInPeriodFebruray	= 22,
	xlFilterAllDatesInPeriodMarch	= 23,
	xlFilterAllDatesInPeriodApril	= 24,
	xlFilterAllDatesInPeriodMay	= 25,
	xlFilterAllDatesInPeriodJune	= 26,
	xlFilterAllDatesInPeriodJuly	= 27,
	xlFilterAllDatesInPeriodAugust	= 28,
	xlFilterAllDatesInPeriodSeptember	= 29,
	xlFilterAllDatesInPeriodOctober	= 30,
	xlFilterAllDatesInPeriodNovember	= 31,
	xlFilterAllDatesInPeriodDecember	= 32,
	xlFilterAboveAverage	= 33,
	xlFilterBelowAverage	= 34
    } 	XlDynamicFilterCriteria;

typedef 
enum XlFilterAllDatesInPeriod
    {	xlFilterAllDatesInPeriodYear	= 0,
	xlFilterAllDatesInPeriodMonth	= 1,
	xlFilterAllDatesInPeriodDay	= 2,
	xlFilterAllDatesInPeriodHour	= 3,
	xlFilterAllDatesInPeriodMinute	= 4,
	xlFilterAllDatesInPeriodSecond	= 5
    } 	XlFilterAllDatesInPeriod;

typedef 
enum XlTableStyleElementType
    {	xlWholeTable	= 0,
	xlHeaderRow	= 1,
	xlTotalRow	= 2,
	xlGrandTotalRow	= 2,
	xlFirstColumn	= 3,
	xlLastColumn	= 4,
	xlGrandTotalColumn	= 4,
	xlRowStripe1	= 5,
	xlRowStripe2	= 6,
	xlColumnStripe1	= 7,
	xlColumnStripe2	= 8,
	xlFirstHeaderCell	= 9,
	xlLastHeaderCell	= 10,
	xlFirstTotalCell	= 11,
	xlLastTotalCell	= 12,
	xlSubtotalColumn1	= 13,
	xlSubtotalColumn2	= 14,
	xlSubtotalColumn3	= 15,
	xlSubtotalRow1	= 16,
	xlSubtotalRow2	= 17,
	xlSubtotalRow3	= 18,
	xlBlankRow	= 19,
	xlColumnSubheading1	= 20,
	xlColumnSubheading2	= 21,
	xlColumnSubheading3	= 22,
	xlRowSubheading1	= 23,
	xlRowSubheading2	= 24,
	xlRowSubheading3	= 25,
	xlPageFieldLabels	= 26,
	xlPageFieldValues	= 27,
	xlSlicerUnselectedItemWithData	= 28,
	xlSlicerUnselectedItemWithNoData	= 29,
	xlSlicerSelectedItemWithData	= 30,
	xlSlicerSelectedItemWithNoData	= 31,
	xlSlicerHoveredUnselectedItemWithData	= 32,
	xlSlicerHoveredSelectedItemWithData	= 33,
	xlSlicerHoveredUnselectedItemWithNoData	= 34,
	xlSlicerHoveredSelectedItemWithNoData	= 35,
	xlTimelineSelectionLabel	= 36,
	xlTimelineTimeLevel	= 37,
	xlTimelinePeriodLabels1	= 38,
	xlTimelinePeriodLabels2	= 39,
	xlTimelineSelectedTimeBlock	= 40,
	xlTimelineUnselectedTimeBlock	= 41,
	xlTimelineSelectedTimeBlockSpace	= 42
    } 	XlTableStyleElementType;

typedef 
enum XlPivotConditionScope
    {	xlSelectionScope	= 0,
	xlFieldsScope	= 1,
	xlDataFieldScope	= 2
    } 	XlPivotConditionScope;

typedef 
enum XlCalcFor
    {	xlAllValues	= 0,
	xlRowGroups	= 1,
	xlColGroups	= 2
    } 	XlCalcFor;

typedef 
enum XlThemeColor
    {	xlThemeColorDark1	= 1,
	xlThemeColorLight1	= 2,
	xlThemeColorDark2	= 3,
	xlThemeColorLight2	= 4,
	xlThemeColorAccent1	= 5,
	xlThemeColorAccent2	= 6,
	xlThemeColorAccent3	= 7,
	xlThemeColorAccent4	= 8,
	xlThemeColorAccent5	= 9,
	xlThemeColorAccent6	= 10,
	xlThemeColorHyperlink	= 11,
	xlThemeColorFollowedHyperlink	= 12
    } 	XlThemeColor;

typedef 
enum XlFixedFormatType
    {	xlTypePDF	= 0,
	xlTypeXPS	= 1
    } 	XlFixedFormatType;

typedef 
enum XlFixedFormatQuality
    {	xlQualityStandard	= 0,
	xlQualityMinimum	= 1
    } 	XlFixedFormatQuality;

typedef 
enum XlChartElementPosition
    {	xlChartElementPositionAutomatic	= -4105,
	xlChartElementPositionCustom	= -4114
    } 	XlChartElementPosition;

typedef 
enum XlGenerateTableRefs
    {	xlGenerateTableRefA1	= 0,
	xlGenerateTableRefStruct	= 1
    } 	XlGenerateTableRefs;

typedef 
enum XlGradientFillType
    {	xlGradientFillLinear	= 0,
	xlGradientFillPath	= 1
    } 	XlGradientFillType;

typedef 
enum XlThreadMode
    {	xlThreadModeAutomatic	= 0,
	xlThreadModeManual	= 1
    } 	XlThreadMode;

typedef 
enum XlOartHorizontalOverflow
    {	xlOartHorizontalOverflowOverflow	= 0,
	xlOartHorizontalOverflowClip	= 1
    } 	XlOartHorizontalOverflow;

typedef 
enum XlOartVerticalOverflow
    {	xlOartVerticalOverflowOverflow	= 0,
	xlOartVerticalOverflowClip	= 1,
	xlOartVerticalOverflowEllipsis	= 2
    } 	XlOartVerticalOverflow;

typedef 
enum XlSparkScale
    {	xlSparkScaleGroup	= 1,
	xlSparkScaleSingle	= 2,
	xlSparkScaleCustom	= 3
    } 	XlSparkScale;

typedef 
enum XlSparkType
    {	xlSparkLine	= 1,
	xlSparkColumn	= 2,
	xlSparkColumnStacked100	= 3
    } 	XlSparkType;

typedef 
enum XlSparklineRowCol
    {	xlSparklineNonSquare	= 0,
	xlSparklineRowsSquare	= 1,
	xlSparklineColumnsSquare	= 2
    } 	XlSparklineRowCol;

typedef 
enum XlDataBarFillType
    {	xlDataBarFillSolid	= 0,
	xlDataBarFillGradient	= 1
    } 	XlDataBarFillType;

typedef 
enum XlDataBarBorderType
    {	xlDataBarBorderNone	= 0,
	xlDataBarBorderSolid	= 1
    } 	XlDataBarBorderType;

typedef 
enum XlDataBarAxisPosition
    {	xlDataBarAxisAutomatic	= 0,
	xlDataBarAxisMidpoint	= 1,
	xlDataBarAxisNone	= 2
    } 	XlDataBarAxisPosition;

typedef 
enum XlDataBarNegativeColorType
    {	xlDataBarColor	= 0,
	xlDataBarSameAsPositive	= 1
    } 	XlDataBarNegativeColorType;

typedef 
enum XlAllocation
    {	xlManualAllocation	= 1,
	xlAutomaticAllocation	= 2
    } 	XlAllocation;

typedef 
enum XlAllocationValue
    {	xlAllocateValue	= 1,
	xlAllocateIncrement	= 2
    } 	XlAllocationValue;

typedef 
enum XlAllocationMethod
    {	xlEqualAllocation	= 1,
	xlWeightedAllocation	= 2
    } 	XlAllocationMethod;

typedef 
enum XlCellChangedState
    {	xlCellNotChanged	= 1,
	xlCellChanged	= 2,
	xlCellChangeApplied	= 3
    } 	XlCellChangedState;

typedef 
enum XlPivotFieldRepeatLabels
    {	xlDoNotRepeatLabels	= 1,
	xlRepeatLabels	= 2
    } 	XlPivotFieldRepeatLabels;

typedef 
enum XlPieSliceIndex
    {	xlOuterCounterClockwisePoint	= 1,
	xlOuterCenterPoint	= 2,
	xlOuterClockwisePoint	= 3,
	xlMidClockwiseRadiusPoint	= 4,
	xlCenterPoint	= 5,
	xlMidCounterClockwiseRadiusPoint	= 6,
	xlInnerClockwisePoint	= 7,
	xlInnerCenterPoint	= 8,
	xlInnerCounterClockwisePoint	= 9
    } 	XlPieSliceIndex;

typedef 
enum XlSpanishModes
    {	xlSpanishTuteoOnly	= 0,
	xlSpanishTuteoAndVoseo	= 1,
	xlSpanishVoseoOnly	= 2
    } 	XlSpanishModes;

typedef 
enum XlSlicerCrossFilterType
    {	xlSlicerNoCrossFilter	= 1,
	xlSlicerCrossFilterShowItemsWithDataAtTop	= 2,
	xlSlicerCrossFilterShowItemsWithNoData	= 3,
	xlSlicerCrossFilterHideButtonsWithNoData	= 4
    } 	XlSlicerCrossFilterType;

typedef 
enum XlSlicerSort
    {	xlSlicerSortDataSourceOrder	= 1,
	xlSlicerSortAscending	= 2,
	xlSlicerSortDescending	= 3
    } 	XlSlicerSort;

typedef 
enum XlIcon
    {	xlIconNoCellIcon	= -1,
	xlIconGreenUpArrow	= 1,
	xlIconYellowSideArrow	= 2,
	xlIconRedDownArrow	= 3,
	xlIconGrayUpArrow	= 4,
	xlIconGraySideArrow	= 5,
	xlIconGrayDownArrow	= 6,
	xlIconGreenFlag	= 7,
	xlIconYellowFlag	= 8,
	xlIconRedFlag	= 9,
	xlIconGreenCircle	= 10,
	xlIconYellowCircle	= 11,
	xlIconRedCircleWithBorder	= 12,
	xlIconBlackCircleWithBorder	= 13,
	xlIconGreenTrafficLight	= 14,
	xlIconYellowTrafficLight	= 15,
	xlIconRedTrafficLight	= 16,
	xlIconYellowTriangle	= 17,
	xlIconRedDiamond	= 18,
	xlIconGreenCheckSymbol	= 19,
	xlIconYellowExclamationSymbol	= 20,
	xlIconRedCrossSymbol	= 21,
	xlIconGreenCheck	= 22,
	xlIconYellowExclamation	= 23,
	xlIconRedCross	= 24,
	xlIconYellowUpInclineArrow	= 25,
	xlIconYellowDownInclineArrow	= 26,
	xlIconGrayUpInclineArrow	= 27,
	xlIconGrayDownInclineArrow	= 28,
	xlIconRedCircle	= 29,
	xlIconPinkCircle	= 30,
	xlIconGrayCircle	= 31,
	xlIconBlackCircle	= 32,
	xlIconCircleWithOneWhiteQuarter	= 33,
	xlIconCircleWithTwoWhiteQuarters	= 34,
	xlIconCircleWithThreeWhiteQuarters	= 35,
	xlIconWhiteCircleAllWhiteQuarters	= 36,
	xlIcon0Bars	= 37,
	xlIcon1Bar	= 38,
	xlIcon2Bars	= 39,
	xlIcon3Bars	= 40,
	xlIcon4Bars	= 41,
	xlIconGoldStar	= 42,
	xlIconHalfGoldStar	= 43,
	xlIconSilverStar	= 44,
	xlIconGreenUpTriangle	= 45,
	xlIconYellowDash	= 46,
	xlIconRedDownTriangle	= 47,
	xlIcon4FilledBoxes	= 48,
	xlIcon3FilledBoxes	= 49,
	xlIcon2FilledBoxes	= 50,
	xlIcon1FilledBox	= 51,
	xlIcon0FilledBoxes	= 52
    } 	XlIcon;

typedef 
enum XlProtectedViewCloseReason
    {	xlProtectedViewCloseNormal	= 0,
	xlProtectedViewCloseEdit	= 1,
	xlProtectedViewCloseForced	= 2
    } 	XlProtectedViewCloseReason;

typedef 
enum XlProtectedViewWindowState
    {	xlProtectedViewWindowNormal	= 0,
	xlProtectedViewWindowMinimized	= 1,
	xlProtectedViewWindowMaximized	= 2
    } 	XlProtectedViewWindowState;

typedef 
enum XlFileValidationPivotMode
    {	xlFileValidationPivotDefault	= 0,
	xlFileValidationPivotRun	= 1,
	xlFileValidationPivotSkip	= 2
    } 	XlFileValidationPivotMode;

typedef 
enum XlPieSliceLocation
    {	xlHorizontalCoordinate	= 1,
	xlVerticalCoordinate	= 2
    } 	XlPieSliceLocation;

typedef 
enum XlPortugueseReform
    {	xlPortuguesePreReform	= 1,
	xlPortuguesePostReform	= 2,
	xlPortugueseBoth	= 3
    } 	XlPortugueseReform;

typedef 
enum XlQuickAnalysisMode
    {	xlLensOnly	= 0,
	xlFormatConditions	= 1,
	xlRecommendedCharts	= 2,
	xlTotals	= 3,
	xlTables	= 4,
	xlSparklines	= 5
    } 	XlQuickAnalysisMode;

typedef 
enum XlSlicerCacheType
    {	xlSlicer	= 1,
	xlTimeline	= 2
    } 	XlSlicerCacheType;

typedef 
enum XlCategoryLabelLevel
    {	xlCategoryLabelLevelNone	= -3,
	xlCategoryLabelLevelCustom	= -2,
	xlCategoryLabelLevelAll	= -1
    } 	XlCategoryLabelLevel;

typedef 
enum XlSeriesNameLevel
    {	xlSeriesNameLevelNone	= -3,
	xlSeriesNameLevelCustom	= -2,
	xlSeriesNameLevelAll	= -1
    } 	XlSeriesNameLevel;

typedef 
enum XlCalcMemNumberFormatType
    {	xlNumberFormatTypeDefault	= 0,
	xlNumberFormatTypeNumber	= 1,
	xlNumberFormatTypePercent	= 2
    } 	XlCalcMemNumberFormatType;

typedef 
enum XlTimelineLevel
    {	xlTimelineLevelYears	= 0,
	xlTimelineLevelQuarters	= 1,
	xlTimelineLevelMonths	= 2,
	xlTimelineLevelDays	= 3
    } 	XlTimelineLevel;

typedef 
enum XlFilterStatus
    {	xlFilterStatusOK	= 0,
	xlFilterStatusDateWrongOrder	= 1,
	xlFilterStatusDateHasTime	= 2,
	xlFilterStatusInvalidDate	= 3
    } 	XlFilterStatus;

typedef 
enum XlModelChangeSource
    {	xlChangeByExcel	= 0,
	xlChangeByPowerPivotAddIn	= 1
    } 	XlModelChangeSource;
































































































































































































































































































































































































































































































































































































































































































































EXTERN_C const IID LIBID_Excel;

#ifndef __Adjustments_INTERFACE_DEFINED__
#define __Adjustments_INTERFACE_DEFINED__

/* interface Adjustments */
/* [object][oleautomation][nonextensible][dual][helpcontext][uuid] */ 


EXTERN_C const IID IID_Adjustments;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000C0310-0000-0000-C000-000000000046")
    Adjustments : public _IMsoDispObj
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Parent( 
            /* [retval][out] */ IDispatch **Parent) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Count( 
            /* [retval][out] */ int *Count) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Item( 
            /* [in] */ int Index,
            /* [retval][out] */ single *Val) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_Item( 
            /* [in] */ int Index,
            /* [in] */ single Val) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct AdjustmentsVtbl
    {
        BEGIN_INTERFACE
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Adjustments * This,
            /* [in][idldescattr] */ struct GUID *riid,
            /* [out][idldescattr] */ void **ppvObj,
            /* [retval][out] */ void *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *AddRef )( 
            Adjustments * This,
            /* [retval][out] */ unsigned long *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *Release )( 
            Adjustments * This,
            /* [retval][out] */ unsigned long *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Adjustments * This,
            /* [out][idldescattr] */ unsigned UINT *pctinfo,
            /* [retval][out] */ void *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Adjustments * This,
            /* [in][idldescattr] */ unsigned UINT itinfo,
            /* [in][idldescattr] */ unsigned long lcid,
            /* [out][idldescattr] */ void **pptinfo,
            /* [retval][out] */ void *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Adjustments * This,
            /* [in][idldescattr] */ struct GUID *riid,
            /* [in][idldescattr] */ signed char **rgszNames,
            /* [in][idldescattr] */ unsigned UINT cNames,
            /* [in][idldescattr] */ unsigned long lcid,
            /* [out][idldescattr] */ signed long *rgdispid,
            /* [retval][out] */ void *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Adjustments * This,
            /* [in][idldescattr] */ signed long dispidMember,
            /* [in][idldescattr] */ struct GUID *riid,
            /* [in][idldescattr] */ unsigned long lcid,
            /* [in][idldescattr] */ unsigned short wFlags,
            /* [in][idldescattr] */ struct DISPPARAMS *pdispparams,
            /* [out][idldescattr] */ VARIANT *pvarResult,
            /* [out][idldescattr] */ struct EXCEPINFO *pexcepinfo,
            /* [out][idldescattr] */ unsigned UINT *puArgErr,
            /* [retval][out] */ void *retval);
        
        /* [id][propget][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *get_Application )( 
            Adjustments * This,
            /* [retval][out] */ IDispatch **retval);
        
        /* [id][propget][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *get_Creator )( 
            Adjustments * This,
            /* [retval][out] */ signed long *retval);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Parent )( 
            Adjustments * This,
            /* [retval][out] */ IDispatch **Parent);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Count )( 
            Adjustments * This,
            /* [retval][out] */ int *Count);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Item )( 
            Adjustments * This,
            /* [in] */ int Index,
            /* [retval][out] */ single *Val);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Item )( 
            Adjustments * This,
            /* [in] */ int Index,
            /* [in] */ single Val);
        
        END_INTERFACE
    } AdjustmentsVtbl;

    interface Adjustments
    {
        CONST_VTBL struct AdjustmentsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Adjustments_QueryInterface(This,riid,ppvObj,retval)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObj,retval) ) 

#define Adjustments_AddRef(This,retval)	\
    ( (This)->lpVtbl -> AddRef(This,retval) ) 

#define Adjustments_Release(This,retval)	\
    ( (This)->lpVtbl -> Release(This,retval) ) 

#define Adjustments_GetTypeInfoCount(This,pctinfo,retval)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo,retval) ) 

#define Adjustments_GetTypeInfo(This,itinfo,lcid,pptinfo,retval)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,itinfo,lcid,pptinfo,retval) ) 

#define Adjustments_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgdispid,retval)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgdispid,retval) ) 

#define Adjustments_Invoke(This,dispidMember,riid,lcid,wFlags,pdispparams,pvarResult,pexcepinfo,puArgErr,retval)	\
    ( (This)->lpVtbl -> Invoke(This,dispidMember,riid,lcid,wFlags,pdispparams,pvarResult,pexcepinfo,puArgErr,retval) ) 

#define Adjustments_get_Application(This,retval)	\
    ( (This)->lpVtbl -> get_Application(This,retval) ) 

#define Adjustments_get_Creator(This,retval)	\
    ( (This)->lpVtbl -> get_Creator(This,retval) ) 


#define Adjustments_get_Parent(This,Parent)	\
    ( (This)->lpVtbl -> get_Parent(This,Parent) ) 

#define Adjustments_get_Count(This,Count)	\
    ( (This)->lpVtbl -> get_Count(This,Count) ) 

#define Adjustments_get_Item(This,Index,Val)	\
    ( (This)->lpVtbl -> get_Item(This,Index,Val) ) 

#define Adjustments_put_Item(This,Index,Val)	\
    ( (This)->lpVtbl -> put_Item(This,Index,Val) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __Adjustments_INTERFACE_DEFINED__ */


#ifndef __CalloutFormat_INTERFACE_DEFINED__
#define __CalloutFormat_INTERFACE_DEFINED__

/* interface CalloutFormat */
/* [object][oleautomation][nonextensible][dual][helpcontext][uuid] */ 


EXTERN_C const IID IID_CalloutFormat;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000C0311-0000-0000-C000-000000000046")
    CalloutFormat : public _IMsoDispObj
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Parent( 
            /* [retval][out] */ IDispatch **Parent) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE AutomaticLength( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE CustomDrop( 
            /* [in] */ single Drop) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE CustomLength( 
            /* [in] */ single Length) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE PresetDrop( 
            /* [in] */ MsoCalloutDropType DropType) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Accent( 
            /* [retval][out] */ MsoTriState *Accent) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_Accent( 
            /* [in] */ MsoTriState Accent) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Angle( 
            /* [retval][out] */ MsoCalloutAngleType *Angle) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_Angle( 
            /* [in] */ MsoCalloutAngleType Angle) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_AutoAttach( 
            /* [retval][out] */ MsoTriState *AutoAttach) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_AutoAttach( 
            /* [in] */ MsoTriState AutoAttach) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_AutoLength( 
            /* [retval][out] */ MsoTriState *AutoLength) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Border( 
            /* [retval][out] */ MsoTriState *Border) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_Border( 
            /* [in] */ MsoTriState Border) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Drop( 
            /* [retval][out] */ single *Drop) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_DropType( 
            /* [retval][out] */ MsoCalloutDropType *DropType) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Gap( 
            /* [retval][out] */ single *Gap) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_Gap( 
            /* [in] */ single Gap) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Length( 
            /* [retval][out] */ single *Length) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Type( 
            /* [retval][out] */ MsoCalloutType *Type) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_Type( 
            /* [in] */ MsoCalloutType Type) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct CalloutFormatVtbl
    {
        BEGIN_INTERFACE
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            CalloutFormat * This,
            /* [in][idldescattr] */ struct GUID *riid,
            /* [out][idldescattr] */ void **ppvObj,
            /* [retval][out] */ void *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *AddRef )( 
            CalloutFormat * This,
            /* [retval][out] */ unsigned long *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *Release )( 
            CalloutFormat * This,
            /* [retval][out] */ unsigned long *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            CalloutFormat * This,
            /* [out][idldescattr] */ unsigned UINT *pctinfo,
            /* [retval][out] */ void *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            CalloutFormat * This,
            /* [in][idldescattr] */ unsigned UINT itinfo,
            /* [in][idldescattr] */ unsigned long lcid,
            /* [out][idldescattr] */ void **pptinfo,
            /* [retval][out] */ void *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            CalloutFormat * This,
            /* [in][idldescattr] */ struct GUID *riid,
            /* [in][idldescattr] */ signed char **rgszNames,
            /* [in][idldescattr] */ unsigned UINT cNames,
            /* [in][idldescattr] */ unsigned long lcid,
            /* [out][idldescattr] */ signed long *rgdispid,
            /* [retval][out] */ void *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            CalloutFormat * This,
            /* [in][idldescattr] */ signed long dispidMember,
            /* [in][idldescattr] */ struct GUID *riid,
            /* [in][idldescattr] */ unsigned long lcid,
            /* [in][idldescattr] */ unsigned short wFlags,
            /* [in][idldescattr] */ struct DISPPARAMS *pdispparams,
            /* [out][idldescattr] */ VARIANT *pvarResult,
            /* [out][idldescattr] */ struct EXCEPINFO *pexcepinfo,
            /* [out][idldescattr] */ unsigned UINT *puArgErr,
            /* [retval][out] */ void *retval);
        
        /* [id][propget][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *get_Application )( 
            CalloutFormat * This,
            /* [retval][out] */ IDispatch **retval);
        
        /* [id][propget][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *get_Creator )( 
            CalloutFormat * This,
            /* [retval][out] */ signed long *retval);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Parent )( 
            CalloutFormat * This,
            /* [retval][out] */ IDispatch **Parent);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *AutomaticLength )( 
            CalloutFormat * This);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *CustomDrop )( 
            CalloutFormat * This,
            /* [in] */ single Drop);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *CustomLength )( 
            CalloutFormat * This,
            /* [in] */ single Length);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *PresetDrop )( 
            CalloutFormat * This,
            /* [in] */ MsoCalloutDropType DropType);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Accent )( 
            CalloutFormat * This,
            /* [retval][out] */ MsoTriState *Accent);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Accent )( 
            CalloutFormat * This,
            /* [in] */ MsoTriState Accent);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Angle )( 
            CalloutFormat * This,
            /* [retval][out] */ MsoCalloutAngleType *Angle);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Angle )( 
            CalloutFormat * This,
            /* [in] */ MsoCalloutAngleType Angle);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_AutoAttach )( 
            CalloutFormat * This,
            /* [retval][out] */ MsoTriState *AutoAttach);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_AutoAttach )( 
            CalloutFormat * This,
            /* [in] */ MsoTriState AutoAttach);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_AutoLength )( 
            CalloutFormat * This,
            /* [retval][out] */ MsoTriState *AutoLength);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Border )( 
            CalloutFormat * This,
            /* [retval][out] */ MsoTriState *Border);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Border )( 
            CalloutFormat * This,
            /* [in] */ MsoTriState Border);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Drop )( 
            CalloutFormat * This,
            /* [retval][out] */ single *Drop);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_DropType )( 
            CalloutFormat * This,
            /* [retval][out] */ MsoCalloutDropType *DropType);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Gap )( 
            CalloutFormat * This,
            /* [retval][out] */ single *Gap);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Gap )( 
            CalloutFormat * This,
            /* [in] */ single Gap);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Length )( 
            CalloutFormat * This,
            /* [retval][out] */ single *Length);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Type )( 
            CalloutFormat * This,
            /* [retval][out] */ MsoCalloutType *Type);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Type )( 
            CalloutFormat * This,
            /* [in] */ MsoCalloutType Type);
        
        END_INTERFACE
    } CalloutFormatVtbl;

    interface CalloutFormat
    {
        CONST_VTBL struct CalloutFormatVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define CalloutFormat_QueryInterface(This,riid,ppvObj,retval)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObj,retval) ) 

#define CalloutFormat_AddRef(This,retval)	\
    ( (This)->lpVtbl -> AddRef(This,retval) ) 

#define CalloutFormat_Release(This,retval)	\
    ( (This)->lpVtbl -> Release(This,retval) ) 

#define CalloutFormat_GetTypeInfoCount(This,pctinfo,retval)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo,retval) ) 

#define CalloutFormat_GetTypeInfo(This,itinfo,lcid,pptinfo,retval)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,itinfo,lcid,pptinfo,retval) ) 

#define CalloutFormat_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgdispid,retval)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgdispid,retval) ) 

#define CalloutFormat_Invoke(This,dispidMember,riid,lcid,wFlags,pdispparams,pvarResult,pexcepinfo,puArgErr,retval)	\
    ( (This)->lpVtbl -> Invoke(This,dispidMember,riid,lcid,wFlags,pdispparams,pvarResult,pexcepinfo,puArgErr,retval) ) 

#define CalloutFormat_get_Application(This,retval)	\
    ( (This)->lpVtbl -> get_Application(This,retval) ) 

#define CalloutFormat_get_Creator(This,retval)	\
    ( (This)->lpVtbl -> get_Creator(This,retval) ) 


#define CalloutFormat_get_Parent(This,Parent)	\
    ( (This)->lpVtbl -> get_Parent(This,Parent) ) 

#define CalloutFormat_AutomaticLength(This)	\
    ( (This)->lpVtbl -> AutomaticLength(This) ) 

#define CalloutFormat_CustomDrop(This,Drop)	\
    ( (This)->lpVtbl -> CustomDrop(This,Drop) ) 

#define CalloutFormat_CustomLength(This,Length)	\
    ( (This)->lpVtbl -> CustomLength(This,Length) ) 

#define CalloutFormat_PresetDrop(This,DropType)	\
    ( (This)->lpVtbl -> PresetDrop(This,DropType) ) 

#define CalloutFormat_get_Accent(This,Accent)	\
    ( (This)->lpVtbl -> get_Accent(This,Accent) ) 

#define CalloutFormat_put_Accent(This,Accent)	\
    ( (This)->lpVtbl -> put_Accent(This,Accent) ) 

#define CalloutFormat_get_Angle(This,Angle)	\
    ( (This)->lpVtbl -> get_Angle(This,Angle) ) 

#define CalloutFormat_put_Angle(This,Angle)	\
    ( (This)->lpVtbl -> put_Angle(This,Angle) ) 

#define CalloutFormat_get_AutoAttach(This,AutoAttach)	\
    ( (This)->lpVtbl -> get_AutoAttach(This,AutoAttach) ) 

#define CalloutFormat_put_AutoAttach(This,AutoAttach)	\
    ( (This)->lpVtbl -> put_AutoAttach(This,AutoAttach) ) 

#define CalloutFormat_get_AutoLength(This,AutoLength)	\
    ( (This)->lpVtbl -> get_AutoLength(This,AutoLength) ) 

#define CalloutFormat_get_Border(This,Border)	\
    ( (This)->lpVtbl -> get_Border(This,Border) ) 

#define CalloutFormat_put_Border(This,Border)	\
    ( (This)->lpVtbl -> put_Border(This,Border) ) 

#define CalloutFormat_get_Drop(This,Drop)	\
    ( (This)->lpVtbl -> get_Drop(This,Drop) ) 

#define CalloutFormat_get_DropType(This,DropType)	\
    ( (This)->lpVtbl -> get_DropType(This,DropType) ) 

#define CalloutFormat_get_Gap(This,Gap)	\
    ( (This)->lpVtbl -> get_Gap(This,Gap) ) 

#define CalloutFormat_put_Gap(This,Gap)	\
    ( (This)->lpVtbl -> put_Gap(This,Gap) ) 

#define CalloutFormat_get_Length(This,Length)	\
    ( (This)->lpVtbl -> get_Length(This,Length) ) 

#define CalloutFormat_get_Type(This,Type)	\
    ( (This)->lpVtbl -> get_Type(This,Type) ) 

#define CalloutFormat_put_Type(This,Type)	\
    ( (This)->lpVtbl -> put_Type(This,Type) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __CalloutFormat_INTERFACE_DEFINED__ */


#ifndef __ColorFormat_INTERFACE_DEFINED__
#define __ColorFormat_INTERFACE_DEFINED__

/* interface ColorFormat */
/* [object][oleautomation][nonextensible][dual][helpcontext][uuid] */ 


EXTERN_C const IID IID_ColorFormat;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000C0312-0000-0000-C000-000000000046")
    ColorFormat : public _IMsoDispObj
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Parent( 
            /* [retval][out] */ IDispatch **Parent) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_RGB( 
            /* [retval][out] */ MsoRGBType *RGB) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_RGB( 
            /* [in] */ MsoRGBType RGB) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_SchemeColor( 
            /* [retval][out] */ int *SchemeColor) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_SchemeColor( 
            /* [in] */ int SchemeColor) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Type( 
            /* [retval][out] */ MsoColorType *Type) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_TintAndShade( 
            /* [retval][out] */ single *pValue) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_TintAndShade( 
            /* [in] */ single pValue) = 0;
        
        virtual /* [propget][id] */ HRESULT STDMETHODCALLTYPE get_ObjectThemeColor( 
            /* [retval][out] */ MsoThemeColorIndex *ObjectThemeColor) = 0;
        
        virtual /* [propput][id] */ HRESULT STDMETHODCALLTYPE put_ObjectThemeColor( 
            /* [in] */ MsoThemeColorIndex ObjectThemeColor) = 0;
        
        virtual /* [propget][id] */ HRESULT STDMETHODCALLTYPE get_Brightness( 
            /* [retval][out] */ single *pValue) = 0;
        
        virtual /* [propput][id] */ HRESULT STDMETHODCALLTYPE put_Brightness( 
            /* [in] */ single pValue) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ColorFormatVtbl
    {
        BEGIN_INTERFACE
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ColorFormat * This,
            /* [in][idldescattr] */ struct GUID *riid,
            /* [out][idldescattr] */ void **ppvObj,
            /* [retval][out] */ void *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *AddRef )( 
            ColorFormat * This,
            /* [retval][out] */ unsigned long *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *Release )( 
            ColorFormat * This,
            /* [retval][out] */ unsigned long *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ColorFormat * This,
            /* [out][idldescattr] */ unsigned UINT *pctinfo,
            /* [retval][out] */ void *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ColorFormat * This,
            /* [in][idldescattr] */ unsigned UINT itinfo,
            /* [in][idldescattr] */ unsigned long lcid,
            /* [out][idldescattr] */ void **pptinfo,
            /* [retval][out] */ void *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ColorFormat * This,
            /* [in][idldescattr] */ struct GUID *riid,
            /* [in][idldescattr] */ signed char **rgszNames,
            /* [in][idldescattr] */ unsigned UINT cNames,
            /* [in][idldescattr] */ unsigned long lcid,
            /* [out][idldescattr] */ signed long *rgdispid,
            /* [retval][out] */ void *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ColorFormat * This,
            /* [in][idldescattr] */ signed long dispidMember,
            /* [in][idldescattr] */ struct GUID *riid,
            /* [in][idldescattr] */ unsigned long lcid,
            /* [in][idldescattr] */ unsigned short wFlags,
            /* [in][idldescattr] */ struct DISPPARAMS *pdispparams,
            /* [out][idldescattr] */ VARIANT *pvarResult,
            /* [out][idldescattr] */ struct EXCEPINFO *pexcepinfo,
            /* [out][idldescattr] */ unsigned UINT *puArgErr,
            /* [retval][out] */ void *retval);
        
        /* [id][propget][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *get_Application )( 
            ColorFormat * This,
            /* [retval][out] */ IDispatch **retval);
        
        /* [id][propget][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *get_Creator )( 
            ColorFormat * This,
            /* [retval][out] */ signed long *retval);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Parent )( 
            ColorFormat * This,
            /* [retval][out] */ IDispatch **Parent);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_RGB )( 
            ColorFormat * This,
            /* [retval][out] */ MsoRGBType *RGB);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_RGB )( 
            ColorFormat * This,
            /* [in] */ MsoRGBType RGB);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_SchemeColor )( 
            ColorFormat * This,
            /* [retval][out] */ int *SchemeColor);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_SchemeColor )( 
            ColorFormat * This,
            /* [in] */ int SchemeColor);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Type )( 
            ColorFormat * This,
            /* [retval][out] */ MsoColorType *Type);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_TintAndShade )( 
            ColorFormat * This,
            /* [retval][out] */ single *pValue);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_TintAndShade )( 
            ColorFormat * This,
            /* [in] */ single pValue);
        
        /* [propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ObjectThemeColor )( 
            ColorFormat * This,
            /* [retval][out] */ MsoThemeColorIndex *ObjectThemeColor);
        
        /* [propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_ObjectThemeColor )( 
            ColorFormat * This,
            /* [in] */ MsoThemeColorIndex ObjectThemeColor);
        
        /* [propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Brightness )( 
            ColorFormat * This,
            /* [retval][out] */ single *pValue);
        
        /* [propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Brightness )( 
            ColorFormat * This,
            /* [in] */ single pValue);
        
        END_INTERFACE
    } ColorFormatVtbl;

    interface ColorFormat
    {
        CONST_VTBL struct ColorFormatVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ColorFormat_QueryInterface(This,riid,ppvObj,retval)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObj,retval) ) 

#define ColorFormat_AddRef(This,retval)	\
    ( (This)->lpVtbl -> AddRef(This,retval) ) 

#define ColorFormat_Release(This,retval)	\
    ( (This)->lpVtbl -> Release(This,retval) ) 

#define ColorFormat_GetTypeInfoCount(This,pctinfo,retval)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo,retval) ) 

#define ColorFormat_GetTypeInfo(This,itinfo,lcid,pptinfo,retval)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,itinfo,lcid,pptinfo,retval) ) 

#define ColorFormat_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgdispid,retval)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgdispid,retval) ) 

#define ColorFormat_Invoke(This,dispidMember,riid,lcid,wFlags,pdispparams,pvarResult,pexcepinfo,puArgErr,retval)	\
    ( (This)->lpVtbl -> Invoke(This,dispidMember,riid,lcid,wFlags,pdispparams,pvarResult,pexcepinfo,puArgErr,retval) ) 

#define ColorFormat_get_Application(This,retval)	\
    ( (This)->lpVtbl -> get_Application(This,retval) ) 

#define ColorFormat_get_Creator(This,retval)	\
    ( (This)->lpVtbl -> get_Creator(This,retval) ) 


#define ColorFormat_get_Parent(This,Parent)	\
    ( (This)->lpVtbl -> get_Parent(This,Parent) ) 

#define ColorFormat_get_RGB(This,RGB)	\
    ( (This)->lpVtbl -> get_RGB(This,RGB) ) 

#define ColorFormat_put_RGB(This,RGB)	\
    ( (This)->lpVtbl -> put_RGB(This,RGB) ) 

#define ColorFormat_get_SchemeColor(This,SchemeColor)	\
    ( (This)->lpVtbl -> get_SchemeColor(This,SchemeColor) ) 

#define ColorFormat_put_SchemeColor(This,SchemeColor)	\
    ( (This)->lpVtbl -> put_SchemeColor(This,SchemeColor) ) 

#define ColorFormat_get_Type(This,Type)	\
    ( (This)->lpVtbl -> get_Type(This,Type) ) 

#define ColorFormat_get_TintAndShade(This,pValue)	\
    ( (This)->lpVtbl -> get_TintAndShade(This,pValue) ) 

#define ColorFormat_put_TintAndShade(This,pValue)	\
    ( (This)->lpVtbl -> put_TintAndShade(This,pValue) ) 

#define ColorFormat_get_ObjectThemeColor(This,ObjectThemeColor)	\
    ( (This)->lpVtbl -> get_ObjectThemeColor(This,ObjectThemeColor) ) 

#define ColorFormat_put_ObjectThemeColor(This,ObjectThemeColor)	\
    ( (This)->lpVtbl -> put_ObjectThemeColor(This,ObjectThemeColor) ) 

#define ColorFormat_get_Brightness(This,pValue)	\
    ( (This)->lpVtbl -> get_Brightness(This,pValue) ) 

#define ColorFormat_put_Brightness(This,pValue)	\
    ( (This)->lpVtbl -> put_Brightness(This,pValue) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ColorFormat_INTERFACE_DEFINED__ */


#ifndef __LineFormat_INTERFACE_DEFINED__
#define __LineFormat_INTERFACE_DEFINED__

/* interface LineFormat */
/* [object][oleautomation][nonextensible][dual][helpcontext][uuid] */ 


EXTERN_C const IID IID_LineFormat;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000C0317-0000-0000-C000-000000000046")
    LineFormat : public _IMsoDispObj
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Parent( 
            /* [retval][out] */ IDispatch **Parent) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_BackColor( 
            /* [retval][out] */ ColorFormat **BackColor) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_BackColor( 
            /* [in] */ ColorFormat *BackColor) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_BeginArrowheadLength( 
            /* [retval][out] */ MsoArrowheadLength *BeginArrowheadLength) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_BeginArrowheadLength( 
            /* [in] */ MsoArrowheadLength BeginArrowheadLength) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_BeginArrowheadStyle( 
            /* [retval][out] */ MsoArrowheadStyle *BeginArrowheadStyle) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_BeginArrowheadStyle( 
            /* [in] */ MsoArrowheadStyle BeginArrowheadStyle) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_BeginArrowheadWidth( 
            /* [retval][out] */ MsoArrowheadWidth *BeginArrowheadWidth) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_BeginArrowheadWidth( 
            /* [in] */ MsoArrowheadWidth BeginArrowheadWidth) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_DashStyle( 
            /* [retval][out] */ MsoLineDashStyle *DashStyle) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_DashStyle( 
            /* [in] */ MsoLineDashStyle DashStyle) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_EndArrowheadLength( 
            /* [retval][out] */ MsoArrowheadLength *EndArrowheadLength) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_EndArrowheadLength( 
            /* [in] */ MsoArrowheadLength EndArrowheadLength) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_EndArrowheadStyle( 
            /* [retval][out] */ MsoArrowheadStyle *EndArrowheadStyle) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_EndArrowheadStyle( 
            /* [in] */ MsoArrowheadStyle EndArrowheadStyle) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_EndArrowheadWidth( 
            /* [retval][out] */ MsoArrowheadWidth *EndArrowheadWidth) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_EndArrowheadWidth( 
            /* [in] */ MsoArrowheadWidth EndArrowheadWidth) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ForeColor( 
            /* [retval][out] */ ColorFormat **ForeColor) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_ForeColor( 
            /* [in] */ ColorFormat *ForeColor) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Pattern( 
            /* [retval][out] */ MsoPatternType *Pattern) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_Pattern( 
            /* [in] */ MsoPatternType Pattern) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Style( 
            /* [retval][out] */ MsoLineStyle *Style) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_Style( 
            /* [in] */ MsoLineStyle Style) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Transparency( 
            /* [retval][out] */ single *Transparency) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_Transparency( 
            /* [in] */ single Transparency) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Visible( 
            /* [retval][out] */ MsoTriState *Visible) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_Visible( 
            /* [in] */ MsoTriState Visible) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Weight( 
            /* [retval][out] */ single *Weight) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_Weight( 
            /* [in] */ single Weight) = 0;
        
        virtual /* [propget][id] */ HRESULT STDMETHODCALLTYPE get_InsetPen( 
            /* [retval][out] */ MsoTriState *InsetPen) = 0;
        
        virtual /* [propput][id] */ HRESULT STDMETHODCALLTYPE put_InsetPen( 
            /* [in] */ MsoTriState InsetPen) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct LineFormatVtbl
    {
        BEGIN_INTERFACE
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            LineFormat * This,
            /* [in][idldescattr] */ struct GUID *riid,
            /* [out][idldescattr] */ void **ppvObj,
            /* [retval][out] */ void *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *AddRef )( 
            LineFormat * This,
            /* [retval][out] */ unsigned long *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *Release )( 
            LineFormat * This,
            /* [retval][out] */ unsigned long *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            LineFormat * This,
            /* [out][idldescattr] */ unsigned UINT *pctinfo,
            /* [retval][out] */ void *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            LineFormat * This,
            /* [in][idldescattr] */ unsigned UINT itinfo,
            /* [in][idldescattr] */ unsigned long lcid,
            /* [out][idldescattr] */ void **pptinfo,
            /* [retval][out] */ void *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            LineFormat * This,
            /* [in][idldescattr] */ struct GUID *riid,
            /* [in][idldescattr] */ signed char **rgszNames,
            /* [in][idldescattr] */ unsigned UINT cNames,
            /* [in][idldescattr] */ unsigned long lcid,
            /* [out][idldescattr] */ signed long *rgdispid,
            /* [retval][out] */ void *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            LineFormat * This,
            /* [in][idldescattr] */ signed long dispidMember,
            /* [in][idldescattr] */ struct GUID *riid,
            /* [in][idldescattr] */ unsigned long lcid,
            /* [in][idldescattr] */ unsigned short wFlags,
            /* [in][idldescattr] */ struct DISPPARAMS *pdispparams,
            /* [out][idldescattr] */ VARIANT *pvarResult,
            /* [out][idldescattr] */ struct EXCEPINFO *pexcepinfo,
            /* [out][idldescattr] */ unsigned UINT *puArgErr,
            /* [retval][out] */ void *retval);
        
        /* [id][propget][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *get_Application )( 
            LineFormat * This,
            /* [retval][out] */ IDispatch **retval);
        
        /* [id][propget][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *get_Creator )( 
            LineFormat * This,
            /* [retval][out] */ signed long *retval);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Parent )( 
            LineFormat * This,
            /* [retval][out] */ IDispatch **Parent);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_BackColor )( 
            LineFormat * This,
            /* [retval][out] */ ColorFormat **BackColor);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_BackColor )( 
            LineFormat * This,
            /* [in] */ ColorFormat *BackColor);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_BeginArrowheadLength )( 
            LineFormat * This,
            /* [retval][out] */ MsoArrowheadLength *BeginArrowheadLength);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_BeginArrowheadLength )( 
            LineFormat * This,
            /* [in] */ MsoArrowheadLength BeginArrowheadLength);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_BeginArrowheadStyle )( 
            LineFormat * This,
            /* [retval][out] */ MsoArrowheadStyle *BeginArrowheadStyle);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_BeginArrowheadStyle )( 
            LineFormat * This,
            /* [in] */ MsoArrowheadStyle BeginArrowheadStyle);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_BeginArrowheadWidth )( 
            LineFormat * This,
            /* [retval][out] */ MsoArrowheadWidth *BeginArrowheadWidth);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_BeginArrowheadWidth )( 
            LineFormat * This,
            /* [in] */ MsoArrowheadWidth BeginArrowheadWidth);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_DashStyle )( 
            LineFormat * This,
            /* [retval][out] */ MsoLineDashStyle *DashStyle);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_DashStyle )( 
            LineFormat * This,
            /* [in] */ MsoLineDashStyle DashStyle);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_EndArrowheadLength )( 
            LineFormat * This,
            /* [retval][out] */ MsoArrowheadLength *EndArrowheadLength);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_EndArrowheadLength )( 
            LineFormat * This,
            /* [in] */ MsoArrowheadLength EndArrowheadLength);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_EndArrowheadStyle )( 
            LineFormat * This,
            /* [retval][out] */ MsoArrowheadStyle *EndArrowheadStyle);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_EndArrowheadStyle )( 
            LineFormat * This,
            /* [in] */ MsoArrowheadStyle EndArrowheadStyle);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_EndArrowheadWidth )( 
            LineFormat * This,
            /* [retval][out] */ MsoArrowheadWidth *EndArrowheadWidth);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_EndArrowheadWidth )( 
            LineFormat * This,
            /* [in] */ MsoArrowheadWidth EndArrowheadWidth);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ForeColor )( 
            LineFormat * This,
            /* [retval][out] */ ColorFormat **ForeColor);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_ForeColor )( 
            LineFormat * This,
            /* [in] */ ColorFormat *ForeColor);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Pattern )( 
            LineFormat * This,
            /* [retval][out] */ MsoPatternType *Pattern);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Pattern )( 
            LineFormat * This,
            /* [in] */ MsoPatternType Pattern);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Style )( 
            LineFormat * This,
            /* [retval][out] */ MsoLineStyle *Style);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Style )( 
            LineFormat * This,
            /* [in] */ MsoLineStyle Style);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Transparency )( 
            LineFormat * This,
            /* [retval][out] */ single *Transparency);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Transparency )( 
            LineFormat * This,
            /* [in] */ single Transparency);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Visible )( 
            LineFormat * This,
            /* [retval][out] */ MsoTriState *Visible);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Visible )( 
            LineFormat * This,
            /* [in] */ MsoTriState Visible);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Weight )( 
            LineFormat * This,
            /* [retval][out] */ single *Weight);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Weight )( 
            LineFormat * This,
            /* [in] */ single Weight);
        
        /* [propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_InsetPen )( 
            LineFormat * This,
            /* [retval][out] */ MsoTriState *InsetPen);
        
        /* [propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_InsetPen )( 
            LineFormat * This,
            /* [in] */ MsoTriState InsetPen);
        
        END_INTERFACE
    } LineFormatVtbl;

    interface LineFormat
    {
        CONST_VTBL struct LineFormatVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define LineFormat_QueryInterface(This,riid,ppvObj,retval)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObj,retval) ) 

#define LineFormat_AddRef(This,retval)	\
    ( (This)->lpVtbl -> AddRef(This,retval) ) 

#define LineFormat_Release(This,retval)	\
    ( (This)->lpVtbl -> Release(This,retval) ) 

#define LineFormat_GetTypeInfoCount(This,pctinfo,retval)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo,retval) ) 

#define LineFormat_GetTypeInfo(This,itinfo,lcid,pptinfo,retval)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,itinfo,lcid,pptinfo,retval) ) 

#define LineFormat_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgdispid,retval)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgdispid,retval) ) 

#define LineFormat_Invoke(This,dispidMember,riid,lcid,wFlags,pdispparams,pvarResult,pexcepinfo,puArgErr,retval)	\
    ( (This)->lpVtbl -> Invoke(This,dispidMember,riid,lcid,wFlags,pdispparams,pvarResult,pexcepinfo,puArgErr,retval) ) 

#define LineFormat_get_Application(This,retval)	\
    ( (This)->lpVtbl -> get_Application(This,retval) ) 

#define LineFormat_get_Creator(This,retval)	\
    ( (This)->lpVtbl -> get_Creator(This,retval) ) 


#define LineFormat_get_Parent(This,Parent)	\
    ( (This)->lpVtbl -> get_Parent(This,Parent) ) 

#define LineFormat_get_BackColor(This,BackColor)	\
    ( (This)->lpVtbl -> get_BackColor(This,BackColor) ) 

#define LineFormat_put_BackColor(This,BackColor)	\
    ( (This)->lpVtbl -> put_BackColor(This,BackColor) ) 

#define LineFormat_get_BeginArrowheadLength(This,BeginArrowheadLength)	\
    ( (This)->lpVtbl -> get_BeginArrowheadLength(This,BeginArrowheadLength) ) 

#define LineFormat_put_BeginArrowheadLength(This,BeginArrowheadLength)	\
    ( (This)->lpVtbl -> put_BeginArrowheadLength(This,BeginArrowheadLength) ) 

#define LineFormat_get_BeginArrowheadStyle(This,BeginArrowheadStyle)	\
    ( (This)->lpVtbl -> get_BeginArrowheadStyle(This,BeginArrowheadStyle) ) 

#define LineFormat_put_BeginArrowheadStyle(This,BeginArrowheadStyle)	\
    ( (This)->lpVtbl -> put_BeginArrowheadStyle(This,BeginArrowheadStyle) ) 

#define LineFormat_get_BeginArrowheadWidth(This,BeginArrowheadWidth)	\
    ( (This)->lpVtbl -> get_BeginArrowheadWidth(This,BeginArrowheadWidth) ) 

#define LineFormat_put_BeginArrowheadWidth(This,BeginArrowheadWidth)	\
    ( (This)->lpVtbl -> put_BeginArrowheadWidth(This,BeginArrowheadWidth) ) 

#define LineFormat_get_DashStyle(This,DashStyle)	\
    ( (This)->lpVtbl -> get_DashStyle(This,DashStyle) ) 

#define LineFormat_put_DashStyle(This,DashStyle)	\
    ( (This)->lpVtbl -> put_DashStyle(This,DashStyle) ) 

#define LineFormat_get_EndArrowheadLength(This,EndArrowheadLength)	\
    ( (This)->lpVtbl -> get_EndArrowheadLength(This,EndArrowheadLength) ) 

#define LineFormat_put_EndArrowheadLength(This,EndArrowheadLength)	\
    ( (This)->lpVtbl -> put_EndArrowheadLength(This,EndArrowheadLength) ) 

#define LineFormat_get_EndArrowheadStyle(This,EndArrowheadStyle)	\
    ( (This)->lpVtbl -> get_EndArrowheadStyle(This,EndArrowheadStyle) ) 

#define LineFormat_put_EndArrowheadStyle(This,EndArrowheadStyle)	\
    ( (This)->lpVtbl -> put_EndArrowheadStyle(This,EndArrowheadStyle) ) 

#define LineFormat_get_EndArrowheadWidth(This,EndArrowheadWidth)	\
    ( (This)->lpVtbl -> get_EndArrowheadWidth(This,EndArrowheadWidth) ) 

#define LineFormat_put_EndArrowheadWidth(This,EndArrowheadWidth)	\
    ( (This)->lpVtbl -> put_EndArrowheadWidth(This,EndArrowheadWidth) ) 

#define LineFormat_get_ForeColor(This,ForeColor)	\
    ( (This)->lpVtbl -> get_ForeColor(This,ForeColor) ) 

#define LineFormat_put_ForeColor(This,ForeColor)	\
    ( (This)->lpVtbl -> put_ForeColor(This,ForeColor) ) 

#define LineFormat_get_Pattern(This,Pattern)	\
    ( (This)->lpVtbl -> get_Pattern(This,Pattern) ) 

#define LineFormat_put_Pattern(This,Pattern)	\
    ( (This)->lpVtbl -> put_Pattern(This,Pattern) ) 

#define LineFormat_get_Style(This,Style)	\
    ( (This)->lpVtbl -> get_Style(This,Style) ) 

#define LineFormat_put_Style(This,Style)	\
    ( (This)->lpVtbl -> put_Style(This,Style) ) 

#define LineFormat_get_Transparency(This,Transparency)	\
    ( (This)->lpVtbl -> get_Transparency(This,Transparency) ) 

#define LineFormat_put_Transparency(This,Transparency)	\
    ( (This)->lpVtbl -> put_Transparency(This,Transparency) ) 

#define LineFormat_get_Visible(This,Visible)	\
    ( (This)->lpVtbl -> get_Visible(This,Visible) ) 

#define LineFormat_put_Visible(This,Visible)	\
    ( (This)->lpVtbl -> put_Visible(This,Visible) ) 

#define LineFormat_get_Weight(This,Weight)	\
    ( (This)->lpVtbl -> get_Weight(This,Weight) ) 

#define LineFormat_put_Weight(This,Weight)	\
    ( (This)->lpVtbl -> put_Weight(This,Weight) ) 

#define LineFormat_get_InsetPen(This,InsetPen)	\
    ( (This)->lpVtbl -> get_InsetPen(This,InsetPen) ) 

#define LineFormat_put_InsetPen(This,InsetPen)	\
    ( (This)->lpVtbl -> put_InsetPen(This,InsetPen) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __LineFormat_INTERFACE_DEFINED__ */


#ifndef __ShapeNode_INTERFACE_DEFINED__
#define __ShapeNode_INTERFACE_DEFINED__

/* interface ShapeNode */
/* [object][oleautomation][nonextensible][dual][helpcontext][uuid] */ 


EXTERN_C const IID IID_ShapeNode;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000C0318-0000-0000-C000-000000000046")
    ShapeNode : public _IMsoDispObj
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Parent( 
            /* [retval][out] */ IDispatch **Parent) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_EditingType( 
            /* [retval][out] */ MsoEditingType *EditingType) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Points( 
            /* [retval][out] */ VARIANT *Points) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_SegmentType( 
            /* [retval][out] */ MsoSegmentType *SegmentType) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ShapeNodeVtbl
    {
        BEGIN_INTERFACE
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ShapeNode * This,
            /* [in][idldescattr] */ struct GUID *riid,
            /* [out][idldescattr] */ void **ppvObj,
            /* [retval][out] */ void *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *AddRef )( 
            ShapeNode * This,
            /* [retval][out] */ unsigned long *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *Release )( 
            ShapeNode * This,
            /* [retval][out] */ unsigned long *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ShapeNode * This,
            /* [out][idldescattr] */ unsigned UINT *pctinfo,
            /* [retval][out] */ void *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ShapeNode * This,
            /* [in][idldescattr] */ unsigned UINT itinfo,
            /* [in][idldescattr] */ unsigned long lcid,
            /* [out][idldescattr] */ void **pptinfo,
            /* [retval][out] */ void *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ShapeNode * This,
            /* [in][idldescattr] */ struct GUID *riid,
            /* [in][idldescattr] */ signed char **rgszNames,
            /* [in][idldescattr] */ unsigned UINT cNames,
            /* [in][idldescattr] */ unsigned long lcid,
            /* [out][idldescattr] */ signed long *rgdispid,
            /* [retval][out] */ void *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ShapeNode * This,
            /* [in][idldescattr] */ signed long dispidMember,
            /* [in][idldescattr] */ struct GUID *riid,
            /* [in][idldescattr] */ unsigned long lcid,
            /* [in][idldescattr] */ unsigned short wFlags,
            /* [in][idldescattr] */ struct DISPPARAMS *pdispparams,
            /* [out][idldescattr] */ VARIANT *pvarResult,
            /* [out][idldescattr] */ struct EXCEPINFO *pexcepinfo,
            /* [out][idldescattr] */ unsigned UINT *puArgErr,
            /* [retval][out] */ void *retval);
        
        /* [id][propget][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *get_Application )( 
            ShapeNode * This,
            /* [retval][out] */ IDispatch **retval);
        
        /* [id][propget][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *get_Creator )( 
            ShapeNode * This,
            /* [retval][out] */ signed long *retval);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Parent )( 
            ShapeNode * This,
            /* [retval][out] */ IDispatch **Parent);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_EditingType )( 
            ShapeNode * This,
            /* [retval][out] */ MsoEditingType *EditingType);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Points )( 
            ShapeNode * This,
            /* [retval][out] */ VARIANT *Points);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_SegmentType )( 
            ShapeNode * This,
            /* [retval][out] */ MsoSegmentType *SegmentType);
        
        END_INTERFACE
    } ShapeNodeVtbl;

    interface ShapeNode
    {
        CONST_VTBL struct ShapeNodeVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ShapeNode_QueryInterface(This,riid,ppvObj,retval)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObj,retval) ) 

#define ShapeNode_AddRef(This,retval)	\
    ( (This)->lpVtbl -> AddRef(This,retval) ) 

#define ShapeNode_Release(This,retval)	\
    ( (This)->lpVtbl -> Release(This,retval) ) 

#define ShapeNode_GetTypeInfoCount(This,pctinfo,retval)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo,retval) ) 

#define ShapeNode_GetTypeInfo(This,itinfo,lcid,pptinfo,retval)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,itinfo,lcid,pptinfo,retval) ) 

#define ShapeNode_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgdispid,retval)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgdispid,retval) ) 

#define ShapeNode_Invoke(This,dispidMember,riid,lcid,wFlags,pdispparams,pvarResult,pexcepinfo,puArgErr,retval)	\
    ( (This)->lpVtbl -> Invoke(This,dispidMember,riid,lcid,wFlags,pdispparams,pvarResult,pexcepinfo,puArgErr,retval) ) 

#define ShapeNode_get_Application(This,retval)	\
    ( (This)->lpVtbl -> get_Application(This,retval) ) 

#define ShapeNode_get_Creator(This,retval)	\
    ( (This)->lpVtbl -> get_Creator(This,retval) ) 


#define ShapeNode_get_Parent(This,Parent)	\
    ( (This)->lpVtbl -> get_Parent(This,Parent) ) 

#define ShapeNode_get_EditingType(This,EditingType)	\
    ( (This)->lpVtbl -> get_EditingType(This,EditingType) ) 

#define ShapeNode_get_Points(This,Points)	\
    ( (This)->lpVtbl -> get_Points(This,Points) ) 

#define ShapeNode_get_SegmentType(This,SegmentType)	\
    ( (This)->lpVtbl -> get_SegmentType(This,SegmentType) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ShapeNode_INTERFACE_DEFINED__ */


#ifndef __ShapeNodes_INTERFACE_DEFINED__
#define __ShapeNodes_INTERFACE_DEFINED__

/* interface ShapeNodes */
/* [object][oleautomation][nonextensible][dual][helpcontext][uuid] */ 


EXTERN_C const IID IID_ShapeNodes;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000C0319-0000-0000-C000-000000000046")
    ShapeNodes : public _IMsoDispObj
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Parent( 
            /* [retval][out] */ IDispatch **Parent) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Count( 
            /* [retval][out] */ int *Count) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ ShapeNode **Item) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get__NewEnum( 
            /* [retval][out] */ IUnknown **_NewEnum) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Delete( 
            /* [in] */ int Index) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Insert( 
            /* [in] */ int Index,
            /* [in] */ MsoSegmentType SegmentType,
            /* [in] */ MsoEditingType EditingType,
            /* [in] */ single X1,
            /* [in] */ single Y1,
            /* [defaultvalue][optional][in] */ single X2 = 0,
            /* [defaultvalue][optional][in] */ single Y2 = 0,
            /* [defaultvalue][optional][in] */ single X3 = 0,
            /* [defaultvalue][optional][in] */ single Y3 = 0) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE SetEditingType( 
            /* [in] */ int Index,
            /* [in] */ MsoEditingType EditingType) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE SetPosition( 
            /* [in] */ int Index,
            /* [in] */ single X1,
            /* [in] */ single Y1) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE SetSegmentType( 
            /* [in] */ int Index,
            /* [in] */ MsoSegmentType SegmentType) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ShapeNodesVtbl
    {
        BEGIN_INTERFACE
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ShapeNodes * This,
            /* [in][idldescattr] */ struct GUID *riid,
            /* [out][idldescattr] */ void **ppvObj,
            /* [retval][out] */ void *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *AddRef )( 
            ShapeNodes * This,
            /* [retval][out] */ unsigned long *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *Release )( 
            ShapeNodes * This,
            /* [retval][out] */ unsigned long *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ShapeNodes * This,
            /* [out][idldescattr] */ unsigned UINT *pctinfo,
            /* [retval][out] */ void *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ShapeNodes * This,
            /* [in][idldescattr] */ unsigned UINT itinfo,
            /* [in][idldescattr] */ unsigned long lcid,
            /* [out][idldescattr] */ void **pptinfo,
            /* [retval][out] */ void *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ShapeNodes * This,
            /* [in][idldescattr] */ struct GUID *riid,
            /* [in][idldescattr] */ signed char **rgszNames,
            /* [in][idldescattr] */ unsigned UINT cNames,
            /* [in][idldescattr] */ unsigned long lcid,
            /* [out][idldescattr] */ signed long *rgdispid,
            /* [retval][out] */ void *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ShapeNodes * This,
            /* [in][idldescattr] */ signed long dispidMember,
            /* [in][idldescattr] */ struct GUID *riid,
            /* [in][idldescattr] */ unsigned long lcid,
            /* [in][idldescattr] */ unsigned short wFlags,
            /* [in][idldescattr] */ struct DISPPARAMS *pdispparams,
            /* [out][idldescattr] */ VARIANT *pvarResult,
            /* [out][idldescattr] */ struct EXCEPINFO *pexcepinfo,
            /* [out][idldescattr] */ unsigned UINT *puArgErr,
            /* [retval][out] */ void *retval);
        
        /* [id][propget][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *get_Application )( 
            ShapeNodes * This,
            /* [retval][out] */ IDispatch **retval);
        
        /* [id][propget][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *get_Creator )( 
            ShapeNodes * This,
            /* [retval][out] */ signed long *retval);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Parent )( 
            ShapeNodes * This,
            /* [retval][out] */ IDispatch **Parent);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Count )( 
            ShapeNodes * This,
            /* [retval][out] */ int *Count);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Item )( 
            ShapeNodes * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ ShapeNode **Item);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get__NewEnum )( 
            ShapeNodes * This,
            /* [retval][out] */ IUnknown **_NewEnum);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Delete )( 
            ShapeNodes * This,
            /* [in] */ int Index);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Insert )( 
            ShapeNodes * This,
            /* [in] */ int Index,
            /* [in] */ MsoSegmentType SegmentType,
            /* [in] */ MsoEditingType EditingType,
            /* [in] */ single X1,
            /* [in] */ single Y1,
            /* [defaultvalue][optional][in] */ single X2,
            /* [defaultvalue][optional][in] */ single Y2,
            /* [defaultvalue][optional][in] */ single X3,
            /* [defaultvalue][optional][in] */ single Y3);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *SetEditingType )( 
            ShapeNodes * This,
            /* [in] */ int Index,
            /* [in] */ MsoEditingType EditingType);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *SetPosition )( 
            ShapeNodes * This,
            /* [in] */ int Index,
            /* [in] */ single X1,
            /* [in] */ single Y1);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *SetSegmentType )( 
            ShapeNodes * This,
            /* [in] */ int Index,
            /* [in] */ MsoSegmentType SegmentType);
        
        END_INTERFACE
    } ShapeNodesVtbl;

    interface ShapeNodes
    {
        CONST_VTBL struct ShapeNodesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ShapeNodes_QueryInterface(This,riid,ppvObj,retval)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObj,retval) ) 

#define ShapeNodes_AddRef(This,retval)	\
    ( (This)->lpVtbl -> AddRef(This,retval) ) 

#define ShapeNodes_Release(This,retval)	\
    ( (This)->lpVtbl -> Release(This,retval) ) 

#define ShapeNodes_GetTypeInfoCount(This,pctinfo,retval)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo,retval) ) 

#define ShapeNodes_GetTypeInfo(This,itinfo,lcid,pptinfo,retval)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,itinfo,lcid,pptinfo,retval) ) 

#define ShapeNodes_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgdispid,retval)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgdispid,retval) ) 

#define ShapeNodes_Invoke(This,dispidMember,riid,lcid,wFlags,pdispparams,pvarResult,pexcepinfo,puArgErr,retval)	\
    ( (This)->lpVtbl -> Invoke(This,dispidMember,riid,lcid,wFlags,pdispparams,pvarResult,pexcepinfo,puArgErr,retval) ) 

#define ShapeNodes_get_Application(This,retval)	\
    ( (This)->lpVtbl -> get_Application(This,retval) ) 

#define ShapeNodes_get_Creator(This,retval)	\
    ( (This)->lpVtbl -> get_Creator(This,retval) ) 


#define ShapeNodes_get_Parent(This,Parent)	\
    ( (This)->lpVtbl -> get_Parent(This,Parent) ) 

#define ShapeNodes_get_Count(This,Count)	\
    ( (This)->lpVtbl -> get_Count(This,Count) ) 

#define ShapeNodes_Item(This,Index,Item)	\
    ( (This)->lpVtbl -> Item(This,Index,Item) ) 

#define ShapeNodes_get__NewEnum(This,_NewEnum)	\
    ( (This)->lpVtbl -> get__NewEnum(This,_NewEnum) ) 

#define ShapeNodes_Delete(This,Index)	\
    ( (This)->lpVtbl -> Delete(This,Index) ) 

#define ShapeNodes_Insert(This,Index,SegmentType,EditingType,X1,Y1,X2,Y2,X3,Y3)	\
    ( (This)->lpVtbl -> Insert(This,Index,SegmentType,EditingType,X1,Y1,X2,Y2,X3,Y3) ) 

#define ShapeNodes_SetEditingType(This,Index,EditingType)	\
    ( (This)->lpVtbl -> SetEditingType(This,Index,EditingType) ) 

#define ShapeNodes_SetPosition(This,Index,X1,Y1)	\
    ( (This)->lpVtbl -> SetPosition(This,Index,X1,Y1) ) 

#define ShapeNodes_SetSegmentType(This,Index,SegmentType)	\
    ( (This)->lpVtbl -> SetSegmentType(This,Index,SegmentType) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ShapeNodes_INTERFACE_DEFINED__ */


#ifndef __PictureFormat_INTERFACE_DEFINED__
#define __PictureFormat_INTERFACE_DEFINED__

/* interface PictureFormat */
/* [object][oleautomation][nonextensible][dual][helpcontext][uuid] */ 


EXTERN_C const IID IID_PictureFormat;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000C031A-0000-0000-C000-000000000046")
    PictureFormat : public _IMsoDispObj
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Parent( 
            /* [retval][out] */ IDispatch **Parent) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE IncrementBrightness( 
            /* [in] */ single Increment) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE IncrementContrast( 
            /* [in] */ single Increment) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Brightness( 
            /* [retval][out] */ single *Brightness) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_Brightness( 
            /* [in] */ single Brightness) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ColorType( 
            /* [retval][out] */ MsoPictureColorType *ColorType) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_ColorType( 
            /* [in] */ MsoPictureColorType ColorType) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Contrast( 
            /* [retval][out] */ single *Contrast) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_Contrast( 
            /* [in] */ single Contrast) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_CropBottom( 
            /* [retval][out] */ single *CropBottom) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_CropBottom( 
            /* [in] */ single CropBottom) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_CropLeft( 
            /* [retval][out] */ single *CropLeft) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_CropLeft( 
            /* [in] */ single CropLeft) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_CropRight( 
            /* [retval][out] */ single *CropRight) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_CropRight( 
            /* [in] */ single CropRight) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_CropTop( 
            /* [retval][out] */ single *CropTop) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_CropTop( 
            /* [in] */ single CropTop) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_TransparencyColor( 
            /* [retval][out] */ MsoRGBType *TransparencyColor) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_TransparencyColor( 
            /* [in] */ MsoRGBType TransparencyColor) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_TransparentBackground( 
            /* [retval][out] */ MsoTriState *TransparentBackground) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_TransparentBackground( 
            /* [in] */ MsoTriState TransparentBackground) = 0;
        
        virtual /* [propget][id] */ HRESULT STDMETHODCALLTYPE get_Crop( 
            /* [retval][out] */ /* external definition not present */ Crop **Crop) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct PictureFormatVtbl
    {
        BEGIN_INTERFACE
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            PictureFormat * This,
            /* [in][idldescattr] */ struct GUID *riid,
            /* [out][idldescattr] */ void **ppvObj,
            /* [retval][out] */ void *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *AddRef )( 
            PictureFormat * This,
            /* [retval][out] */ unsigned long *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *Release )( 
            PictureFormat * This,
            /* [retval][out] */ unsigned long *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            PictureFormat * This,
            /* [out][idldescattr] */ unsigned UINT *pctinfo,
            /* [retval][out] */ void *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            PictureFormat * This,
            /* [in][idldescattr] */ unsigned UINT itinfo,
            /* [in][idldescattr] */ unsigned long lcid,
            /* [out][idldescattr] */ void **pptinfo,
            /* [retval][out] */ void *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            PictureFormat * This,
            /* [in][idldescattr] */ struct GUID *riid,
            /* [in][idldescattr] */ signed char **rgszNames,
            /* [in][idldescattr] */ unsigned UINT cNames,
            /* [in][idldescattr] */ unsigned long lcid,
            /* [out][idldescattr] */ signed long *rgdispid,
            /* [retval][out] */ void *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            PictureFormat * This,
            /* [in][idldescattr] */ signed long dispidMember,
            /* [in][idldescattr] */ struct GUID *riid,
            /* [in][idldescattr] */ unsigned long lcid,
            /* [in][idldescattr] */ unsigned short wFlags,
            /* [in][idldescattr] */ struct DISPPARAMS *pdispparams,
            /* [out][idldescattr] */ VARIANT *pvarResult,
            /* [out][idldescattr] */ struct EXCEPINFO *pexcepinfo,
            /* [out][idldescattr] */ unsigned UINT *puArgErr,
            /* [retval][out] */ void *retval);
        
        /* [id][propget][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *get_Application )( 
            PictureFormat * This,
            /* [retval][out] */ IDispatch **retval);
        
        /* [id][propget][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *get_Creator )( 
            PictureFormat * This,
            /* [retval][out] */ signed long *retval);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Parent )( 
            PictureFormat * This,
            /* [retval][out] */ IDispatch **Parent);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *IncrementBrightness )( 
            PictureFormat * This,
            /* [in] */ single Increment);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *IncrementContrast )( 
            PictureFormat * This,
            /* [in] */ single Increment);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Brightness )( 
            PictureFormat * This,
            /* [retval][out] */ single *Brightness);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Brightness )( 
            PictureFormat * This,
            /* [in] */ single Brightness);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ColorType )( 
            PictureFormat * This,
            /* [retval][out] */ MsoPictureColorType *ColorType);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_ColorType )( 
            PictureFormat * This,
            /* [in] */ MsoPictureColorType ColorType);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Contrast )( 
            PictureFormat * This,
            /* [retval][out] */ single *Contrast);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Contrast )( 
            PictureFormat * This,
            /* [in] */ single Contrast);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_CropBottom )( 
            PictureFormat * This,
            /* [retval][out] */ single *CropBottom);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_CropBottom )( 
            PictureFormat * This,
            /* [in] */ single CropBottom);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_CropLeft )( 
            PictureFormat * This,
            /* [retval][out] */ single *CropLeft);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_CropLeft )( 
            PictureFormat * This,
            /* [in] */ single CropLeft);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_CropRight )( 
            PictureFormat * This,
            /* [retval][out] */ single *CropRight);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_CropRight )( 
            PictureFormat * This,
            /* [in] */ single CropRight);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_CropTop )( 
            PictureFormat * This,
            /* [retval][out] */ single *CropTop);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_CropTop )( 
            PictureFormat * This,
            /* [in] */ single CropTop);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_TransparencyColor )( 
            PictureFormat * This,
            /* [retval][out] */ MsoRGBType *TransparencyColor);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_TransparencyColor )( 
            PictureFormat * This,
            /* [in] */ MsoRGBType TransparencyColor);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_TransparentBackground )( 
            PictureFormat * This,
            /* [retval][out] */ MsoTriState *TransparentBackground);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_TransparentBackground )( 
            PictureFormat * This,
            /* [in] */ MsoTriState TransparentBackground);
        
        /* [propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Crop )( 
            PictureFormat * This,
            /* [retval][out] */ /* external definition not present */ Crop **Crop);
        
        END_INTERFACE
    } PictureFormatVtbl;

    interface PictureFormat
    {
        CONST_VTBL struct PictureFormatVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define PictureFormat_QueryInterface(This,riid,ppvObj,retval)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObj,retval) ) 

#define PictureFormat_AddRef(This,retval)	\
    ( (This)->lpVtbl -> AddRef(This,retval) ) 

#define PictureFormat_Release(This,retval)	\
    ( (This)->lpVtbl -> Release(This,retval) ) 

#define PictureFormat_GetTypeInfoCount(This,pctinfo,retval)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo,retval) ) 

#define PictureFormat_GetTypeInfo(This,itinfo,lcid,pptinfo,retval)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,itinfo,lcid,pptinfo,retval) ) 

#define PictureFormat_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgdispid,retval)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgdispid,retval) ) 

#define PictureFormat_Invoke(This,dispidMember,riid,lcid,wFlags,pdispparams,pvarResult,pexcepinfo,puArgErr,retval)	\
    ( (This)->lpVtbl -> Invoke(This,dispidMember,riid,lcid,wFlags,pdispparams,pvarResult,pexcepinfo,puArgErr,retval) ) 

#define PictureFormat_get_Application(This,retval)	\
    ( (This)->lpVtbl -> get_Application(This,retval) ) 

#define PictureFormat_get_Creator(This,retval)	\
    ( (This)->lpVtbl -> get_Creator(This,retval) ) 


#define PictureFormat_get_Parent(This,Parent)	\
    ( (This)->lpVtbl -> get_Parent(This,Parent) ) 

#define PictureFormat_IncrementBrightness(This,Increment)	\
    ( (This)->lpVtbl -> IncrementBrightness(This,Increment) ) 

#define PictureFormat_IncrementContrast(This,Increment)	\
    ( (This)->lpVtbl -> IncrementContrast(This,Increment) ) 

#define PictureFormat_get_Brightness(This,Brightness)	\
    ( (This)->lpVtbl -> get_Brightness(This,Brightness) ) 

#define PictureFormat_put_Brightness(This,Brightness)	\
    ( (This)->lpVtbl -> put_Brightness(This,Brightness) ) 

#define PictureFormat_get_ColorType(This,ColorType)	\
    ( (This)->lpVtbl -> get_ColorType(This,ColorType) ) 

#define PictureFormat_put_ColorType(This,ColorType)	\
    ( (This)->lpVtbl -> put_ColorType(This,ColorType) ) 

#define PictureFormat_get_Contrast(This,Contrast)	\
    ( (This)->lpVtbl -> get_Contrast(This,Contrast) ) 

#define PictureFormat_put_Contrast(This,Contrast)	\
    ( (This)->lpVtbl -> put_Contrast(This,Contrast) ) 

#define PictureFormat_get_CropBottom(This,CropBottom)	\
    ( (This)->lpVtbl -> get_CropBottom(This,CropBottom) ) 

#define PictureFormat_put_CropBottom(This,CropBottom)	\
    ( (This)->lpVtbl -> put_CropBottom(This,CropBottom) ) 

#define PictureFormat_get_CropLeft(This,CropLeft)	\
    ( (This)->lpVtbl -> get_CropLeft(This,CropLeft) ) 

#define PictureFormat_put_CropLeft(This,CropLeft)	\
    ( (This)->lpVtbl -> put_CropLeft(This,CropLeft) ) 

#define PictureFormat_get_CropRight(This,CropRight)	\
    ( (This)->lpVtbl -> get_CropRight(This,CropRight) ) 

#define PictureFormat_put_CropRight(This,CropRight)	\
    ( (This)->lpVtbl -> put_CropRight(This,CropRight) ) 

#define PictureFormat_get_CropTop(This,CropTop)	\
    ( (This)->lpVtbl -> get_CropTop(This,CropTop) ) 

#define PictureFormat_put_CropTop(This,CropTop)	\
    ( (This)->lpVtbl -> put_CropTop(This,CropTop) ) 

#define PictureFormat_get_TransparencyColor(This,TransparencyColor)	\
    ( (This)->lpVtbl -> get_TransparencyColor(This,TransparencyColor) ) 

#define PictureFormat_put_TransparencyColor(This,TransparencyColor)	\
    ( (This)->lpVtbl -> put_TransparencyColor(This,TransparencyColor) ) 

#define PictureFormat_get_TransparentBackground(This,TransparentBackground)	\
    ( (This)->lpVtbl -> get_TransparentBackground(This,TransparentBackground) ) 

#define PictureFormat_put_TransparentBackground(This,TransparentBackground)	\
    ( (This)->lpVtbl -> put_TransparentBackground(This,TransparentBackground) ) 

#define PictureFormat_get_Crop(This,Crop)	\
    ( (This)->lpVtbl -> get_Crop(This,Crop) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __PictureFormat_INTERFACE_DEFINED__ */


#ifndef __ShadowFormat_INTERFACE_DEFINED__
#define __ShadowFormat_INTERFACE_DEFINED__

/* interface ShadowFormat */
/* [object][oleautomation][nonextensible][dual][helpcontext][uuid] */ 


EXTERN_C const IID IID_ShadowFormat;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000C031B-0000-0000-C000-000000000046")
    ShadowFormat : public _IMsoDispObj
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Parent( 
            /* [retval][out] */ IDispatch **Parent) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE IncrementOffsetX( 
            /* [in] */ single Increment) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE IncrementOffsetY( 
            /* [in] */ single Increment) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ForeColor( 
            /* [retval][out] */ ColorFormat **ForeColor) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_ForeColor( 
            /* [in] */ ColorFormat *ForeColor) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Obscured( 
            /* [retval][out] */ MsoTriState *Obscured) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_Obscured( 
            /* [in] */ MsoTriState Obscured) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_OffsetX( 
            /* [retval][out] */ single *OffsetX) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_OffsetX( 
            /* [in] */ single OffsetX) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_OffsetY( 
            /* [retval][out] */ single *OffsetY) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_OffsetY( 
            /* [in] */ single OffsetY) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Transparency( 
            /* [retval][out] */ single *Transparency) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_Transparency( 
            /* [in] */ single Transparency) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Type( 
            /* [retval][out] */ MsoShadowType *Type) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_Type( 
            /* [in] */ MsoShadowType Type) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Visible( 
            /* [retval][out] */ MsoTriState *Visible) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_Visible( 
            /* [in] */ MsoTriState Visible) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Style( 
            /* [retval][out] */ MsoShadowStyle *ShadowStyle) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_Style( 
            /* [in] */ MsoShadowStyle ShadowStyle) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Blur( 
            /* [retval][out] */ single *Blur) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_Blur( 
            /* [in] */ single Blur) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Size( 
            /* [retval][out] */ single *Size) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_Size( 
            /* [in] */ single Size) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_RotateWithShape( 
            /* [retval][out] */ MsoTriState *RotateWithShape) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_RotateWithShape( 
            /* [in] */ MsoTriState RotateWithShape) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ShadowFormatVtbl
    {
        BEGIN_INTERFACE
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ShadowFormat * This,
            /* [in][idldescattr] */ struct GUID *riid,
            /* [out][idldescattr] */ void **ppvObj,
            /* [retval][out] */ void *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *AddRef )( 
            ShadowFormat * This,
            /* [retval][out] */ unsigned long *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *Release )( 
            ShadowFormat * This,
            /* [retval][out] */ unsigned long *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ShadowFormat * This,
            /* [out][idldescattr] */ unsigned UINT *pctinfo,
            /* [retval][out] */ void *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ShadowFormat * This,
            /* [in][idldescattr] */ unsigned UINT itinfo,
            /* [in][idldescattr] */ unsigned long lcid,
            /* [out][idldescattr] */ void **pptinfo,
            /* [retval][out] */ void *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ShadowFormat * This,
            /* [in][idldescattr] */ struct GUID *riid,
            /* [in][idldescattr] */ signed char **rgszNames,
            /* [in][idldescattr] */ unsigned UINT cNames,
            /* [in][idldescattr] */ unsigned long lcid,
            /* [out][idldescattr] */ signed long *rgdispid,
            /* [retval][out] */ void *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ShadowFormat * This,
            /* [in][idldescattr] */ signed long dispidMember,
            /* [in][idldescattr] */ struct GUID *riid,
            /* [in][idldescattr] */ unsigned long lcid,
            /* [in][idldescattr] */ unsigned short wFlags,
            /* [in][idldescattr] */ struct DISPPARAMS *pdispparams,
            /* [out][idldescattr] */ VARIANT *pvarResult,
            /* [out][idldescattr] */ struct EXCEPINFO *pexcepinfo,
            /* [out][idldescattr] */ unsigned UINT *puArgErr,
            /* [retval][out] */ void *retval);
        
        /* [id][propget][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *get_Application )( 
            ShadowFormat * This,
            /* [retval][out] */ IDispatch **retval);
        
        /* [id][propget][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *get_Creator )( 
            ShadowFormat * This,
            /* [retval][out] */ signed long *retval);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Parent )( 
            ShadowFormat * This,
            /* [retval][out] */ IDispatch **Parent);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *IncrementOffsetX )( 
            ShadowFormat * This,
            /* [in] */ single Increment);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *IncrementOffsetY )( 
            ShadowFormat * This,
            /* [in] */ single Increment);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ForeColor )( 
            ShadowFormat * This,
            /* [retval][out] */ ColorFormat **ForeColor);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_ForeColor )( 
            ShadowFormat * This,
            /* [in] */ ColorFormat *ForeColor);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Obscured )( 
            ShadowFormat * This,
            /* [retval][out] */ MsoTriState *Obscured);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Obscured )( 
            ShadowFormat * This,
            /* [in] */ MsoTriState Obscured);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_OffsetX )( 
            ShadowFormat * This,
            /* [retval][out] */ single *OffsetX);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_OffsetX )( 
            ShadowFormat * This,
            /* [in] */ single OffsetX);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_OffsetY )( 
            ShadowFormat * This,
            /* [retval][out] */ single *OffsetY);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_OffsetY )( 
            ShadowFormat * This,
            /* [in] */ single OffsetY);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Transparency )( 
            ShadowFormat * This,
            /* [retval][out] */ single *Transparency);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Transparency )( 
            ShadowFormat * This,
            /* [in] */ single Transparency);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Type )( 
            ShadowFormat * This,
            /* [retval][out] */ MsoShadowType *Type);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Type )( 
            ShadowFormat * This,
            /* [in] */ MsoShadowType Type);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Visible )( 
            ShadowFormat * This,
            /* [retval][out] */ MsoTriState *Visible);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Visible )( 
            ShadowFormat * This,
            /* [in] */ MsoTriState Visible);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Style )( 
            ShadowFormat * This,
            /* [retval][out] */ MsoShadowStyle *ShadowStyle);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Style )( 
            ShadowFormat * This,
            /* [in] */ MsoShadowStyle ShadowStyle);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Blur )( 
            ShadowFormat * This,
            /* [retval][out] */ single *Blur);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Blur )( 
            ShadowFormat * This,
            /* [in] */ single Blur);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Size )( 
            ShadowFormat * This,
            /* [retval][out] */ single *Size);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Size )( 
            ShadowFormat * This,
            /* [in] */ single Size);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_RotateWithShape )( 
            ShadowFormat * This,
            /* [retval][out] */ MsoTriState *RotateWithShape);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_RotateWithShape )( 
            ShadowFormat * This,
            /* [in] */ MsoTriState RotateWithShape);
        
        END_INTERFACE
    } ShadowFormatVtbl;

    interface ShadowFormat
    {
        CONST_VTBL struct ShadowFormatVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ShadowFormat_QueryInterface(This,riid,ppvObj,retval)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObj,retval) ) 

#define ShadowFormat_AddRef(This,retval)	\
    ( (This)->lpVtbl -> AddRef(This,retval) ) 

#define ShadowFormat_Release(This,retval)	\
    ( (This)->lpVtbl -> Release(This,retval) ) 

#define ShadowFormat_GetTypeInfoCount(This,pctinfo,retval)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo,retval) ) 

#define ShadowFormat_GetTypeInfo(This,itinfo,lcid,pptinfo,retval)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,itinfo,lcid,pptinfo,retval) ) 

#define ShadowFormat_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgdispid,retval)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgdispid,retval) ) 

#define ShadowFormat_Invoke(This,dispidMember,riid,lcid,wFlags,pdispparams,pvarResult,pexcepinfo,puArgErr,retval)	\
    ( (This)->lpVtbl -> Invoke(This,dispidMember,riid,lcid,wFlags,pdispparams,pvarResult,pexcepinfo,puArgErr,retval) ) 

#define ShadowFormat_get_Application(This,retval)	\
    ( (This)->lpVtbl -> get_Application(This,retval) ) 

#define ShadowFormat_get_Creator(This,retval)	\
    ( (This)->lpVtbl -> get_Creator(This,retval) ) 


#define ShadowFormat_get_Parent(This,Parent)	\
    ( (This)->lpVtbl -> get_Parent(This,Parent) ) 

#define ShadowFormat_IncrementOffsetX(This,Increment)	\
    ( (This)->lpVtbl -> IncrementOffsetX(This,Increment) ) 

#define ShadowFormat_IncrementOffsetY(This,Increment)	\
    ( (This)->lpVtbl -> IncrementOffsetY(This,Increment) ) 

#define ShadowFormat_get_ForeColor(This,ForeColor)	\
    ( (This)->lpVtbl -> get_ForeColor(This,ForeColor) ) 

#define ShadowFormat_put_ForeColor(This,ForeColor)	\
    ( (This)->lpVtbl -> put_ForeColor(This,ForeColor) ) 

#define ShadowFormat_get_Obscured(This,Obscured)	\
    ( (This)->lpVtbl -> get_Obscured(This,Obscured) ) 

#define ShadowFormat_put_Obscured(This,Obscured)	\
    ( (This)->lpVtbl -> put_Obscured(This,Obscured) ) 

#define ShadowFormat_get_OffsetX(This,OffsetX)	\
    ( (This)->lpVtbl -> get_OffsetX(This,OffsetX) ) 

#define ShadowFormat_put_OffsetX(This,OffsetX)	\
    ( (This)->lpVtbl -> put_OffsetX(This,OffsetX) ) 

#define ShadowFormat_get_OffsetY(This,OffsetY)	\
    ( (This)->lpVtbl -> get_OffsetY(This,OffsetY) ) 

#define ShadowFormat_put_OffsetY(This,OffsetY)	\
    ( (This)->lpVtbl -> put_OffsetY(This,OffsetY) ) 

#define ShadowFormat_get_Transparency(This,Transparency)	\
    ( (This)->lpVtbl -> get_Transparency(This,Transparency) ) 

#define ShadowFormat_put_Transparency(This,Transparency)	\
    ( (This)->lpVtbl -> put_Transparency(This,Transparency) ) 

#define ShadowFormat_get_Type(This,Type)	\
    ( (This)->lpVtbl -> get_Type(This,Type) ) 

#define ShadowFormat_put_Type(This,Type)	\
    ( (This)->lpVtbl -> put_Type(This,Type) ) 

#define ShadowFormat_get_Visible(This,Visible)	\
    ( (This)->lpVtbl -> get_Visible(This,Visible) ) 

#define ShadowFormat_put_Visible(This,Visible)	\
    ( (This)->lpVtbl -> put_Visible(This,Visible) ) 

#define ShadowFormat_get_Style(This,ShadowStyle)	\
    ( (This)->lpVtbl -> get_Style(This,ShadowStyle) ) 

#define ShadowFormat_put_Style(This,ShadowStyle)	\
    ( (This)->lpVtbl -> put_Style(This,ShadowStyle) ) 

#define ShadowFormat_get_Blur(This,Blur)	\
    ( (This)->lpVtbl -> get_Blur(This,Blur) ) 

#define ShadowFormat_put_Blur(This,Blur)	\
    ( (This)->lpVtbl -> put_Blur(This,Blur) ) 

#define ShadowFormat_get_Size(This,Size)	\
    ( (This)->lpVtbl -> get_Size(This,Size) ) 

#define ShadowFormat_put_Size(This,Size)	\
    ( (This)->lpVtbl -> put_Size(This,Size) ) 

#define ShadowFormat_get_RotateWithShape(This,RotateWithShape)	\
    ( (This)->lpVtbl -> get_RotateWithShape(This,RotateWithShape) ) 

#define ShadowFormat_put_RotateWithShape(This,RotateWithShape)	\
    ( (This)->lpVtbl -> put_RotateWithShape(This,RotateWithShape) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ShadowFormat_INTERFACE_DEFINED__ */


#ifndef __TextEffectFormat_INTERFACE_DEFINED__
#define __TextEffectFormat_INTERFACE_DEFINED__

/* interface TextEffectFormat */
/* [object][oleautomation][nonextensible][dual][helpcontext][uuid] */ 


EXTERN_C const IID IID_TextEffectFormat;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000C031F-0000-0000-C000-000000000046")
    TextEffectFormat : public _IMsoDispObj
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Parent( 
            /* [retval][out] */ IDispatch **Parent) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE ToggleVerticalText( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Alignment( 
            /* [retval][out] */ MsoTextEffectAlignment *Alignment) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_Alignment( 
            /* [in] */ MsoTextEffectAlignment Alignment) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_FontBold( 
            /* [retval][out] */ MsoTriState *FontBold) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_FontBold( 
            /* [in] */ MsoTriState FontBold) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_FontItalic( 
            /* [retval][out] */ MsoTriState *FontItalic) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_FontItalic( 
            /* [in] */ MsoTriState FontItalic) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_FontName( 
            /* [retval][out] */ BSTR *FontName) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_FontName( 
            /* [in] */ BSTR FontName) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_FontSize( 
            /* [retval][out] */ single *FontSize) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_FontSize( 
            /* [in] */ single FontSize) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_KernedPairs( 
            /* [retval][out] */ MsoTriState *KernedPairs) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_KernedPairs( 
            /* [in] */ MsoTriState KernedPairs) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_NormalizedHeight( 
            /* [retval][out] */ MsoTriState *NormalizedHeight) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_NormalizedHeight( 
            /* [in] */ MsoTriState NormalizedHeight) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_PresetShape( 
            /* [retval][out] */ MsoPresetTextEffectShape *PresetShape) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_PresetShape( 
            /* [in] */ MsoPresetTextEffectShape PresetShape) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_PresetTextEffect( 
            /* [retval][out] */ MsoPresetTextEffect *Preset) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_PresetTextEffect( 
            /* [in] */ MsoPresetTextEffect Preset) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_RotatedChars( 
            /* [retval][out] */ MsoTriState *RotatedChars) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_RotatedChars( 
            /* [in] */ MsoTriState RotatedChars) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Text( 
            /* [retval][out] */ BSTR *Text) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_Text( 
            /* [in] */ BSTR Text) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Tracking( 
            /* [retval][out] */ single *Tracking) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_Tracking( 
            /* [in] */ single Tracking) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct TextEffectFormatVtbl
    {
        BEGIN_INTERFACE
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            TextEffectFormat * This,
            /* [in][idldescattr] */ struct GUID *riid,
            /* [out][idldescattr] */ void **ppvObj,
            /* [retval][out] */ void *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *AddRef )( 
            TextEffectFormat * This,
            /* [retval][out] */ unsigned long *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *Release )( 
            TextEffectFormat * This,
            /* [retval][out] */ unsigned long *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            TextEffectFormat * This,
            /* [out][idldescattr] */ unsigned UINT *pctinfo,
            /* [retval][out] */ void *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            TextEffectFormat * This,
            /* [in][idldescattr] */ unsigned UINT itinfo,
            /* [in][idldescattr] */ unsigned long lcid,
            /* [out][idldescattr] */ void **pptinfo,
            /* [retval][out] */ void *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            TextEffectFormat * This,
            /* [in][idldescattr] */ struct GUID *riid,
            /* [in][idldescattr] */ signed char **rgszNames,
            /* [in][idldescattr] */ unsigned UINT cNames,
            /* [in][idldescattr] */ unsigned long lcid,
            /* [out][idldescattr] */ signed long *rgdispid,
            /* [retval][out] */ void *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            TextEffectFormat * This,
            /* [in][idldescattr] */ signed long dispidMember,
            /* [in][idldescattr] */ struct GUID *riid,
            /* [in][idldescattr] */ unsigned long lcid,
            /* [in][idldescattr] */ unsigned short wFlags,
            /* [in][idldescattr] */ struct DISPPARAMS *pdispparams,
            /* [out][idldescattr] */ VARIANT *pvarResult,
            /* [out][idldescattr] */ struct EXCEPINFO *pexcepinfo,
            /* [out][idldescattr] */ unsigned UINT *puArgErr,
            /* [retval][out] */ void *retval);
        
        /* [id][propget][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *get_Application )( 
            TextEffectFormat * This,
            /* [retval][out] */ IDispatch **retval);
        
        /* [id][propget][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *get_Creator )( 
            TextEffectFormat * This,
            /* [retval][out] */ signed long *retval);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Parent )( 
            TextEffectFormat * This,
            /* [retval][out] */ IDispatch **Parent);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *ToggleVerticalText )( 
            TextEffectFormat * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Alignment )( 
            TextEffectFormat * This,
            /* [retval][out] */ MsoTextEffectAlignment *Alignment);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Alignment )( 
            TextEffectFormat * This,
            /* [in] */ MsoTextEffectAlignment Alignment);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_FontBold )( 
            TextEffectFormat * This,
            /* [retval][out] */ MsoTriState *FontBold);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_FontBold )( 
            TextEffectFormat * This,
            /* [in] */ MsoTriState FontBold);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_FontItalic )( 
            TextEffectFormat * This,
            /* [retval][out] */ MsoTriState *FontItalic);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_FontItalic )( 
            TextEffectFormat * This,
            /* [in] */ MsoTriState FontItalic);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_FontName )( 
            TextEffectFormat * This,
            /* [retval][out] */ BSTR *FontName);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_FontName )( 
            TextEffectFormat * This,
            /* [in] */ BSTR FontName);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_FontSize )( 
            TextEffectFormat * This,
            /* [retval][out] */ single *FontSize);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_FontSize )( 
            TextEffectFormat * This,
            /* [in] */ single FontSize);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_KernedPairs )( 
            TextEffectFormat * This,
            /* [retval][out] */ MsoTriState *KernedPairs);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_KernedPairs )( 
            TextEffectFormat * This,
            /* [in] */ MsoTriState KernedPairs);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_NormalizedHeight )( 
            TextEffectFormat * This,
            /* [retval][out] */ MsoTriState *NormalizedHeight);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_NormalizedHeight )( 
            TextEffectFormat * This,
            /* [in] */ MsoTriState NormalizedHeight);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_PresetShape )( 
            TextEffectFormat * This,
            /* [retval][out] */ MsoPresetTextEffectShape *PresetShape);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_PresetShape )( 
            TextEffectFormat * This,
            /* [in] */ MsoPresetTextEffectShape PresetShape);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_PresetTextEffect )( 
            TextEffectFormat * This,
            /* [retval][out] */ MsoPresetTextEffect *Preset);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_PresetTextEffect )( 
            TextEffectFormat * This,
            /* [in] */ MsoPresetTextEffect Preset);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_RotatedChars )( 
            TextEffectFormat * This,
            /* [retval][out] */ MsoTriState *RotatedChars);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_RotatedChars )( 
            TextEffectFormat * This,
            /* [in] */ MsoTriState RotatedChars);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Text )( 
            TextEffectFormat * This,
            /* [retval][out] */ BSTR *Text);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Text )( 
            TextEffectFormat * This,
            /* [in] */ BSTR Text);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Tracking )( 
            TextEffectFormat * This,
            /* [retval][out] */ single *Tracking);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Tracking )( 
            TextEffectFormat * This,
            /* [in] */ single Tracking);
        
        END_INTERFACE
    } TextEffectFormatVtbl;

    interface TextEffectFormat
    {
        CONST_VTBL struct TextEffectFormatVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define TextEffectFormat_QueryInterface(This,riid,ppvObj,retval)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObj,retval) ) 

#define TextEffectFormat_AddRef(This,retval)	\
    ( (This)->lpVtbl -> AddRef(This,retval) ) 

#define TextEffectFormat_Release(This,retval)	\
    ( (This)->lpVtbl -> Release(This,retval) ) 

#define TextEffectFormat_GetTypeInfoCount(This,pctinfo,retval)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo,retval) ) 

#define TextEffectFormat_GetTypeInfo(This,itinfo,lcid,pptinfo,retval)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,itinfo,lcid,pptinfo,retval) ) 

#define TextEffectFormat_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgdispid,retval)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgdispid,retval) ) 

#define TextEffectFormat_Invoke(This,dispidMember,riid,lcid,wFlags,pdispparams,pvarResult,pexcepinfo,puArgErr,retval)	\
    ( (This)->lpVtbl -> Invoke(This,dispidMember,riid,lcid,wFlags,pdispparams,pvarResult,pexcepinfo,puArgErr,retval) ) 

#define TextEffectFormat_get_Application(This,retval)	\
    ( (This)->lpVtbl -> get_Application(This,retval) ) 

#define TextEffectFormat_get_Creator(This,retval)	\
    ( (This)->lpVtbl -> get_Creator(This,retval) ) 


#define TextEffectFormat_get_Parent(This,Parent)	\
    ( (This)->lpVtbl -> get_Parent(This,Parent) ) 

#define TextEffectFormat_ToggleVerticalText(This)	\
    ( (This)->lpVtbl -> ToggleVerticalText(This) ) 

#define TextEffectFormat_get_Alignment(This,Alignment)	\
    ( (This)->lpVtbl -> get_Alignment(This,Alignment) ) 

#define TextEffectFormat_put_Alignment(This,Alignment)	\
    ( (This)->lpVtbl -> put_Alignment(This,Alignment) ) 

#define TextEffectFormat_get_FontBold(This,FontBold)	\
    ( (This)->lpVtbl -> get_FontBold(This,FontBold) ) 

#define TextEffectFormat_put_FontBold(This,FontBold)	\
    ( (This)->lpVtbl -> put_FontBold(This,FontBold) ) 

#define TextEffectFormat_get_FontItalic(This,FontItalic)	\
    ( (This)->lpVtbl -> get_FontItalic(This,FontItalic) ) 

#define TextEffectFormat_put_FontItalic(This,FontItalic)	\
    ( (This)->lpVtbl -> put_FontItalic(This,FontItalic) ) 

#define TextEffectFormat_get_FontName(This,FontName)	\
    ( (This)->lpVtbl -> get_FontName(This,FontName) ) 

#define TextEffectFormat_put_FontName(This,FontName)	\
    ( (This)->lpVtbl -> put_FontName(This,FontName) ) 

#define TextEffectFormat_get_FontSize(This,FontSize)	\
    ( (This)->lpVtbl -> get_FontSize(This,FontSize) ) 

#define TextEffectFormat_put_FontSize(This,FontSize)	\
    ( (This)->lpVtbl -> put_FontSize(This,FontSize) ) 

#define TextEffectFormat_get_KernedPairs(This,KernedPairs)	\
    ( (This)->lpVtbl -> get_KernedPairs(This,KernedPairs) ) 

#define TextEffectFormat_put_KernedPairs(This,KernedPairs)	\
    ( (This)->lpVtbl -> put_KernedPairs(This,KernedPairs) ) 

#define TextEffectFormat_get_NormalizedHeight(This,NormalizedHeight)	\
    ( (This)->lpVtbl -> get_NormalizedHeight(This,NormalizedHeight) ) 

#define TextEffectFormat_put_NormalizedHeight(This,NormalizedHeight)	\
    ( (This)->lpVtbl -> put_NormalizedHeight(This,NormalizedHeight) ) 

#define TextEffectFormat_get_PresetShape(This,PresetShape)	\
    ( (This)->lpVtbl -> get_PresetShape(This,PresetShape) ) 

#define TextEffectFormat_put_PresetShape(This,PresetShape)	\
    ( (This)->lpVtbl -> put_PresetShape(This,PresetShape) ) 

#define TextEffectFormat_get_PresetTextEffect(This,Preset)	\
    ( (This)->lpVtbl -> get_PresetTextEffect(This,Preset) ) 

#define TextEffectFormat_put_PresetTextEffect(This,Preset)	\
    ( (This)->lpVtbl -> put_PresetTextEffect(This,Preset) ) 

#define TextEffectFormat_get_RotatedChars(This,RotatedChars)	\
    ( (This)->lpVtbl -> get_RotatedChars(This,RotatedChars) ) 

#define TextEffectFormat_put_RotatedChars(This,RotatedChars)	\
    ( (This)->lpVtbl -> put_RotatedChars(This,RotatedChars) ) 

#define TextEffectFormat_get_Text(This,Text)	\
    ( (This)->lpVtbl -> get_Text(This,Text) ) 

#define TextEffectFormat_put_Text(This,Text)	\
    ( (This)->lpVtbl -> put_Text(This,Text) ) 

#define TextEffectFormat_get_Tracking(This,Tracking)	\
    ( (This)->lpVtbl -> get_Tracking(This,Tracking) ) 

#define TextEffectFormat_put_Tracking(This,Tracking)	\
    ( (This)->lpVtbl -> put_Tracking(This,Tracking) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __TextEffectFormat_INTERFACE_DEFINED__ */


#ifndef __ThreeDFormat_INTERFACE_DEFINED__
#define __ThreeDFormat_INTERFACE_DEFINED__

/* interface ThreeDFormat */
/* [object][oleautomation][nonextensible][dual][helpcontext][uuid] */ 


EXTERN_C const IID IID_ThreeDFormat;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000C0321-0000-0000-C000-000000000046")
    ThreeDFormat : public _IMsoDispObj
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Parent( 
            /* [retval][out] */ IDispatch **Parent) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE IncrementRotationX( 
            /* [in] */ single Increment) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE IncrementRotationY( 
            /* [in] */ single Increment) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE ResetRotation( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE SetThreeDFormat( 
            /* [in] */ MsoPresetThreeDFormat PresetThreeDFormat) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE SetExtrusionDirection( 
            /* [in] */ MsoPresetExtrusionDirection PresetExtrusionDirection) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Depth( 
            /* [retval][out] */ single *Depth) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_Depth( 
            /* [in] */ single Depth) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ExtrusionColor( 
            /* [retval][out] */ ColorFormat **ExtrusionColor) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ExtrusionColorType( 
            /* [retval][out] */ MsoExtrusionColorType *ExtrusionColorType) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_ExtrusionColorType( 
            /* [in] */ MsoExtrusionColorType ExtrusionColorType) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Perspective( 
            /* [retval][out] */ MsoTriState *Perspective) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_Perspective( 
            /* [in] */ MsoTriState Perspective) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_PresetExtrusionDirection( 
            /* [retval][out] */ MsoPresetExtrusionDirection *PresetExtrusionDirection) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_PresetLightingDirection( 
            /* [retval][out] */ MsoPresetLightingDirection *PresetLightingDirection) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_PresetLightingDirection( 
            /* [in] */ MsoPresetLightingDirection PresetLightingDirection) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_PresetLightingSoftness( 
            /* [retval][out] */ MsoPresetLightingSoftness *PresetLightingSoftness) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_PresetLightingSoftness( 
            /* [in] */ MsoPresetLightingSoftness PresetLightingSoftness) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_PresetMaterial( 
            /* [retval][out] */ MsoPresetMaterial *PresetMaterial) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_PresetMaterial( 
            /* [in] */ MsoPresetMaterial PresetMaterial) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_PresetThreeDFormat( 
            /* [retval][out] */ MsoPresetThreeDFormat *PresetThreeDFormat) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_RotationX( 
            /* [retval][out] */ single *RotationX) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_RotationX( 
            /* [in] */ single RotationX) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_RotationY( 
            /* [retval][out] */ single *RotationY) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_RotationY( 
            /* [in] */ single RotationY) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Visible( 
            /* [retval][out] */ MsoTriState *Visible) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_Visible( 
            /* [in] */ MsoTriState Visible) = 0;
        
        virtual /* [id] */ HRESULT STDMETHODCALLTYPE SetPresetCamera( 
            /* [in] */ MsoPresetCamera PresetCamera) = 0;
        
        virtual /* [id] */ HRESULT STDMETHODCALLTYPE IncrementRotationZ( 
            /* [in] */ single Increment) = 0;
        
        virtual /* [id] */ HRESULT STDMETHODCALLTYPE IncrementRotationHorizontal( 
            /* [in] */ single Increment) = 0;
        
        virtual /* [id] */ HRESULT STDMETHODCALLTYPE IncrementRotationVertical( 
            /* [in] */ single Increment) = 0;
        
        virtual /* [propget][id] */ HRESULT STDMETHODCALLTYPE get_PresetLighting( 
            /* [retval][out] */ MsoLightRigType *PresetLightRigType) = 0;
        
        virtual /* [propput][id] */ HRESULT STDMETHODCALLTYPE put_PresetLighting( 
            /* [in] */ MsoLightRigType PresetLightRigType) = 0;
        
        virtual /* [propget][id] */ HRESULT STDMETHODCALLTYPE get_Z( 
            /* [retval][out] */ single *Z) = 0;
        
        virtual /* [propput][id] */ HRESULT STDMETHODCALLTYPE put_Z( 
            /* [in] */ single Z) = 0;
        
        virtual /* [propget][id] */ HRESULT STDMETHODCALLTYPE get_BevelTopType( 
            /* [retval][out] */ MsoBevelType *BevelTopType) = 0;
        
        virtual /* [propput][id] */ HRESULT STDMETHODCALLTYPE put_BevelTopType( 
            /* [in] */ MsoBevelType BevelTopType) = 0;
        
        virtual /* [propget][id] */ HRESULT STDMETHODCALLTYPE get_BevelTopInset( 
            /* [retval][out] */ single *BevelTopInset) = 0;
        
        virtual /* [propput][id] */ HRESULT STDMETHODCALLTYPE put_BevelTopInset( 
            /* [in] */ single BevelTopInset) = 0;
        
        virtual /* [propget][id] */ HRESULT STDMETHODCALLTYPE get_BevelTopDepth( 
            /* [retval][out] */ single *BevelTopDepth) = 0;
        
        virtual /* [propput][id] */ HRESULT STDMETHODCALLTYPE put_BevelTopDepth( 
            /* [in] */ single BevelTopDepth) = 0;
        
        virtual /* [propget][id] */ HRESULT STDMETHODCALLTYPE get_BevelBottomType( 
            /* [retval][out] */ MsoBevelType *BevelBottomType) = 0;
        
        virtual /* [propput][id] */ HRESULT STDMETHODCALLTYPE put_BevelBottomType( 
            /* [in] */ MsoBevelType BevelBottomType) = 0;
        
        virtual /* [propget][id] */ HRESULT STDMETHODCALLTYPE get_BevelBottomInset( 
            /* [retval][out] */ single *BevelBottomInset) = 0;
        
        virtual /* [propput][id] */ HRESULT STDMETHODCALLTYPE put_BevelBottomInset( 
            /* [in] */ single BevelBottomInset) = 0;
        
        virtual /* [propget][id] */ HRESULT STDMETHODCALLTYPE get_BevelBottomDepth( 
            /* [retval][out] */ single *BevelBottomDepth) = 0;
        
        virtual /* [propput][id] */ HRESULT STDMETHODCALLTYPE put_BevelBottomDepth( 
            /* [in] */ single BevelBottomDepth) = 0;
        
        virtual /* [propget][id] */ HRESULT STDMETHODCALLTYPE get_PresetCamera( 
            /* [retval][out] */ MsoPresetCamera *PresetCamera) = 0;
        
        virtual /* [propget][id] */ HRESULT STDMETHODCALLTYPE get_RotationZ( 
            /* [retval][out] */ single *RotationZ) = 0;
        
        virtual /* [propput][id] */ HRESULT STDMETHODCALLTYPE put_RotationZ( 
            /* [in] */ single RotationZ) = 0;
        
        virtual /* [propget][id] */ HRESULT STDMETHODCALLTYPE get_ContourWidth( 
            /* [retval][out] */ single *Width) = 0;
        
        virtual /* [propput][id] */ HRESULT STDMETHODCALLTYPE put_ContourWidth( 
            /* [in] */ single Width) = 0;
        
        virtual /* [propget][id] */ HRESULT STDMETHODCALLTYPE get_ContourColor( 
            /* [retval][out] */ ColorFormat **ContourColor) = 0;
        
        virtual /* [propget][id] */ HRESULT STDMETHODCALLTYPE get_FieldOfView( 
            /* [retval][out] */ single *FOV) = 0;
        
        virtual /* [propput][id] */ HRESULT STDMETHODCALLTYPE put_FieldOfView( 
            /* [in] */ single FOV) = 0;
        
        virtual /* [propget][id] */ HRESULT STDMETHODCALLTYPE get_ProjectText( 
            /* [retval][out] */ MsoTriState *ProjectText) = 0;
        
        virtual /* [propput][id] */ HRESULT STDMETHODCALLTYPE put_ProjectText( 
            /* [in] */ MsoTriState ProjectText) = 0;
        
        virtual /* [propget][id] */ HRESULT STDMETHODCALLTYPE get_LightAngle( 
            /* [retval][out] */ single *LightAngle) = 0;
        
        virtual /* [propput][id] */ HRESULT STDMETHODCALLTYPE put_LightAngle( 
            /* [in] */ single LightAngle) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ThreeDFormatVtbl
    {
        BEGIN_INTERFACE
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ThreeDFormat * This,
            /* [in][idldescattr] */ struct GUID *riid,
            /* [out][idldescattr] */ void **ppvObj,
            /* [retval][out] */ void *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *AddRef )( 
            ThreeDFormat * This,
            /* [retval][out] */ unsigned long *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *Release )( 
            ThreeDFormat * This,
            /* [retval][out] */ unsigned long *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ThreeDFormat * This,
            /* [out][idldescattr] */ unsigned UINT *pctinfo,
            /* [retval][out] */ void *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ThreeDFormat * This,
            /* [in][idldescattr] */ unsigned UINT itinfo,
            /* [in][idldescattr] */ unsigned long lcid,
            /* [out][idldescattr] */ void **pptinfo,
            /* [retval][out] */ void *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ThreeDFormat * This,
            /* [in][idldescattr] */ struct GUID *riid,
            /* [in][idldescattr] */ signed char **rgszNames,
            /* [in][idldescattr] */ unsigned UINT cNames,
            /* [in][idldescattr] */ unsigned long lcid,
            /* [out][idldescattr] */ signed long *rgdispid,
            /* [retval][out] */ void *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ThreeDFormat * This,
            /* [in][idldescattr] */ signed long dispidMember,
            /* [in][idldescattr] */ struct GUID *riid,
            /* [in][idldescattr] */ unsigned long lcid,
            /* [in][idldescattr] */ unsigned short wFlags,
            /* [in][idldescattr] */ struct DISPPARAMS *pdispparams,
            /* [out][idldescattr] */ VARIANT *pvarResult,
            /* [out][idldescattr] */ struct EXCEPINFO *pexcepinfo,
            /* [out][idldescattr] */ unsigned UINT *puArgErr,
            /* [retval][out] */ void *retval);
        
        /* [id][propget][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *get_Application )( 
            ThreeDFormat * This,
            /* [retval][out] */ IDispatch **retval);
        
        /* [id][propget][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *get_Creator )( 
            ThreeDFormat * This,
            /* [retval][out] */ signed long *retval);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Parent )( 
            ThreeDFormat * This,
            /* [retval][out] */ IDispatch **Parent);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *IncrementRotationX )( 
            ThreeDFormat * This,
            /* [in] */ single Increment);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *IncrementRotationY )( 
            ThreeDFormat * This,
            /* [in] */ single Increment);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *ResetRotation )( 
            ThreeDFormat * This);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *SetThreeDFormat )( 
            ThreeDFormat * This,
            /* [in] */ MsoPresetThreeDFormat PresetThreeDFormat);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *SetExtrusionDirection )( 
            ThreeDFormat * This,
            /* [in] */ MsoPresetExtrusionDirection PresetExtrusionDirection);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Depth )( 
            ThreeDFormat * This,
            /* [retval][out] */ single *Depth);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Depth )( 
            ThreeDFormat * This,
            /* [in] */ single Depth);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ExtrusionColor )( 
            ThreeDFormat * This,
            /* [retval][out] */ ColorFormat **ExtrusionColor);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ExtrusionColorType )( 
            ThreeDFormat * This,
            /* [retval][out] */ MsoExtrusionColorType *ExtrusionColorType);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_ExtrusionColorType )( 
            ThreeDFormat * This,
            /* [in] */ MsoExtrusionColorType ExtrusionColorType);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Perspective )( 
            ThreeDFormat * This,
            /* [retval][out] */ MsoTriState *Perspective);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Perspective )( 
            ThreeDFormat * This,
            /* [in] */ MsoTriState Perspective);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_PresetExtrusionDirection )( 
            ThreeDFormat * This,
            /* [retval][out] */ MsoPresetExtrusionDirection *PresetExtrusionDirection);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_PresetLightingDirection )( 
            ThreeDFormat * This,
            /* [retval][out] */ MsoPresetLightingDirection *PresetLightingDirection);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_PresetLightingDirection )( 
            ThreeDFormat * This,
            /* [in] */ MsoPresetLightingDirection PresetLightingDirection);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_PresetLightingSoftness )( 
            ThreeDFormat * This,
            /* [retval][out] */ MsoPresetLightingSoftness *PresetLightingSoftness);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_PresetLightingSoftness )( 
            ThreeDFormat * This,
            /* [in] */ MsoPresetLightingSoftness PresetLightingSoftness);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_PresetMaterial )( 
            ThreeDFormat * This,
            /* [retval][out] */ MsoPresetMaterial *PresetMaterial);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_PresetMaterial )( 
            ThreeDFormat * This,
            /* [in] */ MsoPresetMaterial PresetMaterial);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_PresetThreeDFormat )( 
            ThreeDFormat * This,
            /* [retval][out] */ MsoPresetThreeDFormat *PresetThreeDFormat);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_RotationX )( 
            ThreeDFormat * This,
            /* [retval][out] */ single *RotationX);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_RotationX )( 
            ThreeDFormat * This,
            /* [in] */ single RotationX);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_RotationY )( 
            ThreeDFormat * This,
            /* [retval][out] */ single *RotationY);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_RotationY )( 
            ThreeDFormat * This,
            /* [in] */ single RotationY);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Visible )( 
            ThreeDFormat * This,
            /* [retval][out] */ MsoTriState *Visible);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Visible )( 
            ThreeDFormat * This,
            /* [in] */ MsoTriState Visible);
        
        /* [id] */ HRESULT ( STDMETHODCALLTYPE *SetPresetCamera )( 
            ThreeDFormat * This,
            /* [in] */ MsoPresetCamera PresetCamera);
        
        /* [id] */ HRESULT ( STDMETHODCALLTYPE *IncrementRotationZ )( 
            ThreeDFormat * This,
            /* [in] */ single Increment);
        
        /* [id] */ HRESULT ( STDMETHODCALLTYPE *IncrementRotationHorizontal )( 
            ThreeDFormat * This,
            /* [in] */ single Increment);
        
        /* [id] */ HRESULT ( STDMETHODCALLTYPE *IncrementRotationVertical )( 
            ThreeDFormat * This,
            /* [in] */ single Increment);
        
        /* [propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_PresetLighting )( 
            ThreeDFormat * This,
            /* [retval][out] */ MsoLightRigType *PresetLightRigType);
        
        /* [propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_PresetLighting )( 
            ThreeDFormat * This,
            /* [in] */ MsoLightRigType PresetLightRigType);
        
        /* [propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Z )( 
            ThreeDFormat * This,
            /* [retval][out] */ single *Z);
        
        /* [propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Z )( 
            ThreeDFormat * This,
            /* [in] */ single Z);
        
        /* [propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_BevelTopType )( 
            ThreeDFormat * This,
            /* [retval][out] */ MsoBevelType *BevelTopType);
        
        /* [propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_BevelTopType )( 
            ThreeDFormat * This,
            /* [in] */ MsoBevelType BevelTopType);
        
        /* [propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_BevelTopInset )( 
            ThreeDFormat * This,
            /* [retval][out] */ single *BevelTopInset);
        
        /* [propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_BevelTopInset )( 
            ThreeDFormat * This,
            /* [in] */ single BevelTopInset);
        
        /* [propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_BevelTopDepth )( 
            ThreeDFormat * This,
            /* [retval][out] */ single *BevelTopDepth);
        
        /* [propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_BevelTopDepth )( 
            ThreeDFormat * This,
            /* [in] */ single BevelTopDepth);
        
        /* [propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_BevelBottomType )( 
            ThreeDFormat * This,
            /* [retval][out] */ MsoBevelType *BevelBottomType);
        
        /* [propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_BevelBottomType )( 
            ThreeDFormat * This,
            /* [in] */ MsoBevelType BevelBottomType);
        
        /* [propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_BevelBottomInset )( 
            ThreeDFormat * This,
            /* [retval][out] */ single *BevelBottomInset);
        
        /* [propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_BevelBottomInset )( 
            ThreeDFormat * This,
            /* [in] */ single BevelBottomInset);
        
        /* [propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_BevelBottomDepth )( 
            ThreeDFormat * This,
            /* [retval][out] */ single *BevelBottomDepth);
        
        /* [propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_BevelBottomDepth )( 
            ThreeDFormat * This,
            /* [in] */ single BevelBottomDepth);
        
        /* [propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_PresetCamera )( 
            ThreeDFormat * This,
            /* [retval][out] */ MsoPresetCamera *PresetCamera);
        
        /* [propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_RotationZ )( 
            ThreeDFormat * This,
            /* [retval][out] */ single *RotationZ);
        
        /* [propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_RotationZ )( 
            ThreeDFormat * This,
            /* [in] */ single RotationZ);
        
        /* [propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ContourWidth )( 
            ThreeDFormat * This,
            /* [retval][out] */ single *Width);
        
        /* [propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_ContourWidth )( 
            ThreeDFormat * This,
            /* [in] */ single Width);
        
        /* [propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ContourColor )( 
            ThreeDFormat * This,
            /* [retval][out] */ ColorFormat **ContourColor);
        
        /* [propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_FieldOfView )( 
            ThreeDFormat * This,
            /* [retval][out] */ single *FOV);
        
        /* [propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_FieldOfView )( 
            ThreeDFormat * This,
            /* [in] */ single FOV);
        
        /* [propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ProjectText )( 
            ThreeDFormat * This,
            /* [retval][out] */ MsoTriState *ProjectText);
        
        /* [propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_ProjectText )( 
            ThreeDFormat * This,
            /* [in] */ MsoTriState ProjectText);
        
        /* [propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_LightAngle )( 
            ThreeDFormat * This,
            /* [retval][out] */ single *LightAngle);
        
        /* [propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_LightAngle )( 
            ThreeDFormat * This,
            /* [in] */ single LightAngle);
        
        END_INTERFACE
    } ThreeDFormatVtbl;

    interface ThreeDFormat
    {
        CONST_VTBL struct ThreeDFormatVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ThreeDFormat_QueryInterface(This,riid,ppvObj,retval)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObj,retval) ) 

#define ThreeDFormat_AddRef(This,retval)	\
    ( (This)->lpVtbl -> AddRef(This,retval) ) 

#define ThreeDFormat_Release(This,retval)	\
    ( (This)->lpVtbl -> Release(This,retval) ) 

#define ThreeDFormat_GetTypeInfoCount(This,pctinfo,retval)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo,retval) ) 

#define ThreeDFormat_GetTypeInfo(This,itinfo,lcid,pptinfo,retval)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,itinfo,lcid,pptinfo,retval) ) 

#define ThreeDFormat_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgdispid,retval)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgdispid,retval) ) 

#define ThreeDFormat_Invoke(This,dispidMember,riid,lcid,wFlags,pdispparams,pvarResult,pexcepinfo,puArgErr,retval)	\
    ( (This)->lpVtbl -> Invoke(This,dispidMember,riid,lcid,wFlags,pdispparams,pvarResult,pexcepinfo,puArgErr,retval) ) 

#define ThreeDFormat_get_Application(This,retval)	\
    ( (This)->lpVtbl -> get_Application(This,retval) ) 

#define ThreeDFormat_get_Creator(This,retval)	\
    ( (This)->lpVtbl -> get_Creator(This,retval) ) 


#define ThreeDFormat_get_Parent(This,Parent)	\
    ( (This)->lpVtbl -> get_Parent(This,Parent) ) 

#define ThreeDFormat_IncrementRotationX(This,Increment)	\
    ( (This)->lpVtbl -> IncrementRotationX(This,Increment) ) 

#define ThreeDFormat_IncrementRotationY(This,Increment)	\
    ( (This)->lpVtbl -> IncrementRotationY(This,Increment) ) 

#define ThreeDFormat_ResetRotation(This)	\
    ( (This)->lpVtbl -> ResetRotation(This) ) 

#define ThreeDFormat_SetThreeDFormat(This,PresetThreeDFormat)	\
    ( (This)->lpVtbl -> SetThreeDFormat(This,PresetThreeDFormat) ) 

#define ThreeDFormat_SetExtrusionDirection(This,PresetExtrusionDirection)	\
    ( (This)->lpVtbl -> SetExtrusionDirection(This,PresetExtrusionDirection) ) 

#define ThreeDFormat_get_Depth(This,Depth)	\
    ( (This)->lpVtbl -> get_Depth(This,Depth) ) 

#define ThreeDFormat_put_Depth(This,Depth)	\
    ( (This)->lpVtbl -> put_Depth(This,Depth) ) 

#define ThreeDFormat_get_ExtrusionColor(This,ExtrusionColor)	\
    ( (This)->lpVtbl -> get_ExtrusionColor(This,ExtrusionColor) ) 

#define ThreeDFormat_get_ExtrusionColorType(This,ExtrusionColorType)	\
    ( (This)->lpVtbl -> get_ExtrusionColorType(This,ExtrusionColorType) ) 

#define ThreeDFormat_put_ExtrusionColorType(This,ExtrusionColorType)	\
    ( (This)->lpVtbl -> put_ExtrusionColorType(This,ExtrusionColorType) ) 

#define ThreeDFormat_get_Perspective(This,Perspective)	\
    ( (This)->lpVtbl -> get_Perspective(This,Perspective) ) 

#define ThreeDFormat_put_Perspective(This,Perspective)	\
    ( (This)->lpVtbl -> put_Perspective(This,Perspective) ) 

#define ThreeDFormat_get_PresetExtrusionDirection(This,PresetExtrusionDirection)	\
    ( (This)->lpVtbl -> get_PresetExtrusionDirection(This,PresetExtrusionDirection) ) 

#define ThreeDFormat_get_PresetLightingDirection(This,PresetLightingDirection)	\
    ( (This)->lpVtbl -> get_PresetLightingDirection(This,PresetLightingDirection) ) 

#define ThreeDFormat_put_PresetLightingDirection(This,PresetLightingDirection)	\
    ( (This)->lpVtbl -> put_PresetLightingDirection(This,PresetLightingDirection) ) 

#define ThreeDFormat_get_PresetLightingSoftness(This,PresetLightingSoftness)	\
    ( (This)->lpVtbl -> get_PresetLightingSoftness(This,PresetLightingSoftness) ) 

#define ThreeDFormat_put_PresetLightingSoftness(This,PresetLightingSoftness)	\
    ( (This)->lpVtbl -> put_PresetLightingSoftness(This,PresetLightingSoftness) ) 

#define ThreeDFormat_get_PresetMaterial(This,PresetMaterial)	\
    ( (This)->lpVtbl -> get_PresetMaterial(This,PresetMaterial) ) 

#define ThreeDFormat_put_PresetMaterial(This,PresetMaterial)	\
    ( (This)->lpVtbl -> put_PresetMaterial(This,PresetMaterial) ) 

#define ThreeDFormat_get_PresetThreeDFormat(This,PresetThreeDFormat)	\
    ( (This)->lpVtbl -> get_PresetThreeDFormat(This,PresetThreeDFormat) ) 

#define ThreeDFormat_get_RotationX(This,RotationX)	\
    ( (This)->lpVtbl -> get_RotationX(This,RotationX) ) 

#define ThreeDFormat_put_RotationX(This,RotationX)	\
    ( (This)->lpVtbl -> put_RotationX(This,RotationX) ) 

#define ThreeDFormat_get_RotationY(This,RotationY)	\
    ( (This)->lpVtbl -> get_RotationY(This,RotationY) ) 

#define ThreeDFormat_put_RotationY(This,RotationY)	\
    ( (This)->lpVtbl -> put_RotationY(This,RotationY) ) 

#define ThreeDFormat_get_Visible(This,Visible)	\
    ( (This)->lpVtbl -> get_Visible(This,Visible) ) 

#define ThreeDFormat_put_Visible(This,Visible)	\
    ( (This)->lpVtbl -> put_Visible(This,Visible) ) 

#define ThreeDFormat_SetPresetCamera(This,PresetCamera)	\
    ( (This)->lpVtbl -> SetPresetCamera(This,PresetCamera) ) 

#define ThreeDFormat_IncrementRotationZ(This,Increment)	\
    ( (This)->lpVtbl -> IncrementRotationZ(This,Increment) ) 

#define ThreeDFormat_IncrementRotationHorizontal(This,Increment)	\
    ( (This)->lpVtbl -> IncrementRotationHorizontal(This,Increment) ) 

#define ThreeDFormat_IncrementRotationVertical(This,Increment)	\
    ( (This)->lpVtbl -> IncrementRotationVertical(This,Increment) ) 

#define ThreeDFormat_get_PresetLighting(This,PresetLightRigType)	\
    ( (This)->lpVtbl -> get_PresetLighting(This,PresetLightRigType) ) 

#define ThreeDFormat_put_PresetLighting(This,PresetLightRigType)	\
    ( (This)->lpVtbl -> put_PresetLighting(This,PresetLightRigType) ) 

#define ThreeDFormat_get_Z(This,Z)	\
    ( (This)->lpVtbl -> get_Z(This,Z) ) 

#define ThreeDFormat_put_Z(This,Z)	\
    ( (This)->lpVtbl -> put_Z(This,Z) ) 

#define ThreeDFormat_get_BevelTopType(This,BevelTopType)	\
    ( (This)->lpVtbl -> get_BevelTopType(This,BevelTopType) ) 

#define ThreeDFormat_put_BevelTopType(This,BevelTopType)	\
    ( (This)->lpVtbl -> put_BevelTopType(This,BevelTopType) ) 

#define ThreeDFormat_get_BevelTopInset(This,BevelTopInset)	\
    ( (This)->lpVtbl -> get_BevelTopInset(This,BevelTopInset) ) 

#define ThreeDFormat_put_BevelTopInset(This,BevelTopInset)	\
    ( (This)->lpVtbl -> put_BevelTopInset(This,BevelTopInset) ) 

#define ThreeDFormat_get_BevelTopDepth(This,BevelTopDepth)	\
    ( (This)->lpVtbl -> get_BevelTopDepth(This,BevelTopDepth) ) 

#define ThreeDFormat_put_BevelTopDepth(This,BevelTopDepth)	\
    ( (This)->lpVtbl -> put_BevelTopDepth(This,BevelTopDepth) ) 

#define ThreeDFormat_get_BevelBottomType(This,BevelBottomType)	\
    ( (This)->lpVtbl -> get_BevelBottomType(This,BevelBottomType) ) 

#define ThreeDFormat_put_BevelBottomType(This,BevelBottomType)	\
    ( (This)->lpVtbl -> put_BevelBottomType(This,BevelBottomType) ) 

#define ThreeDFormat_get_BevelBottomInset(This,BevelBottomInset)	\
    ( (This)->lpVtbl -> get_BevelBottomInset(This,BevelBottomInset) ) 

#define ThreeDFormat_put_BevelBottomInset(This,BevelBottomInset)	\
    ( (This)->lpVtbl -> put_BevelBottomInset(This,BevelBottomInset) ) 

#define ThreeDFormat_get_BevelBottomDepth(This,BevelBottomDepth)	\
    ( (This)->lpVtbl -> get_BevelBottomDepth(This,BevelBottomDepth) ) 

#define ThreeDFormat_put_BevelBottomDepth(This,BevelBottomDepth)	\
    ( (This)->lpVtbl -> put_BevelBottomDepth(This,BevelBottomDepth) ) 

#define ThreeDFormat_get_PresetCamera(This,PresetCamera)	\
    ( (This)->lpVtbl -> get_PresetCamera(This,PresetCamera) ) 

#define ThreeDFormat_get_RotationZ(This,RotationZ)	\
    ( (This)->lpVtbl -> get_RotationZ(This,RotationZ) ) 

#define ThreeDFormat_put_RotationZ(This,RotationZ)	\
    ( (This)->lpVtbl -> put_RotationZ(This,RotationZ) ) 

#define ThreeDFormat_get_ContourWidth(This,Width)	\
    ( (This)->lpVtbl -> get_ContourWidth(This,Width) ) 

#define ThreeDFormat_put_ContourWidth(This,Width)	\
    ( (This)->lpVtbl -> put_ContourWidth(This,Width) ) 

#define ThreeDFormat_get_ContourColor(This,ContourColor)	\
    ( (This)->lpVtbl -> get_ContourColor(This,ContourColor) ) 

#define ThreeDFormat_get_FieldOfView(This,FOV)	\
    ( (This)->lpVtbl -> get_FieldOfView(This,FOV) ) 

#define ThreeDFormat_put_FieldOfView(This,FOV)	\
    ( (This)->lpVtbl -> put_FieldOfView(This,FOV) ) 

#define ThreeDFormat_get_ProjectText(This,ProjectText)	\
    ( (This)->lpVtbl -> get_ProjectText(This,ProjectText) ) 

#define ThreeDFormat_put_ProjectText(This,ProjectText)	\
    ( (This)->lpVtbl -> put_ProjectText(This,ProjectText) ) 

#define ThreeDFormat_get_LightAngle(This,LightAngle)	\
    ( (This)->lpVtbl -> get_LightAngle(This,LightAngle) ) 

#define ThreeDFormat_put_LightAngle(This,LightAngle)	\
    ( (This)->lpVtbl -> put_LightAngle(This,LightAngle) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ThreeDFormat_INTERFACE_DEFINED__ */


#ifndef __FillFormat_INTERFACE_DEFINED__
#define __FillFormat_INTERFACE_DEFINED__

/* interface FillFormat */
/* [object][oleautomation][nonextensible][dual][helpcontext][uuid] */ 


EXTERN_C const IID IID_FillFormat;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000C0314-0000-0000-C000-000000000046")
    FillFormat : public _IMsoDispObj
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Parent( 
            /* [retval][out] */ IDispatch **Parent) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE Background( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE OneColorGradient( 
            /* [in] */ MsoGradientStyle Style,
            /* [in] */ int Variant,
            /* [in] */ single Degree) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Patterned( 
            /* [in] */ MsoPatternType Pattern) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE PresetGradient( 
            /* [in] */ MsoGradientStyle Style,
            /* [in] */ int Variant,
            /* [in] */ MsoPresetGradientType PresetGradientType) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE PresetTextured( 
            /* [in] */ MsoPresetTexture PresetTexture) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Solid( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE TwoColorGradient( 
            /* [in] */ MsoGradientStyle Style,
            /* [in] */ int Variant) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE UserPicture( 
            /* [in] */ BSTR PictureFile) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE UserTextured( 
            /* [in] */ BSTR TextureFile) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_BackColor( 
            /* [retval][out] */ ColorFormat **BackColor) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_BackColor( 
            /* [in] */ ColorFormat *BackColor) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ForeColor( 
            /* [retval][out] */ ColorFormat **ForeColor) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_ForeColor( 
            /* [in] */ ColorFormat *ForeColor) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_GradientColorType( 
            /* [retval][out] */ MsoGradientColorType *GradientColorType) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_GradientDegree( 
            /* [retval][out] */ single *GradientDegree) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_GradientStyle( 
            /* [retval][out] */ MsoGradientStyle *GradientStyle) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_GradientVariant( 
            /* [retval][out] */ int *GradientVariant) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Pattern( 
            /* [retval][out] */ MsoPatternType *Pattern) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_PresetGradientType( 
            /* [retval][out] */ MsoPresetGradientType *PresetGradientType) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_PresetTexture( 
            /* [retval][out] */ MsoPresetTexture *PresetTexture) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_TextureName( 
            /* [retval][out] */ BSTR *TextureName) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_TextureType( 
            /* [retval][out] */ MsoTextureType *TextureType) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Transparency( 
            /* [retval][out] */ single *Transparency) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_Transparency( 
            /* [in] */ single Transparency) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Type( 
            /* [retval][out] */ MsoFillType *Type) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Visible( 
            /* [retval][out] */ MsoTriState *Visible) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_Visible( 
            /* [in] */ MsoTriState Visible) = 0;
        
        virtual /* [propget][id] */ HRESULT STDMETHODCALLTYPE get_GradientStops( 
            /* [retval][out] */ /* external definition not present */ GradientStops **GradientStops) = 0;
        
        virtual /* [propget][id] */ HRESULT STDMETHODCALLTYPE get_TextureOffsetX( 
            /* [retval][out] */ single *TextureOffsetX) = 0;
        
        virtual /* [propput][id] */ HRESULT STDMETHODCALLTYPE put_TextureOffsetX( 
            /* [in] */ single TextureOffsetX) = 0;
        
        virtual /* [propget][id] */ HRESULT STDMETHODCALLTYPE get_TextureOffsetY( 
            /* [retval][out] */ single *TextureOffsetY) = 0;
        
        virtual /* [propput][id] */ HRESULT STDMETHODCALLTYPE put_TextureOffsetY( 
            /* [in] */ single TextureOffsetY) = 0;
        
        virtual /* [propget][id] */ HRESULT STDMETHODCALLTYPE get_TextureAlignment( 
            /* [retval][out] */ MsoTextureAlignment *TextureAlignment) = 0;
        
        virtual /* [propput][id] */ HRESULT STDMETHODCALLTYPE put_TextureAlignment( 
            /* [in] */ MsoTextureAlignment TextureAlignment) = 0;
        
        virtual /* [propget][id] */ HRESULT STDMETHODCALLTYPE get_TextureHorizontalScale( 
            /* [retval][out] */ single *HorizontalScale) = 0;
        
        virtual /* [propput][id] */ HRESULT STDMETHODCALLTYPE put_TextureHorizontalScale( 
            /* [in] */ single HorizontalScale) = 0;
        
        virtual /* [propget][id] */ HRESULT STDMETHODCALLTYPE get_TextureVerticalScale( 
            /* [retval][out] */ single *VerticalScale) = 0;
        
        virtual /* [propput][id] */ HRESULT STDMETHODCALLTYPE put_TextureVerticalScale( 
            /* [in] */ single VerticalScale) = 0;
        
        virtual /* [propget][id] */ HRESULT STDMETHODCALLTYPE get_TextureTile( 
            /* [retval][out] */ MsoTriState *TextureTile) = 0;
        
        virtual /* [propput][id] */ HRESULT STDMETHODCALLTYPE put_TextureTile( 
            /* [in] */ MsoTriState TextureTile) = 0;
        
        virtual /* [propget][id] */ HRESULT STDMETHODCALLTYPE get_RotateWithObject( 
            /* [retval][out] */ MsoTriState *RotateWithObject) = 0;
        
        virtual /* [propput][id] */ HRESULT STDMETHODCALLTYPE put_RotateWithObject( 
            /* [in] */ MsoTriState RotateWithObject) = 0;
        
        virtual /* [propget][id] */ HRESULT STDMETHODCALLTYPE get_PictureEffects( 
            /* [retval][out] */ /* external definition not present */ PictureEffects **PictureEffects) = 0;
        
        virtual /* [propget][id] */ HRESULT STDMETHODCALLTYPE get_GradientAngle( 
            /* [retval][out] */ single *GradientAngle) = 0;
        
        virtual /* [propput][id] */ HRESULT STDMETHODCALLTYPE put_GradientAngle( 
            /* [in] */ single GradientAngle) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct FillFormatVtbl
    {
        BEGIN_INTERFACE
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            FillFormat * This,
            /* [in][idldescattr] */ struct GUID *riid,
            /* [out][idldescattr] */ void **ppvObj,
            /* [retval][out] */ void *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *AddRef )( 
            FillFormat * This,
            /* [retval][out] */ unsigned long *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *Release )( 
            FillFormat * This,
            /* [retval][out] */ unsigned long *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            FillFormat * This,
            /* [out][idldescattr] */ unsigned UINT *pctinfo,
            /* [retval][out] */ void *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            FillFormat * This,
            /* [in][idldescattr] */ unsigned UINT itinfo,
            /* [in][idldescattr] */ unsigned long lcid,
            /* [out][idldescattr] */ void **pptinfo,
            /* [retval][out] */ void *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            FillFormat * This,
            /* [in][idldescattr] */ struct GUID *riid,
            /* [in][idldescattr] */ signed char **rgszNames,
            /* [in][idldescattr] */ unsigned UINT cNames,
            /* [in][idldescattr] */ unsigned long lcid,
            /* [out][idldescattr] */ signed long *rgdispid,
            /* [retval][out] */ void *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            FillFormat * This,
            /* [in][idldescattr] */ signed long dispidMember,
            /* [in][idldescattr] */ struct GUID *riid,
            /* [in][idldescattr] */ unsigned long lcid,
            /* [in][idldescattr] */ unsigned short wFlags,
            /* [in][idldescattr] */ struct DISPPARAMS *pdispparams,
            /* [out][idldescattr] */ VARIANT *pvarResult,
            /* [out][idldescattr] */ struct EXCEPINFO *pexcepinfo,
            /* [out][idldescattr] */ unsigned UINT *puArgErr,
            /* [retval][out] */ void *retval);
        
        /* [id][propget][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *get_Application )( 
            FillFormat * This,
            /* [retval][out] */ IDispatch **retval);
        
        /* [id][propget][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *get_Creator )( 
            FillFormat * This,
            /* [retval][out] */ signed long *retval);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Parent )( 
            FillFormat * This,
            /* [retval][out] */ IDispatch **Parent);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *Background )( 
            FillFormat * This);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *OneColorGradient )( 
            FillFormat * This,
            /* [in] */ MsoGradientStyle Style,
            /* [in] */ int Variant,
            /* [in] */ single Degree);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Patterned )( 
            FillFormat * This,
            /* [in] */ MsoPatternType Pattern);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *PresetGradient )( 
            FillFormat * This,
            /* [in] */ MsoGradientStyle Style,
            /* [in] */ int Variant,
            /* [in] */ MsoPresetGradientType PresetGradientType);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *PresetTextured )( 
            FillFormat * This,
            /* [in] */ MsoPresetTexture PresetTexture);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Solid )( 
            FillFormat * This);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *TwoColorGradient )( 
            FillFormat * This,
            /* [in] */ MsoGradientStyle Style,
            /* [in] */ int Variant);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *UserPicture )( 
            FillFormat * This,
            /* [in] */ BSTR PictureFile);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *UserTextured )( 
            FillFormat * This,
            /* [in] */ BSTR TextureFile);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_BackColor )( 
            FillFormat * This,
            /* [retval][out] */ ColorFormat **BackColor);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_BackColor )( 
            FillFormat * This,
            /* [in] */ ColorFormat *BackColor);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ForeColor )( 
            FillFormat * This,
            /* [retval][out] */ ColorFormat **ForeColor);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_ForeColor )( 
            FillFormat * This,
            /* [in] */ ColorFormat *ForeColor);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_GradientColorType )( 
            FillFormat * This,
            /* [retval][out] */ MsoGradientColorType *GradientColorType);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_GradientDegree )( 
            FillFormat * This,
            /* [retval][out] */ single *GradientDegree);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_GradientStyle )( 
            FillFormat * This,
            /* [retval][out] */ MsoGradientStyle *GradientStyle);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_GradientVariant )( 
            FillFormat * This,
            /* [retval][out] */ int *GradientVariant);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Pattern )( 
            FillFormat * This,
            /* [retval][out] */ MsoPatternType *Pattern);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_PresetGradientType )( 
            FillFormat * This,
            /* [retval][out] */ MsoPresetGradientType *PresetGradientType);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_PresetTexture )( 
            FillFormat * This,
            /* [retval][out] */ MsoPresetTexture *PresetTexture);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_TextureName )( 
            FillFormat * This,
            /* [retval][out] */ BSTR *TextureName);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_TextureType )( 
            FillFormat * This,
            /* [retval][out] */ MsoTextureType *TextureType);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Transparency )( 
            FillFormat * This,
            /* [retval][out] */ single *Transparency);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Transparency )( 
            FillFormat * This,
            /* [in] */ single Transparency);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Type )( 
            FillFormat * This,
            /* [retval][out] */ MsoFillType *Type);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Visible )( 
            FillFormat * This,
            /* [retval][out] */ MsoTriState *Visible);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Visible )( 
            FillFormat * This,
            /* [in] */ MsoTriState Visible);
        
        /* [propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_GradientStops )( 
            FillFormat * This,
            /* [retval][out] */ /* external definition not present */ GradientStops **GradientStops);
        
        /* [propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_TextureOffsetX )( 
            FillFormat * This,
            /* [retval][out] */ single *TextureOffsetX);
        
        /* [propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_TextureOffsetX )( 
            FillFormat * This,
            /* [in] */ single TextureOffsetX);
        
        /* [propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_TextureOffsetY )( 
            FillFormat * This,
            /* [retval][out] */ single *TextureOffsetY);
        
        /* [propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_TextureOffsetY )( 
            FillFormat * This,
            /* [in] */ single TextureOffsetY);
        
        /* [propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_TextureAlignment )( 
            FillFormat * This,
            /* [retval][out] */ MsoTextureAlignment *TextureAlignment);
        
        /* [propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_TextureAlignment )( 
            FillFormat * This,
            /* [in] */ MsoTextureAlignment TextureAlignment);
        
        /* [propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_TextureHorizontalScale )( 
            FillFormat * This,
            /* [retval][out] */ single *HorizontalScale);
        
        /* [propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_TextureHorizontalScale )( 
            FillFormat * This,
            /* [in] */ single HorizontalScale);
        
        /* [propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_TextureVerticalScale )( 
            FillFormat * This,
            /* [retval][out] */ single *VerticalScale);
        
        /* [propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_TextureVerticalScale )( 
            FillFormat * This,
            /* [in] */ single VerticalScale);
        
        /* [propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_TextureTile )( 
            FillFormat * This,
            /* [retval][out] */ MsoTriState *TextureTile);
        
        /* [propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_TextureTile )( 
            FillFormat * This,
            /* [in] */ MsoTriState TextureTile);
        
        /* [propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_RotateWithObject )( 
            FillFormat * This,
            /* [retval][out] */ MsoTriState *RotateWithObject);
        
        /* [propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_RotateWithObject )( 
            FillFormat * This,
            /* [in] */ MsoTriState RotateWithObject);
        
        /* [propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_PictureEffects )( 
            FillFormat * This,
            /* [retval][out] */ /* external definition not present */ PictureEffects **PictureEffects);
        
        /* [propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_GradientAngle )( 
            FillFormat * This,
            /* [retval][out] */ single *GradientAngle);
        
        /* [propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_GradientAngle )( 
            FillFormat * This,
            /* [in] */ single GradientAngle);
        
        END_INTERFACE
    } FillFormatVtbl;

    interface FillFormat
    {
        CONST_VTBL struct FillFormatVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define FillFormat_QueryInterface(This,riid,ppvObj,retval)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObj,retval) ) 

#define FillFormat_AddRef(This,retval)	\
    ( (This)->lpVtbl -> AddRef(This,retval) ) 

#define FillFormat_Release(This,retval)	\
    ( (This)->lpVtbl -> Release(This,retval) ) 

#define FillFormat_GetTypeInfoCount(This,pctinfo,retval)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo,retval) ) 

#define FillFormat_GetTypeInfo(This,itinfo,lcid,pptinfo,retval)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,itinfo,lcid,pptinfo,retval) ) 

#define FillFormat_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgdispid,retval)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgdispid,retval) ) 

#define FillFormat_Invoke(This,dispidMember,riid,lcid,wFlags,pdispparams,pvarResult,pexcepinfo,puArgErr,retval)	\
    ( (This)->lpVtbl -> Invoke(This,dispidMember,riid,lcid,wFlags,pdispparams,pvarResult,pexcepinfo,puArgErr,retval) ) 

#define FillFormat_get_Application(This,retval)	\
    ( (This)->lpVtbl -> get_Application(This,retval) ) 

#define FillFormat_get_Creator(This,retval)	\
    ( (This)->lpVtbl -> get_Creator(This,retval) ) 


#define FillFormat_get_Parent(This,Parent)	\
    ( (This)->lpVtbl -> get_Parent(This,Parent) ) 

#define FillFormat_Background(This)	\
    ( (This)->lpVtbl -> Background(This) ) 

#define FillFormat_OneColorGradient(This,Style,Variant,Degree)	\
    ( (This)->lpVtbl -> OneColorGradient(This,Style,Variant,Degree) ) 

#define FillFormat_Patterned(This,Pattern)	\
    ( (This)->lpVtbl -> Patterned(This,Pattern) ) 

#define FillFormat_PresetGradient(This,Style,Variant,PresetGradientType)	\
    ( (This)->lpVtbl -> PresetGradient(This,Style,Variant,PresetGradientType) ) 

#define FillFormat_PresetTextured(This,PresetTexture)	\
    ( (This)->lpVtbl -> PresetTextured(This,PresetTexture) ) 

#define FillFormat_Solid(This)	\
    ( (This)->lpVtbl -> Solid(This) ) 

#define FillFormat_TwoColorGradient(This,Style,Variant)	\
    ( (This)->lpVtbl -> TwoColorGradient(This,Style,Variant) ) 

#define FillFormat_UserPicture(This,PictureFile)	\
    ( (This)->lpVtbl -> UserPicture(This,PictureFile) ) 

#define FillFormat_UserTextured(This,TextureFile)	\
    ( (This)->lpVtbl -> UserTextured(This,TextureFile) ) 

#define FillFormat_get_BackColor(This,BackColor)	\
    ( (This)->lpVtbl -> get_BackColor(This,BackColor) ) 

#define FillFormat_put_BackColor(This,BackColor)	\
    ( (This)->lpVtbl -> put_BackColor(This,BackColor) ) 

#define FillFormat_get_ForeColor(This,ForeColor)	\
    ( (This)->lpVtbl -> get_ForeColor(This,ForeColor) ) 

#define FillFormat_put_ForeColor(This,ForeColor)	\
    ( (This)->lpVtbl -> put_ForeColor(This,ForeColor) ) 

#define FillFormat_get_GradientColorType(This,GradientColorType)	\
    ( (This)->lpVtbl -> get_GradientColorType(This,GradientColorType) ) 

#define FillFormat_get_GradientDegree(This,GradientDegree)	\
    ( (This)->lpVtbl -> get_GradientDegree(This,GradientDegree) ) 

#define FillFormat_get_GradientStyle(This,GradientStyle)	\
    ( (This)->lpVtbl -> get_GradientStyle(This,GradientStyle) ) 

#define FillFormat_get_GradientVariant(This,GradientVariant)	\
    ( (This)->lpVtbl -> get_GradientVariant(This,GradientVariant) ) 

#define FillFormat_get_Pattern(This,Pattern)	\
    ( (This)->lpVtbl -> get_Pattern(This,Pattern) ) 

#define FillFormat_get_PresetGradientType(This,PresetGradientType)	\
    ( (This)->lpVtbl -> get_PresetGradientType(This,PresetGradientType) ) 

#define FillFormat_get_PresetTexture(This,PresetTexture)	\
    ( (This)->lpVtbl -> get_PresetTexture(This,PresetTexture) ) 

#define FillFormat_get_TextureName(This,TextureName)	\
    ( (This)->lpVtbl -> get_TextureName(This,TextureName) ) 

#define FillFormat_get_TextureType(This,TextureType)	\
    ( (This)->lpVtbl -> get_TextureType(This,TextureType) ) 

#define FillFormat_get_Transparency(This,Transparency)	\
    ( (This)->lpVtbl -> get_Transparency(This,Transparency) ) 

#define FillFormat_put_Transparency(This,Transparency)	\
    ( (This)->lpVtbl -> put_Transparency(This,Transparency) ) 

#define FillFormat_get_Type(This,Type)	\
    ( (This)->lpVtbl -> get_Type(This,Type) ) 

#define FillFormat_get_Visible(This,Visible)	\
    ( (This)->lpVtbl -> get_Visible(This,Visible) ) 

#define FillFormat_put_Visible(This,Visible)	\
    ( (This)->lpVtbl -> put_Visible(This,Visible) ) 

#define FillFormat_get_GradientStops(This,GradientStops)	\
    ( (This)->lpVtbl -> get_GradientStops(This,GradientStops) ) 

#define FillFormat_get_TextureOffsetX(This,TextureOffsetX)	\
    ( (This)->lpVtbl -> get_TextureOffsetX(This,TextureOffsetX) ) 

#define FillFormat_put_TextureOffsetX(This,TextureOffsetX)	\
    ( (This)->lpVtbl -> put_TextureOffsetX(This,TextureOffsetX) ) 

#define FillFormat_get_TextureOffsetY(This,TextureOffsetY)	\
    ( (This)->lpVtbl -> get_TextureOffsetY(This,TextureOffsetY) ) 

#define FillFormat_put_TextureOffsetY(This,TextureOffsetY)	\
    ( (This)->lpVtbl -> put_TextureOffsetY(This,TextureOffsetY) ) 

#define FillFormat_get_TextureAlignment(This,TextureAlignment)	\
    ( (This)->lpVtbl -> get_TextureAlignment(This,TextureAlignment) ) 

#define FillFormat_put_TextureAlignment(This,TextureAlignment)	\
    ( (This)->lpVtbl -> put_TextureAlignment(This,TextureAlignment) ) 

#define FillFormat_get_TextureHorizontalScale(This,HorizontalScale)	\
    ( (This)->lpVtbl -> get_TextureHorizontalScale(This,HorizontalScale) ) 

#define FillFormat_put_TextureHorizontalScale(This,HorizontalScale)	\
    ( (This)->lpVtbl -> put_TextureHorizontalScale(This,HorizontalScale) ) 

#define FillFormat_get_TextureVerticalScale(This,VerticalScale)	\
    ( (This)->lpVtbl -> get_TextureVerticalScale(This,VerticalScale) ) 

#define FillFormat_put_TextureVerticalScale(This,VerticalScale)	\
    ( (This)->lpVtbl -> put_TextureVerticalScale(This,VerticalScale) ) 

#define FillFormat_get_TextureTile(This,TextureTile)	\
    ( (This)->lpVtbl -> get_TextureTile(This,TextureTile) ) 

#define FillFormat_put_TextureTile(This,TextureTile)	\
    ( (This)->lpVtbl -> put_TextureTile(This,TextureTile) ) 

#define FillFormat_get_RotateWithObject(This,RotateWithObject)	\
    ( (This)->lpVtbl -> get_RotateWithObject(This,RotateWithObject) ) 

#define FillFormat_put_RotateWithObject(This,RotateWithObject)	\
    ( (This)->lpVtbl -> put_RotateWithObject(This,RotateWithObject) ) 

#define FillFormat_get_PictureEffects(This,PictureEffects)	\
    ( (This)->lpVtbl -> get_PictureEffects(This,PictureEffects) ) 

#define FillFormat_get_GradientAngle(This,GradientAngle)	\
    ( (This)->lpVtbl -> get_GradientAngle(This,GradientAngle) ) 

#define FillFormat_put_GradientAngle(This,GradientAngle)	\
    ( (This)->lpVtbl -> put_GradientAngle(This,GradientAngle) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __FillFormat_INTERFACE_DEFINED__ */


#ifndef __DiagramNodes_INTERFACE_DEFINED__
#define __DiagramNodes_INTERFACE_DEFINED__

/* interface DiagramNodes */
/* [object][oleautomation][nonextensible][dual][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_DiagramNodes;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000C036E-0000-0000-C000-000000000046")
    DiagramNodes : public _IMsoDispObj
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get__NewEnum( 
            /* [retval][out] */ IUnknown **ppunkEnum) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ DiagramNode **ppdn) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE SelectAll( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Parent( 
            /* [retval][out] */ IDispatch **ppParent) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Count( 
            /* [retval][out] */ int *pcDiagramNodes) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct DiagramNodesVtbl
    {
        BEGIN_INTERFACE
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            DiagramNodes * This,
            /* [in][idldescattr] */ struct GUID *riid,
            /* [out][idldescattr] */ void **ppvObj,
            /* [retval][out] */ void *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *AddRef )( 
            DiagramNodes * This,
            /* [retval][out] */ unsigned long *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *Release )( 
            DiagramNodes * This,
            /* [retval][out] */ unsigned long *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            DiagramNodes * This,
            /* [out][idldescattr] */ unsigned UINT *pctinfo,
            /* [retval][out] */ void *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            DiagramNodes * This,
            /* [in][idldescattr] */ unsigned UINT itinfo,
            /* [in][idldescattr] */ unsigned long lcid,
            /* [out][idldescattr] */ void **pptinfo,
            /* [retval][out] */ void *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            DiagramNodes * This,
            /* [in][idldescattr] */ struct GUID *riid,
            /* [in][idldescattr] */ signed char **rgszNames,
            /* [in][idldescattr] */ unsigned UINT cNames,
            /* [in][idldescattr] */ unsigned long lcid,
            /* [out][idldescattr] */ signed long *rgdispid,
            /* [retval][out] */ void *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            DiagramNodes * This,
            /* [in][idldescattr] */ signed long dispidMember,
            /* [in][idldescattr] */ struct GUID *riid,
            /* [in][idldescattr] */ unsigned long lcid,
            /* [in][idldescattr] */ unsigned short wFlags,
            /* [in][idldescattr] */ struct DISPPARAMS *pdispparams,
            /* [out][idldescattr] */ VARIANT *pvarResult,
            /* [out][idldescattr] */ struct EXCEPINFO *pexcepinfo,
            /* [out][idldescattr] */ unsigned UINT *puArgErr,
            /* [retval][out] */ void *retval);
        
        /* [id][propget][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *get_Application )( 
            DiagramNodes * This,
            /* [retval][out] */ IDispatch **retval);
        
        /* [id][propget][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *get_Creator )( 
            DiagramNodes * This,
            /* [retval][out] */ signed long *retval);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get__NewEnum )( 
            DiagramNodes * This,
            /* [retval][out] */ IUnknown **ppunkEnum);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Item )( 
            DiagramNodes * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ DiagramNode **ppdn);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *SelectAll )( 
            DiagramNodes * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Parent )( 
            DiagramNodes * This,
            /* [retval][out] */ IDispatch **ppParent);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Count )( 
            DiagramNodes * This,
            /* [retval][out] */ int *pcDiagramNodes);
        
        END_INTERFACE
    } DiagramNodesVtbl;

    interface DiagramNodes
    {
        CONST_VTBL struct DiagramNodesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define DiagramNodes_QueryInterface(This,riid,ppvObj,retval)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObj,retval) ) 

#define DiagramNodes_AddRef(This,retval)	\
    ( (This)->lpVtbl -> AddRef(This,retval) ) 

#define DiagramNodes_Release(This,retval)	\
    ( (This)->lpVtbl -> Release(This,retval) ) 

#define DiagramNodes_GetTypeInfoCount(This,pctinfo,retval)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo,retval) ) 

#define DiagramNodes_GetTypeInfo(This,itinfo,lcid,pptinfo,retval)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,itinfo,lcid,pptinfo,retval) ) 

#define DiagramNodes_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgdispid,retval)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgdispid,retval) ) 

#define DiagramNodes_Invoke(This,dispidMember,riid,lcid,wFlags,pdispparams,pvarResult,pexcepinfo,puArgErr,retval)	\
    ( (This)->lpVtbl -> Invoke(This,dispidMember,riid,lcid,wFlags,pdispparams,pvarResult,pexcepinfo,puArgErr,retval) ) 

#define DiagramNodes_get_Application(This,retval)	\
    ( (This)->lpVtbl -> get_Application(This,retval) ) 

#define DiagramNodes_get_Creator(This,retval)	\
    ( (This)->lpVtbl -> get_Creator(This,retval) ) 


#define DiagramNodes_get__NewEnum(This,ppunkEnum)	\
    ( (This)->lpVtbl -> get__NewEnum(This,ppunkEnum) ) 

#define DiagramNodes_Item(This,Index,ppdn)	\
    ( (This)->lpVtbl -> Item(This,Index,ppdn) ) 

#define DiagramNodes_SelectAll(This)	\
    ( (This)->lpVtbl -> SelectAll(This) ) 

#define DiagramNodes_get_Parent(This,ppParent)	\
    ( (This)->lpVtbl -> get_Parent(This,ppParent) ) 

#define DiagramNodes_get_Count(This,pcDiagramNodes)	\
    ( (This)->lpVtbl -> get_Count(This,pcDiagramNodes) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __DiagramNodes_INTERFACE_DEFINED__ */


#ifndef __DiagramNodeChildren_INTERFACE_DEFINED__
#define __DiagramNodeChildren_INTERFACE_DEFINED__

/* interface DiagramNodeChildren */
/* [object][oleautomation][nonextensible][dual][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_DiagramNodeChildren;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000C036F-0000-0000-C000-000000000046")
    DiagramNodeChildren : public _IMsoDispObj
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get__NewEnum( 
            /* [retval][out] */ IUnknown **ppunkEnum) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ DiagramNode **ppNode) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE AddNode( 
            /* [defaultvalue][optional][in] */ VARIANT Index,
            /* [defaultvalue][optional][in] */ MsoDiagramNodeType nodeType,
            /* [retval][out] */ DiagramNode **ppNewNode) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE SelectAll( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Parent( 
            /* [retval][out] */ IDispatch **ppParent) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Count( 
            /* [retval][out] */ int *pcDiagramNodes) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_FirstChild( 
            /* [retval][out] */ DiagramNode **pFirst) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_LastChild( 
            /* [retval][out] */ DiagramNode **pLast) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct DiagramNodeChildrenVtbl
    {
        BEGIN_INTERFACE
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            DiagramNodeChildren * This,
            /* [in][idldescattr] */ struct GUID *riid,
            /* [out][idldescattr] */ void **ppvObj,
            /* [retval][out] */ void *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *AddRef )( 
            DiagramNodeChildren * This,
            /* [retval][out] */ unsigned long *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *Release )( 
            DiagramNodeChildren * This,
            /* [retval][out] */ unsigned long *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            DiagramNodeChildren * This,
            /* [out][idldescattr] */ unsigned UINT *pctinfo,
            /* [retval][out] */ void *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            DiagramNodeChildren * This,
            /* [in][idldescattr] */ unsigned UINT itinfo,
            /* [in][idldescattr] */ unsigned long lcid,
            /* [out][idldescattr] */ void **pptinfo,
            /* [retval][out] */ void *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            DiagramNodeChildren * This,
            /* [in][idldescattr] */ struct GUID *riid,
            /* [in][idldescattr] */ signed char **rgszNames,
            /* [in][idldescattr] */ unsigned UINT cNames,
            /* [in][idldescattr] */ unsigned long lcid,
            /* [out][idldescattr] */ signed long *rgdispid,
            /* [retval][out] */ void *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            DiagramNodeChildren * This,
            /* [in][idldescattr] */ signed long dispidMember,
            /* [in][idldescattr] */ struct GUID *riid,
            /* [in][idldescattr] */ unsigned long lcid,
            /* [in][idldescattr] */ unsigned short wFlags,
            /* [in][idldescattr] */ struct DISPPARAMS *pdispparams,
            /* [out][idldescattr] */ VARIANT *pvarResult,
            /* [out][idldescattr] */ struct EXCEPINFO *pexcepinfo,
            /* [out][idldescattr] */ unsigned UINT *puArgErr,
            /* [retval][out] */ void *retval);
        
        /* [id][propget][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *get_Application )( 
            DiagramNodeChildren * This,
            /* [retval][out] */ IDispatch **retval);
        
        /* [id][propget][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *get_Creator )( 
            DiagramNodeChildren * This,
            /* [retval][out] */ signed long *retval);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get__NewEnum )( 
            DiagramNodeChildren * This,
            /* [retval][out] */ IUnknown **ppunkEnum);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Item )( 
            DiagramNodeChildren * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ DiagramNode **ppNode);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *AddNode )( 
            DiagramNodeChildren * This,
            /* [defaultvalue][optional][in] */ VARIANT Index,
            /* [defaultvalue][optional][in] */ MsoDiagramNodeType nodeType,
            /* [retval][out] */ DiagramNode **ppNewNode);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *SelectAll )( 
            DiagramNodeChildren * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Parent )( 
            DiagramNodeChildren * This,
            /* [retval][out] */ IDispatch **ppParent);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Count )( 
            DiagramNodeChildren * This,
            /* [retval][out] */ int *pcDiagramNodes);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_FirstChild )( 
            DiagramNodeChildren * This,
            /* [retval][out] */ DiagramNode **pFirst);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_LastChild )( 
            DiagramNodeChildren * This,
            /* [retval][out] */ DiagramNode **pLast);
        
        END_INTERFACE
    } DiagramNodeChildrenVtbl;

    interface DiagramNodeChildren
    {
        CONST_VTBL struct DiagramNodeChildrenVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define DiagramNodeChildren_QueryInterface(This,riid,ppvObj,retval)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObj,retval) ) 

#define DiagramNodeChildren_AddRef(This,retval)	\
    ( (This)->lpVtbl -> AddRef(This,retval) ) 

#define DiagramNodeChildren_Release(This,retval)	\
    ( (This)->lpVtbl -> Release(This,retval) ) 

#define DiagramNodeChildren_GetTypeInfoCount(This,pctinfo,retval)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo,retval) ) 

#define DiagramNodeChildren_GetTypeInfo(This,itinfo,lcid,pptinfo,retval)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,itinfo,lcid,pptinfo,retval) ) 

#define DiagramNodeChildren_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgdispid,retval)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgdispid,retval) ) 

#define DiagramNodeChildren_Invoke(This,dispidMember,riid,lcid,wFlags,pdispparams,pvarResult,pexcepinfo,puArgErr,retval)	\
    ( (This)->lpVtbl -> Invoke(This,dispidMember,riid,lcid,wFlags,pdispparams,pvarResult,pexcepinfo,puArgErr,retval) ) 

#define DiagramNodeChildren_get_Application(This,retval)	\
    ( (This)->lpVtbl -> get_Application(This,retval) ) 

#define DiagramNodeChildren_get_Creator(This,retval)	\
    ( (This)->lpVtbl -> get_Creator(This,retval) ) 


#define DiagramNodeChildren_get__NewEnum(This,ppunkEnum)	\
    ( (This)->lpVtbl -> get__NewEnum(This,ppunkEnum) ) 

#define DiagramNodeChildren_Item(This,Index,ppNode)	\
    ( (This)->lpVtbl -> Item(This,Index,ppNode) ) 

#define DiagramNodeChildren_AddNode(This,Index,nodeType,ppNewNode)	\
    ( (This)->lpVtbl -> AddNode(This,Index,nodeType,ppNewNode) ) 

#define DiagramNodeChildren_SelectAll(This)	\
    ( (This)->lpVtbl -> SelectAll(This) ) 

#define DiagramNodeChildren_get_Parent(This,ppParent)	\
    ( (This)->lpVtbl -> get_Parent(This,ppParent) ) 

#define DiagramNodeChildren_get_Count(This,pcDiagramNodes)	\
    ( (This)->lpVtbl -> get_Count(This,pcDiagramNodes) ) 

#define DiagramNodeChildren_get_FirstChild(This,pFirst)	\
    ( (This)->lpVtbl -> get_FirstChild(This,pFirst) ) 

#define DiagramNodeChildren_get_LastChild(This,pLast)	\
    ( (This)->lpVtbl -> get_LastChild(This,pLast) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __DiagramNodeChildren_INTERFACE_DEFINED__ */


#ifndef __DiagramNode_INTERFACE_DEFINED__
#define __DiagramNode_INTERFACE_DEFINED__

/* interface DiagramNode */
/* [object][oleautomation][nonextensible][dual][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_DiagramNode;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000C0371-0000-0000-C000-000000000046")
    DiagramNode : public _IMsoDispObj
    {
    public:
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE AddNode( 
            /* [defaultvalue][optional][in] */ MsoRelativeNodePosition pos,
            /* [defaultvalue][optional][in] */ MsoDiagramNodeType nodeType,
            /* [retval][out] */ DiagramNode **NewNode) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Delete( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE MoveNode( 
            /* [in] */ DiagramNode *pTargetNode,
            /* [in] */ MsoRelativeNodePosition pos) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE ReplaceNode( 
            /* [in] */ DiagramNode *pTargetNode) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE SwapNode( 
            /* [in] */ DiagramNode *pTargetNode,
            /* [defaultvalue][optional][in] */ VARIANT_BOOL swapChildren = -1) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE CloneNode( 
            /* [in] */ VARIANT_BOOL copyChildren,
            /* [in] */ DiagramNode *pTargetNode,
            /* [defaultvalue][optional][in] */ MsoRelativeNodePosition pos,
            /* [retval][out] */ DiagramNode **ppNode) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE TransferChildren( 
            /* [in] */ DiagramNode *pReceivingNode) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE NextNode( 
            /* [retval][out] */ DiagramNode **ppNextNode) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE PrevNode( 
            /* [retval][out] */ DiagramNode **ppPrevNode) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Parent( 
            /* [retval][out] */ IDispatch **ppParent) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Children( 
            /* [retval][out] */ DiagramNodeChildren **ppChildren) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Shape( 
            /* [retval][out] */ Shape	**ppShape) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Root( 
            /* [retval][out] */ DiagramNode **ppRoot) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Diagram( 
            /* [retval][out] */ /* external definition not present */ IMsoDiagram **ppDiagram) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Layout( 
            /* [retval][out] */ MsoOrgChartLayoutType *pdgmType) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_Layout( 
            /* [in] */ MsoOrgChartLayoutType pdgmType) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_TextShape( 
            /* [retval][out] */ Shape	**Shape) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct DiagramNodeVtbl
    {
        BEGIN_INTERFACE
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            DiagramNode * This,
            /* [in][idldescattr] */ struct GUID *riid,
            /* [out][idldescattr] */ void **ppvObj,
            /* [retval][out] */ void *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *AddRef )( 
            DiagramNode * This,
            /* [retval][out] */ unsigned long *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *Release )( 
            DiagramNode * This,
            /* [retval][out] */ unsigned long *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            DiagramNode * This,
            /* [out][idldescattr] */ unsigned UINT *pctinfo,
            /* [retval][out] */ void *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            DiagramNode * This,
            /* [in][idldescattr] */ unsigned UINT itinfo,
            /* [in][idldescattr] */ unsigned long lcid,
            /* [out][idldescattr] */ void **pptinfo,
            /* [retval][out] */ void *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            DiagramNode * This,
            /* [in][idldescattr] */ struct GUID *riid,
            /* [in][idldescattr] */ signed char **rgszNames,
            /* [in][idldescattr] */ unsigned UINT cNames,
            /* [in][idldescattr] */ unsigned long lcid,
            /* [out][idldescattr] */ signed long *rgdispid,
            /* [retval][out] */ void *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            DiagramNode * This,
            /* [in][idldescattr] */ signed long dispidMember,
            /* [in][idldescattr] */ struct GUID *riid,
            /* [in][idldescattr] */ unsigned long lcid,
            /* [in][idldescattr] */ unsigned short wFlags,
            /* [in][idldescattr] */ struct DISPPARAMS *pdispparams,
            /* [out][idldescattr] */ VARIANT *pvarResult,
            /* [out][idldescattr] */ struct EXCEPINFO *pexcepinfo,
            /* [out][idldescattr] */ unsigned UINT *puArgErr,
            /* [retval][out] */ void *retval);
        
        /* [id][propget][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *get_Application )( 
            DiagramNode * This,
            /* [retval][out] */ IDispatch **retval);
        
        /* [id][propget][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *get_Creator )( 
            DiagramNode * This,
            /* [retval][out] */ signed long *retval);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *AddNode )( 
            DiagramNode * This,
            /* [defaultvalue][optional][in] */ MsoRelativeNodePosition pos,
            /* [defaultvalue][optional][in] */ MsoDiagramNodeType nodeType,
            /* [retval][out] */ DiagramNode **NewNode);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Delete )( 
            DiagramNode * This);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *MoveNode )( 
            DiagramNode * This,
            /* [in] */ DiagramNode *pTargetNode,
            /* [in] */ MsoRelativeNodePosition pos);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *ReplaceNode )( 
            DiagramNode * This,
            /* [in] */ DiagramNode *pTargetNode);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *SwapNode )( 
            DiagramNode * This,
            /* [in] */ DiagramNode *pTargetNode,
            /* [defaultvalue][optional][in] */ VARIANT_BOOL swapChildren);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *CloneNode )( 
            DiagramNode * This,
            /* [in] */ VARIANT_BOOL copyChildren,
            /* [in] */ DiagramNode *pTargetNode,
            /* [defaultvalue][optional][in] */ MsoRelativeNodePosition pos,
            /* [retval][out] */ DiagramNode **ppNode);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *TransferChildren )( 
            DiagramNode * This,
            /* [in] */ DiagramNode *pReceivingNode);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *NextNode )( 
            DiagramNode * This,
            /* [retval][out] */ DiagramNode **ppNextNode);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *PrevNode )( 
            DiagramNode * This,
            /* [retval][out] */ DiagramNode **ppPrevNode);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Parent )( 
            DiagramNode * This,
            /* [retval][out] */ IDispatch **ppParent);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Children )( 
            DiagramNode * This,
            /* [retval][out] */ DiagramNodeChildren **ppChildren);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Shape )( 
            DiagramNode * This,
            /* [retval][out] */ Shape	**ppShape);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Root )( 
            DiagramNode * This,
            /* [retval][out] */ DiagramNode **ppRoot);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Diagram )( 
            DiagramNode * This,
            /* [retval][out] */ /* external definition not present */ IMsoDiagram **ppDiagram);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Layout )( 
            DiagramNode * This,
            /* [retval][out] */ MsoOrgChartLayoutType *pdgmType);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Layout )( 
            DiagramNode * This,
            /* [in] */ MsoOrgChartLayoutType pdgmType);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_TextShape )( 
            DiagramNode * This,
            /* [retval][out] */ Shape	**Shape);
        
        END_INTERFACE
    } DiagramNodeVtbl;

    interface DiagramNode
    {
        CONST_VTBL struct DiagramNodeVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define DiagramNode_QueryInterface(This,riid,ppvObj,retval)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObj,retval) ) 

#define DiagramNode_AddRef(This,retval)	\
    ( (This)->lpVtbl -> AddRef(This,retval) ) 

#define DiagramNode_Release(This,retval)	\
    ( (This)->lpVtbl -> Release(This,retval) ) 

#define DiagramNode_GetTypeInfoCount(This,pctinfo,retval)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo,retval) ) 

#define DiagramNode_GetTypeInfo(This,itinfo,lcid,pptinfo,retval)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,itinfo,lcid,pptinfo,retval) ) 

#define DiagramNode_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgdispid,retval)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgdispid,retval) ) 

#define DiagramNode_Invoke(This,dispidMember,riid,lcid,wFlags,pdispparams,pvarResult,pexcepinfo,puArgErr,retval)	\
    ( (This)->lpVtbl -> Invoke(This,dispidMember,riid,lcid,wFlags,pdispparams,pvarResult,pexcepinfo,puArgErr,retval) ) 

#define DiagramNode_get_Application(This,retval)	\
    ( (This)->lpVtbl -> get_Application(This,retval) ) 

#define DiagramNode_get_Creator(This,retval)	\
    ( (This)->lpVtbl -> get_Creator(This,retval) ) 


#define DiagramNode_AddNode(This,pos,nodeType,NewNode)	\
    ( (This)->lpVtbl -> AddNode(This,pos,nodeType,NewNode) ) 

#define DiagramNode_Delete(This)	\
    ( (This)->lpVtbl -> Delete(This) ) 

#define DiagramNode_MoveNode(This,pTargetNode,pos)	\
    ( (This)->lpVtbl -> MoveNode(This,pTargetNode,pos) ) 

#define DiagramNode_ReplaceNode(This,pTargetNode)	\
    ( (This)->lpVtbl -> ReplaceNode(This,pTargetNode) ) 

#define DiagramNode_SwapNode(This,pTargetNode,swapChildren)	\
    ( (This)->lpVtbl -> SwapNode(This,pTargetNode,swapChildren) ) 

#define DiagramNode_CloneNode(This,copyChildren,pTargetNode,pos,ppNode)	\
    ( (This)->lpVtbl -> CloneNode(This,copyChildren,pTargetNode,pos,ppNode) ) 

#define DiagramNode_TransferChildren(This,pReceivingNode)	\
    ( (This)->lpVtbl -> TransferChildren(This,pReceivingNode) ) 

#define DiagramNode_NextNode(This,ppNextNode)	\
    ( (This)->lpVtbl -> NextNode(This,ppNextNode) ) 

#define DiagramNode_PrevNode(This,ppPrevNode)	\
    ( (This)->lpVtbl -> PrevNode(This,ppPrevNode) ) 

#define DiagramNode_get_Parent(This,ppParent)	\
    ( (This)->lpVtbl -> get_Parent(This,ppParent) ) 

#define DiagramNode_get_Children(This,ppChildren)	\
    ( (This)->lpVtbl -> get_Children(This,ppChildren) ) 

#define DiagramNode_get_Shape(This,ppShape)	\
    ( (This)->lpVtbl -> get_Shape(This,ppShape) ) 

#define DiagramNode_get_Root(This,ppRoot)	\
    ( (This)->lpVtbl -> get_Root(This,ppRoot) ) 

#define DiagramNode_get_Diagram(This,ppDiagram)	\
    ( (This)->lpVtbl -> get_Diagram(This,ppDiagram) ) 

#define DiagramNode_get_Layout(This,pdgmType)	\
    ( (This)->lpVtbl -> get_Layout(This,pdgmType) ) 

#define DiagramNode_put_Layout(This,pdgmType)	\
    ( (This)->lpVtbl -> put_Layout(This,pdgmType) ) 

#define DiagramNode_get_TextShape(This,Shape)	\
    ( (This)->lpVtbl -> get_TextShape(This,Shape) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __DiagramNode_INTERFACE_DEFINED__ */


#ifndef __IRTDUpdateEvent_INTERFACE_DEFINED__
#define __IRTDUpdateEvent_INTERFACE_DEFINED__

/* interface IRTDUpdateEvent */
/* [object][oleautomation][dual][helpcontext][uuid] */ 


EXTERN_C const IID IID_IRTDUpdateEvent;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("A43788C1-D91B-11D3-8F39-00C04F3651B8")
    IRTDUpdateEvent : public IDispatch
    {
    public:
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE UpdateNotify( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_HeartbeatInterval( 
            /* [retval][out] */ long *plRetVal) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_HeartbeatInterval( 
            /* [in] */ long plRetVal) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Disconnect( void) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IRTDUpdateEventVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IRTDUpdateEvent * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IRTDUpdateEvent * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IRTDUpdateEvent * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IRTDUpdateEvent * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IRTDUpdateEvent * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IRTDUpdateEvent * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IRTDUpdateEvent * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *UpdateNotify )( 
            IRTDUpdateEvent * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_HeartbeatInterval )( 
            IRTDUpdateEvent * This,
            /* [retval][out] */ long *plRetVal);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_HeartbeatInterval )( 
            IRTDUpdateEvent * This,
            /* [in] */ long plRetVal);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Disconnect )( 
            IRTDUpdateEvent * This);
        
        END_INTERFACE
    } IRTDUpdateEventVtbl;

    interface IRTDUpdateEvent
    {
        CONST_VTBL struct IRTDUpdateEventVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IRTDUpdateEvent_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IRTDUpdateEvent_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IRTDUpdateEvent_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IRTDUpdateEvent_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IRTDUpdateEvent_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IRTDUpdateEvent_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IRTDUpdateEvent_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IRTDUpdateEvent_UpdateNotify(This)	\
    ( (This)->lpVtbl -> UpdateNotify(This) ) 

#define IRTDUpdateEvent_get_HeartbeatInterval(This,plRetVal)	\
    ( (This)->lpVtbl -> get_HeartbeatInterval(This,plRetVal) ) 

#define IRTDUpdateEvent_put_HeartbeatInterval(This,plRetVal)	\
    ( (This)->lpVtbl -> put_HeartbeatInterval(This,plRetVal) ) 

#define IRTDUpdateEvent_Disconnect(This)	\
    ( (This)->lpVtbl -> Disconnect(This) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IRTDUpdateEvent_INTERFACE_DEFINED__ */


#ifndef __IRtdServer_INTERFACE_DEFINED__
#define __IRtdServer_INTERFACE_DEFINED__

/* interface IRtdServer */
/* [object][oleautomation][dual][helpcontext][uuid] */ 


EXTERN_C const IID IID_IRtdServer;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("EC0E6191-DB51-11D3-8F3E-00C04F3651B8")
    IRtdServer : public IDispatch
    {
    public:
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE ServerStart( 
            /* [in] */ IRTDUpdateEvent *CallbackObject,
            /* [retval][out] */ long *pfRes) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE ConnectData( 
            /* [in] */ long TopicID,
            /* [in] */ SAFEARRAY * *Strings,
            /* [out][in] */ VARIANT_BOOL *GetNewValues,
            /* [retval][out] */ VARIANT *pvarOut) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE RefreshData( 
            /* [out][in] */ long *TopicCount,
            /* [retval][out] */ SAFEARRAY * *parrayOut) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE DisconnectData( 
            /* [in] */ long TopicID) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Heartbeat( 
            /* [retval][out] */ long *pfRes) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE ServerTerminate( void) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IRtdServerVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IRtdServer * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IRtdServer * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IRtdServer * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IRtdServer * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IRtdServer * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IRtdServer * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IRtdServer * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *ServerStart )( 
            IRtdServer * This,
            /* [in] */ IRTDUpdateEvent *CallbackObject,
            /* [retval][out] */ long *pfRes);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *ConnectData )( 
            IRtdServer * This,
            /* [in] */ long TopicID,
            /* [in] */ SAFEARRAY * *Strings,
            /* [out][in] */ VARIANT_BOOL *GetNewValues,
            /* [retval][out] */ VARIANT *pvarOut);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *RefreshData )( 
            IRtdServer * This,
            /* [out][in] */ long *TopicCount,
            /* [retval][out] */ SAFEARRAY * *parrayOut);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *DisconnectData )( 
            IRtdServer * This,
            /* [in] */ long TopicID);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Heartbeat )( 
            IRtdServer * This,
            /* [retval][out] */ long *pfRes);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *ServerTerminate )( 
            IRtdServer * This);
        
        END_INTERFACE
    } IRtdServerVtbl;

    interface IRtdServer
    {
        CONST_VTBL struct IRtdServerVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IRtdServer_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IRtdServer_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IRtdServer_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IRtdServer_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IRtdServer_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IRtdServer_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IRtdServer_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IRtdServer_ServerStart(This,CallbackObject,pfRes)	\
    ( (This)->lpVtbl -> ServerStart(This,CallbackObject,pfRes) ) 

#define IRtdServer_ConnectData(This,TopicID,Strings,GetNewValues,pvarOut)	\
    ( (This)->lpVtbl -> ConnectData(This,TopicID,Strings,GetNewValues,pvarOut) ) 

#define IRtdServer_RefreshData(This,TopicCount,parrayOut)	\
    ( (This)->lpVtbl -> RefreshData(This,TopicCount,parrayOut) ) 

#define IRtdServer_DisconnectData(This,TopicID)	\
    ( (This)->lpVtbl -> DisconnectData(This,TopicID) ) 

#define IRtdServer_Heartbeat(This,pfRes)	\
    ( (This)->lpVtbl -> Heartbeat(This,pfRes) ) 

#define IRtdServer_ServerTerminate(This)	\
    ( (This)->lpVtbl -> ServerTerminate(This) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IRtdServer_INTERFACE_DEFINED__ */


#ifndef __TextFrame2_INTERFACE_DEFINED__
#define __TextFrame2_INTERFACE_DEFINED__

/* interface TextFrame2 */
/* [object][oleautomation][nonextensible][dual][uuid] */ 


EXTERN_C const IID IID_TextFrame2;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000C0398-0000-0000-C000-000000000046")
    TextFrame2 : public _IMsoDispObj
    {
    public:
        virtual /* [propget][id] */ HRESULT STDMETHODCALLTYPE get_Parent( 
            /* [retval][out] */ IDispatch **Parent) = 0;
        
        virtual /* [propget][id] */ HRESULT STDMETHODCALLTYPE get_MarginBottom( 
            /* [retval][out] */ single *MarginBottom) = 0;
        
        virtual /* [propput][id] */ HRESULT STDMETHODCALLTYPE put_MarginBottom( 
            /* [in] */ single MarginBottom) = 0;
        
        virtual /* [propget][id] */ HRESULT STDMETHODCALLTYPE get_MarginLeft( 
            /* [retval][out] */ single *MarginLeft) = 0;
        
        virtual /* [propput][id] */ HRESULT STDMETHODCALLTYPE put_MarginLeft( 
            /* [in] */ single MarginLeft) = 0;
        
        virtual /* [propget][id] */ HRESULT STDMETHODCALLTYPE get_MarginRight( 
            /* [retval][out] */ single *MarginRight) = 0;
        
        virtual /* [propput][id] */ HRESULT STDMETHODCALLTYPE put_MarginRight( 
            /* [in] */ single MarginRight) = 0;
        
        virtual /* [propget][id] */ HRESULT STDMETHODCALLTYPE get_MarginTop( 
            /* [retval][out] */ single *MarginTop) = 0;
        
        virtual /* [propput][id] */ HRESULT STDMETHODCALLTYPE put_MarginTop( 
            /* [in] */ single MarginTop) = 0;
        
        virtual /* [propget][id] */ HRESULT STDMETHODCALLTYPE get_Orientation( 
            /* [retval][out] */ MsoTextOrientation *Orientation) = 0;
        
        virtual /* [propput][id] */ HRESULT STDMETHODCALLTYPE put_Orientation( 
            /* [in] */ MsoTextOrientation Orientation) = 0;
        
        virtual /* [propget][id] */ HRESULT STDMETHODCALLTYPE get_HorizontalAnchor( 
            /* [retval][out] */ MsoHorizontalAnchor *HorizontalAnchor) = 0;
        
        virtual /* [propput][id] */ HRESULT STDMETHODCALLTYPE put_HorizontalAnchor( 
            /* [in] */ MsoHorizontalAnchor HorizontalAnchor) = 0;
        
        virtual /* [propget][id] */ HRESULT STDMETHODCALLTYPE get_VerticalAnchor( 
            /* [retval][out] */ MsoVerticalAnchor *VerticalAnchor) = 0;
        
        virtual /* [propput][id] */ HRESULT STDMETHODCALLTYPE put_VerticalAnchor( 
            /* [in] */ MsoVerticalAnchor VerticalAnchor) = 0;
        
        virtual /* [propget][id] */ HRESULT STDMETHODCALLTYPE get_PathFormat( 
            /* [retval][out] */ MsoPathFormat *PathFormat) = 0;
        
        virtual /* [propput][id] */ HRESULT STDMETHODCALLTYPE put_PathFormat( 
            /* [in] */ MsoPathFormat PathFormat) = 0;
        
        virtual /* [propget][id] */ HRESULT STDMETHODCALLTYPE get_WarpFormat( 
            /* [retval][out] */ MsoWarpFormat *WarpFormat) = 0;
        
        virtual /* [propput][id] */ HRESULT STDMETHODCALLTYPE put_WarpFormat( 
            /* [in] */ MsoWarpFormat WarpFormat) = 0;
        
        virtual /* [propget][id] */ HRESULT STDMETHODCALLTYPE get_WordArtformat( 
            /* [retval][out] */ MsoPresetTextEffect *WordArtformat) = 0;
        
        virtual /* [propput][id] */ HRESULT STDMETHODCALLTYPE put_WordArtformat( 
            /* [in] */ MsoPresetTextEffect WordArtformat) = 0;
        
        virtual /* [propget][id] */ HRESULT STDMETHODCALLTYPE get_WordWrap( 
            /* [retval][out] */ MsoTriState *WordWrap) = 0;
        
        virtual /* [propput][id] */ HRESULT STDMETHODCALLTYPE put_WordWrap( 
            /* [in] */ MsoTriState WordWrap) = 0;
        
        virtual /* [propget][id] */ HRESULT STDMETHODCALLTYPE get_AutoSize( 
            /* [retval][out] */ MsoAutoSize *AutoSize) = 0;
        
        virtual /* [propput][id] */ HRESULT STDMETHODCALLTYPE put_AutoSize( 
            /* [in] */ MsoAutoSize AutoSize) = 0;
        
        virtual /* [propget][id] */ HRESULT STDMETHODCALLTYPE get_ThreeD( 
            /* [retval][out] */ ThreeDFormat **ThreeD) = 0;
        
        virtual /* [propget][id] */ HRESULT STDMETHODCALLTYPE get_HasText( 
            /* [retval][out] */ MsoTriState *pHasText) = 0;
        
        virtual /* [propget][id] */ HRESULT STDMETHODCALLTYPE get_TextRange( 
            /* [retval][out] */ /* external definition not present */ TextRange2 **Range) = 0;
        
        virtual /* [propget][id] */ HRESULT STDMETHODCALLTYPE get_Column( 
            /* [retval][out] */ /* external definition not present */ TextColumn2 **Column) = 0;
        
        virtual /* [propget][id] */ HRESULT STDMETHODCALLTYPE get_Ruler( 
            /* [retval][out] */ /* external definition not present */ Ruler2 **Ruler) = 0;
        
        virtual /* [id] */ HRESULT STDMETHODCALLTYPE DeleteText( void) = 0;
        
        virtual /* [propget][id] */ HRESULT STDMETHODCALLTYPE get_NoTextRotation( 
            /* [retval][out] */ MsoTriState *NoTextRotation) = 0;
        
        virtual /* [propput][id] */ HRESULT STDMETHODCALLTYPE put_NoTextRotation( 
            /* [in] */ MsoTriState NoTextRotation) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct TextFrame2Vtbl
    {
        BEGIN_INTERFACE
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            TextFrame2 * This,
            /* [in][idldescattr] */ struct GUID *riid,
            /* [out][idldescattr] */ void **ppvObj,
            /* [retval][out] */ void *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *AddRef )( 
            TextFrame2 * This,
            /* [retval][out] */ unsigned long *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *Release )( 
            TextFrame2 * This,
            /* [retval][out] */ unsigned long *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            TextFrame2 * This,
            /* [out][idldescattr] */ unsigned UINT *pctinfo,
            /* [retval][out] */ void *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            TextFrame2 * This,
            /* [in][idldescattr] */ unsigned UINT itinfo,
            /* [in][idldescattr] */ unsigned long lcid,
            /* [out][idldescattr] */ void **pptinfo,
            /* [retval][out] */ void *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            TextFrame2 * This,
            /* [in][idldescattr] */ struct GUID *riid,
            /* [in][idldescattr] */ signed char **rgszNames,
            /* [in][idldescattr] */ unsigned UINT cNames,
            /* [in][idldescattr] */ unsigned long lcid,
            /* [out][idldescattr] */ signed long *rgdispid,
            /* [retval][out] */ void *retval);
        
        /* [id][restricted][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            TextFrame2 * This,
            /* [in][idldescattr] */ signed long dispidMember,
            /* [in][idldescattr] */ struct GUID *riid,
            /* [in][idldescattr] */ unsigned long lcid,
            /* [in][idldescattr] */ unsigned short wFlags,
            /* [in][idldescattr] */ struct DISPPARAMS *pdispparams,
            /* [out][idldescattr] */ VARIANT *pvarResult,
            /* [out][idldescattr] */ struct EXCEPINFO *pexcepinfo,
            /* [out][idldescattr] */ unsigned UINT *puArgErr,
            /* [retval][out] */ void *retval);
        
        /* [id][propget][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *get_Application )( 
            TextFrame2 * This,
            /* [retval][out] */ IDispatch **retval);
        
        /* [id][propget][funcdescattr] */ HRESULT ( STDMETHODCALLTYPE *get_Creator )( 
            TextFrame2 * This,
            /* [retval][out] */ signed long *retval);
        
        /* [propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Parent )( 
            TextFrame2 * This,
            /* [retval][out] */ IDispatch **Parent);
        
        /* [propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_MarginBottom )( 
            TextFrame2 * This,
            /* [retval][out] */ single *MarginBottom);
        
        /* [propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_MarginBottom )( 
            TextFrame2 * This,
            /* [in] */ single MarginBottom);
        
        /* [propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_MarginLeft )( 
            TextFrame2 * This,
            /* [retval][out] */ single *MarginLeft);
        
        /* [propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_MarginLeft )( 
            TextFrame2 * This,
            /* [in] */ single MarginLeft);
        
        /* [propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_MarginRight )( 
            TextFrame2 * This,
            /* [retval][out] */ single *MarginRight);
        
        /* [propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_MarginRight )( 
            TextFrame2 * This,
            /* [in] */ single MarginRight);
        
        /* [propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_MarginTop )( 
            TextFrame2 * This,
            /* [retval][out] */ single *MarginTop);
        
        /* [propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_MarginTop )( 
            TextFrame2 * This,
            /* [in] */ single MarginTop);
        
        /* [propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Orientation )( 
            TextFrame2 * This,
            /* [retval][out] */ MsoTextOrientation *Orientation);
        
        /* [propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Orientation )( 
            TextFrame2 * This,
            /* [in] */ MsoTextOrientation Orientation);
        
        /* [propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_HorizontalAnchor )( 
            TextFrame2 * This,
            /* [retval][out] */ MsoHorizontalAnchor *HorizontalAnchor);
        
        /* [propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_HorizontalAnchor )( 
            TextFrame2 * This,
            /* [in] */ MsoHorizontalAnchor HorizontalAnchor);
        
        /* [propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_VerticalAnchor )( 
            TextFrame2 * This,
            /* [retval][out] */ MsoVerticalAnchor *VerticalAnchor);
        
        /* [propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_VerticalAnchor )( 
            TextFrame2 * This,
            /* [in] */ MsoVerticalAnchor VerticalAnchor);
        
        /* [propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_PathFormat )( 
            TextFrame2 * This,
            /* [retval][out] */ MsoPathFormat *PathFormat);
        
        /* [propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_PathFormat )( 
            TextFrame2 * This,
            /* [in] */ MsoPathFormat PathFormat);
        
        /* [propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_WarpFormat )( 
            TextFrame2 * This,
            /* [retval][out] */ MsoWarpFormat *WarpFormat);
        
        /* [propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_WarpFormat )( 
            TextFrame2 * This,
            /* [in] */ MsoWarpFormat WarpFormat);
        
        /* [propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_WordArtformat )( 
            TextFrame2 * This,
            /* [retval][out] */ MsoPresetTextEffect *WordArtformat);
        
        /* [propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_WordArtformat )( 
            TextFrame2 * This,
            /* [in] */ MsoPresetTextEffect WordArtformat);
        
        /* [propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_WordWrap )( 
            TextFrame2 * This,
            /* [retval][out] */ MsoTriState *WordWrap);
        
        /* [propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_WordWrap )( 
            TextFrame2 * This,
            /* [in] */ MsoTriState WordWrap);
        
        /* [propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_AutoSize )( 
            TextFrame2 * This,
            /* [retval][out] */ MsoAutoSize *AutoSize);
        
        /* [propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_AutoSize )( 
            TextFrame2 * This,
            /* [in] */ MsoAutoSize AutoSize);
        
        /* [propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ThreeD )( 
            TextFrame2 * This,
            /* [retval][out] */ ThreeDFormat **ThreeD);
        
        /* [propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_HasText )( 
            TextFrame2 * This,
            /* [retval][out] */ MsoTriState *pHasText);
        
        /* [propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_TextRange )( 
            TextFrame2 * This,
            /* [retval][out] */ /* external definition not present */ TextRange2 **Range);
        
        /* [propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Column )( 
            TextFrame2 * This,
            /* [retval][out] */ /* external definition not present */ TextColumn2 **Column);
        
        /* [propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Ruler )( 
            TextFrame2 * This,
            /* [retval][out] */ /* external definition not present */ Ruler2 **Ruler);
        
        /* [id] */ HRESULT ( STDMETHODCALLTYPE *DeleteText )( 
            TextFrame2 * This);
        
        /* [propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_NoTextRotation )( 
            TextFrame2 * This,
            /* [retval][out] */ MsoTriState *NoTextRotation);
        
        /* [propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_NoTextRotation )( 
            TextFrame2 * This,
            /* [in] */ MsoTriState NoTextRotation);
        
        END_INTERFACE
    } TextFrame2Vtbl;

    interface TextFrame2
    {
        CONST_VTBL struct TextFrame2Vtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define TextFrame2_QueryInterface(This,riid,ppvObj,retval)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObj,retval) ) 

#define TextFrame2_AddRef(This,retval)	\
    ( (This)->lpVtbl -> AddRef(This,retval) ) 

#define TextFrame2_Release(This,retval)	\
    ( (This)->lpVtbl -> Release(This,retval) ) 

#define TextFrame2_GetTypeInfoCount(This,pctinfo,retval)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo,retval) ) 

#define TextFrame2_GetTypeInfo(This,itinfo,lcid,pptinfo,retval)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,itinfo,lcid,pptinfo,retval) ) 

#define TextFrame2_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgdispid,retval)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgdispid,retval) ) 

#define TextFrame2_Invoke(This,dispidMember,riid,lcid,wFlags,pdispparams,pvarResult,pexcepinfo,puArgErr,retval)	\
    ( (This)->lpVtbl -> Invoke(This,dispidMember,riid,lcid,wFlags,pdispparams,pvarResult,pexcepinfo,puArgErr,retval) ) 

#define TextFrame2_get_Application(This,retval)	\
    ( (This)->lpVtbl -> get_Application(This,retval) ) 

#define TextFrame2_get_Creator(This,retval)	\
    ( (This)->lpVtbl -> get_Creator(This,retval) ) 


#define TextFrame2_get_Parent(This,Parent)	\
    ( (This)->lpVtbl -> get_Parent(This,Parent) ) 

#define TextFrame2_get_MarginBottom(This,MarginBottom)	\
    ( (This)->lpVtbl -> get_MarginBottom(This,MarginBottom) ) 

#define TextFrame2_put_MarginBottom(This,MarginBottom)	\
    ( (This)->lpVtbl -> put_MarginBottom(This,MarginBottom) ) 

#define TextFrame2_get_MarginLeft(This,MarginLeft)	\
    ( (This)->lpVtbl -> get_MarginLeft(This,MarginLeft) ) 

#define TextFrame2_put_MarginLeft(This,MarginLeft)	\
    ( (This)->lpVtbl -> put_MarginLeft(This,MarginLeft) ) 

#define TextFrame2_get_MarginRight(This,MarginRight)	\
    ( (This)->lpVtbl -> get_MarginRight(This,MarginRight) ) 

#define TextFrame2_put_MarginRight(This,MarginRight)	\
    ( (This)->lpVtbl -> put_MarginRight(This,MarginRight) ) 

#define TextFrame2_get_MarginTop(This,MarginTop)	\
    ( (This)->lpVtbl -> get_MarginTop(This,MarginTop) ) 

#define TextFrame2_put_MarginTop(This,MarginTop)	\
    ( (This)->lpVtbl -> put_MarginTop(This,MarginTop) ) 

#define TextFrame2_get_Orientation(This,Orientation)	\
    ( (This)->lpVtbl -> get_Orientation(This,Orientation) ) 

#define TextFrame2_put_Orientation(This,Orientation)	\
    ( (This)->lpVtbl -> put_Orientation(This,Orientation) ) 

#define TextFrame2_get_HorizontalAnchor(This,HorizontalAnchor)	\
    ( (This)->lpVtbl -> get_HorizontalAnchor(This,HorizontalAnchor) ) 

#define TextFrame2_put_HorizontalAnchor(This,HorizontalAnchor)	\
    ( (This)->lpVtbl -> put_HorizontalAnchor(This,HorizontalAnchor) ) 

#define TextFrame2_get_VerticalAnchor(This,VerticalAnchor)	\
    ( (This)->lpVtbl -> get_VerticalAnchor(This,VerticalAnchor) ) 

#define TextFrame2_put_VerticalAnchor(This,VerticalAnchor)	\
    ( (This)->lpVtbl -> put_VerticalAnchor(This,VerticalAnchor) ) 

#define TextFrame2_get_PathFormat(This,PathFormat)	\
    ( (This)->lpVtbl -> get_PathFormat(This,PathFormat) ) 

#define TextFrame2_put_PathFormat(This,PathFormat)	\
    ( (This)->lpVtbl -> put_PathFormat(This,PathFormat) ) 

#define TextFrame2_get_WarpFormat(This,WarpFormat)	\
    ( (This)->lpVtbl -> get_WarpFormat(This,WarpFormat) ) 

#define TextFrame2_put_WarpFormat(This,WarpFormat)	\
    ( (This)->lpVtbl -> put_WarpFormat(This,WarpFormat) ) 

#define TextFrame2_get_WordArtformat(This,WordArtformat)	\
    ( (This)->lpVtbl -> get_WordArtformat(This,WordArtformat) ) 

#define TextFrame2_put_WordArtformat(This,WordArtformat)	\
    ( (This)->lpVtbl -> put_WordArtformat(This,WordArtformat) ) 

#define TextFrame2_get_WordWrap(This,WordWrap)	\
    ( (This)->lpVtbl -> get_WordWrap(This,WordWrap) ) 

#define TextFrame2_put_WordWrap(This,WordWrap)	\
    ( (This)->lpVtbl -> put_WordWrap(This,WordWrap) ) 

#define TextFrame2_get_AutoSize(This,AutoSize)	\
    ( (This)->lpVtbl -> get_AutoSize(This,AutoSize) ) 

#define TextFrame2_put_AutoSize(This,AutoSize)	\
    ( (This)->lpVtbl -> put_AutoSize(This,AutoSize) ) 

#define TextFrame2_get_ThreeD(This,ThreeD)	\
    ( (This)->lpVtbl -> get_ThreeD(This,ThreeD) ) 

#define TextFrame2_get_HasText(This,pHasText)	\
    ( (This)->lpVtbl -> get_HasText(This,pHasText) ) 

#define TextFrame2_get_TextRange(This,Range)	\
    ( (This)->lpVtbl -> get_TextRange(This,Range) ) 

#define TextFrame2_get_Column(This,Column)	\
    ( (This)->lpVtbl -> get_Column(This,Column) ) 

#define TextFrame2_get_Ruler(This,Ruler)	\
    ( (This)->lpVtbl -> get_Ruler(This,Ruler) ) 

#define TextFrame2_DeleteText(This)	\
    ( (This)->lpVtbl -> DeleteText(This) ) 

#define TextFrame2_get_NoTextRotation(This,NoTextRotation)	\
    ( (This)->lpVtbl -> get_NoTextRotation(This,NoTextRotation) ) 

#define TextFrame2_put_NoTextRotation(This,NoTextRotation)	\
    ( (This)->lpVtbl -> put_NoTextRotation(This,NoTextRotation) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __TextFrame2_INTERFACE_DEFINED__ */


#ifndef __IFont_INTERFACE_DEFINED__
#define __IFont_INTERFACE_DEFINED__

/* interface IFont */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IFont;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002084D-0001-0000-C000-000000000046")
    IFont : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Background( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Background( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Bold( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Bold( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Color( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Color( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ColorIndex( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ColorIndex( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_FontStyle( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_FontStyle( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Italic( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Italic( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Name( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_OutlineFont( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_OutlineFont( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Shadow( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_Shadow( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Size( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Size( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Strikethrough( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Strikethrough( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Subscript( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Subscript( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Superscript( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Superscript( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Underline( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Underline( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ThemeColor( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ThemeColor( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TintAndShade( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_TintAndShade( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ThemeFont( 
            /* [retval][out] */ XlThemeFont *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ThemeFont( 
            /* [in] */ XlThemeFont RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IFontVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IFont * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IFont * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IFont * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IFont * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IFont * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IFont * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IFont * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IFont * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IFont * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IFont * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Background )( 
            IFont * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Background )( 
            IFont * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Bold )( 
            IFont * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Bold )( 
            IFont * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Color )( 
            IFont * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Color )( 
            IFont * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ColorIndex )( 
            IFont * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ColorIndex )( 
            IFont * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_FontStyle )( 
            IFont * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_FontStyle )( 
            IFont * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Italic )( 
            IFont * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Italic )( 
            IFont * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            IFont * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Name )( 
            IFont * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_OutlineFont )( 
            IFont * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_OutlineFont )( 
            IFont * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Shadow )( 
            IFont * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_Shadow )( 
            IFont * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Size )( 
            IFont * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Size )( 
            IFont * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Strikethrough )( 
            IFont * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Strikethrough )( 
            IFont * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Subscript )( 
            IFont * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Subscript )( 
            IFont * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Superscript )( 
            IFont * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Superscript )( 
            IFont * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Underline )( 
            IFont * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Underline )( 
            IFont * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ThemeColor )( 
            IFont * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ThemeColor )( 
            IFont * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TintAndShade )( 
            IFont * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_TintAndShade )( 
            IFont * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ThemeFont )( 
            IFont * This,
            /* [retval][out] */ XlThemeFont *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ThemeFont )( 
            IFont * This,
            /* [in] */ XlThemeFont RHS);
        
        END_INTERFACE
    } IFontVtbl;

    interface IFont
    {
        CONST_VTBL struct IFontVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IFont_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IFont_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IFont_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IFont_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IFont_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IFont_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IFont_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IFont_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IFont_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IFont_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IFont_get_Background(This,RHS)	\
    ( (This)->lpVtbl -> get_Background(This,RHS) ) 

#define IFont_put_Background(This,RHS)	\
    ( (This)->lpVtbl -> put_Background(This,RHS) ) 

#define IFont_get_Bold(This,RHS)	\
    ( (This)->lpVtbl -> get_Bold(This,RHS) ) 

#define IFont_put_Bold(This,RHS)	\
    ( (This)->lpVtbl -> put_Bold(This,RHS) ) 

#define IFont_get_Color(This,RHS)	\
    ( (This)->lpVtbl -> get_Color(This,RHS) ) 

#define IFont_put_Color(This,RHS)	\
    ( (This)->lpVtbl -> put_Color(This,RHS) ) 

#define IFont_get_ColorIndex(This,RHS)	\
    ( (This)->lpVtbl -> get_ColorIndex(This,RHS) ) 

#define IFont_put_ColorIndex(This,RHS)	\
    ( (This)->lpVtbl -> put_ColorIndex(This,RHS) ) 

#define IFont_get_FontStyle(This,RHS)	\
    ( (This)->lpVtbl -> get_FontStyle(This,RHS) ) 

#define IFont_put_FontStyle(This,RHS)	\
    ( (This)->lpVtbl -> put_FontStyle(This,RHS) ) 

#define IFont_get_Italic(This,RHS)	\
    ( (This)->lpVtbl -> get_Italic(This,RHS) ) 

#define IFont_put_Italic(This,RHS)	\
    ( (This)->lpVtbl -> put_Italic(This,RHS) ) 

#define IFont_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define IFont_put_Name(This,RHS)	\
    ( (This)->lpVtbl -> put_Name(This,RHS) ) 

#define IFont_get_OutlineFont(This,RHS)	\
    ( (This)->lpVtbl -> get_OutlineFont(This,RHS) ) 

#define IFont_put_OutlineFont(This,RHS)	\
    ( (This)->lpVtbl -> put_OutlineFont(This,RHS) ) 

#define IFont_get_Shadow(This,RHS)	\
    ( (This)->lpVtbl -> get_Shadow(This,RHS) ) 

#define IFont_put_Shadow(This,RHS)	\
    ( (This)->lpVtbl -> put_Shadow(This,RHS) ) 

#define IFont_get_Size(This,RHS)	\
    ( (This)->lpVtbl -> get_Size(This,RHS) ) 

#define IFont_put_Size(This,RHS)	\
    ( (This)->lpVtbl -> put_Size(This,RHS) ) 

#define IFont_get_Strikethrough(This,RHS)	\
    ( (This)->lpVtbl -> get_Strikethrough(This,RHS) ) 

#define IFont_put_Strikethrough(This,RHS)	\
    ( (This)->lpVtbl -> put_Strikethrough(This,RHS) ) 

#define IFont_get_Subscript(This,RHS)	\
    ( (This)->lpVtbl -> get_Subscript(This,RHS) ) 

#define IFont_put_Subscript(This,RHS)	\
    ( (This)->lpVtbl -> put_Subscript(This,RHS) ) 

#define IFont_get_Superscript(This,RHS)	\
    ( (This)->lpVtbl -> get_Superscript(This,RHS) ) 

#define IFont_put_Superscript(This,RHS)	\
    ( (This)->lpVtbl -> put_Superscript(This,RHS) ) 

#define IFont_get_Underline(This,RHS)	\
    ( (This)->lpVtbl -> get_Underline(This,RHS) ) 

#define IFont_put_Underline(This,RHS)	\
    ( (This)->lpVtbl -> put_Underline(This,RHS) ) 

#define IFont_get_ThemeColor(This,RHS)	\
    ( (This)->lpVtbl -> get_ThemeColor(This,RHS) ) 

#define IFont_put_ThemeColor(This,RHS)	\
    ( (This)->lpVtbl -> put_ThemeColor(This,RHS) ) 

#define IFont_get_TintAndShade(This,RHS)	\
    ( (This)->lpVtbl -> get_TintAndShade(This,RHS) ) 

#define IFont_put_TintAndShade(This,RHS)	\
    ( (This)->lpVtbl -> put_TintAndShade(This,RHS) ) 

#define IFont_get_ThemeFont(This,RHS)	\
    ( (This)->lpVtbl -> get_ThemeFont(This,RHS) ) 

#define IFont_put_ThemeFont(This,RHS)	\
    ( (This)->lpVtbl -> put_ThemeFont(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IFont_INTERFACE_DEFINED__ */


#ifndef __IWindow_INTERFACE_DEFINED__
#define __IWindow_INTERFACE_DEFINED__

/* interface IWindow */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IWindow;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00020893-0001-0000-C000-000000000046")
    IWindow : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Activate( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ActivateNext( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ActivatePrevious( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ActiveCell( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ActiveChart( 
            /* [retval][out] */ Chart	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ActivePane( 
            /* [retval][out] */ Pane	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ActiveSheet( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Caption( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Caption( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Close( 
            /* [optional][in] */ VARIANT SaveChanges,
            /* [optional][in] */ VARIANT Filename,
            /* [optional][in] */ VARIANT RouteWorkbook,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DisplayFormulas( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DisplayFormulas( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DisplayGridlines( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DisplayGridlines( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DisplayHeadings( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DisplayHeadings( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DisplayHorizontalScrollBar( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DisplayHorizontalScrollBar( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DisplayOutline( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DisplayOutline( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get__DisplayRightToLeft( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put__DisplayRightToLeft( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DisplayVerticalScrollBar( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DisplayVerticalScrollBar( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DisplayWorkbookTabs( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DisplayWorkbookTabs( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DisplayZeros( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DisplayZeros( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_EnableResize( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_EnableResize( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_FreezePanes( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_FreezePanes( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_GridlineColor( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_GridlineColor( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_GridlineColorIndex( 
            /* [retval][out] */ XlColorIndex *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_GridlineColorIndex( 
            /* [in] */ XlColorIndex RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Height( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Height( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Index( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall LargeScroll( 
            /* [optional][in] */ VARIANT Down,
            /* [optional][in] */ VARIANT Up,
            /* [optional][in] */ VARIANT ToRight,
            /* [optional][in] */ VARIANT ToLeft,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Left( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Left( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall NewWindow( 
            /* [retval][out] */ Window	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_OnWindow( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_OnWindow( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Panes( 
            /* [retval][out] */ Panes	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall _PrintOut( 
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate,
            /* [optional][in] */ VARIANT PrToFileName,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall PrintPreview( 
            /* [optional][in] */ VARIANT EnableChanges,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RangeSelection( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ScrollColumn( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ScrollColumn( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ScrollRow( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ScrollRow( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ScrollWorkbookTabs( 
            /* [optional][in] */ VARIANT Sheets,
            /* [optional][in] */ VARIANT Position,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SelectedSheets( 
            /* [retval][out] */ Sheets **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Selection( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SmallScroll( 
            /* [optional][in] */ VARIANT Down,
            /* [optional][in] */ VARIANT Up,
            /* [optional][in] */ VARIANT ToRight,
            /* [optional][in] */ VARIANT ToLeft,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Split( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Split( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SplitColumn( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_SplitColumn( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SplitHorizontal( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_SplitHorizontal( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SplitRow( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_SplitRow( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SplitVertical( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_SplitVertical( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TabRatio( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_TabRatio( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Top( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Top( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Type( 
            /* [retval][out] */ XlWindowType *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_UsableHeight( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_UsableWidth( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Visible( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Visible( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_VisibleRange( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Width( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Width( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_WindowNumber( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_WindowState( 
            /* [retval][out] */ XlWindowState *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_WindowState( 
            /* [in] */ XlWindowState RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Zoom( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Zoom( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_View( 
            /* [retval][out] */ XlWindowView *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_View( 
            /* [in] */ XlWindowView RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DisplayRightToLeft( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DisplayRightToLeft( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall PointsToScreenPixelsX( 
            /* [in] */ long Points,
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall PointsToScreenPixelsY( 
            /* [in] */ long Points,
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall RangeFromPoint( 
            /* [in] */ long x,
            /* [in] */ long y,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ScrollIntoView( 
            /* [in] */ long Left,
            /* [in] */ long Top,
            /* [in] */ long Width,
            /* [in] */ long Height,
            /* [optional][in] */ VARIANT Start) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SheetViews( 
            /* [retval][out] */ SheetViews	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ActiveSheetView( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall PrintOut( 
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate,
            /* [optional][in] */ VARIANT PrToFileName,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DisplayRuler( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DisplayRuler( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AutoFilterDateGrouping( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AutoFilterDateGrouping( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DisplayWhitespace( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DisplayWhitespace( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Hwnd( 
            /* [retval][out] */ long *RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IWindowVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IWindow * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IWindow * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IWindow * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IWindow * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IWindow * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IWindow * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IWindow * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IWindow * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IWindow * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IWindow * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Activate )( 
            IWindow * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ActivateNext )( 
            IWindow * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ActivatePrevious )( 
            IWindow * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ActiveCell )( 
            IWindow * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ActiveChart )( 
            IWindow * This,
            /* [retval][out] */ Chart	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ActivePane )( 
            IWindow * This,
            /* [retval][out] */ Pane	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ActiveSheet )( 
            IWindow * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Caption )( 
            IWindow * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Caption )( 
            IWindow * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Close )( 
            IWindow * This,
            /* [optional][in] */ VARIANT SaveChanges,
            /* [optional][in] */ VARIANT Filename,
            /* [optional][in] */ VARIANT RouteWorkbook,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DisplayFormulas )( 
            IWindow * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DisplayFormulas )( 
            IWindow * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DisplayGridlines )( 
            IWindow * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DisplayGridlines )( 
            IWindow * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DisplayHeadings )( 
            IWindow * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DisplayHeadings )( 
            IWindow * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DisplayHorizontalScrollBar )( 
            IWindow * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DisplayHorizontalScrollBar )( 
            IWindow * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DisplayOutline )( 
            IWindow * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DisplayOutline )( 
            IWindow * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get__DisplayRightToLeft )( 
            IWindow * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put__DisplayRightToLeft )( 
            IWindow * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DisplayVerticalScrollBar )( 
            IWindow * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DisplayVerticalScrollBar )( 
            IWindow * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DisplayWorkbookTabs )( 
            IWindow * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DisplayWorkbookTabs )( 
            IWindow * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DisplayZeros )( 
            IWindow * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DisplayZeros )( 
            IWindow * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_EnableResize )( 
            IWindow * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_EnableResize )( 
            IWindow * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_FreezePanes )( 
            IWindow * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_FreezePanes )( 
            IWindow * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_GridlineColor )( 
            IWindow * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_GridlineColor )( 
            IWindow * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_GridlineColorIndex )( 
            IWindow * This,
            /* [retval][out] */ XlColorIndex *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_GridlineColorIndex )( 
            IWindow * This,
            /* [in] */ XlColorIndex RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Height )( 
            IWindow * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Height )( 
            IWindow * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Index )( 
            IWindow * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *LargeScroll )( 
            IWindow * This,
            /* [optional][in] */ VARIANT Down,
            /* [optional][in] */ VARIANT Up,
            /* [optional][in] */ VARIANT ToRight,
            /* [optional][in] */ VARIANT ToLeft,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Left )( 
            IWindow * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Left )( 
            IWindow * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *NewWindow )( 
            IWindow * This,
            /* [retval][out] */ Window	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_OnWindow )( 
            IWindow * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_OnWindow )( 
            IWindow * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Panes )( 
            IWindow * This,
            /* [retval][out] */ Panes	**RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *_PrintOut )( 
            IWindow * This,
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate,
            /* [optional][in] */ VARIANT PrToFileName,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *PrintPreview )( 
            IWindow * This,
            /* [optional][in] */ VARIANT EnableChanges,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RangeSelection )( 
            IWindow * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ScrollColumn )( 
            IWindow * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ScrollColumn )( 
            IWindow * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ScrollRow )( 
            IWindow * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ScrollRow )( 
            IWindow * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ScrollWorkbookTabs )( 
            IWindow * This,
            /* [optional][in] */ VARIANT Sheets,
            /* [optional][in] */ VARIANT Position,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SelectedSheets )( 
            IWindow * This,
            /* [retval][out] */ Sheets **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Selection )( 
            IWindow * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SmallScroll )( 
            IWindow * This,
            /* [optional][in] */ VARIANT Down,
            /* [optional][in] */ VARIANT Up,
            /* [optional][in] */ VARIANT ToRight,
            /* [optional][in] */ VARIANT ToLeft,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Split )( 
            IWindow * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Split )( 
            IWindow * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SplitColumn )( 
            IWindow * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_SplitColumn )( 
            IWindow * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SplitHorizontal )( 
            IWindow * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_SplitHorizontal )( 
            IWindow * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SplitRow )( 
            IWindow * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_SplitRow )( 
            IWindow * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SplitVertical )( 
            IWindow * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_SplitVertical )( 
            IWindow * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TabRatio )( 
            IWindow * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_TabRatio )( 
            IWindow * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Top )( 
            IWindow * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Top )( 
            IWindow * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Type )( 
            IWindow * This,
            /* [retval][out] */ XlWindowType *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_UsableHeight )( 
            IWindow * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_UsableWidth )( 
            IWindow * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Visible )( 
            IWindow * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Visible )( 
            IWindow * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_VisibleRange )( 
            IWindow * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Width )( 
            IWindow * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Width )( 
            IWindow * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_WindowNumber )( 
            IWindow * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_WindowState )( 
            IWindow * This,
            /* [retval][out] */ XlWindowState *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_WindowState )( 
            IWindow * This,
            /* [in] */ XlWindowState RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Zoom )( 
            IWindow * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Zoom )( 
            IWindow * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_View )( 
            IWindow * This,
            /* [retval][out] */ XlWindowView *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_View )( 
            IWindow * This,
            /* [in] */ XlWindowView RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DisplayRightToLeft )( 
            IWindow * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DisplayRightToLeft )( 
            IWindow * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *PointsToScreenPixelsX )( 
            IWindow * This,
            /* [in] */ long Points,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *PointsToScreenPixelsY )( 
            IWindow * This,
            /* [in] */ long Points,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *RangeFromPoint )( 
            IWindow * This,
            /* [in] */ long x,
            /* [in] */ long y,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ScrollIntoView )( 
            IWindow * This,
            /* [in] */ long Left,
            /* [in] */ long Top,
            /* [in] */ long Width,
            /* [in] */ long Height,
            /* [optional][in] */ VARIANT Start);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SheetViews )( 
            IWindow * This,
            /* [retval][out] */ SheetViews	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ActiveSheetView )( 
            IWindow * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *PrintOut )( 
            IWindow * This,
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate,
            /* [optional][in] */ VARIANT PrToFileName,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DisplayRuler )( 
            IWindow * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DisplayRuler )( 
            IWindow * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AutoFilterDateGrouping )( 
            IWindow * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AutoFilterDateGrouping )( 
            IWindow * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DisplayWhitespace )( 
            IWindow * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DisplayWhitespace )( 
            IWindow * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Hwnd )( 
            IWindow * This,
            /* [retval][out] */ long *RHS);
        
        END_INTERFACE
    } IWindowVtbl;

    interface IWindow
    {
        CONST_VTBL struct IWindowVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IWindow_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IWindow_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IWindow_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IWindow_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IWindow_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IWindow_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IWindow_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IWindow_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IWindow_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IWindow_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IWindow_Activate(This,RHS)	\
    ( (This)->lpVtbl -> Activate(This,RHS) ) 

#define IWindow_ActivateNext(This,RHS)	\
    ( (This)->lpVtbl -> ActivateNext(This,RHS) ) 

#define IWindow_ActivatePrevious(This,RHS)	\
    ( (This)->lpVtbl -> ActivatePrevious(This,RHS) ) 

#define IWindow_get_ActiveCell(This,RHS)	\
    ( (This)->lpVtbl -> get_ActiveCell(This,RHS) ) 

#define IWindow_get_ActiveChart(This,RHS)	\
    ( (This)->lpVtbl -> get_ActiveChart(This,RHS) ) 

#define IWindow_get_ActivePane(This,RHS)	\
    ( (This)->lpVtbl -> get_ActivePane(This,RHS) ) 

#define IWindow_get_ActiveSheet(This,RHS)	\
    ( (This)->lpVtbl -> get_ActiveSheet(This,RHS) ) 

#define IWindow_get_Caption(This,RHS)	\
    ( (This)->lpVtbl -> get_Caption(This,RHS) ) 

#define IWindow_put_Caption(This,RHS)	\
    ( (This)->lpVtbl -> put_Caption(This,RHS) ) 

#define IWindow_Close(This,SaveChanges,Filename,RouteWorkbook,RHS)	\
    ( (This)->lpVtbl -> Close(This,SaveChanges,Filename,RouteWorkbook,RHS) ) 

#define IWindow_get_DisplayFormulas(This,RHS)	\
    ( (This)->lpVtbl -> get_DisplayFormulas(This,RHS) ) 

#define IWindow_put_DisplayFormulas(This,RHS)	\
    ( (This)->lpVtbl -> put_DisplayFormulas(This,RHS) ) 

#define IWindow_get_DisplayGridlines(This,RHS)	\
    ( (This)->lpVtbl -> get_DisplayGridlines(This,RHS) ) 

#define IWindow_put_DisplayGridlines(This,RHS)	\
    ( (This)->lpVtbl -> put_DisplayGridlines(This,RHS) ) 

#define IWindow_get_DisplayHeadings(This,RHS)	\
    ( (This)->lpVtbl -> get_DisplayHeadings(This,RHS) ) 

#define IWindow_put_DisplayHeadings(This,RHS)	\
    ( (This)->lpVtbl -> put_DisplayHeadings(This,RHS) ) 

#define IWindow_get_DisplayHorizontalScrollBar(This,RHS)	\
    ( (This)->lpVtbl -> get_DisplayHorizontalScrollBar(This,RHS) ) 

#define IWindow_put_DisplayHorizontalScrollBar(This,RHS)	\
    ( (This)->lpVtbl -> put_DisplayHorizontalScrollBar(This,RHS) ) 

#define IWindow_get_DisplayOutline(This,RHS)	\
    ( (This)->lpVtbl -> get_DisplayOutline(This,RHS) ) 

#define IWindow_put_DisplayOutline(This,RHS)	\
    ( (This)->lpVtbl -> put_DisplayOutline(This,RHS) ) 

#define IWindow_get__DisplayRightToLeft(This,RHS)	\
    ( (This)->lpVtbl -> get__DisplayRightToLeft(This,RHS) ) 

#define IWindow_put__DisplayRightToLeft(This,RHS)	\
    ( (This)->lpVtbl -> put__DisplayRightToLeft(This,RHS) ) 

#define IWindow_get_DisplayVerticalScrollBar(This,RHS)	\
    ( (This)->lpVtbl -> get_DisplayVerticalScrollBar(This,RHS) ) 

#define IWindow_put_DisplayVerticalScrollBar(This,RHS)	\
    ( (This)->lpVtbl -> put_DisplayVerticalScrollBar(This,RHS) ) 

#define IWindow_get_DisplayWorkbookTabs(This,RHS)	\
    ( (This)->lpVtbl -> get_DisplayWorkbookTabs(This,RHS) ) 

#define IWindow_put_DisplayWorkbookTabs(This,RHS)	\
    ( (This)->lpVtbl -> put_DisplayWorkbookTabs(This,RHS) ) 

#define IWindow_get_DisplayZeros(This,RHS)	\
    ( (This)->lpVtbl -> get_DisplayZeros(This,RHS) ) 

#define IWindow_put_DisplayZeros(This,RHS)	\
    ( (This)->lpVtbl -> put_DisplayZeros(This,RHS) ) 

#define IWindow_get_EnableResize(This,RHS)	\
    ( (This)->lpVtbl -> get_EnableResize(This,RHS) ) 

#define IWindow_put_EnableResize(This,RHS)	\
    ( (This)->lpVtbl -> put_EnableResize(This,RHS) ) 

#define IWindow_get_FreezePanes(This,RHS)	\
    ( (This)->lpVtbl -> get_FreezePanes(This,RHS) ) 

#define IWindow_put_FreezePanes(This,RHS)	\
    ( (This)->lpVtbl -> put_FreezePanes(This,RHS) ) 

#define IWindow_get_GridlineColor(This,RHS)	\
    ( (This)->lpVtbl -> get_GridlineColor(This,RHS) ) 

#define IWindow_put_GridlineColor(This,RHS)	\
    ( (This)->lpVtbl -> put_GridlineColor(This,RHS) ) 

#define IWindow_get_GridlineColorIndex(This,RHS)	\
    ( (This)->lpVtbl -> get_GridlineColorIndex(This,RHS) ) 

#define IWindow_put_GridlineColorIndex(This,RHS)	\
    ( (This)->lpVtbl -> put_GridlineColorIndex(This,RHS) ) 

#define IWindow_get_Height(This,RHS)	\
    ( (This)->lpVtbl -> get_Height(This,RHS) ) 

#define IWindow_put_Height(This,RHS)	\
    ( (This)->lpVtbl -> put_Height(This,RHS) ) 

#define IWindow_get_Index(This,RHS)	\
    ( (This)->lpVtbl -> get_Index(This,RHS) ) 

#define IWindow_LargeScroll(This,Down,Up,ToRight,ToLeft,RHS)	\
    ( (This)->lpVtbl -> LargeScroll(This,Down,Up,ToRight,ToLeft,RHS) ) 

#define IWindow_get_Left(This,RHS)	\
    ( (This)->lpVtbl -> get_Left(This,RHS) ) 

#define IWindow_put_Left(This,RHS)	\
    ( (This)->lpVtbl -> put_Left(This,RHS) ) 

#define IWindow_NewWindow(This,RHS)	\
    ( (This)->lpVtbl -> NewWindow(This,RHS) ) 

#define IWindow_get_OnWindow(This,RHS)	\
    ( (This)->lpVtbl -> get_OnWindow(This,RHS) ) 

#define IWindow_put_OnWindow(This,RHS)	\
    ( (This)->lpVtbl -> put_OnWindow(This,RHS) ) 

#define IWindow_get_Panes(This,RHS)	\
    ( (This)->lpVtbl -> get_Panes(This,RHS) ) 

#define IWindow__PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate,PrToFileName,RHS)	\
    ( (This)->lpVtbl -> _PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate,PrToFileName,RHS) ) 

#define IWindow_PrintPreview(This,EnableChanges,RHS)	\
    ( (This)->lpVtbl -> PrintPreview(This,EnableChanges,RHS) ) 

#define IWindow_get_RangeSelection(This,RHS)	\
    ( (This)->lpVtbl -> get_RangeSelection(This,RHS) ) 

#define IWindow_get_ScrollColumn(This,RHS)	\
    ( (This)->lpVtbl -> get_ScrollColumn(This,RHS) ) 

#define IWindow_put_ScrollColumn(This,RHS)	\
    ( (This)->lpVtbl -> put_ScrollColumn(This,RHS) ) 

#define IWindow_get_ScrollRow(This,RHS)	\
    ( (This)->lpVtbl -> get_ScrollRow(This,RHS) ) 

#define IWindow_put_ScrollRow(This,RHS)	\
    ( (This)->lpVtbl -> put_ScrollRow(This,RHS) ) 

#define IWindow_ScrollWorkbookTabs(This,Sheets,Position,RHS)	\
    ( (This)->lpVtbl -> ScrollWorkbookTabs(This,Sheets,Position,RHS) ) 

#define IWindow_get_SelectedSheets(This,RHS)	\
    ( (This)->lpVtbl -> get_SelectedSheets(This,RHS) ) 

#define IWindow_get_Selection(This,RHS)	\
    ( (This)->lpVtbl -> get_Selection(This,RHS) ) 

#define IWindow_SmallScroll(This,Down,Up,ToRight,ToLeft,RHS)	\
    ( (This)->lpVtbl -> SmallScroll(This,Down,Up,ToRight,ToLeft,RHS) ) 

#define IWindow_get_Split(This,RHS)	\
    ( (This)->lpVtbl -> get_Split(This,RHS) ) 

#define IWindow_put_Split(This,RHS)	\
    ( (This)->lpVtbl -> put_Split(This,RHS) ) 

#define IWindow_get_SplitColumn(This,RHS)	\
    ( (This)->lpVtbl -> get_SplitColumn(This,RHS) ) 

#define IWindow_put_SplitColumn(This,RHS)	\
    ( (This)->lpVtbl -> put_SplitColumn(This,RHS) ) 

#define IWindow_get_SplitHorizontal(This,RHS)	\
    ( (This)->lpVtbl -> get_SplitHorizontal(This,RHS) ) 

#define IWindow_put_SplitHorizontal(This,RHS)	\
    ( (This)->lpVtbl -> put_SplitHorizontal(This,RHS) ) 

#define IWindow_get_SplitRow(This,RHS)	\
    ( (This)->lpVtbl -> get_SplitRow(This,RHS) ) 

#define IWindow_put_SplitRow(This,RHS)	\
    ( (This)->lpVtbl -> put_SplitRow(This,RHS) ) 

#define IWindow_get_SplitVertical(This,RHS)	\
    ( (This)->lpVtbl -> get_SplitVertical(This,RHS) ) 

#define IWindow_put_SplitVertical(This,RHS)	\
    ( (This)->lpVtbl -> put_SplitVertical(This,RHS) ) 

#define IWindow_get_TabRatio(This,RHS)	\
    ( (This)->lpVtbl -> get_TabRatio(This,RHS) ) 

#define IWindow_put_TabRatio(This,RHS)	\
    ( (This)->lpVtbl -> put_TabRatio(This,RHS) ) 

#define IWindow_get_Top(This,RHS)	\
    ( (This)->lpVtbl -> get_Top(This,RHS) ) 

#define IWindow_put_Top(This,RHS)	\
    ( (This)->lpVtbl -> put_Top(This,RHS) ) 

#define IWindow_get_Type(This,RHS)	\
    ( (This)->lpVtbl -> get_Type(This,RHS) ) 

#define IWindow_get_UsableHeight(This,RHS)	\
    ( (This)->lpVtbl -> get_UsableHeight(This,RHS) ) 

#define IWindow_get_UsableWidth(This,RHS)	\
    ( (This)->lpVtbl -> get_UsableWidth(This,RHS) ) 

#define IWindow_get_Visible(This,RHS)	\
    ( (This)->lpVtbl -> get_Visible(This,RHS) ) 

#define IWindow_put_Visible(This,RHS)	\
    ( (This)->lpVtbl -> put_Visible(This,RHS) ) 

#define IWindow_get_VisibleRange(This,RHS)	\
    ( (This)->lpVtbl -> get_VisibleRange(This,RHS) ) 

#define IWindow_get_Width(This,RHS)	\
    ( (This)->lpVtbl -> get_Width(This,RHS) ) 

#define IWindow_put_Width(This,RHS)	\
    ( (This)->lpVtbl -> put_Width(This,RHS) ) 

#define IWindow_get_WindowNumber(This,RHS)	\
    ( (This)->lpVtbl -> get_WindowNumber(This,RHS) ) 

#define IWindow_get_WindowState(This,RHS)	\
    ( (This)->lpVtbl -> get_WindowState(This,RHS) ) 

#define IWindow_put_WindowState(This,RHS)	\
    ( (This)->lpVtbl -> put_WindowState(This,RHS) ) 

#define IWindow_get_Zoom(This,RHS)	\
    ( (This)->lpVtbl -> get_Zoom(This,RHS) ) 

#define IWindow_put_Zoom(This,RHS)	\
    ( (This)->lpVtbl -> put_Zoom(This,RHS) ) 

#define IWindow_get_View(This,RHS)	\
    ( (This)->lpVtbl -> get_View(This,RHS) ) 

#define IWindow_put_View(This,RHS)	\
    ( (This)->lpVtbl -> put_View(This,RHS) ) 

#define IWindow_get_DisplayRightToLeft(This,RHS)	\
    ( (This)->lpVtbl -> get_DisplayRightToLeft(This,RHS) ) 

#define IWindow_put_DisplayRightToLeft(This,RHS)	\
    ( (This)->lpVtbl -> put_DisplayRightToLeft(This,RHS) ) 

#define IWindow_PointsToScreenPixelsX(This,Points,RHS)	\
    ( (This)->lpVtbl -> PointsToScreenPixelsX(This,Points,RHS) ) 

#define IWindow_PointsToScreenPixelsY(This,Points,RHS)	\
    ( (This)->lpVtbl -> PointsToScreenPixelsY(This,Points,RHS) ) 

#define IWindow_RangeFromPoint(This,x,y,RHS)	\
    ( (This)->lpVtbl -> RangeFromPoint(This,x,y,RHS) ) 

#define IWindow_ScrollIntoView(This,Left,Top,Width,Height,Start)	\
    ( (This)->lpVtbl -> ScrollIntoView(This,Left,Top,Width,Height,Start) ) 

#define IWindow_get_SheetViews(This,RHS)	\
    ( (This)->lpVtbl -> get_SheetViews(This,RHS) ) 

#define IWindow_get_ActiveSheetView(This,RHS)	\
    ( (This)->lpVtbl -> get_ActiveSheetView(This,RHS) ) 

#define IWindow_PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate,PrToFileName,RHS)	\
    ( (This)->lpVtbl -> PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate,PrToFileName,RHS) ) 

#define IWindow_get_DisplayRuler(This,RHS)	\
    ( (This)->lpVtbl -> get_DisplayRuler(This,RHS) ) 

#define IWindow_put_DisplayRuler(This,RHS)	\
    ( (This)->lpVtbl -> put_DisplayRuler(This,RHS) ) 

#define IWindow_get_AutoFilterDateGrouping(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoFilterDateGrouping(This,RHS) ) 

#define IWindow_put_AutoFilterDateGrouping(This,RHS)	\
    ( (This)->lpVtbl -> put_AutoFilterDateGrouping(This,RHS) ) 

#define IWindow_get_DisplayWhitespace(This,RHS)	\
    ( (This)->lpVtbl -> get_DisplayWhitespace(This,RHS) ) 

#define IWindow_put_DisplayWhitespace(This,RHS)	\
    ( (This)->lpVtbl -> put_DisplayWhitespace(This,RHS) ) 

#define IWindow_get_Hwnd(This,RHS)	\
    ( (This)->lpVtbl -> get_Hwnd(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IWindow_INTERFACE_DEFINED__ */


#ifndef __IWindows_INTERFACE_DEFINED__
#define __IWindows_INTERFACE_DEFINED__

/* interface IWindows */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IWindows;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00020892-0001-0000-C000-000000000046")
    IWindows : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Arrange( 
            /* [defaultvalue][optional][in] */ XlArrangeStyle ArrangeStyle,
            /* [optional][in] */ VARIANT ActiveWorkbook,
            /* [optional][in] */ VARIANT SyncHorizontal,
            /* [optional][in] */ VARIANT SyncVertical,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Window	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Window	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CompareSideBySideWith( 
            /* [in] */ VARIANT WindowName,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall BreakSideBySide( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SyncScrollingSideBySide( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_SyncScrollingSideBySide( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ResetPositionsSideBySide( void) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IWindowsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IWindows * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IWindows * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IWindows * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IWindows * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IWindows * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IWindows * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IWindows * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IWindows * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IWindows * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IWindows * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Arrange )( 
            IWindows * This,
            /* [defaultvalue][optional][in] */ XlArrangeStyle ArrangeStyle,
            /* [optional][in] */ VARIANT ActiveWorkbook,
            /* [optional][in] */ VARIANT SyncHorizontal,
            /* [optional][in] */ VARIANT SyncVertical,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IWindows * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Item )( 
            IWindows * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Window	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            IWindows * This,
            /* [retval][out] */ IUnknown **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IWindows * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Window	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CompareSideBySideWith )( 
            IWindows * This,
            /* [in] */ VARIANT WindowName,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *BreakSideBySide )( 
            IWindows * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SyncScrollingSideBySide )( 
            IWindows * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_SyncScrollingSideBySide )( 
            IWindows * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ResetPositionsSideBySide )( 
            IWindows * This);
        
        END_INTERFACE
    } IWindowsVtbl;

    interface IWindows
    {
        CONST_VTBL struct IWindowsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IWindows_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IWindows_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IWindows_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IWindows_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IWindows_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IWindows_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IWindows_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IWindows_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IWindows_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IWindows_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IWindows_Arrange(This,ArrangeStyle,ActiveWorkbook,SyncHorizontal,SyncVertical,RHS)	\
    ( (This)->lpVtbl -> Arrange(This,ArrangeStyle,ActiveWorkbook,SyncHorizontal,SyncVertical,RHS) ) 

#define IWindows_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IWindows_get_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Item(This,Index,RHS) ) 

#define IWindows_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#define IWindows_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define IWindows_CompareSideBySideWith(This,WindowName,RHS)	\
    ( (This)->lpVtbl -> CompareSideBySideWith(This,WindowName,RHS) ) 

#define IWindows_BreakSideBySide(This,RHS)	\
    ( (This)->lpVtbl -> BreakSideBySide(This,RHS) ) 

#define IWindows_get_SyncScrollingSideBySide(This,RHS)	\
    ( (This)->lpVtbl -> get_SyncScrollingSideBySide(This,RHS) ) 

#define IWindows_put_SyncScrollingSideBySide(This,RHS)	\
    ( (This)->lpVtbl -> put_SyncScrollingSideBySide(This,RHS) ) 

#define IWindows_ResetPositionsSideBySide(This)	\
    ( (This)->lpVtbl -> ResetPositionsSideBySide(This) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IWindows_INTERFACE_DEFINED__ */


#ifndef __IAppEvents_INTERFACE_DEFINED__
#define __IAppEvents_INTERFACE_DEFINED__

/* interface IAppEvents */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IAppEvents;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024413-0001-0000-C000-000000000046")
    IAppEvents : public IDispatch
    {
    public:
        virtual /* [helpcontext][id] */ HRESULT __stdcall NewWorkbook( 
            /* [in] */ Workbook	*Wb) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SheetSelectionChange( 
            /* [in] */ IDispatch *Sh,
            /* [in] */ Range	*Target) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SheetBeforeDoubleClick( 
            /* [in] */ IDispatch *Sh,
            /* [in] */ Range	*Target,
            /* [out][in] */ VARIANT_BOOL *Cancel) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SheetBeforeRightClick( 
            /* [in] */ IDispatch *Sh,
            /* [in] */ Range	*Target,
            /* [out][in] */ VARIANT_BOOL *Cancel) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SheetActivate( 
            /* [in] */ IDispatch *Sh) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SheetDeactivate( 
            /* [in] */ IDispatch *Sh) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SheetCalculate( 
            /* [in] */ IDispatch *Sh) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SheetChange( 
            /* [in] */ IDispatch *Sh,
            /* [in] */ Range	*Target) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall WorkbookOpen( 
            /* [in] */ Workbook	*Wb) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall WorkbookActivate( 
            /* [in] */ Workbook	*Wb) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall WorkbookDeactivate( 
            /* [in] */ Workbook	*Wb) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall WorkbookBeforeClose( 
            /* [in] */ Workbook	*Wb,
            /* [out][in] */ VARIANT_BOOL *Cancel) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall WorkbookBeforeSave( 
            /* [in] */ Workbook	*Wb,
            /* [in] */ VARIANT_BOOL SaveAsUI,
            /* [out][in] */ VARIANT_BOOL *Cancel) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall WorkbookBeforePrint( 
            /* [in] */ Workbook	*Wb,
            /* [out][in] */ VARIANT_BOOL *Cancel) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall WorkbookNewSheet( 
            /* [in] */ Workbook	*Wb,
            /* [in] */ IDispatch *Sh) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall WorkbookAddinInstall( 
            /* [in] */ Workbook	*Wb) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall WorkbookAddinUninstall( 
            /* [in] */ Workbook	*Wb) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall WindowResize( 
            /* [in] */ Workbook	*Wb,
            /* [in] */ Window	*Wn) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall WindowActivate( 
            /* [in] */ Workbook	*Wb,
            /* [in] */ Window	*Wn) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall WindowDeactivate( 
            /* [in] */ Workbook	*Wb,
            /* [in] */ Window	*Wn) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SheetFollowHyperlink( 
            /* [in] */ IDispatch *Sh,
            /* [in] */ Hyperlink	*Target) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SheetPivotTableUpdate( 
            /* [in] */ IDispatch *Sh,
            /* [in] */ PivotTable	*Target) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall WorkbookPivotTableCloseConnection( 
            /* [in] */ Workbook	*Wb,
            /* [in] */ PivotTable	*Target) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall WorkbookPivotTableOpenConnection( 
            /* [in] */ Workbook	*Wb,
            /* [in] */ PivotTable	*Target) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall WorkbookSync( 
            /* [in] */ Workbook	*Wb,
            /* [in] */ MsoSyncEventType SyncEventType) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall WorkbookBeforeXmlImport( 
            /* [in] */ Workbook	*Wb,
            /* [in] */ XmlMap	*Map,
            /* [in] */ BSTR Url,
            /* [in] */ VARIANT_BOOL IsRefresh,
            /* [out][in] */ VARIANT_BOOL *Cancel) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall WorkbookAfterXmlImport( 
            /* [in] */ Workbook	*Wb,
            /* [in] */ XmlMap	*Map,
            /* [in] */ VARIANT_BOOL IsRefresh,
            /* [in] */ XlXmlImportResult Result) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall WorkbookBeforeXmlExport( 
            /* [in] */ Workbook	*Wb,
            /* [in] */ XmlMap	*Map,
            /* [in] */ BSTR Url,
            /* [out][in] */ VARIANT_BOOL *Cancel) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall WorkbookAfterXmlExport( 
            /* [in] */ Workbook	*Wb,
            /* [in] */ XmlMap	*Map,
            /* [in] */ BSTR Url,
            /* [in] */ XlXmlExportResult Result) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall WorkbookRowsetComplete( 
            /* [in] */ Workbook	*Wb,
            /* [in] */ BSTR Description,
            /* [in] */ BSTR Sheet,
            /* [in] */ VARIANT_BOOL Success) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall AfterCalculate( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SheetPivotTableAfterValueChange( 
            /* [in] */ IDispatch *Sh,
            /* [in] */ PivotTable	*TargetPivotTable,
            /* [in] */ Range	*TargetRange) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SheetPivotTableBeforeAllocateChanges( 
            /* [in] */ IDispatch *Sh,
            /* [in] */ PivotTable	*TargetPivotTable,
            /* [in] */ long ValueChangeStart,
            /* [in] */ long ValueChangeEnd,
            /* [out][in] */ VARIANT_BOOL *Cancel) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SheetPivotTableBeforeCommitChanges( 
            /* [in] */ IDispatch *Sh,
            /* [in] */ PivotTable	*TargetPivotTable,
            /* [in] */ long ValueChangeStart,
            /* [in] */ long ValueChangeEnd,
            /* [out][in] */ VARIANT_BOOL *Cancel) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SheetPivotTableBeforeDiscardChanges( 
            /* [in] */ IDispatch *Sh,
            /* [in] */ PivotTable	*TargetPivotTable,
            /* [in] */ long ValueChangeStart,
            /* [in] */ long ValueChangeEnd) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ProtectedViewWindowOpen( 
            /* [in] */ ProtectedViewWindow	*Pvw) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ProtectedViewWindowBeforeEdit( 
            /* [in] */ ProtectedViewWindow	*Pvw,
            /* [out][in] */ VARIANT_BOOL *Cancel) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ProtectedViewWindowBeforeClose( 
            /* [in] */ ProtectedViewWindow	*Pvw,
            /* [in] */ XlProtectedViewCloseReason Reason,
            /* [out][in] */ VARIANT_BOOL *Cancel) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ProtectedViewWindowResize( 
            /* [in] */ ProtectedViewWindow	*Pvw) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ProtectedViewWindowActivate( 
            /* [in] */ ProtectedViewWindow	*Pvw) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ProtectedViewWindowDeactivate( 
            /* [in] */ ProtectedViewWindow	*Pvw) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall WorkbookAfterSave( 
            /* [in] */ Workbook	*Wb,
            /* [in] */ VARIANT_BOOL Success) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall WorkbookNewChart( 
            /* [in] */ Workbook	*Wb,
            /* [in] */ Chart	*Ch) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SheetLensGalleryRenderComplete( 
            /* [in] */ IDispatch *Sh) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SheetTableUpdate( 
            /* [in] */ IDispatch *Sh,
            /* [in] */ TableObject	*Target) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall WorkbookModelChange( 
            /* [in] */ Workbook	*Wb,
            /* [in] */ ModelChanges	*Changes) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SheetBeforeDelete( 
            /* [in] */ IDispatch *Sh) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IAppEventsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IAppEvents * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IAppEvents * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IAppEvents * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IAppEvents * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IAppEvents * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IAppEvents * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IAppEvents * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *NewWorkbook )( 
            IAppEvents * This,
            /* [in] */ Workbook	*Wb);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SheetSelectionChange )( 
            IAppEvents * This,
            /* [in] */ IDispatch *Sh,
            /* [in] */ Range	*Target);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SheetBeforeDoubleClick )( 
            IAppEvents * This,
            /* [in] */ IDispatch *Sh,
            /* [in] */ Range	*Target,
            /* [out][in] */ VARIANT_BOOL *Cancel);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SheetBeforeRightClick )( 
            IAppEvents * This,
            /* [in] */ IDispatch *Sh,
            /* [in] */ Range	*Target,
            /* [out][in] */ VARIANT_BOOL *Cancel);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SheetActivate )( 
            IAppEvents * This,
            /* [in] */ IDispatch *Sh);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SheetDeactivate )( 
            IAppEvents * This,
            /* [in] */ IDispatch *Sh);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SheetCalculate )( 
            IAppEvents * This,
            /* [in] */ IDispatch *Sh);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SheetChange )( 
            IAppEvents * This,
            /* [in] */ IDispatch *Sh,
            /* [in] */ Range	*Target);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *WorkbookOpen )( 
            IAppEvents * This,
            /* [in] */ Workbook	*Wb);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *WorkbookActivate )( 
            IAppEvents * This,
            /* [in] */ Workbook	*Wb);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *WorkbookDeactivate )( 
            IAppEvents * This,
            /* [in] */ Workbook	*Wb);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *WorkbookBeforeClose )( 
            IAppEvents * This,
            /* [in] */ Workbook	*Wb,
            /* [out][in] */ VARIANT_BOOL *Cancel);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *WorkbookBeforeSave )( 
            IAppEvents * This,
            /* [in] */ Workbook	*Wb,
            /* [in] */ VARIANT_BOOL SaveAsUI,
            /* [out][in] */ VARIANT_BOOL *Cancel);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *WorkbookBeforePrint )( 
            IAppEvents * This,
            /* [in] */ Workbook	*Wb,
            /* [out][in] */ VARIANT_BOOL *Cancel);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *WorkbookNewSheet )( 
            IAppEvents * This,
            /* [in] */ Workbook	*Wb,
            /* [in] */ IDispatch *Sh);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *WorkbookAddinInstall )( 
            IAppEvents * This,
            /* [in] */ Workbook	*Wb);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *WorkbookAddinUninstall )( 
            IAppEvents * This,
            /* [in] */ Workbook	*Wb);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *WindowResize )( 
            IAppEvents * This,
            /* [in] */ Workbook	*Wb,
            /* [in] */ Window	*Wn);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *WindowActivate )( 
            IAppEvents * This,
            /* [in] */ Workbook	*Wb,
            /* [in] */ Window	*Wn);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *WindowDeactivate )( 
            IAppEvents * This,
            /* [in] */ Workbook	*Wb,
            /* [in] */ Window	*Wn);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SheetFollowHyperlink )( 
            IAppEvents * This,
            /* [in] */ IDispatch *Sh,
            /* [in] */ Hyperlink	*Target);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SheetPivotTableUpdate )( 
            IAppEvents * This,
            /* [in] */ IDispatch *Sh,
            /* [in] */ PivotTable	*Target);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *WorkbookPivotTableCloseConnection )( 
            IAppEvents * This,
            /* [in] */ Workbook	*Wb,
            /* [in] */ PivotTable	*Target);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *WorkbookPivotTableOpenConnection )( 
            IAppEvents * This,
            /* [in] */ Workbook	*Wb,
            /* [in] */ PivotTable	*Target);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *WorkbookSync )( 
            IAppEvents * This,
            /* [in] */ Workbook	*Wb,
            /* [in] */ MsoSyncEventType SyncEventType);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *WorkbookBeforeXmlImport )( 
            IAppEvents * This,
            /* [in] */ Workbook	*Wb,
            /* [in] */ XmlMap	*Map,
            /* [in] */ BSTR Url,
            /* [in] */ VARIANT_BOOL IsRefresh,
            /* [out][in] */ VARIANT_BOOL *Cancel);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *WorkbookAfterXmlImport )( 
            IAppEvents * This,
            /* [in] */ Workbook	*Wb,
            /* [in] */ XmlMap	*Map,
            /* [in] */ VARIANT_BOOL IsRefresh,
            /* [in] */ XlXmlImportResult Result);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *WorkbookBeforeXmlExport )( 
            IAppEvents * This,
            /* [in] */ Workbook	*Wb,
            /* [in] */ XmlMap	*Map,
            /* [in] */ BSTR Url,
            /* [out][in] */ VARIANT_BOOL *Cancel);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *WorkbookAfterXmlExport )( 
            IAppEvents * This,
            /* [in] */ Workbook	*Wb,
            /* [in] */ XmlMap	*Map,
            /* [in] */ BSTR Url,
            /* [in] */ XlXmlExportResult Result);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *WorkbookRowsetComplete )( 
            IAppEvents * This,
            /* [in] */ Workbook	*Wb,
            /* [in] */ BSTR Description,
            /* [in] */ BSTR Sheet,
            /* [in] */ VARIANT_BOOL Success);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *AfterCalculate )( 
            IAppEvents * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SheetPivotTableAfterValueChange )( 
            IAppEvents * This,
            /* [in] */ IDispatch *Sh,
            /* [in] */ PivotTable	*TargetPivotTable,
            /* [in] */ Range	*TargetRange);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SheetPivotTableBeforeAllocateChanges )( 
            IAppEvents * This,
            /* [in] */ IDispatch *Sh,
            /* [in] */ PivotTable	*TargetPivotTable,
            /* [in] */ long ValueChangeStart,
            /* [in] */ long ValueChangeEnd,
            /* [out][in] */ VARIANT_BOOL *Cancel);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SheetPivotTableBeforeCommitChanges )( 
            IAppEvents * This,
            /* [in] */ IDispatch *Sh,
            /* [in] */ PivotTable	*TargetPivotTable,
            /* [in] */ long ValueChangeStart,
            /* [in] */ long ValueChangeEnd,
            /* [out][in] */ VARIANT_BOOL *Cancel);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SheetPivotTableBeforeDiscardChanges )( 
            IAppEvents * This,
            /* [in] */ IDispatch *Sh,
            /* [in] */ PivotTable	*TargetPivotTable,
            /* [in] */ long ValueChangeStart,
            /* [in] */ long ValueChangeEnd);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ProtectedViewWindowOpen )( 
            IAppEvents * This,
            /* [in] */ ProtectedViewWindow	*Pvw);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ProtectedViewWindowBeforeEdit )( 
            IAppEvents * This,
            /* [in] */ ProtectedViewWindow	*Pvw,
            /* [out][in] */ VARIANT_BOOL *Cancel);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ProtectedViewWindowBeforeClose )( 
            IAppEvents * This,
            /* [in] */ ProtectedViewWindow	*Pvw,
            /* [in] */ XlProtectedViewCloseReason Reason,
            /* [out][in] */ VARIANT_BOOL *Cancel);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ProtectedViewWindowResize )( 
            IAppEvents * This,
            /* [in] */ ProtectedViewWindow	*Pvw);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ProtectedViewWindowActivate )( 
            IAppEvents * This,
            /* [in] */ ProtectedViewWindow	*Pvw);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ProtectedViewWindowDeactivate )( 
            IAppEvents * This,
            /* [in] */ ProtectedViewWindow	*Pvw);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *WorkbookAfterSave )( 
            IAppEvents * This,
            /* [in] */ Workbook	*Wb,
            /* [in] */ VARIANT_BOOL Success);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *WorkbookNewChart )( 
            IAppEvents * This,
            /* [in] */ Workbook	*Wb,
            /* [in] */ Chart	*Ch);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SheetLensGalleryRenderComplete )( 
            IAppEvents * This,
            /* [in] */ IDispatch *Sh);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SheetTableUpdate )( 
            IAppEvents * This,
            /* [in] */ IDispatch *Sh,
            /* [in] */ TableObject	*Target);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *WorkbookModelChange )( 
            IAppEvents * This,
            /* [in] */ Workbook	*Wb,
            /* [in] */ ModelChanges	*Changes);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SheetBeforeDelete )( 
            IAppEvents * This,
            /* [in] */ IDispatch *Sh);
        
        END_INTERFACE
    } IAppEventsVtbl;

    interface IAppEvents
    {
        CONST_VTBL struct IAppEventsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IAppEvents_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IAppEvents_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IAppEvents_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IAppEvents_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IAppEvents_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IAppEvents_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IAppEvents_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IAppEvents_NewWorkbook(This,Wb)	\
    ( (This)->lpVtbl -> NewWorkbook(This,Wb) ) 

#define IAppEvents_SheetSelectionChange(This,Sh,Target)	\
    ( (This)->lpVtbl -> SheetSelectionChange(This,Sh,Target) ) 

#define IAppEvents_SheetBeforeDoubleClick(This,Sh,Target,Cancel)	\
    ( (This)->lpVtbl -> SheetBeforeDoubleClick(This,Sh,Target,Cancel) ) 

#define IAppEvents_SheetBeforeRightClick(This,Sh,Target,Cancel)	\
    ( (This)->lpVtbl -> SheetBeforeRightClick(This,Sh,Target,Cancel) ) 

#define IAppEvents_SheetActivate(This,Sh)	\
    ( (This)->lpVtbl -> SheetActivate(This,Sh) ) 

#define IAppEvents_SheetDeactivate(This,Sh)	\
    ( (This)->lpVtbl -> SheetDeactivate(This,Sh) ) 

#define IAppEvents_SheetCalculate(This,Sh)	\
    ( (This)->lpVtbl -> SheetCalculate(This,Sh) ) 

#define IAppEvents_SheetChange(This,Sh,Target)	\
    ( (This)->lpVtbl -> SheetChange(This,Sh,Target) ) 

#define IAppEvents_WorkbookOpen(This,Wb)	\
    ( (This)->lpVtbl -> WorkbookOpen(This,Wb) ) 

#define IAppEvents_WorkbookActivate(This,Wb)	\
    ( (This)->lpVtbl -> WorkbookActivate(This,Wb) ) 

#define IAppEvents_WorkbookDeactivate(This,Wb)	\
    ( (This)->lpVtbl -> WorkbookDeactivate(This,Wb) ) 

#define IAppEvents_WorkbookBeforeClose(This,Wb,Cancel)	\
    ( (This)->lpVtbl -> WorkbookBeforeClose(This,Wb,Cancel) ) 

#define IAppEvents_WorkbookBeforeSave(This,Wb,SaveAsUI,Cancel)	\
    ( (This)->lpVtbl -> WorkbookBeforeSave(This,Wb,SaveAsUI,Cancel) ) 

#define IAppEvents_WorkbookBeforePrint(This,Wb,Cancel)	\
    ( (This)->lpVtbl -> WorkbookBeforePrint(This,Wb,Cancel) ) 

#define IAppEvents_WorkbookNewSheet(This,Wb,Sh)	\
    ( (This)->lpVtbl -> WorkbookNewSheet(This,Wb,Sh) ) 

#define IAppEvents_WorkbookAddinInstall(This,Wb)	\
    ( (This)->lpVtbl -> WorkbookAddinInstall(This,Wb) ) 

#define IAppEvents_WorkbookAddinUninstall(This,Wb)	\
    ( (This)->lpVtbl -> WorkbookAddinUninstall(This,Wb) ) 

#define IAppEvents_WindowResize(This,Wb,Wn)	\
    ( (This)->lpVtbl -> WindowResize(This,Wb,Wn) ) 

#define IAppEvents_WindowActivate(This,Wb,Wn)	\
    ( (This)->lpVtbl -> WindowActivate(This,Wb,Wn) ) 

#define IAppEvents_WindowDeactivate(This,Wb,Wn)	\
    ( (This)->lpVtbl -> WindowDeactivate(This,Wb,Wn) ) 

#define IAppEvents_SheetFollowHyperlink(This,Sh,Target)	\
    ( (This)->lpVtbl -> SheetFollowHyperlink(This,Sh,Target) ) 

#define IAppEvents_SheetPivotTableUpdate(This,Sh,Target)	\
    ( (This)->lpVtbl -> SheetPivotTableUpdate(This,Sh,Target) ) 

#define IAppEvents_WorkbookPivotTableCloseConnection(This,Wb,Target)	\
    ( (This)->lpVtbl -> WorkbookPivotTableCloseConnection(This,Wb,Target) ) 

#define IAppEvents_WorkbookPivotTableOpenConnection(This,Wb,Target)	\
    ( (This)->lpVtbl -> WorkbookPivotTableOpenConnection(This,Wb,Target) ) 

#define IAppEvents_WorkbookSync(This,Wb,SyncEventType)	\
    ( (This)->lpVtbl -> WorkbookSync(This,Wb,SyncEventType) ) 

#define IAppEvents_WorkbookBeforeXmlImport(This,Wb,Map,Url,IsRefresh,Cancel)	\
    ( (This)->lpVtbl -> WorkbookBeforeXmlImport(This,Wb,Map,Url,IsRefresh,Cancel) ) 

#define IAppEvents_WorkbookAfterXmlImport(This,Wb,Map,IsRefresh,Result)	\
    ( (This)->lpVtbl -> WorkbookAfterXmlImport(This,Wb,Map,IsRefresh,Result) ) 

#define IAppEvents_WorkbookBeforeXmlExport(This,Wb,Map,Url,Cancel)	\
    ( (This)->lpVtbl -> WorkbookBeforeXmlExport(This,Wb,Map,Url,Cancel) ) 

#define IAppEvents_WorkbookAfterXmlExport(This,Wb,Map,Url,Result)	\
    ( (This)->lpVtbl -> WorkbookAfterXmlExport(This,Wb,Map,Url,Result) ) 

#define IAppEvents_WorkbookRowsetComplete(This,Wb,Description,Sheet,Success)	\
    ( (This)->lpVtbl -> WorkbookRowsetComplete(This,Wb,Description,Sheet,Success) ) 

#define IAppEvents_AfterCalculate(This)	\
    ( (This)->lpVtbl -> AfterCalculate(This) ) 

#define IAppEvents_SheetPivotTableAfterValueChange(This,Sh,TargetPivotTable,TargetRange)	\
    ( (This)->lpVtbl -> SheetPivotTableAfterValueChange(This,Sh,TargetPivotTable,TargetRange) ) 

#define IAppEvents_SheetPivotTableBeforeAllocateChanges(This,Sh,TargetPivotTable,ValueChangeStart,ValueChangeEnd,Cancel)	\
    ( (This)->lpVtbl -> SheetPivotTableBeforeAllocateChanges(This,Sh,TargetPivotTable,ValueChangeStart,ValueChangeEnd,Cancel) ) 

#define IAppEvents_SheetPivotTableBeforeCommitChanges(This,Sh,TargetPivotTable,ValueChangeStart,ValueChangeEnd,Cancel)	\
    ( (This)->lpVtbl -> SheetPivotTableBeforeCommitChanges(This,Sh,TargetPivotTable,ValueChangeStart,ValueChangeEnd,Cancel) ) 

#define IAppEvents_SheetPivotTableBeforeDiscardChanges(This,Sh,TargetPivotTable,ValueChangeStart,ValueChangeEnd)	\
    ( (This)->lpVtbl -> SheetPivotTableBeforeDiscardChanges(This,Sh,TargetPivotTable,ValueChangeStart,ValueChangeEnd) ) 

#define IAppEvents_ProtectedViewWindowOpen(This,Pvw)	\
    ( (This)->lpVtbl -> ProtectedViewWindowOpen(This,Pvw) ) 

#define IAppEvents_ProtectedViewWindowBeforeEdit(This,Pvw,Cancel)	\
    ( (This)->lpVtbl -> ProtectedViewWindowBeforeEdit(This,Pvw,Cancel) ) 

#define IAppEvents_ProtectedViewWindowBeforeClose(This,Pvw,Reason,Cancel)	\
    ( (This)->lpVtbl -> ProtectedViewWindowBeforeClose(This,Pvw,Reason,Cancel) ) 

#define IAppEvents_ProtectedViewWindowResize(This,Pvw)	\
    ( (This)->lpVtbl -> ProtectedViewWindowResize(This,Pvw) ) 

#define IAppEvents_ProtectedViewWindowActivate(This,Pvw)	\
    ( (This)->lpVtbl -> ProtectedViewWindowActivate(This,Pvw) ) 

#define IAppEvents_ProtectedViewWindowDeactivate(This,Pvw)	\
    ( (This)->lpVtbl -> ProtectedViewWindowDeactivate(This,Pvw) ) 

#define IAppEvents_WorkbookAfterSave(This,Wb,Success)	\
    ( (This)->lpVtbl -> WorkbookAfterSave(This,Wb,Success) ) 

#define IAppEvents_WorkbookNewChart(This,Wb,Ch)	\
    ( (This)->lpVtbl -> WorkbookNewChart(This,Wb,Ch) ) 

#define IAppEvents_SheetLensGalleryRenderComplete(This,Sh)	\
    ( (This)->lpVtbl -> SheetLensGalleryRenderComplete(This,Sh) ) 

#define IAppEvents_SheetTableUpdate(This,Sh,Target)	\
    ( (This)->lpVtbl -> SheetTableUpdate(This,Sh,Target) ) 

#define IAppEvents_WorkbookModelChange(This,Wb,Changes)	\
    ( (This)->lpVtbl -> WorkbookModelChange(This,Wb,Changes) ) 

#define IAppEvents_SheetBeforeDelete(This,Sh)	\
    ( (This)->lpVtbl -> SheetBeforeDelete(This,Sh) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IAppEvents_INTERFACE_DEFINED__ */


#ifndef ___Application_INTERFACE_DEFINED__
#define ___Application_INTERFACE_DEFINED__

/* interface _Application */
/* [object][oleautomation][dual][helpcontext][uuid] */ 


EXTERN_C const IID IID__Application;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000208D5-0000-0000-C000-000000000046")
    _Application : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Parent( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ActiveCell( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ActiveChart( 
            /* [retval][out] */ Chart	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_ActiveDialog( 
            /* [retval][out] */ DialogSheet	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_ActiveMenuBar( 
            /* [retval][out] */ MenuBar	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ActivePrinter( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_ActivePrinter( 
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ActiveSheet( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ActiveWindow( 
            /* [retval][out] */ Window	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ActiveWorkbook( 
            /* [retval][out] */ Workbook	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_AddIns( 
            /* [retval][out] */ AddIns	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_Assistant( 
            /* [retval][out] */ /* external definition not present */ Assistant **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Calculate( 
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Cells( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Charts( 
            /* [retval][out] */ Sheets **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Columns( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_CommandBars( 
            /* [retval][out] */ /* external definition not present */ CommandBars **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_DDEAppReturnCode( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE DDEExecute( 
            /* [in] */ long Channel,
            /* [in] */ BSTR String,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE DDEInitiate( 
            /* [in] */ BSTR App,
            /* [in] */ BSTR Topic,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE DDEPoke( 
            /* [in] */ long Channel,
            /* [in] */ VARIANT Item,
            /* [in] */ VARIANT Data,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE DDERequest( 
            /* [in] */ long Channel,
            /* [in] */ BSTR Item,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE DDETerminate( 
            /* [in] */ long Channel,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_DialogSheets( 
            /* [retval][out] */ Sheets **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Evaluate( 
            /* [in] */ VARIANT Name,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Evaluate( 
            /* [in] */ VARIANT Name,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE ExecuteExcel4Macro( 
            /* [in] */ BSTR String,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Intersect( 
            /* [in] */ Range	*Arg1,
            /* [in] */ Range	*Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_MenuBars( 
            /* [retval][out] */ MenuBars	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_Modules( 
            /* [retval][out] */ Modules	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Names( 
            /* [retval][out] */ Names	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Range( 
            /* [in] */ VARIANT Cell1,
            /* [optional][in] */ VARIANT Cell2,
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Rows( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Run( 
            /* [optional][in] */ VARIANT Macro,
            /* [optional][in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Run2( 
            /* [optional][in] */ VARIANT Macro,
            /* [optional][in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Selection( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE SendKeys( 
            /* [in] */ VARIANT Keys,
            /* [optional][in] */ VARIANT Wait,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Sheets( 
            /* [retval][out] */ Sheets **RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_ShortcutMenus( 
            /* [in] */ long Index,
            /* [retval][out] */ Menu	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ThisWorkbook( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ Workbook	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_Toolbars( 
            /* [retval][out] */ Toolbars	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Union( 
            /* [in] */ Range	*Arg1,
            /* [in] */ Range	*Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Windows( 
            /* [retval][out] */ Windows	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Workbooks( 
            /* [retval][out] */ Workbooks **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_WorksheetFunction( 
            /* [retval][out] */ WorksheetFunction	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Worksheets( 
            /* [retval][out] */ Sheets **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Excel4IntlMacroSheets( 
            /* [retval][out] */ Sheets **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Excel4MacroSheets( 
            /* [retval][out] */ Sheets **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE ActivateMicrosoftApp( 
            /* [in] */ XlMSApplication Index,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE AddChartAutoFormat( 
            /* [in] */ VARIANT Chart,
            /* [in] */ BSTR Name,
            /* [optional][in] */ VARIANT Description,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE AddCustomList( 
            /* [in] */ VARIANT ListArray,
            /* [optional][in] */ VARIANT ByRow,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_AlertBeforeOverwriting( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_AlertBeforeOverwriting( 
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_AltStartupPath( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_AltStartupPath( 
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_AskToUpdateLinks( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_AskToUpdateLinks( 
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_EnableAnimations( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE put_EnableAnimations( 
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_AutoCorrect( 
            /* [retval][out] */ AutoCorrect	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Build( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_CalculateBeforeSave( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_CalculateBeforeSave( 
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Calculation( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ XlCalculation *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_Calculation( 
            /* [lcid][in] */ long lcid,
            /* [in] */ XlCalculation RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Caller( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_CanPlaySounds( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_CanRecordSounds( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Caption( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_Caption( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_CellDragAndDrop( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_CellDragAndDrop( 
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE CentimetersToPoints( 
            /* [in] */ double Centimeters,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE CheckSpelling( 
            /* [in] */ BSTR Word,
            /* [optional][in] */ VARIANT CustomDictionary,
            /* [optional][in] */ VARIANT IgnoreUppercase,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ClipboardFormats( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_DisplayClipboardWindow( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_DisplayClipboardWindow( 
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_ColorButtons( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE put_ColorButtons( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_CommandUnderlines( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ XlCommandUnderlines *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_CommandUnderlines( 
            /* [lcid][in] */ long lcid,
            /* [in] */ XlCommandUnderlines RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ConstrainNumeric( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_ConstrainNumeric( 
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE ConvertFormula( 
            /* [in] */ VARIANT Formula,
            /* [in] */ XlReferenceStyle FromReferenceStyle,
            /* [optional][in] */ VARIANT ToReferenceStyle,
            /* [optional][in] */ VARIANT ToAbsolute,
            /* [optional][in] */ VARIANT RelativeTo,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_CopyObjectsWithCells( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_CopyObjectsWithCells( 
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Cursor( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ XlMousePointer *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_Cursor( 
            /* [lcid][in] */ long lcid,
            /* [in] */ XlMousePointer RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_CustomListCount( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_CutCopyMode( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ XlCutCopyMode *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_CutCopyMode( 
            /* [lcid][in] */ long lcid,
            /* [in] */ XlCutCopyMode RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_DataEntryMode( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_DataEntryMode( 
            /* [lcid][in] */ long lcid,
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE Dummy1( 
            /* [optional][in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE Dummy2( 
            /* [optional][in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE Dummy3( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE Dummy4( 
            /* [optional][in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE Dummy5( 
            /* [optional][in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE Dummy6( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE Dummy7( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE Dummy8( 
            /* [optional][in] */ VARIANT Arg1,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE Dummy9( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE Dummy10( 
            /* [optional][in] */ VARIANT arg,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE Dummy11( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get__Default( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_DefaultFilePath( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_DefaultFilePath( 
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE DeleteChartAutoFormat( 
            /* [in] */ BSTR Name,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE DeleteCustomList( 
            /* [in] */ long ListNum,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Dialogs( 
            /* [retval][out] */ Dialogs	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_DisplayAlerts( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_DisplayAlerts( 
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_DisplayFormulaBar( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_DisplayFormulaBar( 
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_DisplayFullScreen( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_DisplayFullScreen( 
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_DisplayNoteIndicator( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_DisplayNoteIndicator( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_DisplayCommentIndicator( 
            /* [retval][out] */ XlCommentDisplayMode *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_DisplayCommentIndicator( 
            /* [in] */ XlCommentDisplayMode RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_DisplayExcel4Menus( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_DisplayExcel4Menus( 
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_DisplayRecentFiles( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_DisplayRecentFiles( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_DisplayScrollBars( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_DisplayScrollBars( 
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_DisplayStatusBar( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_DisplayStatusBar( 
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE DoubleClick( 
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_EditDirectlyInCell( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_EditDirectlyInCell( 
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_EnableAutoComplete( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_EnableAutoComplete( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_EnableCancelKey( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ XlEnableCancelKey *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_EnableCancelKey( 
            /* [lcid][in] */ long lcid,
            /* [in] */ XlEnableCancelKey RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_EnableSound( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_EnableSound( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_EnableTipWizard( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE put_EnableTipWizard( 
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_FileConverters( 
            /* [optional][in] */ VARIANT Index1,
            /* [optional][in] */ VARIANT Index2,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_FileSearch( 
            /* [retval][out] */ /* external definition not present */ FileSearch **RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_FileFind( 
            /* [retval][out] */ /* external definition not present */ IFind **RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE _FindFile( 
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_FixedDecimal( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_FixedDecimal( 
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_FixedDecimalPlaces( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_FixedDecimalPlaces( 
            /* [lcid][in] */ long lcid,
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE GetCustomListContents( 
            /* [in] */ long ListNum,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE GetCustomListNum( 
            /* [in] */ VARIANT ListArray,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE GetOpenFilename( 
            /* [optional][in] */ VARIANT FileFilter,
            /* [optional][in] */ VARIANT FilterIndex,
            /* [optional][in] */ VARIANT Title,
            /* [optional][in] */ VARIANT ButtonText,
            /* [optional][in] */ VARIANT MultiSelect,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE GetSaveAsFilename( 
            /* [optional][in] */ VARIANT InitialFilename,
            /* [optional][in] */ VARIANT FileFilter,
            /* [optional][in] */ VARIANT FilterIndex,
            /* [optional][in] */ VARIANT Title,
            /* [optional][in] */ VARIANT ButtonText,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Goto( 
            /* [optional][in] */ VARIANT Reference,
            /* [optional][in] */ VARIANT Scroll,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Height( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_Height( 
            /* [lcid][in] */ long lcid,
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Help( 
            /* [optional][in] */ VARIANT HelpFile,
            /* [optional][in] */ VARIANT HelpContextID,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_IgnoreRemoteRequests( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_IgnoreRemoteRequests( 
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE InchesToPoints( 
            /* [in] */ double Inches,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE InputBox( 
            /* [in] */ BSTR Prompt,
            /* [optional][in] */ VARIANT Title,
            /* [optional][in] */ VARIANT Default,
            /* [optional][in] */ VARIANT Left,
            /* [optional][in] */ VARIANT Top,
            /* [optional][in] */ VARIANT HelpFile,
            /* [optional][in] */ VARIANT HelpContextID,
            /* [optional][in] */ VARIANT Type,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Interactive( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_Interactive( 
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_International( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Iteration( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_Iteration( 
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_LargeButtons( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE put_LargeButtons( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Left( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_Left( 
            /* [lcid][in] */ long lcid,
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_LibraryPath( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [custom][helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE _MacroOptions( 
            /* [optional][in] */ VARIANT Macro,
            /* [optional][in] */ VARIANT Description,
            /* [optional][in] */ VARIANT HasMenu,
            /* [optional][in] */ VARIANT MenuText,
            /* [optional][in] */ VARIANT HasShortcutKey,
            /* [optional][in] */ VARIANT ShortcutKey,
            /* [optional][in] */ VARIANT Category,
            /* [optional][in] */ VARIANT StatusBar,
            /* [optional][in] */ VARIANT HelpContextID,
            /* [optional][in] */ VARIANT HelpFile,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE MailLogoff( 
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE MailLogon( 
            /* [optional][in] */ VARIANT Name,
            /* [optional][in] */ VARIANT Password,
            /* [optional][in] */ VARIANT DownloadNewMail,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_MailSession( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_MailSystem( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ XlMailSystem *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_MathCoprocessorAvailable( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_MaxChange( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_MaxChange( 
            /* [lcid][in] */ long lcid,
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_MaxIterations( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_MaxIterations( 
            /* [lcid][in] */ long lcid,
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_MemoryFree( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_MemoryTotal( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_MemoryUsed( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_MouseAvailable( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_MoveAfterReturn( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_MoveAfterReturn( 
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_MoveAfterReturnDirection( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ XlDirection *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_MoveAfterReturnDirection( 
            /* [lcid][in] */ long lcid,
            /* [in] */ XlDirection RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_RecentFiles( 
            /* [retval][out] */ RecentFiles	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE NextLetter( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ Workbook	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_NetworkTemplatesPath( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ODBCErrors( 
            /* [retval][out] */ ODBCErrors	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ODBCTimeout( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_ODBCTimeout( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_OnCalculate( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE put_OnCalculate( 
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_OnData( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE put_OnData( 
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_OnDoubleClick( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE put_OnDoubleClick( 
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_OnEntry( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE put_OnEntry( 
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE OnKey( 
            /* [in] */ BSTR Key,
            /* [optional][in] */ VARIANT Procedure,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE OnRepeat( 
            /* [in] */ BSTR Text,
            /* [in] */ BSTR Procedure,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_OnSheetActivate( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE put_OnSheetActivate( 
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_OnSheetDeactivate( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE put_OnSheetDeactivate( 
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE OnTime( 
            /* [in] */ VARIANT EarliestTime,
            /* [in] */ BSTR Procedure,
            /* [optional][in] */ VARIANT LatestTime,
            /* [optional][in] */ VARIANT Schedule,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE OnUndo( 
            /* [in] */ BSTR Text,
            /* [in] */ BSTR Procedure,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_OnWindow( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_OnWindow( 
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_OperatingSystem( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_OrganizationName( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Path( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_PathSeparator( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_PreviousSelections( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_PivotTableSelection( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_PivotTableSelection( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_PromptForSummaryInfo( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_PromptForSummaryInfo( 
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Quit( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE RecordMacro( 
            /* [optional][in] */ VARIANT BasicCode,
            /* [optional][in] */ VARIANT XlmCode,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_RecordRelative( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ReferenceStyle( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ XlReferenceStyle *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_ReferenceStyle( 
            /* [lcid][in] */ long lcid,
            /* [in] */ XlReferenceStyle RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_RegisteredFunctions( 
            /* [optional][in] */ VARIANT Index1,
            /* [optional][in] */ VARIANT Index2,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE RegisterXLL( 
            /* [in] */ BSTR Filename,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Repeat( 
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE ResetTipWizard( 
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_RollZoom( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_RollZoom( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE Save( 
            /* [optional][in] */ VARIANT Filename,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE SaveWorkspace( 
            /* [optional][in] */ VARIANT Filename,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ScreenUpdating( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_ScreenUpdating( 
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE SetDefaultChart( 
            /* [optional][in] */ VARIANT FormatName,
            /* [optional][in] */ VARIANT Gallery) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_SheetsInNewWorkbook( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_SheetsInNewWorkbook( 
            /* [lcid][in] */ long lcid,
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ShowChartTipNames( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_ShowChartTipNames( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ShowChartTipValues( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_ShowChartTipValues( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_StandardFont( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_StandardFont( 
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_StandardFontSize( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_StandardFontSize( 
            /* [lcid][in] */ long lcid,
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_StartupPath( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_StatusBar( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_StatusBar( 
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_TemplatesPath( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ShowToolTips( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_ShowToolTips( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Top( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_Top( 
            /* [lcid][in] */ long lcid,
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_DefaultSaveFormat( 
            /* [retval][out] */ XlFileFormat *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_DefaultSaveFormat( 
            /* [in] */ XlFileFormat RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_TransitionMenuKey( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_TransitionMenuKey( 
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_TransitionMenuKeyAction( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_TransitionMenuKeyAction( 
            /* [lcid][in] */ long lcid,
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_TransitionNavigKeys( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_TransitionNavigKeys( 
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Undo( 
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_UsableHeight( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_UsableWidth( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_UserControl( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_UserControl( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_UserName( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_UserName( 
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Value( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_VBE( 
            /* [retval][out] */ /* external definition not present */ VBE **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Version( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Visible( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_Visible( 
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Volatile( 
            /* [optional][in] */ VARIANT Volatile,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE _Wait( 
            /* [in] */ VARIANT Time,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Width( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_Width( 
            /* [lcid][in] */ long lcid,
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_WindowsForPens( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_WindowState( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ XlWindowState *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_WindowState( 
            /* [lcid][in] */ long lcid,
            /* [in] */ XlWindowState RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_UILanguage( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE put_UILanguage( 
            /* [lcid][in] */ long lcid,
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_DefaultSheetDirection( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_DefaultSheetDirection( 
            /* [lcid][in] */ long lcid,
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_CursorMovement( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_CursorMovement( 
            /* [lcid][in] */ long lcid,
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ControlCharacters( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_ControlCharacters( 
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE _WSFunction( 
            /* [optional][in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_EnableEvents( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_EnableEvents( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_DisplayInfoWindow( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE put_DisplayInfoWindow( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Wait( 
            /* [in] */ VARIANT Time,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ExtendList( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_ExtendList( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_OLEDBErrors( 
            /* [retval][out] */ OLEDBErrors	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE GetPhonetic( 
            /* [optional][in] */ VARIANT Text,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_COMAddIns( 
            /* [retval][out] */ /* external definition not present */ COMAddIns **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_DefaultWebOptions( 
            /* [retval][out] */ DefaultWebOptions **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ProductCode( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_UserLibraryPath( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_AutoPercentEntry( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_AutoPercentEntry( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_LanguageSettings( 
            /* [retval][out] */ /* external definition not present */ LanguageSettings **RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_Dummy101( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE Dummy12( 
            /* [in] */ PivotTable	*p1,
            /* [in] */ PivotTable	*p2) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_AnswerWizard( 
            /* [retval][out] */ /* external definition not present */ AnswerWizard **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE CalculateFull( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE FindFile( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_CalculationVersion( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_ShowWindowsInTaskbar( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE put_ShowWindowsInTaskbar( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_FeatureInstall( 
            /* [retval][out] */ MsoFeatureInstall *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_FeatureInstall( 
            /* [in] */ MsoFeatureInstall RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Ready( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE Dummy13( 
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_FindFormat( 
            /* [retval][out] */ CellFormat	**RHS) = 0;
        
        virtual /* [helpcontext][propputref][id] */ HRESULT STDMETHODCALLTYPE putref_FindFormat( 
            /* [in] */ CellFormat	*RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ReplaceFormat( 
            /* [retval][out] */ CellFormat	**RHS) = 0;
        
        virtual /* [helpcontext][propputref][id] */ HRESULT STDMETHODCALLTYPE putref_ReplaceFormat( 
            /* [in] */ CellFormat	*RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_UsedObjects( 
            /* [retval][out] */ UsedObjects	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_CalculationState( 
            /* [retval][out] */ XlCalculationState *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_CalculationInterruptKey( 
            /* [retval][out] */ XlCalculationInterruptKey *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_CalculationInterruptKey( 
            /* [in] */ XlCalculationInterruptKey RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Watches( 
            /* [retval][out] */ Watches	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_DisplayFunctionToolTips( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_DisplayFunctionToolTips( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_AutomationSecurity( 
            /* [retval][out] */ MsoAutomationSecurity *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_AutomationSecurity( 
            /* [in] */ MsoAutomationSecurity RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_FileDialog( 
            /* [in] */ MsoFileDialogType fileDialogType,
            /* [retval][out] */ /* external definition not present */ FileDialog **RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE Dummy14( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE CalculateFullRebuild( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_DisplayPasteOptions( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_DisplayPasteOptions( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_DisplayInsertOptions( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_DisplayInsertOptions( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_GenerateGetPivotData( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_GenerateGetPivotData( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_AutoRecover( 
            /* [retval][out] */ AutoRecover	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Hwnd( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Hinstance( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE CheckAbort( 
            /* [optional][in] */ VARIANT KeepAbort) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ErrorCheckingOptions( 
            /* [retval][out] */ ErrorCheckingOptions	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_AutoFormatAsYouTypeReplaceHyperlinks( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_AutoFormatAsYouTypeReplaceHyperlinks( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_SmartTagRecognizers( 
            /* [retval][out] */ SmartTagRecognizers	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_NewWorkbook( 
            /* [retval][out] */ /* external definition not present */ NewFile **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_SpellingOptions( 
            /* [retval][out] */ SpellingOptions	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Speech( 
            /* [retval][out] */ Speech	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_MapPaperSize( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_MapPaperSize( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ShowStartupDialog( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_ShowStartupDialog( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_DecimalSeparator( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_DecimalSeparator( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ThousandsSeparator( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_ThousandsSeparator( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_UseSystemSeparators( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_UseSystemSeparators( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ThisCell( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_RTD( 
            /* [retval][out] */ RTD	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_DisplayDocumentActionTaskPane( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_DisplayDocumentActionTaskPane( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE DisplayXMLSourcePane( 
            /* [optional][in] */ VARIANT XmlMap) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ArbitraryXMLSupportAvailable( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE Support( 
            /* [in] */ IDispatch *Object,
            /* [in] */ long ID,
            /* [optional][in] */ VARIANT arg,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE Dummy20( 
            /* [in] */ long grfCompareFunctions,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_MeasurementUnit( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_MeasurementUnit( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ShowSelectionFloaties( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_ShowSelectionFloaties( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ShowMenuFloaties( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_ShowMenuFloaties( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ShowDevTools( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_ShowDevTools( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_EnableLivePreview( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_EnableLivePreview( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_DisplayDocumentInformationPanel( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_DisplayDocumentInformationPanel( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_AlwaysUseClearType( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_AlwaysUseClearType( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_WarnOnFunctionNameConflict( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_WarnOnFunctionNameConflict( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_FormulaBarHeight( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_FormulaBarHeight( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_DisplayFormulaAutoComplete( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_DisplayFormulaAutoComplete( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_GenerateTableRefs( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ XlGenerateTableRefs *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_GenerateTableRefs( 
            /* [lcid][in] */ long lcid,
            /* [in] */ XlGenerateTableRefs RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Assistance( 
            /* [retval][out] */ /* external definition not present */ IAssistance **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE CalculateUntilAsyncQueriesDone( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_EnableLargeOperationAlert( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_EnableLargeOperationAlert( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_LargeOperationCellThousandCount( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_LargeOperationCellThousandCount( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_DeferAsyncQueries( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_DeferAsyncQueries( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_MultiThreadedCalculation( 
            /* [retval][out] */ MultiThreadedCalculation	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE SharePointVersion( 
            /* [in] */ BSTR bstrUrl,
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ActiveEncryptionSession( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_HighQualityModeForGraphics( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_HighQualityModeForGraphics( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_FileExportConverters( 
            /* [retval][out] */ FileExportConverters	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_SmartArtLayouts( 
            /* [retval][out] */ /* external definition not present */ SmartArtLayouts **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_SmartArtQuickStyles( 
            /* [retval][out] */ /* external definition not present */ SmartArtQuickStyles **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_SmartArtColors( 
            /* [retval][out] */ /* external definition not present */ SmartArtColors **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_AddIns2( 
            /* [retval][out] */ AddIns2	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_PrintCommunication( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_PrintCommunication( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [custom][helpcontext][id] */ HRESULT STDMETHODCALLTYPE MacroOptions( 
            /* [optional][in] */ VARIANT Macro,
            /* [optional][in] */ VARIANT Description,
            /* [optional][in] */ VARIANT HasMenu,
            /* [optional][in] */ VARIANT MenuText,
            /* [optional][in] */ VARIANT HasShortcutKey,
            /* [optional][in] */ VARIANT ShortcutKey,
            /* [optional][in] */ VARIANT Category,
            /* [optional][in] */ VARIANT StatusBar,
            /* [optional][in] */ VARIANT HelpContextID,
            /* [optional][in] */ VARIANT HelpFile,
            /* [optional][in] */ VARIANT ArgumentDescriptions,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_UseClusterConnector( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_UseClusterConnector( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ClusterConnector( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_ClusterConnector( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_Quitting( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_Dummy22( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE put_Dummy22( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_Dummy23( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE put_Dummy23( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ProtectedViewWindows( 
            /* [retval][out] */ ProtectedViewWindows	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ActiveProtectedViewWindow( 
            /* [retval][out] */ ProtectedViewWindow	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_IsSandboxed( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_SaveISO8601Dates( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE put_SaveISO8601Dates( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_HinstancePtr( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_FileValidation( 
            /* [retval][out] */ MsoFileValidationMode *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_FileValidation( 
            /* [in] */ MsoFileValidationMode RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_FileValidationPivot( 
            /* [retval][out] */ XlFileValidationPivotMode *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_FileValidationPivot( 
            /* [in] */ XlFileValidationPivotMode RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ShowQuickAnalysis( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_ShowQuickAnalysis( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_QuickAnalysis( 
            /* [retval][out] */ QuickAnalysis	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_FlashFill( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_FlashFill( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_EnableMacroAnimations( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_EnableMacroAnimations( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ChartDataPointTrack( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_ChartDataPointTrack( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_FlashFillMode( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_FlashFillMode( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_MergeInstances( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_MergeInstances( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_EnableCheckFileExtensions( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_EnableCheckFileExtensions( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [propget][id] */ HRESULT STDMETHODCALLTYPE get_DebugTools( 
            /* [retval][out] */ _DebugTools **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct _ApplicationVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            _Application * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            _Application * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            _Application * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            _Application * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            _Application * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            _Application * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            _Application * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Application )( 
            _Application * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Creator )( 
            _Application * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Parent )( 
            _Application * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ActiveCell )( 
            _Application * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ActiveChart )( 
            _Application * This,
            /* [retval][out] */ Chart	**RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ActiveDialog )( 
            _Application * This,
            /* [retval][out] */ DialogSheet	**RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ActiveMenuBar )( 
            _Application * This,
            /* [retval][out] */ MenuBar	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ActivePrinter )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_ActivePrinter )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ActiveSheet )( 
            _Application * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ActiveWindow )( 
            _Application * This,
            /* [retval][out] */ Window	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ActiveWorkbook )( 
            _Application * This,
            /* [retval][out] */ Workbook	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_AddIns )( 
            _Application * This,
            /* [retval][out] */ AddIns	**RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Assistant )( 
            _Application * This,
            /* [retval][out] */ /* external definition not present */ Assistant **RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Calculate )( 
            _Application * This,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Cells )( 
            _Application * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Charts )( 
            _Application * This,
            /* [retval][out] */ Sheets **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Columns )( 
            _Application * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_CommandBars )( 
            _Application * This,
            /* [retval][out] */ /* external definition not present */ CommandBars **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_DDEAppReturnCode )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *DDEExecute )( 
            _Application * This,
            /* [in] */ long Channel,
            /* [in] */ BSTR String,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *DDEInitiate )( 
            _Application * This,
            /* [in] */ BSTR App,
            /* [in] */ BSTR Topic,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *DDEPoke )( 
            _Application * This,
            /* [in] */ long Channel,
            /* [in] */ VARIANT Item,
            /* [in] */ VARIANT Data,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *DDERequest )( 
            _Application * This,
            /* [in] */ long Channel,
            /* [in] */ BSTR Item,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *DDETerminate )( 
            _Application * This,
            /* [in] */ long Channel,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_DialogSheets )( 
            _Application * This,
            /* [retval][out] */ Sheets **RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Evaluate )( 
            _Application * This,
            /* [in] */ VARIANT Name,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *_Evaluate )( 
            _Application * This,
            /* [in] */ VARIANT Name,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *ExecuteExcel4Macro )( 
            _Application * This,
            /* [in] */ BSTR String,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Intersect )( 
            _Application * This,
            /* [in] */ Range	*Arg1,
            /* [in] */ Range	*Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_MenuBars )( 
            _Application * This,
            /* [retval][out] */ MenuBars	**RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Modules )( 
            _Application * This,
            /* [retval][out] */ Modules	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Names )( 
            _Application * This,
            /* [retval][out] */ Names	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Range )( 
            _Application * This,
            /* [in] */ VARIANT Cell1,
            /* [optional][in] */ VARIANT Cell2,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Rows )( 
            _Application * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Run )( 
            _Application * This,
            /* [optional][in] */ VARIANT Macro,
            /* [optional][in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *_Run2 )( 
            _Application * This,
            /* [optional][in] */ VARIANT Macro,
            /* [optional][in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Selection )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *SendKeys )( 
            _Application * This,
            /* [in] */ VARIANT Keys,
            /* [optional][in] */ VARIANT Wait,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Sheets )( 
            _Application * This,
            /* [retval][out] */ Sheets **RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ShortcutMenus )( 
            _Application * This,
            /* [in] */ long Index,
            /* [retval][out] */ Menu	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ThisWorkbook )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ Workbook	**RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Toolbars )( 
            _Application * This,
            /* [retval][out] */ Toolbars	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Union )( 
            _Application * This,
            /* [in] */ Range	*Arg1,
            /* [in] */ Range	*Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Windows )( 
            _Application * This,
            /* [retval][out] */ Windows	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Workbooks )( 
            _Application * This,
            /* [retval][out] */ Workbooks **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_WorksheetFunction )( 
            _Application * This,
            /* [retval][out] */ WorksheetFunction	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Worksheets )( 
            _Application * This,
            /* [retval][out] */ Sheets **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Excel4IntlMacroSheets )( 
            _Application * This,
            /* [retval][out] */ Sheets **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Excel4MacroSheets )( 
            _Application * This,
            /* [retval][out] */ Sheets **RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *ActivateMicrosoftApp )( 
            _Application * This,
            /* [in] */ XlMSApplication Index,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *AddChartAutoFormat )( 
            _Application * This,
            /* [in] */ VARIANT Chart,
            /* [in] */ BSTR Name,
            /* [optional][in] */ VARIANT Description,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *AddCustomList )( 
            _Application * This,
            /* [in] */ VARIANT ListArray,
            /* [optional][in] */ VARIANT ByRow,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_AlertBeforeOverwriting )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_AlertBeforeOverwriting )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_AltStartupPath )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_AltStartupPath )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_AskToUpdateLinks )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_AskToUpdateLinks )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_EnableAnimations )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_EnableAnimations )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_AutoCorrect )( 
            _Application * This,
            /* [retval][out] */ AutoCorrect	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Build )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_CalculateBeforeSave )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_CalculateBeforeSave )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Calculation )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ XlCalculation *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Calculation )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ XlCalculation RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Caller )( 
            _Application * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_CanPlaySounds )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_CanRecordSounds )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Caption )( 
            _Application * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Caption )( 
            _Application * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_CellDragAndDrop )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_CellDragAndDrop )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *CentimetersToPoints )( 
            _Application * This,
            /* [in] */ double Centimeters,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *CheckSpelling )( 
            _Application * This,
            /* [in] */ BSTR Word,
            /* [optional][in] */ VARIANT CustomDictionary,
            /* [optional][in] */ VARIANT IgnoreUppercase,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ClipboardFormats )( 
            _Application * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_DisplayClipboardWindow )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_DisplayClipboardWindow )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ColorButtons )( 
            _Application * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_ColorButtons )( 
            _Application * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_CommandUnderlines )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ XlCommandUnderlines *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_CommandUnderlines )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ XlCommandUnderlines RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ConstrainNumeric )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_ConstrainNumeric )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *ConvertFormula )( 
            _Application * This,
            /* [in] */ VARIANT Formula,
            /* [in] */ XlReferenceStyle FromReferenceStyle,
            /* [optional][in] */ VARIANT ToReferenceStyle,
            /* [optional][in] */ VARIANT ToAbsolute,
            /* [optional][in] */ VARIANT RelativeTo,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_CopyObjectsWithCells )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_CopyObjectsWithCells )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Cursor )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ XlMousePointer *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Cursor )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ XlMousePointer RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_CustomListCount )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_CutCopyMode )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ XlCutCopyMode *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_CutCopyMode )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ XlCutCopyMode RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_DataEntryMode )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_DataEntryMode )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ long RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *Dummy1 )( 
            _Application * This,
            /* [optional][in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *Dummy2 )( 
            _Application * This,
            /* [optional][in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *Dummy3 )( 
            _Application * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *Dummy4 )( 
            _Application * This,
            /* [optional][in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *Dummy5 )( 
            _Application * This,
            /* [optional][in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *Dummy6 )( 
            _Application * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *Dummy7 )( 
            _Application * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *Dummy8 )( 
            _Application * This,
            /* [optional][in] */ VARIANT Arg1,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *Dummy9 )( 
            _Application * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *Dummy10 )( 
            _Application * This,
            /* [optional][in] */ VARIANT arg,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *Dummy11 )( 
            _Application * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get__Default )( 
            _Application * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_DefaultFilePath )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_DefaultFilePath )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *DeleteChartAutoFormat )( 
            _Application * This,
            /* [in] */ BSTR Name,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *DeleteCustomList )( 
            _Application * This,
            /* [in] */ long ListNum,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Dialogs )( 
            _Application * This,
            /* [retval][out] */ Dialogs	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_DisplayAlerts )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_DisplayAlerts )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_DisplayFormulaBar )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_DisplayFormulaBar )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_DisplayFullScreen )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_DisplayFullScreen )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_DisplayNoteIndicator )( 
            _Application * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_DisplayNoteIndicator )( 
            _Application * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_DisplayCommentIndicator )( 
            _Application * This,
            /* [retval][out] */ XlCommentDisplayMode *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_DisplayCommentIndicator )( 
            _Application * This,
            /* [in] */ XlCommentDisplayMode RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_DisplayExcel4Menus )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_DisplayExcel4Menus )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_DisplayRecentFiles )( 
            _Application * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_DisplayRecentFiles )( 
            _Application * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_DisplayScrollBars )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_DisplayScrollBars )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_DisplayStatusBar )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_DisplayStatusBar )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *DoubleClick )( 
            _Application * This,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_EditDirectlyInCell )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_EditDirectlyInCell )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_EnableAutoComplete )( 
            _Application * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_EnableAutoComplete )( 
            _Application * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_EnableCancelKey )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ XlEnableCancelKey *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_EnableCancelKey )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ XlEnableCancelKey RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_EnableSound )( 
            _Application * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_EnableSound )( 
            _Application * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_EnableTipWizard )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_EnableTipWizard )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_FileConverters )( 
            _Application * This,
            /* [optional][in] */ VARIANT Index1,
            /* [optional][in] */ VARIANT Index2,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_FileSearch )( 
            _Application * This,
            /* [retval][out] */ /* external definition not present */ FileSearch **RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_FileFind )( 
            _Application * This,
            /* [retval][out] */ /* external definition not present */ IFind **RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *_FindFile )( 
            _Application * This,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_FixedDecimal )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_FixedDecimal )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_FixedDecimalPlaces )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_FixedDecimalPlaces )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ long RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *GetCustomListContents )( 
            _Application * This,
            /* [in] */ long ListNum,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *GetCustomListNum )( 
            _Application * This,
            /* [in] */ VARIANT ListArray,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *GetOpenFilename )( 
            _Application * This,
            /* [optional][in] */ VARIANT FileFilter,
            /* [optional][in] */ VARIANT FilterIndex,
            /* [optional][in] */ VARIANT Title,
            /* [optional][in] */ VARIANT ButtonText,
            /* [optional][in] */ VARIANT MultiSelect,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *GetSaveAsFilename )( 
            _Application * This,
            /* [optional][in] */ VARIANT InitialFilename,
            /* [optional][in] */ VARIANT FileFilter,
            /* [optional][in] */ VARIANT FilterIndex,
            /* [optional][in] */ VARIANT Title,
            /* [optional][in] */ VARIANT ButtonText,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Goto )( 
            _Application * This,
            /* [optional][in] */ VARIANT Reference,
            /* [optional][in] */ VARIANT Scroll,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Height )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Height )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ double RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Help )( 
            _Application * This,
            /* [optional][in] */ VARIANT HelpFile,
            /* [optional][in] */ VARIANT HelpContextID,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_IgnoreRemoteRequests )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_IgnoreRemoteRequests )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *InchesToPoints )( 
            _Application * This,
            /* [in] */ double Inches,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *InputBox )( 
            _Application * This,
            /* [in] */ BSTR Prompt,
            /* [optional][in] */ VARIANT Title,
            /* [optional][in] */ VARIANT Default,
            /* [optional][in] */ VARIANT Left,
            /* [optional][in] */ VARIANT Top,
            /* [optional][in] */ VARIANT HelpFile,
            /* [optional][in] */ VARIANT HelpContextID,
            /* [optional][in] */ VARIANT Type,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Interactive )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Interactive )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_International )( 
            _Application * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Iteration )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Iteration )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_LargeButtons )( 
            _Application * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_LargeButtons )( 
            _Application * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Left )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Left )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_LibraryPath )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS);
        
        /* [custom][helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *_MacroOptions )( 
            _Application * This,
            /* [optional][in] */ VARIANT Macro,
            /* [optional][in] */ VARIANT Description,
            /* [optional][in] */ VARIANT HasMenu,
            /* [optional][in] */ VARIANT MenuText,
            /* [optional][in] */ VARIANT HasShortcutKey,
            /* [optional][in] */ VARIANT ShortcutKey,
            /* [optional][in] */ VARIANT Category,
            /* [optional][in] */ VARIANT StatusBar,
            /* [optional][in] */ VARIANT HelpContextID,
            /* [optional][in] */ VARIANT HelpFile,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *MailLogoff )( 
            _Application * This,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *MailLogon )( 
            _Application * This,
            /* [optional][in] */ VARIANT Name,
            /* [optional][in] */ VARIANT Password,
            /* [optional][in] */ VARIANT DownloadNewMail,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_MailSession )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_MailSystem )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ XlMailSystem *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_MathCoprocessorAvailable )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_MaxChange )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_MaxChange )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_MaxIterations )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_MaxIterations )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ long RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_MemoryFree )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_MemoryTotal )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_MemoryUsed )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_MouseAvailable )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_MoveAfterReturn )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_MoveAfterReturn )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_MoveAfterReturnDirection )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ XlDirection *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_MoveAfterReturnDirection )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ XlDirection RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_RecentFiles )( 
            _Application * This,
            /* [retval][out] */ RecentFiles	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Name )( 
            _Application * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *NextLetter )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ Workbook	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_NetworkTemplatesPath )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ODBCErrors )( 
            _Application * This,
            /* [retval][out] */ ODBCErrors	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ODBCTimeout )( 
            _Application * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_ODBCTimeout )( 
            _Application * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_OnCalculate )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_OnCalculate )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_OnData )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_OnData )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_OnDoubleClick )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_OnDoubleClick )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_OnEntry )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_OnEntry )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *OnKey )( 
            _Application * This,
            /* [in] */ BSTR Key,
            /* [optional][in] */ VARIANT Procedure,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *OnRepeat )( 
            _Application * This,
            /* [in] */ BSTR Text,
            /* [in] */ BSTR Procedure,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_OnSheetActivate )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_OnSheetActivate )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_OnSheetDeactivate )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_OnSheetDeactivate )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *OnTime )( 
            _Application * This,
            /* [in] */ VARIANT EarliestTime,
            /* [in] */ BSTR Procedure,
            /* [optional][in] */ VARIANT LatestTime,
            /* [optional][in] */ VARIANT Schedule,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *OnUndo )( 
            _Application * This,
            /* [in] */ BSTR Text,
            /* [in] */ BSTR Procedure,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_OnWindow )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_OnWindow )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_OperatingSystem )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_OrganizationName )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Path )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_PathSeparator )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_PreviousSelections )( 
            _Application * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_PivotTableSelection )( 
            _Application * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_PivotTableSelection )( 
            _Application * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_PromptForSummaryInfo )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_PromptForSummaryInfo )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Quit )( 
            _Application * This);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *RecordMacro )( 
            _Application * This,
            /* [optional][in] */ VARIANT BasicCode,
            /* [optional][in] */ VARIANT XlmCode,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_RecordRelative )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ReferenceStyle )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ XlReferenceStyle *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_ReferenceStyle )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ XlReferenceStyle RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_RegisteredFunctions )( 
            _Application * This,
            /* [optional][in] */ VARIANT Index1,
            /* [optional][in] */ VARIANT Index2,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *RegisterXLL )( 
            _Application * This,
            /* [in] */ BSTR Filename,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Repeat )( 
            _Application * This,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *ResetTipWizard )( 
            _Application * This,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_RollZoom )( 
            _Application * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_RollZoom )( 
            _Application * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *Save )( 
            _Application * This,
            /* [optional][in] */ VARIANT Filename,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *SaveWorkspace )( 
            _Application * This,
            /* [optional][in] */ VARIANT Filename,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ScreenUpdating )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_ScreenUpdating )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *SetDefaultChart )( 
            _Application * This,
            /* [optional][in] */ VARIANT FormatName,
            /* [optional][in] */ VARIANT Gallery);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_SheetsInNewWorkbook )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_SheetsInNewWorkbook )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ShowChartTipNames )( 
            _Application * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_ShowChartTipNames )( 
            _Application * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ShowChartTipValues )( 
            _Application * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_ShowChartTipValues )( 
            _Application * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_StandardFont )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_StandardFont )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_StandardFontSize )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_StandardFontSize )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_StartupPath )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_StatusBar )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_StatusBar )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_TemplatesPath )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ShowToolTips )( 
            _Application * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_ShowToolTips )( 
            _Application * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Top )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Top )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_DefaultSaveFormat )( 
            _Application * This,
            /* [retval][out] */ XlFileFormat *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_DefaultSaveFormat )( 
            _Application * This,
            /* [in] */ XlFileFormat RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_TransitionMenuKey )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_TransitionMenuKey )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_TransitionMenuKeyAction )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_TransitionMenuKeyAction )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_TransitionNavigKeys )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_TransitionNavigKeys )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Undo )( 
            _Application * This,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_UsableHeight )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_UsableWidth )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_UserControl )( 
            _Application * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_UserControl )( 
            _Application * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_UserName )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_UserName )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Value )( 
            _Application * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_VBE )( 
            _Application * This,
            /* [retval][out] */ /* external definition not present */ VBE **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Version )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Visible )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Visible )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Volatile )( 
            _Application * This,
            /* [optional][in] */ VARIANT Volatile,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *_Wait )( 
            _Application * This,
            /* [in] */ VARIANT Time,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Width )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Width )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_WindowsForPens )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_WindowState )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ XlWindowState *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_WindowState )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ XlWindowState RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_UILanguage )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_UILanguage )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_DefaultSheetDirection )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_DefaultSheetDirection )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_CursorMovement )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_CursorMovement )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ControlCharacters )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_ControlCharacters )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *_WSFunction )( 
            _Application * This,
            /* [optional][in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_EnableEvents )( 
            _Application * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_EnableEvents )( 
            _Application * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_DisplayInfoWindow )( 
            _Application * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_DisplayInfoWindow )( 
            _Application * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Wait )( 
            _Application * This,
            /* [in] */ VARIANT Time,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ExtendList )( 
            _Application * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_ExtendList )( 
            _Application * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_OLEDBErrors )( 
            _Application * This,
            /* [retval][out] */ OLEDBErrors	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *GetPhonetic )( 
            _Application * This,
            /* [optional][in] */ VARIANT Text,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_COMAddIns )( 
            _Application * This,
            /* [retval][out] */ /* external definition not present */ COMAddIns **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_DefaultWebOptions )( 
            _Application * This,
            /* [retval][out] */ DefaultWebOptions **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ProductCode )( 
            _Application * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_UserLibraryPath )( 
            _Application * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_AutoPercentEntry )( 
            _Application * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_AutoPercentEntry )( 
            _Application * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_LanguageSettings )( 
            _Application * This,
            /* [retval][out] */ /* external definition not present */ LanguageSettings **RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Dummy101 )( 
            _Application * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *Dummy12 )( 
            _Application * This,
            /* [in] */ PivotTable	*p1,
            /* [in] */ PivotTable	*p2);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_AnswerWizard )( 
            _Application * This,
            /* [retval][out] */ /* external definition not present */ AnswerWizard **RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *CalculateFull )( 
            _Application * This);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *FindFile )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_CalculationVersion )( 
            _Application * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ShowWindowsInTaskbar )( 
            _Application * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_ShowWindowsInTaskbar )( 
            _Application * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_FeatureInstall )( 
            _Application * This,
            /* [retval][out] */ MsoFeatureInstall *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_FeatureInstall )( 
            _Application * This,
            /* [in] */ MsoFeatureInstall RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Ready )( 
            _Application * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *Dummy13 )( 
            _Application * This,
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_FindFormat )( 
            _Application * This,
            /* [retval][out] */ CellFormat	**RHS);
        
        /* [helpcontext][propputref][id] */ HRESULT ( STDMETHODCALLTYPE *putref_FindFormat )( 
            _Application * This,
            /* [in] */ CellFormat	*RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ReplaceFormat )( 
            _Application * This,
            /* [retval][out] */ CellFormat	**RHS);
        
        /* [helpcontext][propputref][id] */ HRESULT ( STDMETHODCALLTYPE *putref_ReplaceFormat )( 
            _Application * This,
            /* [in] */ CellFormat	*RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_UsedObjects )( 
            _Application * This,
            /* [retval][out] */ UsedObjects	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_CalculationState )( 
            _Application * This,
            /* [retval][out] */ XlCalculationState *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_CalculationInterruptKey )( 
            _Application * This,
            /* [retval][out] */ XlCalculationInterruptKey *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_CalculationInterruptKey )( 
            _Application * This,
            /* [in] */ XlCalculationInterruptKey RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Watches )( 
            _Application * This,
            /* [retval][out] */ Watches	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_DisplayFunctionToolTips )( 
            _Application * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_DisplayFunctionToolTips )( 
            _Application * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_AutomationSecurity )( 
            _Application * This,
            /* [retval][out] */ MsoAutomationSecurity *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_AutomationSecurity )( 
            _Application * This,
            /* [in] */ MsoAutomationSecurity RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_FileDialog )( 
            _Application * This,
            /* [in] */ MsoFileDialogType fileDialogType,
            /* [retval][out] */ /* external definition not present */ FileDialog **RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *Dummy14 )( 
            _Application * This);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *CalculateFullRebuild )( 
            _Application * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_DisplayPasteOptions )( 
            _Application * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_DisplayPasteOptions )( 
            _Application * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_DisplayInsertOptions )( 
            _Application * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_DisplayInsertOptions )( 
            _Application * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_GenerateGetPivotData )( 
            _Application * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_GenerateGetPivotData )( 
            _Application * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_AutoRecover )( 
            _Application * This,
            /* [retval][out] */ AutoRecover	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Hwnd )( 
            _Application * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Hinstance )( 
            _Application * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *CheckAbort )( 
            _Application * This,
            /* [optional][in] */ VARIANT KeepAbort);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ErrorCheckingOptions )( 
            _Application * This,
            /* [retval][out] */ ErrorCheckingOptions	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_AutoFormatAsYouTypeReplaceHyperlinks )( 
            _Application * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_AutoFormatAsYouTypeReplaceHyperlinks )( 
            _Application * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_SmartTagRecognizers )( 
            _Application * This,
            /* [retval][out] */ SmartTagRecognizers	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_NewWorkbook )( 
            _Application * This,
            /* [retval][out] */ /* external definition not present */ NewFile **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_SpellingOptions )( 
            _Application * This,
            /* [retval][out] */ SpellingOptions	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Speech )( 
            _Application * This,
            /* [retval][out] */ Speech	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_MapPaperSize )( 
            _Application * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_MapPaperSize )( 
            _Application * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ShowStartupDialog )( 
            _Application * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_ShowStartupDialog )( 
            _Application * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_DecimalSeparator )( 
            _Application * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_DecimalSeparator )( 
            _Application * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ThousandsSeparator )( 
            _Application * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_ThousandsSeparator )( 
            _Application * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_UseSystemSeparators )( 
            _Application * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_UseSystemSeparators )( 
            _Application * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ThisCell )( 
            _Application * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_RTD )( 
            _Application * This,
            /* [retval][out] */ RTD	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_DisplayDocumentActionTaskPane )( 
            _Application * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_DisplayDocumentActionTaskPane )( 
            _Application * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *DisplayXMLSourcePane )( 
            _Application * This,
            /* [optional][in] */ VARIANT XmlMap);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ArbitraryXMLSupportAvailable )( 
            _Application * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *Support )( 
            _Application * This,
            /* [in] */ IDispatch *Object,
            /* [in] */ long ID,
            /* [optional][in] */ VARIANT arg,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *Dummy20 )( 
            _Application * This,
            /* [in] */ long grfCompareFunctions,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_MeasurementUnit )( 
            _Application * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_MeasurementUnit )( 
            _Application * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ShowSelectionFloaties )( 
            _Application * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_ShowSelectionFloaties )( 
            _Application * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ShowMenuFloaties )( 
            _Application * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_ShowMenuFloaties )( 
            _Application * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ShowDevTools )( 
            _Application * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_ShowDevTools )( 
            _Application * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_EnableLivePreview )( 
            _Application * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_EnableLivePreview )( 
            _Application * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_DisplayDocumentInformationPanel )( 
            _Application * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_DisplayDocumentInformationPanel )( 
            _Application * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_AlwaysUseClearType )( 
            _Application * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_AlwaysUseClearType )( 
            _Application * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_WarnOnFunctionNameConflict )( 
            _Application * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_WarnOnFunctionNameConflict )( 
            _Application * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_FormulaBarHeight )( 
            _Application * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_FormulaBarHeight )( 
            _Application * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_DisplayFormulaAutoComplete )( 
            _Application * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_DisplayFormulaAutoComplete )( 
            _Application * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_GenerateTableRefs )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ XlGenerateTableRefs *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_GenerateTableRefs )( 
            _Application * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ XlGenerateTableRefs RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Assistance )( 
            _Application * This,
            /* [retval][out] */ /* external definition not present */ IAssistance **RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *CalculateUntilAsyncQueriesDone )( 
            _Application * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_EnableLargeOperationAlert )( 
            _Application * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_EnableLargeOperationAlert )( 
            _Application * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_LargeOperationCellThousandCount )( 
            _Application * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_LargeOperationCellThousandCount )( 
            _Application * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_DeferAsyncQueries )( 
            _Application * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_DeferAsyncQueries )( 
            _Application * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_MultiThreadedCalculation )( 
            _Application * This,
            /* [retval][out] */ MultiThreadedCalculation	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *SharePointVersion )( 
            _Application * This,
            /* [in] */ BSTR bstrUrl,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ActiveEncryptionSession )( 
            _Application * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_HighQualityModeForGraphics )( 
            _Application * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_HighQualityModeForGraphics )( 
            _Application * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_FileExportConverters )( 
            _Application * This,
            /* [retval][out] */ FileExportConverters	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_SmartArtLayouts )( 
            _Application * This,
            /* [retval][out] */ /* external definition not present */ SmartArtLayouts **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_SmartArtQuickStyles )( 
            _Application * This,
            /* [retval][out] */ /* external definition not present */ SmartArtQuickStyles **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_SmartArtColors )( 
            _Application * This,
            /* [retval][out] */ /* external definition not present */ SmartArtColors **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_AddIns2 )( 
            _Application * This,
            /* [retval][out] */ AddIns2	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_PrintCommunication )( 
            _Application * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_PrintCommunication )( 
            _Application * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [custom][helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *MacroOptions )( 
            _Application * This,
            /* [optional][in] */ VARIANT Macro,
            /* [optional][in] */ VARIANT Description,
            /* [optional][in] */ VARIANT HasMenu,
            /* [optional][in] */ VARIANT MenuText,
            /* [optional][in] */ VARIANT HasShortcutKey,
            /* [optional][in] */ VARIANT ShortcutKey,
            /* [optional][in] */ VARIANT Category,
            /* [optional][in] */ VARIANT StatusBar,
            /* [optional][in] */ VARIANT HelpContextID,
            /* [optional][in] */ VARIANT HelpFile,
            /* [optional][in] */ VARIANT ArgumentDescriptions,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_UseClusterConnector )( 
            _Application * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_UseClusterConnector )( 
            _Application * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ClusterConnector )( 
            _Application * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_ClusterConnector )( 
            _Application * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Quitting )( 
            _Application * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Dummy22 )( 
            _Application * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Dummy22 )( 
            _Application * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Dummy23 )( 
            _Application * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Dummy23 )( 
            _Application * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ProtectedViewWindows )( 
            _Application * This,
            /* [retval][out] */ ProtectedViewWindows	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ActiveProtectedViewWindow )( 
            _Application * This,
            /* [retval][out] */ ProtectedViewWindow	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_IsSandboxed )( 
            _Application * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_SaveISO8601Dates )( 
            _Application * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_SaveISO8601Dates )( 
            _Application * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_HinstancePtr )( 
            _Application * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_FileValidation )( 
            _Application * This,
            /* [retval][out] */ MsoFileValidationMode *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_FileValidation )( 
            _Application * This,
            /* [in] */ MsoFileValidationMode RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_FileValidationPivot )( 
            _Application * This,
            /* [retval][out] */ XlFileValidationPivotMode *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_FileValidationPivot )( 
            _Application * This,
            /* [in] */ XlFileValidationPivotMode RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ShowQuickAnalysis )( 
            _Application * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_ShowQuickAnalysis )( 
            _Application * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_QuickAnalysis )( 
            _Application * This,
            /* [retval][out] */ QuickAnalysis	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_FlashFill )( 
            _Application * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_FlashFill )( 
            _Application * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_EnableMacroAnimations )( 
            _Application * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_EnableMacroAnimations )( 
            _Application * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ChartDataPointTrack )( 
            _Application * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_ChartDataPointTrack )( 
            _Application * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_FlashFillMode )( 
            _Application * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_FlashFillMode )( 
            _Application * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_MergeInstances )( 
            _Application * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_MergeInstances )( 
            _Application * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_EnableCheckFileExtensions )( 
            _Application * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_EnableCheckFileExtensions )( 
            _Application * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_DebugTools )( 
            _Application * This,
            /* [retval][out] */ _DebugTools **RHS);
        
        END_INTERFACE
    } _ApplicationVtbl;

    interface _Application
    {
        CONST_VTBL struct _ApplicationVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define _Application_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define _Application_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define _Application_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define _Application_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define _Application_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define _Application_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define _Application_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define _Application_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define _Application_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define _Application_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define _Application_get_ActiveCell(This,RHS)	\
    ( (This)->lpVtbl -> get_ActiveCell(This,RHS) ) 

#define _Application_get_ActiveChart(This,RHS)	\
    ( (This)->lpVtbl -> get_ActiveChart(This,RHS) ) 

#define _Application_get_ActiveDialog(This,RHS)	\
    ( (This)->lpVtbl -> get_ActiveDialog(This,RHS) ) 

#define _Application_get_ActiveMenuBar(This,RHS)	\
    ( (This)->lpVtbl -> get_ActiveMenuBar(This,RHS) ) 

#define _Application_get_ActivePrinter(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_ActivePrinter(This,lcid,RHS) ) 

#define _Application_put_ActivePrinter(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_ActivePrinter(This,lcid,RHS) ) 

#define _Application_get_ActiveSheet(This,RHS)	\
    ( (This)->lpVtbl -> get_ActiveSheet(This,RHS) ) 

#define _Application_get_ActiveWindow(This,RHS)	\
    ( (This)->lpVtbl -> get_ActiveWindow(This,RHS) ) 

#define _Application_get_ActiveWorkbook(This,RHS)	\
    ( (This)->lpVtbl -> get_ActiveWorkbook(This,RHS) ) 

#define _Application_get_AddIns(This,RHS)	\
    ( (This)->lpVtbl -> get_AddIns(This,RHS) ) 

#define _Application_get_Assistant(This,RHS)	\
    ( (This)->lpVtbl -> get_Assistant(This,RHS) ) 

#define _Application_Calculate(This,lcid)	\
    ( (This)->lpVtbl -> Calculate(This,lcid) ) 

#define _Application_get_Cells(This,RHS)	\
    ( (This)->lpVtbl -> get_Cells(This,RHS) ) 

#define _Application_get_Charts(This,RHS)	\
    ( (This)->lpVtbl -> get_Charts(This,RHS) ) 

#define _Application_get_Columns(This,RHS)	\
    ( (This)->lpVtbl -> get_Columns(This,RHS) ) 

#define _Application_get_CommandBars(This,RHS)	\
    ( (This)->lpVtbl -> get_CommandBars(This,RHS) ) 

#define _Application_get_DDEAppReturnCode(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_DDEAppReturnCode(This,lcid,RHS) ) 

#define _Application_DDEExecute(This,Channel,String,lcid)	\
    ( (This)->lpVtbl -> DDEExecute(This,Channel,String,lcid) ) 

#define _Application_DDEInitiate(This,App,Topic,lcid,RHS)	\
    ( (This)->lpVtbl -> DDEInitiate(This,App,Topic,lcid,RHS) ) 

#define _Application_DDEPoke(This,Channel,Item,Data,lcid)	\
    ( (This)->lpVtbl -> DDEPoke(This,Channel,Item,Data,lcid) ) 

#define _Application_DDERequest(This,Channel,Item,lcid,RHS)	\
    ( (This)->lpVtbl -> DDERequest(This,Channel,Item,lcid,RHS) ) 

#define _Application_DDETerminate(This,Channel,lcid)	\
    ( (This)->lpVtbl -> DDETerminate(This,Channel,lcid) ) 

#define _Application_get_DialogSheets(This,RHS)	\
    ( (This)->lpVtbl -> get_DialogSheets(This,RHS) ) 

#define _Application_Evaluate(This,Name,lcid,RHS)	\
    ( (This)->lpVtbl -> Evaluate(This,Name,lcid,RHS) ) 

#define _Application__Evaluate(This,Name,lcid,RHS)	\
    ( (This)->lpVtbl -> _Evaluate(This,Name,lcid,RHS) ) 

#define _Application_ExecuteExcel4Macro(This,String,lcid,RHS)	\
    ( (This)->lpVtbl -> ExecuteExcel4Macro(This,String,lcid,RHS) ) 

#define _Application_Intersect(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,lcid,RHS)	\
    ( (This)->lpVtbl -> Intersect(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,lcid,RHS) ) 

#define _Application_get_MenuBars(This,RHS)	\
    ( (This)->lpVtbl -> get_MenuBars(This,RHS) ) 

#define _Application_get_Modules(This,RHS)	\
    ( (This)->lpVtbl -> get_Modules(This,RHS) ) 

#define _Application_get_Names(This,RHS)	\
    ( (This)->lpVtbl -> get_Names(This,RHS) ) 

#define _Application_get_Range(This,Cell1,Cell2,RHS)	\
    ( (This)->lpVtbl -> get_Range(This,Cell1,Cell2,RHS) ) 

#define _Application_get_Rows(This,RHS)	\
    ( (This)->lpVtbl -> get_Rows(This,RHS) ) 

#define _Application_Run(This,Macro,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS)	\
    ( (This)->lpVtbl -> Run(This,Macro,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS) ) 

#define _Application__Run2(This,Macro,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,lcid,RHS)	\
    ( (This)->lpVtbl -> _Run2(This,Macro,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,lcid,RHS) ) 

#define _Application_get_Selection(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_Selection(This,lcid,RHS) ) 

#define _Application_SendKeys(This,Keys,Wait,lcid)	\
    ( (This)->lpVtbl -> SendKeys(This,Keys,Wait,lcid) ) 

#define _Application_get_Sheets(This,RHS)	\
    ( (This)->lpVtbl -> get_Sheets(This,RHS) ) 

#define _Application_get_ShortcutMenus(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_ShortcutMenus(This,Index,RHS) ) 

#define _Application_get_ThisWorkbook(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_ThisWorkbook(This,lcid,RHS) ) 

#define _Application_get_Toolbars(This,RHS)	\
    ( (This)->lpVtbl -> get_Toolbars(This,RHS) ) 

#define _Application_Union(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,lcid,RHS)	\
    ( (This)->lpVtbl -> Union(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,lcid,RHS) ) 

#define _Application_get_Windows(This,RHS)	\
    ( (This)->lpVtbl -> get_Windows(This,RHS) ) 

#define _Application_get_Workbooks(This,RHS)	\
    ( (This)->lpVtbl -> get_Workbooks(This,RHS) ) 

#define _Application_get_WorksheetFunction(This,RHS)	\
    ( (This)->lpVtbl -> get_WorksheetFunction(This,RHS) ) 

#define _Application_get_Worksheets(This,RHS)	\
    ( (This)->lpVtbl -> get_Worksheets(This,RHS) ) 

#define _Application_get_Excel4IntlMacroSheets(This,RHS)	\
    ( (This)->lpVtbl -> get_Excel4IntlMacroSheets(This,RHS) ) 

#define _Application_get_Excel4MacroSheets(This,RHS)	\
    ( (This)->lpVtbl -> get_Excel4MacroSheets(This,RHS) ) 

#define _Application_ActivateMicrosoftApp(This,Index,lcid)	\
    ( (This)->lpVtbl -> ActivateMicrosoftApp(This,Index,lcid) ) 

#define _Application_AddChartAutoFormat(This,Chart,Name,Description,lcid)	\
    ( (This)->lpVtbl -> AddChartAutoFormat(This,Chart,Name,Description,lcid) ) 

#define _Application_AddCustomList(This,ListArray,ByRow,lcid)	\
    ( (This)->lpVtbl -> AddCustomList(This,ListArray,ByRow,lcid) ) 

#define _Application_get_AlertBeforeOverwriting(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_AlertBeforeOverwriting(This,lcid,RHS) ) 

#define _Application_put_AlertBeforeOverwriting(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_AlertBeforeOverwriting(This,lcid,RHS) ) 

#define _Application_get_AltStartupPath(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_AltStartupPath(This,lcid,RHS) ) 

#define _Application_put_AltStartupPath(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_AltStartupPath(This,lcid,RHS) ) 

#define _Application_get_AskToUpdateLinks(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_AskToUpdateLinks(This,lcid,RHS) ) 

#define _Application_put_AskToUpdateLinks(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_AskToUpdateLinks(This,lcid,RHS) ) 

#define _Application_get_EnableAnimations(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_EnableAnimations(This,lcid,RHS) ) 

#define _Application_put_EnableAnimations(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_EnableAnimations(This,lcid,RHS) ) 

#define _Application_get_AutoCorrect(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoCorrect(This,RHS) ) 

#define _Application_get_Build(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_Build(This,lcid,RHS) ) 

#define _Application_get_CalculateBeforeSave(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_CalculateBeforeSave(This,lcid,RHS) ) 

#define _Application_put_CalculateBeforeSave(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_CalculateBeforeSave(This,lcid,RHS) ) 

#define _Application_get_Calculation(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_Calculation(This,lcid,RHS) ) 

#define _Application_put_Calculation(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_Calculation(This,lcid,RHS) ) 

#define _Application_get_Caller(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> get_Caller(This,Index,lcid,RHS) ) 

#define _Application_get_CanPlaySounds(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_CanPlaySounds(This,lcid,RHS) ) 

#define _Application_get_CanRecordSounds(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_CanRecordSounds(This,lcid,RHS) ) 

#define _Application_get_Caption(This,RHS)	\
    ( (This)->lpVtbl -> get_Caption(This,RHS) ) 

#define _Application_put_Caption(This,RHS)	\
    ( (This)->lpVtbl -> put_Caption(This,RHS) ) 

#define _Application_get_CellDragAndDrop(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_CellDragAndDrop(This,lcid,RHS) ) 

#define _Application_put_CellDragAndDrop(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_CellDragAndDrop(This,lcid,RHS) ) 

#define _Application_CentimetersToPoints(This,Centimeters,lcid,RHS)	\
    ( (This)->lpVtbl -> CentimetersToPoints(This,Centimeters,lcid,RHS) ) 

#define _Application_CheckSpelling(This,Word,CustomDictionary,IgnoreUppercase,lcid,RHS)	\
    ( (This)->lpVtbl -> CheckSpelling(This,Word,CustomDictionary,IgnoreUppercase,lcid,RHS) ) 

#define _Application_get_ClipboardFormats(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> get_ClipboardFormats(This,Index,lcid,RHS) ) 

#define _Application_get_DisplayClipboardWindow(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_DisplayClipboardWindow(This,lcid,RHS) ) 

#define _Application_put_DisplayClipboardWindow(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_DisplayClipboardWindow(This,lcid,RHS) ) 

#define _Application_get_ColorButtons(This,RHS)	\
    ( (This)->lpVtbl -> get_ColorButtons(This,RHS) ) 

#define _Application_put_ColorButtons(This,RHS)	\
    ( (This)->lpVtbl -> put_ColorButtons(This,RHS) ) 

#define _Application_get_CommandUnderlines(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_CommandUnderlines(This,lcid,RHS) ) 

#define _Application_put_CommandUnderlines(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_CommandUnderlines(This,lcid,RHS) ) 

#define _Application_get_ConstrainNumeric(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_ConstrainNumeric(This,lcid,RHS) ) 

#define _Application_put_ConstrainNumeric(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_ConstrainNumeric(This,lcid,RHS) ) 

#define _Application_ConvertFormula(This,Formula,FromReferenceStyle,ToReferenceStyle,ToAbsolute,RelativeTo,lcid,RHS)	\
    ( (This)->lpVtbl -> ConvertFormula(This,Formula,FromReferenceStyle,ToReferenceStyle,ToAbsolute,RelativeTo,lcid,RHS) ) 

#define _Application_get_CopyObjectsWithCells(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_CopyObjectsWithCells(This,lcid,RHS) ) 

#define _Application_put_CopyObjectsWithCells(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_CopyObjectsWithCells(This,lcid,RHS) ) 

#define _Application_get_Cursor(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_Cursor(This,lcid,RHS) ) 

#define _Application_put_Cursor(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_Cursor(This,lcid,RHS) ) 

#define _Application_get_CustomListCount(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_CustomListCount(This,lcid,RHS) ) 

#define _Application_get_CutCopyMode(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_CutCopyMode(This,lcid,RHS) ) 

#define _Application_put_CutCopyMode(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_CutCopyMode(This,lcid,RHS) ) 

#define _Application_get_DataEntryMode(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_DataEntryMode(This,lcid,RHS) ) 

#define _Application_put_DataEntryMode(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_DataEntryMode(This,lcid,RHS) ) 

#define _Application_Dummy1(This,Arg1,Arg2,Arg3,Arg4,RHS)	\
    ( (This)->lpVtbl -> Dummy1(This,Arg1,Arg2,Arg3,Arg4,RHS) ) 

#define _Application_Dummy2(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,RHS)	\
    ( (This)->lpVtbl -> Dummy2(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,RHS) ) 

#define _Application_Dummy3(This,RHS)	\
    ( (This)->lpVtbl -> Dummy3(This,RHS) ) 

#define _Application_Dummy4(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,RHS)	\
    ( (This)->lpVtbl -> Dummy4(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,RHS) ) 

#define _Application_Dummy5(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,RHS)	\
    ( (This)->lpVtbl -> Dummy5(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,RHS) ) 

#define _Application_Dummy6(This,RHS)	\
    ( (This)->lpVtbl -> Dummy6(This,RHS) ) 

#define _Application_Dummy7(This,RHS)	\
    ( (This)->lpVtbl -> Dummy7(This,RHS) ) 

#define _Application_Dummy8(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> Dummy8(This,Arg1,RHS) ) 

#define _Application_Dummy9(This,RHS)	\
    ( (This)->lpVtbl -> Dummy9(This,RHS) ) 

#define _Application_Dummy10(This,arg,RHS)	\
    ( (This)->lpVtbl -> Dummy10(This,arg,RHS) ) 

#define _Application_Dummy11(This)	\
    ( (This)->lpVtbl -> Dummy11(This) ) 

#define _Application_get__Default(This,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,RHS) ) 

#define _Application_get_DefaultFilePath(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_DefaultFilePath(This,lcid,RHS) ) 

#define _Application_put_DefaultFilePath(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_DefaultFilePath(This,lcid,RHS) ) 

#define _Application_DeleteChartAutoFormat(This,Name,lcid)	\
    ( (This)->lpVtbl -> DeleteChartAutoFormat(This,Name,lcid) ) 

#define _Application_DeleteCustomList(This,ListNum,lcid)	\
    ( (This)->lpVtbl -> DeleteCustomList(This,ListNum,lcid) ) 

#define _Application_get_Dialogs(This,RHS)	\
    ( (This)->lpVtbl -> get_Dialogs(This,RHS) ) 

#define _Application_get_DisplayAlerts(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_DisplayAlerts(This,lcid,RHS) ) 

#define _Application_put_DisplayAlerts(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_DisplayAlerts(This,lcid,RHS) ) 

#define _Application_get_DisplayFormulaBar(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_DisplayFormulaBar(This,lcid,RHS) ) 

#define _Application_put_DisplayFormulaBar(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_DisplayFormulaBar(This,lcid,RHS) ) 

#define _Application_get_DisplayFullScreen(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_DisplayFullScreen(This,lcid,RHS) ) 

#define _Application_put_DisplayFullScreen(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_DisplayFullScreen(This,lcid,RHS) ) 

#define _Application_get_DisplayNoteIndicator(This,RHS)	\
    ( (This)->lpVtbl -> get_DisplayNoteIndicator(This,RHS) ) 

#define _Application_put_DisplayNoteIndicator(This,RHS)	\
    ( (This)->lpVtbl -> put_DisplayNoteIndicator(This,RHS) ) 

#define _Application_get_DisplayCommentIndicator(This,RHS)	\
    ( (This)->lpVtbl -> get_DisplayCommentIndicator(This,RHS) ) 

#define _Application_put_DisplayCommentIndicator(This,RHS)	\
    ( (This)->lpVtbl -> put_DisplayCommentIndicator(This,RHS) ) 

#define _Application_get_DisplayExcel4Menus(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_DisplayExcel4Menus(This,lcid,RHS) ) 

#define _Application_put_DisplayExcel4Menus(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_DisplayExcel4Menus(This,lcid,RHS) ) 

#define _Application_get_DisplayRecentFiles(This,RHS)	\
    ( (This)->lpVtbl -> get_DisplayRecentFiles(This,RHS) ) 

#define _Application_put_DisplayRecentFiles(This,RHS)	\
    ( (This)->lpVtbl -> put_DisplayRecentFiles(This,RHS) ) 

#define _Application_get_DisplayScrollBars(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_DisplayScrollBars(This,lcid,RHS) ) 

#define _Application_put_DisplayScrollBars(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_DisplayScrollBars(This,lcid,RHS) ) 

#define _Application_get_DisplayStatusBar(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_DisplayStatusBar(This,lcid,RHS) ) 

#define _Application_put_DisplayStatusBar(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_DisplayStatusBar(This,lcid,RHS) ) 

#define _Application_DoubleClick(This,lcid)	\
    ( (This)->lpVtbl -> DoubleClick(This,lcid) ) 

#define _Application_get_EditDirectlyInCell(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_EditDirectlyInCell(This,lcid,RHS) ) 

#define _Application_put_EditDirectlyInCell(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_EditDirectlyInCell(This,lcid,RHS) ) 

#define _Application_get_EnableAutoComplete(This,RHS)	\
    ( (This)->lpVtbl -> get_EnableAutoComplete(This,RHS) ) 

#define _Application_put_EnableAutoComplete(This,RHS)	\
    ( (This)->lpVtbl -> put_EnableAutoComplete(This,RHS) ) 

#define _Application_get_EnableCancelKey(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_EnableCancelKey(This,lcid,RHS) ) 

#define _Application_put_EnableCancelKey(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_EnableCancelKey(This,lcid,RHS) ) 

#define _Application_get_EnableSound(This,RHS)	\
    ( (This)->lpVtbl -> get_EnableSound(This,RHS) ) 

#define _Application_put_EnableSound(This,RHS)	\
    ( (This)->lpVtbl -> put_EnableSound(This,RHS) ) 

#define _Application_get_EnableTipWizard(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_EnableTipWizard(This,lcid,RHS) ) 

#define _Application_put_EnableTipWizard(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_EnableTipWizard(This,lcid,RHS) ) 

#define _Application_get_FileConverters(This,Index1,Index2,lcid,RHS)	\
    ( (This)->lpVtbl -> get_FileConverters(This,Index1,Index2,lcid,RHS) ) 

#define _Application_get_FileSearch(This,RHS)	\
    ( (This)->lpVtbl -> get_FileSearch(This,RHS) ) 

#define _Application_get_FileFind(This,RHS)	\
    ( (This)->lpVtbl -> get_FileFind(This,RHS) ) 

#define _Application__FindFile(This,lcid)	\
    ( (This)->lpVtbl -> _FindFile(This,lcid) ) 

#define _Application_get_FixedDecimal(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_FixedDecimal(This,lcid,RHS) ) 

#define _Application_put_FixedDecimal(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_FixedDecimal(This,lcid,RHS) ) 

#define _Application_get_FixedDecimalPlaces(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_FixedDecimalPlaces(This,lcid,RHS) ) 

#define _Application_put_FixedDecimalPlaces(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_FixedDecimalPlaces(This,lcid,RHS) ) 

#define _Application_GetCustomListContents(This,ListNum,lcid,RHS)	\
    ( (This)->lpVtbl -> GetCustomListContents(This,ListNum,lcid,RHS) ) 

#define _Application_GetCustomListNum(This,ListArray,lcid,RHS)	\
    ( (This)->lpVtbl -> GetCustomListNum(This,ListArray,lcid,RHS) ) 

#define _Application_GetOpenFilename(This,FileFilter,FilterIndex,Title,ButtonText,MultiSelect,lcid,RHS)	\
    ( (This)->lpVtbl -> GetOpenFilename(This,FileFilter,FilterIndex,Title,ButtonText,MultiSelect,lcid,RHS) ) 

#define _Application_GetSaveAsFilename(This,InitialFilename,FileFilter,FilterIndex,Title,ButtonText,lcid,RHS)	\
    ( (This)->lpVtbl -> GetSaveAsFilename(This,InitialFilename,FileFilter,FilterIndex,Title,ButtonText,lcid,RHS) ) 

#define _Application_Goto(This,Reference,Scroll,lcid)	\
    ( (This)->lpVtbl -> Goto(This,Reference,Scroll,lcid) ) 

#define _Application_get_Height(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_Height(This,lcid,RHS) ) 

#define _Application_put_Height(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_Height(This,lcid,RHS) ) 

#define _Application_Help(This,HelpFile,HelpContextID,lcid)	\
    ( (This)->lpVtbl -> Help(This,HelpFile,HelpContextID,lcid) ) 

#define _Application_get_IgnoreRemoteRequests(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_IgnoreRemoteRequests(This,lcid,RHS) ) 

#define _Application_put_IgnoreRemoteRequests(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_IgnoreRemoteRequests(This,lcid,RHS) ) 

#define _Application_InchesToPoints(This,Inches,lcid,RHS)	\
    ( (This)->lpVtbl -> InchesToPoints(This,Inches,lcid,RHS) ) 

#define _Application_InputBox(This,Prompt,Title,Default,Left,Top,HelpFile,HelpContextID,Type,lcid,RHS)	\
    ( (This)->lpVtbl -> InputBox(This,Prompt,Title,Default,Left,Top,HelpFile,HelpContextID,Type,lcid,RHS) ) 

#define _Application_get_Interactive(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_Interactive(This,lcid,RHS) ) 

#define _Application_put_Interactive(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_Interactive(This,lcid,RHS) ) 

#define _Application_get_International(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> get_International(This,Index,lcid,RHS) ) 

#define _Application_get_Iteration(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_Iteration(This,lcid,RHS) ) 

#define _Application_put_Iteration(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_Iteration(This,lcid,RHS) ) 

#define _Application_get_LargeButtons(This,RHS)	\
    ( (This)->lpVtbl -> get_LargeButtons(This,RHS) ) 

#define _Application_put_LargeButtons(This,RHS)	\
    ( (This)->lpVtbl -> put_LargeButtons(This,RHS) ) 

#define _Application_get_Left(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_Left(This,lcid,RHS) ) 

#define _Application_put_Left(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_Left(This,lcid,RHS) ) 

#define _Application_get_LibraryPath(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_LibraryPath(This,lcid,RHS) ) 

#define _Application__MacroOptions(This,Macro,Description,HasMenu,MenuText,HasShortcutKey,ShortcutKey,Category,StatusBar,HelpContextID,HelpFile,lcid)	\
    ( (This)->lpVtbl -> _MacroOptions(This,Macro,Description,HasMenu,MenuText,HasShortcutKey,ShortcutKey,Category,StatusBar,HelpContextID,HelpFile,lcid) ) 

#define _Application_MailLogoff(This,lcid)	\
    ( (This)->lpVtbl -> MailLogoff(This,lcid) ) 

#define _Application_MailLogon(This,Name,Password,DownloadNewMail,lcid)	\
    ( (This)->lpVtbl -> MailLogon(This,Name,Password,DownloadNewMail,lcid) ) 

#define _Application_get_MailSession(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_MailSession(This,lcid,RHS) ) 

#define _Application_get_MailSystem(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_MailSystem(This,lcid,RHS) ) 

#define _Application_get_MathCoprocessorAvailable(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_MathCoprocessorAvailable(This,lcid,RHS) ) 

#define _Application_get_MaxChange(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_MaxChange(This,lcid,RHS) ) 

#define _Application_put_MaxChange(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_MaxChange(This,lcid,RHS) ) 

#define _Application_get_MaxIterations(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_MaxIterations(This,lcid,RHS) ) 

#define _Application_put_MaxIterations(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_MaxIterations(This,lcid,RHS) ) 

#define _Application_get_MemoryFree(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_MemoryFree(This,lcid,RHS) ) 

#define _Application_get_MemoryTotal(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_MemoryTotal(This,lcid,RHS) ) 

#define _Application_get_MemoryUsed(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_MemoryUsed(This,lcid,RHS) ) 

#define _Application_get_MouseAvailable(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_MouseAvailable(This,lcid,RHS) ) 

#define _Application_get_MoveAfterReturn(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_MoveAfterReturn(This,lcid,RHS) ) 

#define _Application_put_MoveAfterReturn(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_MoveAfterReturn(This,lcid,RHS) ) 

#define _Application_get_MoveAfterReturnDirection(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_MoveAfterReturnDirection(This,lcid,RHS) ) 

#define _Application_put_MoveAfterReturnDirection(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_MoveAfterReturnDirection(This,lcid,RHS) ) 

#define _Application_get_RecentFiles(This,RHS)	\
    ( (This)->lpVtbl -> get_RecentFiles(This,RHS) ) 

#define _Application_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define _Application_NextLetter(This,lcid,RHS)	\
    ( (This)->lpVtbl -> NextLetter(This,lcid,RHS) ) 

#define _Application_get_NetworkTemplatesPath(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_NetworkTemplatesPath(This,lcid,RHS) ) 

#define _Application_get_ODBCErrors(This,RHS)	\
    ( (This)->lpVtbl -> get_ODBCErrors(This,RHS) ) 

#define _Application_get_ODBCTimeout(This,RHS)	\
    ( (This)->lpVtbl -> get_ODBCTimeout(This,RHS) ) 

#define _Application_put_ODBCTimeout(This,RHS)	\
    ( (This)->lpVtbl -> put_ODBCTimeout(This,RHS) ) 

#define _Application_get_OnCalculate(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_OnCalculate(This,lcid,RHS) ) 

#define _Application_put_OnCalculate(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_OnCalculate(This,lcid,RHS) ) 

#define _Application_get_OnData(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_OnData(This,lcid,RHS) ) 

#define _Application_put_OnData(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_OnData(This,lcid,RHS) ) 

#define _Application_get_OnDoubleClick(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_OnDoubleClick(This,lcid,RHS) ) 

#define _Application_put_OnDoubleClick(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_OnDoubleClick(This,lcid,RHS) ) 

#define _Application_get_OnEntry(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_OnEntry(This,lcid,RHS) ) 

#define _Application_put_OnEntry(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_OnEntry(This,lcid,RHS) ) 

#define _Application_OnKey(This,Key,Procedure,lcid)	\
    ( (This)->lpVtbl -> OnKey(This,Key,Procedure,lcid) ) 

#define _Application_OnRepeat(This,Text,Procedure,lcid)	\
    ( (This)->lpVtbl -> OnRepeat(This,Text,Procedure,lcid) ) 

#define _Application_get_OnSheetActivate(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_OnSheetActivate(This,lcid,RHS) ) 

#define _Application_put_OnSheetActivate(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_OnSheetActivate(This,lcid,RHS) ) 

#define _Application_get_OnSheetDeactivate(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_OnSheetDeactivate(This,lcid,RHS) ) 

#define _Application_put_OnSheetDeactivate(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_OnSheetDeactivate(This,lcid,RHS) ) 

#define _Application_OnTime(This,EarliestTime,Procedure,LatestTime,Schedule,lcid)	\
    ( (This)->lpVtbl -> OnTime(This,EarliestTime,Procedure,LatestTime,Schedule,lcid) ) 

#define _Application_OnUndo(This,Text,Procedure,lcid)	\
    ( (This)->lpVtbl -> OnUndo(This,Text,Procedure,lcid) ) 

#define _Application_get_OnWindow(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_OnWindow(This,lcid,RHS) ) 

#define _Application_put_OnWindow(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_OnWindow(This,lcid,RHS) ) 

#define _Application_get_OperatingSystem(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_OperatingSystem(This,lcid,RHS) ) 

#define _Application_get_OrganizationName(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_OrganizationName(This,lcid,RHS) ) 

#define _Application_get_Path(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_Path(This,lcid,RHS) ) 

#define _Application_get_PathSeparator(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_PathSeparator(This,lcid,RHS) ) 

#define _Application_get_PreviousSelections(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> get_PreviousSelections(This,Index,lcid,RHS) ) 

#define _Application_get_PivotTableSelection(This,RHS)	\
    ( (This)->lpVtbl -> get_PivotTableSelection(This,RHS) ) 

#define _Application_put_PivotTableSelection(This,RHS)	\
    ( (This)->lpVtbl -> put_PivotTableSelection(This,RHS) ) 

#define _Application_get_PromptForSummaryInfo(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_PromptForSummaryInfo(This,lcid,RHS) ) 

#define _Application_put_PromptForSummaryInfo(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_PromptForSummaryInfo(This,lcid,RHS) ) 

#define _Application_Quit(This)	\
    ( (This)->lpVtbl -> Quit(This) ) 

#define _Application_RecordMacro(This,BasicCode,XlmCode,lcid)	\
    ( (This)->lpVtbl -> RecordMacro(This,BasicCode,XlmCode,lcid) ) 

#define _Application_get_RecordRelative(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_RecordRelative(This,lcid,RHS) ) 

#define _Application_get_ReferenceStyle(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_ReferenceStyle(This,lcid,RHS) ) 

#define _Application_put_ReferenceStyle(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_ReferenceStyle(This,lcid,RHS) ) 

#define _Application_get_RegisteredFunctions(This,Index1,Index2,lcid,RHS)	\
    ( (This)->lpVtbl -> get_RegisteredFunctions(This,Index1,Index2,lcid,RHS) ) 

#define _Application_RegisterXLL(This,Filename,lcid,RHS)	\
    ( (This)->lpVtbl -> RegisterXLL(This,Filename,lcid,RHS) ) 

#define _Application_Repeat(This,lcid)	\
    ( (This)->lpVtbl -> Repeat(This,lcid) ) 

#define _Application_ResetTipWizard(This,lcid)	\
    ( (This)->lpVtbl -> ResetTipWizard(This,lcid) ) 

#define _Application_get_RollZoom(This,RHS)	\
    ( (This)->lpVtbl -> get_RollZoom(This,RHS) ) 

#define _Application_put_RollZoom(This,RHS)	\
    ( (This)->lpVtbl -> put_RollZoom(This,RHS) ) 

#define _Application_Save(This,Filename,lcid)	\
    ( (This)->lpVtbl -> Save(This,Filename,lcid) ) 

#define _Application_SaveWorkspace(This,Filename,lcid)	\
    ( (This)->lpVtbl -> SaveWorkspace(This,Filename,lcid) ) 

#define _Application_get_ScreenUpdating(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_ScreenUpdating(This,lcid,RHS) ) 

#define _Application_put_ScreenUpdating(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_ScreenUpdating(This,lcid,RHS) ) 

#define _Application_SetDefaultChart(This,FormatName,Gallery)	\
    ( (This)->lpVtbl -> SetDefaultChart(This,FormatName,Gallery) ) 

#define _Application_get_SheetsInNewWorkbook(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_SheetsInNewWorkbook(This,lcid,RHS) ) 

#define _Application_put_SheetsInNewWorkbook(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_SheetsInNewWorkbook(This,lcid,RHS) ) 

#define _Application_get_ShowChartTipNames(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowChartTipNames(This,RHS) ) 

#define _Application_put_ShowChartTipNames(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowChartTipNames(This,RHS) ) 

#define _Application_get_ShowChartTipValues(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowChartTipValues(This,RHS) ) 

#define _Application_put_ShowChartTipValues(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowChartTipValues(This,RHS) ) 

#define _Application_get_StandardFont(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_StandardFont(This,lcid,RHS) ) 

#define _Application_put_StandardFont(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_StandardFont(This,lcid,RHS) ) 

#define _Application_get_StandardFontSize(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_StandardFontSize(This,lcid,RHS) ) 

#define _Application_put_StandardFontSize(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_StandardFontSize(This,lcid,RHS) ) 

#define _Application_get_StartupPath(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_StartupPath(This,lcid,RHS) ) 

#define _Application_get_StatusBar(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_StatusBar(This,lcid,RHS) ) 

#define _Application_put_StatusBar(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_StatusBar(This,lcid,RHS) ) 

#define _Application_get_TemplatesPath(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_TemplatesPath(This,lcid,RHS) ) 

#define _Application_get_ShowToolTips(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowToolTips(This,RHS) ) 

#define _Application_put_ShowToolTips(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowToolTips(This,RHS) ) 

#define _Application_get_Top(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_Top(This,lcid,RHS) ) 

#define _Application_put_Top(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_Top(This,lcid,RHS) ) 

#define _Application_get_DefaultSaveFormat(This,RHS)	\
    ( (This)->lpVtbl -> get_DefaultSaveFormat(This,RHS) ) 

#define _Application_put_DefaultSaveFormat(This,RHS)	\
    ( (This)->lpVtbl -> put_DefaultSaveFormat(This,RHS) ) 

#define _Application_get_TransitionMenuKey(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_TransitionMenuKey(This,lcid,RHS) ) 

#define _Application_put_TransitionMenuKey(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_TransitionMenuKey(This,lcid,RHS) ) 

#define _Application_get_TransitionMenuKeyAction(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_TransitionMenuKeyAction(This,lcid,RHS) ) 

#define _Application_put_TransitionMenuKeyAction(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_TransitionMenuKeyAction(This,lcid,RHS) ) 

#define _Application_get_TransitionNavigKeys(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_TransitionNavigKeys(This,lcid,RHS) ) 

#define _Application_put_TransitionNavigKeys(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_TransitionNavigKeys(This,lcid,RHS) ) 

#define _Application_Undo(This,lcid)	\
    ( (This)->lpVtbl -> Undo(This,lcid) ) 

#define _Application_get_UsableHeight(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_UsableHeight(This,lcid,RHS) ) 

#define _Application_get_UsableWidth(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_UsableWidth(This,lcid,RHS) ) 

#define _Application_get_UserControl(This,RHS)	\
    ( (This)->lpVtbl -> get_UserControl(This,RHS) ) 

#define _Application_put_UserControl(This,RHS)	\
    ( (This)->lpVtbl -> put_UserControl(This,RHS) ) 

#define _Application_get_UserName(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_UserName(This,lcid,RHS) ) 

#define _Application_put_UserName(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_UserName(This,lcid,RHS) ) 

#define _Application_get_Value(This,RHS)	\
    ( (This)->lpVtbl -> get_Value(This,RHS) ) 

#define _Application_get_VBE(This,RHS)	\
    ( (This)->lpVtbl -> get_VBE(This,RHS) ) 

#define _Application_get_Version(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_Version(This,lcid,RHS) ) 

#define _Application_get_Visible(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_Visible(This,lcid,RHS) ) 

#define _Application_put_Visible(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_Visible(This,lcid,RHS) ) 

#define _Application_Volatile(This,Volatile,lcid)	\
    ( (This)->lpVtbl -> Volatile(This,Volatile,lcid) ) 

#define _Application__Wait(This,Time,lcid)	\
    ( (This)->lpVtbl -> _Wait(This,Time,lcid) ) 

#define _Application_get_Width(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_Width(This,lcid,RHS) ) 

#define _Application_put_Width(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_Width(This,lcid,RHS) ) 

#define _Application_get_WindowsForPens(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_WindowsForPens(This,lcid,RHS) ) 

#define _Application_get_WindowState(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_WindowState(This,lcid,RHS) ) 

#define _Application_put_WindowState(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_WindowState(This,lcid,RHS) ) 

#define _Application_get_UILanguage(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_UILanguage(This,lcid,RHS) ) 

#define _Application_put_UILanguage(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_UILanguage(This,lcid,RHS) ) 

#define _Application_get_DefaultSheetDirection(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_DefaultSheetDirection(This,lcid,RHS) ) 

#define _Application_put_DefaultSheetDirection(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_DefaultSheetDirection(This,lcid,RHS) ) 

#define _Application_get_CursorMovement(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_CursorMovement(This,lcid,RHS) ) 

#define _Application_put_CursorMovement(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_CursorMovement(This,lcid,RHS) ) 

#define _Application_get_ControlCharacters(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_ControlCharacters(This,lcid,RHS) ) 

#define _Application_put_ControlCharacters(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_ControlCharacters(This,lcid,RHS) ) 

#define _Application__WSFunction(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,lcid,RHS)	\
    ( (This)->lpVtbl -> _WSFunction(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,lcid,RHS) ) 

#define _Application_get_EnableEvents(This,RHS)	\
    ( (This)->lpVtbl -> get_EnableEvents(This,RHS) ) 

#define _Application_put_EnableEvents(This,RHS)	\
    ( (This)->lpVtbl -> put_EnableEvents(This,RHS) ) 

#define _Application_get_DisplayInfoWindow(This,RHS)	\
    ( (This)->lpVtbl -> get_DisplayInfoWindow(This,RHS) ) 

#define _Application_put_DisplayInfoWindow(This,RHS)	\
    ( (This)->lpVtbl -> put_DisplayInfoWindow(This,RHS) ) 

#define _Application_Wait(This,Time,lcid,RHS)	\
    ( (This)->lpVtbl -> Wait(This,Time,lcid,RHS) ) 

#define _Application_get_ExtendList(This,RHS)	\
    ( (This)->lpVtbl -> get_ExtendList(This,RHS) ) 

#define _Application_put_ExtendList(This,RHS)	\
    ( (This)->lpVtbl -> put_ExtendList(This,RHS) ) 

#define _Application_get_OLEDBErrors(This,RHS)	\
    ( (This)->lpVtbl -> get_OLEDBErrors(This,RHS) ) 

#define _Application_GetPhonetic(This,Text,RHS)	\
    ( (This)->lpVtbl -> GetPhonetic(This,Text,RHS) ) 

#define _Application_get_COMAddIns(This,RHS)	\
    ( (This)->lpVtbl -> get_COMAddIns(This,RHS) ) 

#define _Application_get_DefaultWebOptions(This,RHS)	\
    ( (This)->lpVtbl -> get_DefaultWebOptions(This,RHS) ) 

#define _Application_get_ProductCode(This,RHS)	\
    ( (This)->lpVtbl -> get_ProductCode(This,RHS) ) 

#define _Application_get_UserLibraryPath(This,RHS)	\
    ( (This)->lpVtbl -> get_UserLibraryPath(This,RHS) ) 

#define _Application_get_AutoPercentEntry(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoPercentEntry(This,RHS) ) 

#define _Application_put_AutoPercentEntry(This,RHS)	\
    ( (This)->lpVtbl -> put_AutoPercentEntry(This,RHS) ) 

#define _Application_get_LanguageSettings(This,RHS)	\
    ( (This)->lpVtbl -> get_LanguageSettings(This,RHS) ) 

#define _Application_get_Dummy101(This,RHS)	\
    ( (This)->lpVtbl -> get_Dummy101(This,RHS) ) 

#define _Application_Dummy12(This,p1,p2)	\
    ( (This)->lpVtbl -> Dummy12(This,p1,p2) ) 

#define _Application_get_AnswerWizard(This,RHS)	\
    ( (This)->lpVtbl -> get_AnswerWizard(This,RHS) ) 

#define _Application_CalculateFull(This)	\
    ( (This)->lpVtbl -> CalculateFull(This) ) 

#define _Application_FindFile(This,lcid,RHS)	\
    ( (This)->lpVtbl -> FindFile(This,lcid,RHS) ) 

#define _Application_get_CalculationVersion(This,RHS)	\
    ( (This)->lpVtbl -> get_CalculationVersion(This,RHS) ) 

#define _Application_get_ShowWindowsInTaskbar(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowWindowsInTaskbar(This,RHS) ) 

#define _Application_put_ShowWindowsInTaskbar(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowWindowsInTaskbar(This,RHS) ) 

#define _Application_get_FeatureInstall(This,RHS)	\
    ( (This)->lpVtbl -> get_FeatureInstall(This,RHS) ) 

#define _Application_put_FeatureInstall(This,RHS)	\
    ( (This)->lpVtbl -> put_FeatureInstall(This,RHS) ) 

#define _Application_get_Ready(This,RHS)	\
    ( (This)->lpVtbl -> get_Ready(This,RHS) ) 

#define _Application_Dummy13(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS)	\
    ( (This)->lpVtbl -> Dummy13(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS) ) 

#define _Application_get_FindFormat(This,RHS)	\
    ( (This)->lpVtbl -> get_FindFormat(This,RHS) ) 

#define _Application_putref_FindFormat(This,RHS)	\
    ( (This)->lpVtbl -> putref_FindFormat(This,RHS) ) 

#define _Application_get_ReplaceFormat(This,RHS)	\
    ( (This)->lpVtbl -> get_ReplaceFormat(This,RHS) ) 

#define _Application_putref_ReplaceFormat(This,RHS)	\
    ( (This)->lpVtbl -> putref_ReplaceFormat(This,RHS) ) 

#define _Application_get_UsedObjects(This,RHS)	\
    ( (This)->lpVtbl -> get_UsedObjects(This,RHS) ) 

#define _Application_get_CalculationState(This,RHS)	\
    ( (This)->lpVtbl -> get_CalculationState(This,RHS) ) 

#define _Application_get_CalculationInterruptKey(This,RHS)	\
    ( (This)->lpVtbl -> get_CalculationInterruptKey(This,RHS) ) 

#define _Application_put_CalculationInterruptKey(This,RHS)	\
    ( (This)->lpVtbl -> put_CalculationInterruptKey(This,RHS) ) 

#define _Application_get_Watches(This,RHS)	\
    ( (This)->lpVtbl -> get_Watches(This,RHS) ) 

#define _Application_get_DisplayFunctionToolTips(This,RHS)	\
    ( (This)->lpVtbl -> get_DisplayFunctionToolTips(This,RHS) ) 

#define _Application_put_DisplayFunctionToolTips(This,RHS)	\
    ( (This)->lpVtbl -> put_DisplayFunctionToolTips(This,RHS) ) 

#define _Application_get_AutomationSecurity(This,RHS)	\
    ( (This)->lpVtbl -> get_AutomationSecurity(This,RHS) ) 

#define _Application_put_AutomationSecurity(This,RHS)	\
    ( (This)->lpVtbl -> put_AutomationSecurity(This,RHS) ) 

#define _Application_get_FileDialog(This,fileDialogType,RHS)	\
    ( (This)->lpVtbl -> get_FileDialog(This,fileDialogType,RHS) ) 

#define _Application_Dummy14(This)	\
    ( (This)->lpVtbl -> Dummy14(This) ) 

#define _Application_CalculateFullRebuild(This)	\
    ( (This)->lpVtbl -> CalculateFullRebuild(This) ) 

#define _Application_get_DisplayPasteOptions(This,RHS)	\
    ( (This)->lpVtbl -> get_DisplayPasteOptions(This,RHS) ) 

#define _Application_put_DisplayPasteOptions(This,RHS)	\
    ( (This)->lpVtbl -> put_DisplayPasteOptions(This,RHS) ) 

#define _Application_get_DisplayInsertOptions(This,RHS)	\
    ( (This)->lpVtbl -> get_DisplayInsertOptions(This,RHS) ) 

#define _Application_put_DisplayInsertOptions(This,RHS)	\
    ( (This)->lpVtbl -> put_DisplayInsertOptions(This,RHS) ) 

#define _Application_get_GenerateGetPivotData(This,RHS)	\
    ( (This)->lpVtbl -> get_GenerateGetPivotData(This,RHS) ) 

#define _Application_put_GenerateGetPivotData(This,RHS)	\
    ( (This)->lpVtbl -> put_GenerateGetPivotData(This,RHS) ) 

#define _Application_get_AutoRecover(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoRecover(This,RHS) ) 

#define _Application_get_Hwnd(This,RHS)	\
    ( (This)->lpVtbl -> get_Hwnd(This,RHS) ) 

#define _Application_get_Hinstance(This,RHS)	\
    ( (This)->lpVtbl -> get_Hinstance(This,RHS) ) 

#define _Application_CheckAbort(This,KeepAbort)	\
    ( (This)->lpVtbl -> CheckAbort(This,KeepAbort) ) 

#define _Application_get_ErrorCheckingOptions(This,RHS)	\
    ( (This)->lpVtbl -> get_ErrorCheckingOptions(This,RHS) ) 

#define _Application_get_AutoFormatAsYouTypeReplaceHyperlinks(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoFormatAsYouTypeReplaceHyperlinks(This,RHS) ) 

#define _Application_put_AutoFormatAsYouTypeReplaceHyperlinks(This,RHS)	\
    ( (This)->lpVtbl -> put_AutoFormatAsYouTypeReplaceHyperlinks(This,RHS) ) 

#define _Application_get_SmartTagRecognizers(This,RHS)	\
    ( (This)->lpVtbl -> get_SmartTagRecognizers(This,RHS) ) 

#define _Application_get_NewWorkbook(This,RHS)	\
    ( (This)->lpVtbl -> get_NewWorkbook(This,RHS) ) 

#define _Application_get_SpellingOptions(This,RHS)	\
    ( (This)->lpVtbl -> get_SpellingOptions(This,RHS) ) 

#define _Application_get_Speech(This,RHS)	\
    ( (This)->lpVtbl -> get_Speech(This,RHS) ) 

#define _Application_get_MapPaperSize(This,RHS)	\
    ( (This)->lpVtbl -> get_MapPaperSize(This,RHS) ) 

#define _Application_put_MapPaperSize(This,RHS)	\
    ( (This)->lpVtbl -> put_MapPaperSize(This,RHS) ) 

#define _Application_get_ShowStartupDialog(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowStartupDialog(This,RHS) ) 

#define _Application_put_ShowStartupDialog(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowStartupDialog(This,RHS) ) 

#define _Application_get_DecimalSeparator(This,RHS)	\
    ( (This)->lpVtbl -> get_DecimalSeparator(This,RHS) ) 

#define _Application_put_DecimalSeparator(This,RHS)	\
    ( (This)->lpVtbl -> put_DecimalSeparator(This,RHS) ) 

#define _Application_get_ThousandsSeparator(This,RHS)	\
    ( (This)->lpVtbl -> get_ThousandsSeparator(This,RHS) ) 

#define _Application_put_ThousandsSeparator(This,RHS)	\
    ( (This)->lpVtbl -> put_ThousandsSeparator(This,RHS) ) 

#define _Application_get_UseSystemSeparators(This,RHS)	\
    ( (This)->lpVtbl -> get_UseSystemSeparators(This,RHS) ) 

#define _Application_put_UseSystemSeparators(This,RHS)	\
    ( (This)->lpVtbl -> put_UseSystemSeparators(This,RHS) ) 

#define _Application_get_ThisCell(This,RHS)	\
    ( (This)->lpVtbl -> get_ThisCell(This,RHS) ) 

#define _Application_get_RTD(This,RHS)	\
    ( (This)->lpVtbl -> get_RTD(This,RHS) ) 

#define _Application_get_DisplayDocumentActionTaskPane(This,RHS)	\
    ( (This)->lpVtbl -> get_DisplayDocumentActionTaskPane(This,RHS) ) 

#define _Application_put_DisplayDocumentActionTaskPane(This,RHS)	\
    ( (This)->lpVtbl -> put_DisplayDocumentActionTaskPane(This,RHS) ) 

#define _Application_DisplayXMLSourcePane(This,XmlMap)	\
    ( (This)->lpVtbl -> DisplayXMLSourcePane(This,XmlMap) ) 

#define _Application_get_ArbitraryXMLSupportAvailable(This,RHS)	\
    ( (This)->lpVtbl -> get_ArbitraryXMLSupportAvailable(This,RHS) ) 

#define _Application_Support(This,Object,ID,arg,RHS)	\
    ( (This)->lpVtbl -> Support(This,Object,ID,arg,RHS) ) 

#define _Application_Dummy20(This,grfCompareFunctions,RHS)	\
    ( (This)->lpVtbl -> Dummy20(This,grfCompareFunctions,RHS) ) 

#define _Application_get_MeasurementUnit(This,RHS)	\
    ( (This)->lpVtbl -> get_MeasurementUnit(This,RHS) ) 

#define _Application_put_MeasurementUnit(This,RHS)	\
    ( (This)->lpVtbl -> put_MeasurementUnit(This,RHS) ) 

#define _Application_get_ShowSelectionFloaties(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowSelectionFloaties(This,RHS) ) 

#define _Application_put_ShowSelectionFloaties(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowSelectionFloaties(This,RHS) ) 

#define _Application_get_ShowMenuFloaties(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowMenuFloaties(This,RHS) ) 

#define _Application_put_ShowMenuFloaties(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowMenuFloaties(This,RHS) ) 

#define _Application_get_ShowDevTools(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowDevTools(This,RHS) ) 

#define _Application_put_ShowDevTools(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowDevTools(This,RHS) ) 

#define _Application_get_EnableLivePreview(This,RHS)	\
    ( (This)->lpVtbl -> get_EnableLivePreview(This,RHS) ) 

#define _Application_put_EnableLivePreview(This,RHS)	\
    ( (This)->lpVtbl -> put_EnableLivePreview(This,RHS) ) 

#define _Application_get_DisplayDocumentInformationPanel(This,RHS)	\
    ( (This)->lpVtbl -> get_DisplayDocumentInformationPanel(This,RHS) ) 

#define _Application_put_DisplayDocumentInformationPanel(This,RHS)	\
    ( (This)->lpVtbl -> put_DisplayDocumentInformationPanel(This,RHS) ) 

#define _Application_get_AlwaysUseClearType(This,RHS)	\
    ( (This)->lpVtbl -> get_AlwaysUseClearType(This,RHS) ) 

#define _Application_put_AlwaysUseClearType(This,RHS)	\
    ( (This)->lpVtbl -> put_AlwaysUseClearType(This,RHS) ) 

#define _Application_get_WarnOnFunctionNameConflict(This,RHS)	\
    ( (This)->lpVtbl -> get_WarnOnFunctionNameConflict(This,RHS) ) 

#define _Application_put_WarnOnFunctionNameConflict(This,RHS)	\
    ( (This)->lpVtbl -> put_WarnOnFunctionNameConflict(This,RHS) ) 

#define _Application_get_FormulaBarHeight(This,RHS)	\
    ( (This)->lpVtbl -> get_FormulaBarHeight(This,RHS) ) 

#define _Application_put_FormulaBarHeight(This,RHS)	\
    ( (This)->lpVtbl -> put_FormulaBarHeight(This,RHS) ) 

#define _Application_get_DisplayFormulaAutoComplete(This,RHS)	\
    ( (This)->lpVtbl -> get_DisplayFormulaAutoComplete(This,RHS) ) 

#define _Application_put_DisplayFormulaAutoComplete(This,RHS)	\
    ( (This)->lpVtbl -> put_DisplayFormulaAutoComplete(This,RHS) ) 

#define _Application_get_GenerateTableRefs(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_GenerateTableRefs(This,lcid,RHS) ) 

#define _Application_put_GenerateTableRefs(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_GenerateTableRefs(This,lcid,RHS) ) 

#define _Application_get_Assistance(This,RHS)	\
    ( (This)->lpVtbl -> get_Assistance(This,RHS) ) 

#define _Application_CalculateUntilAsyncQueriesDone(This)	\
    ( (This)->lpVtbl -> CalculateUntilAsyncQueriesDone(This) ) 

#define _Application_get_EnableLargeOperationAlert(This,RHS)	\
    ( (This)->lpVtbl -> get_EnableLargeOperationAlert(This,RHS) ) 

#define _Application_put_EnableLargeOperationAlert(This,RHS)	\
    ( (This)->lpVtbl -> put_EnableLargeOperationAlert(This,RHS) ) 

#define _Application_get_LargeOperationCellThousandCount(This,RHS)	\
    ( (This)->lpVtbl -> get_LargeOperationCellThousandCount(This,RHS) ) 

#define _Application_put_LargeOperationCellThousandCount(This,RHS)	\
    ( (This)->lpVtbl -> put_LargeOperationCellThousandCount(This,RHS) ) 

#define _Application_get_DeferAsyncQueries(This,RHS)	\
    ( (This)->lpVtbl -> get_DeferAsyncQueries(This,RHS) ) 

#define _Application_put_DeferAsyncQueries(This,RHS)	\
    ( (This)->lpVtbl -> put_DeferAsyncQueries(This,RHS) ) 

#define _Application_get_MultiThreadedCalculation(This,RHS)	\
    ( (This)->lpVtbl -> get_MultiThreadedCalculation(This,RHS) ) 

#define _Application_SharePointVersion(This,bstrUrl,RHS)	\
    ( (This)->lpVtbl -> SharePointVersion(This,bstrUrl,RHS) ) 

#define _Application_get_ActiveEncryptionSession(This,RHS)	\
    ( (This)->lpVtbl -> get_ActiveEncryptionSession(This,RHS) ) 

#define _Application_get_HighQualityModeForGraphics(This,RHS)	\
    ( (This)->lpVtbl -> get_HighQualityModeForGraphics(This,RHS) ) 

#define _Application_put_HighQualityModeForGraphics(This,RHS)	\
    ( (This)->lpVtbl -> put_HighQualityModeForGraphics(This,RHS) ) 

#define _Application_get_FileExportConverters(This,RHS)	\
    ( (This)->lpVtbl -> get_FileExportConverters(This,RHS) ) 

#define _Application_get_SmartArtLayouts(This,RHS)	\
    ( (This)->lpVtbl -> get_SmartArtLayouts(This,RHS) ) 

#define _Application_get_SmartArtQuickStyles(This,RHS)	\
    ( (This)->lpVtbl -> get_SmartArtQuickStyles(This,RHS) ) 

#define _Application_get_SmartArtColors(This,RHS)	\
    ( (This)->lpVtbl -> get_SmartArtColors(This,RHS) ) 

#define _Application_get_AddIns2(This,RHS)	\
    ( (This)->lpVtbl -> get_AddIns2(This,RHS) ) 

#define _Application_get_PrintCommunication(This,RHS)	\
    ( (This)->lpVtbl -> get_PrintCommunication(This,RHS) ) 

#define _Application_put_PrintCommunication(This,RHS)	\
    ( (This)->lpVtbl -> put_PrintCommunication(This,RHS) ) 

#define _Application_MacroOptions(This,Macro,Description,HasMenu,MenuText,HasShortcutKey,ShortcutKey,Category,StatusBar,HelpContextID,HelpFile,ArgumentDescriptions,lcid)	\
    ( (This)->lpVtbl -> MacroOptions(This,Macro,Description,HasMenu,MenuText,HasShortcutKey,ShortcutKey,Category,StatusBar,HelpContextID,HelpFile,ArgumentDescriptions,lcid) ) 

#define _Application_get_UseClusterConnector(This,RHS)	\
    ( (This)->lpVtbl -> get_UseClusterConnector(This,RHS) ) 

#define _Application_put_UseClusterConnector(This,RHS)	\
    ( (This)->lpVtbl -> put_UseClusterConnector(This,RHS) ) 

#define _Application_get_ClusterConnector(This,RHS)	\
    ( (This)->lpVtbl -> get_ClusterConnector(This,RHS) ) 

#define _Application_put_ClusterConnector(This,RHS)	\
    ( (This)->lpVtbl -> put_ClusterConnector(This,RHS) ) 

#define _Application_get_Quitting(This,RHS)	\
    ( (This)->lpVtbl -> get_Quitting(This,RHS) ) 

#define _Application_get_Dummy22(This,RHS)	\
    ( (This)->lpVtbl -> get_Dummy22(This,RHS) ) 

#define _Application_put_Dummy22(This,RHS)	\
    ( (This)->lpVtbl -> put_Dummy22(This,RHS) ) 

#define _Application_get_Dummy23(This,RHS)	\
    ( (This)->lpVtbl -> get_Dummy23(This,RHS) ) 

#define _Application_put_Dummy23(This,RHS)	\
    ( (This)->lpVtbl -> put_Dummy23(This,RHS) ) 

#define _Application_get_ProtectedViewWindows(This,RHS)	\
    ( (This)->lpVtbl -> get_ProtectedViewWindows(This,RHS) ) 

#define _Application_get_ActiveProtectedViewWindow(This,RHS)	\
    ( (This)->lpVtbl -> get_ActiveProtectedViewWindow(This,RHS) ) 

#define _Application_get_IsSandboxed(This,RHS)	\
    ( (This)->lpVtbl -> get_IsSandboxed(This,RHS) ) 

#define _Application_get_SaveISO8601Dates(This,RHS)	\
    ( (This)->lpVtbl -> get_SaveISO8601Dates(This,RHS) ) 

#define _Application_put_SaveISO8601Dates(This,RHS)	\
    ( (This)->lpVtbl -> put_SaveISO8601Dates(This,RHS) ) 

#define _Application_get_HinstancePtr(This,RHS)	\
    ( (This)->lpVtbl -> get_HinstancePtr(This,RHS) ) 

#define _Application_get_FileValidation(This,RHS)	\
    ( (This)->lpVtbl -> get_FileValidation(This,RHS) ) 

#define _Application_put_FileValidation(This,RHS)	\
    ( (This)->lpVtbl -> put_FileValidation(This,RHS) ) 

#define _Application_get_FileValidationPivot(This,RHS)	\
    ( (This)->lpVtbl -> get_FileValidationPivot(This,RHS) ) 

#define _Application_put_FileValidationPivot(This,RHS)	\
    ( (This)->lpVtbl -> put_FileValidationPivot(This,RHS) ) 

#define _Application_get_ShowQuickAnalysis(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowQuickAnalysis(This,RHS) ) 

#define _Application_put_ShowQuickAnalysis(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowQuickAnalysis(This,RHS) ) 

#define _Application_get_QuickAnalysis(This,RHS)	\
    ( (This)->lpVtbl -> get_QuickAnalysis(This,RHS) ) 

#define _Application_get_FlashFill(This,RHS)	\
    ( (This)->lpVtbl -> get_FlashFill(This,RHS) ) 

#define _Application_put_FlashFill(This,RHS)	\
    ( (This)->lpVtbl -> put_FlashFill(This,RHS) ) 

#define _Application_get_EnableMacroAnimations(This,RHS)	\
    ( (This)->lpVtbl -> get_EnableMacroAnimations(This,RHS) ) 

#define _Application_put_EnableMacroAnimations(This,RHS)	\
    ( (This)->lpVtbl -> put_EnableMacroAnimations(This,RHS) ) 

#define _Application_get_ChartDataPointTrack(This,RHS)	\
    ( (This)->lpVtbl -> get_ChartDataPointTrack(This,RHS) ) 

#define _Application_put_ChartDataPointTrack(This,RHS)	\
    ( (This)->lpVtbl -> put_ChartDataPointTrack(This,RHS) ) 

#define _Application_get_FlashFillMode(This,RHS)	\
    ( (This)->lpVtbl -> get_FlashFillMode(This,RHS) ) 

#define _Application_put_FlashFillMode(This,RHS)	\
    ( (This)->lpVtbl -> put_FlashFillMode(This,RHS) ) 

#define _Application_get_MergeInstances(This,RHS)	\
    ( (This)->lpVtbl -> get_MergeInstances(This,RHS) ) 

#define _Application_put_MergeInstances(This,RHS)	\
    ( (This)->lpVtbl -> put_MergeInstances(This,RHS) ) 

#define _Application_get_EnableCheckFileExtensions(This,RHS)	\
    ( (This)->lpVtbl -> get_EnableCheckFileExtensions(This,RHS) ) 

#define _Application_put_EnableCheckFileExtensions(This,RHS)	\
    ( (This)->lpVtbl -> put_EnableCheckFileExtensions(This,RHS) ) 

#define _Application_get_DebugTools(This,RHS)	\
    ( (This)->lpVtbl -> get_DebugTools(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */



/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_DisplayCommentIndicator_Proxy( 
    _Application * This,
    /* [in] */ XlCommentDisplayMode RHS);


void __RPC_STUB _Application_put_DisplayCommentIndicator_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_DisplayExcel4Menus_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_DisplayExcel4Menus_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_DisplayExcel4Menus_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Application_put_DisplayExcel4Menus_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_DisplayRecentFiles_Proxy( 
    _Application * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_DisplayRecentFiles_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_DisplayRecentFiles_Proxy( 
    _Application * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Application_put_DisplayRecentFiles_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_DisplayScrollBars_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_DisplayScrollBars_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_DisplayScrollBars_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Application_put_DisplayScrollBars_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_DisplayStatusBar_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_DisplayStatusBar_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_DisplayStatusBar_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Application_put_DisplayStatusBar_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Application_DoubleClick_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid);


void __RPC_STUB _Application_DoubleClick_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_EditDirectlyInCell_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_EditDirectlyInCell_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_EditDirectlyInCell_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Application_put_EditDirectlyInCell_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_EnableAutoComplete_Proxy( 
    _Application * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_EnableAutoComplete_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_EnableAutoComplete_Proxy( 
    _Application * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Application_put_EnableAutoComplete_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_EnableCancelKey_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ XlEnableCancelKey *RHS);


void __RPC_STUB _Application_get_EnableCancelKey_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_EnableCancelKey_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [in] */ XlEnableCancelKey RHS);


void __RPC_STUB _Application_put_EnableCancelKey_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_EnableSound_Proxy( 
    _Application * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_EnableSound_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_EnableSound_Proxy( 
    _Application * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Application_put_EnableSound_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_EnableTipWizard_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_EnableTipWizard_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_EnableTipWizard_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Application_put_EnableTipWizard_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_FileConverters_Proxy( 
    _Application * This,
    /* [optional][in] */ VARIANT Index1,
    /* [optional][in] */ VARIANT Index2,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB _Application_get_FileConverters_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_FileSearch_Proxy( 
    _Application * This,
    /* [retval][out] */ /* external definition not present */ FileSearch **RHS);


void __RPC_STUB _Application_get_FileSearch_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_FileFind_Proxy( 
    _Application * This,
    /* [retval][out] */ /* external definition not present */ IFind **RHS);


void __RPC_STUB _Application_get_FileFind_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE _Application__FindFile_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid);


void __RPC_STUB _Application__FindFile_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_FixedDecimal_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_FixedDecimal_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_FixedDecimal_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Application_put_FixedDecimal_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_FixedDecimalPlaces_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ long *RHS);


void __RPC_STUB _Application_get_FixedDecimalPlaces_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_FixedDecimalPlaces_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [in] */ long RHS);


void __RPC_STUB _Application_put_FixedDecimalPlaces_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Application_GetCustomListContents_Proxy( 
    _Application * This,
    /* [in] */ long ListNum,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB _Application_GetCustomListContents_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Application_GetCustomListNum_Proxy( 
    _Application * This,
    /* [in] */ VARIANT ListArray,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ long *RHS);


void __RPC_STUB _Application_GetCustomListNum_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Application_GetOpenFilename_Proxy( 
    _Application * This,
    /* [optional][in] */ VARIANT FileFilter,
    /* [optional][in] */ VARIANT FilterIndex,
    /* [optional][in] */ VARIANT Title,
    /* [optional][in] */ VARIANT ButtonText,
    /* [optional][in] */ VARIANT MultiSelect,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB _Application_GetOpenFilename_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Application_GetSaveAsFilename_Proxy( 
    _Application * This,
    /* [optional][in] */ VARIANT InitialFilename,
    /* [optional][in] */ VARIANT FileFilter,
    /* [optional][in] */ VARIANT FilterIndex,
    /* [optional][in] */ VARIANT Title,
    /* [optional][in] */ VARIANT ButtonText,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB _Application_GetSaveAsFilename_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Application_Goto_Proxy( 
    _Application * This,
    /* [optional][in] */ VARIANT Reference,
    /* [optional][in] */ VARIANT Scroll,
    /* [lcid][in] */ long lcid);


void __RPC_STUB _Application_Goto_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_Height_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ double *RHS);


void __RPC_STUB _Application_get_Height_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_Height_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [in] */ double RHS);


void __RPC_STUB _Application_put_Height_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Application_Help_Proxy( 
    _Application * This,
    /* [optional][in] */ VARIANT HelpFile,
    /* [optional][in] */ VARIANT HelpContextID,
    /* [lcid][in] */ long lcid);


void __RPC_STUB _Application_Help_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_IgnoreRemoteRequests_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_IgnoreRemoteRequests_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_IgnoreRemoteRequests_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Application_put_IgnoreRemoteRequests_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Application_InchesToPoints_Proxy( 
    _Application * This,
    /* [in] */ double Inches,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ double *RHS);


void __RPC_STUB _Application_InchesToPoints_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Application_InputBox_Proxy( 
    _Application * This,
    /* [in] */ BSTR Prompt,
    /* [optional][in] */ VARIANT Title,
    /* [optional][in] */ VARIANT Default,
    /* [optional][in] */ VARIANT Left,
    /* [optional][in] */ VARIANT Top,
    /* [optional][in] */ VARIANT HelpFile,
    /* [optional][in] */ VARIANT HelpContextID,
    /* [optional][in] */ VARIANT Type,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB _Application_InputBox_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_Interactive_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_Interactive_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_Interactive_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Application_put_Interactive_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_International_Proxy( 
    _Application * This,
    /* [optional][in] */ VARIANT Index,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB _Application_get_International_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_Iteration_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_Iteration_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_Iteration_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Application_put_Iteration_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_LargeButtons_Proxy( 
    _Application * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_LargeButtons_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_LargeButtons_Proxy( 
    _Application * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Application_put_LargeButtons_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_Left_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ double *RHS);


void __RPC_STUB _Application_get_Left_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_Left_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [in] */ double RHS);


void __RPC_STUB _Application_put_Left_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_LibraryPath_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB _Application_get_LibraryPath_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [custom][helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE _Application__MacroOptions_Proxy( 
    _Application * This,
    /* [optional][in] */ VARIANT Macro,
    /* [optional][in] */ VARIANT Description,
    /* [optional][in] */ VARIANT HasMenu,
    /* [optional][in] */ VARIANT MenuText,
    /* [optional][in] */ VARIANT HasShortcutKey,
    /* [optional][in] */ VARIANT ShortcutKey,
    /* [optional][in] */ VARIANT Category,
    /* [optional][in] */ VARIANT StatusBar,
    /* [optional][in] */ VARIANT HelpContextID,
    /* [optional][in] */ VARIANT HelpFile,
    /* [lcid][in] */ long lcid);


void __RPC_STUB _Application__MacroOptions_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Application_MailLogoff_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid);


void __RPC_STUB _Application_MailLogoff_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Application_MailLogon_Proxy( 
    _Application * This,
    /* [optional][in] */ VARIANT Name,
    /* [optional][in] */ VARIANT Password,
    /* [optional][in] */ VARIANT DownloadNewMail,
    /* [lcid][in] */ long lcid);


void __RPC_STUB _Application_MailLogon_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_MailSession_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB _Application_get_MailSession_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_MailSystem_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ XlMailSystem *RHS);


void __RPC_STUB _Application_get_MailSystem_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_MathCoprocessorAvailable_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_MathCoprocessorAvailable_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_MaxChange_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ double *RHS);


void __RPC_STUB _Application_get_MaxChange_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_MaxChange_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [in] */ double RHS);


void __RPC_STUB _Application_put_MaxChange_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_MaxIterations_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ long *RHS);


void __RPC_STUB _Application_get_MaxIterations_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_MaxIterations_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [in] */ long RHS);


void __RPC_STUB _Application_put_MaxIterations_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_MemoryFree_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ long *RHS);


void __RPC_STUB _Application_get_MemoryFree_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_MemoryTotal_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ long *RHS);


void __RPC_STUB _Application_get_MemoryTotal_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_MemoryUsed_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ long *RHS);


void __RPC_STUB _Application_get_MemoryUsed_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_MouseAvailable_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_MouseAvailable_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_MoveAfterReturn_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_MoveAfterReturn_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_MoveAfterReturn_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Application_put_MoveAfterReturn_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_MoveAfterReturnDirection_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ XlDirection *RHS);


void __RPC_STUB _Application_get_MoveAfterReturnDirection_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_MoveAfterReturnDirection_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [in] */ XlDirection RHS);


void __RPC_STUB _Application_put_MoveAfterReturnDirection_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_RecentFiles_Proxy( 
    _Application * This,
    /* [retval][out] */ RecentFiles	**RHS);


void __RPC_STUB _Application_get_RecentFiles_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_Name_Proxy( 
    _Application * This,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB _Application_get_Name_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Application_NextLetter_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ Workbook	**RHS);


void __RPC_STUB _Application_NextLetter_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_NetworkTemplatesPath_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB _Application_get_NetworkTemplatesPath_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_ODBCErrors_Proxy( 
    _Application * This,
    /* [retval][out] */ ODBCErrors	**RHS);


void __RPC_STUB _Application_get_ODBCErrors_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_ODBCTimeout_Proxy( 
    _Application * This,
    /* [retval][out] */ long *RHS);


void __RPC_STUB _Application_get_ODBCTimeout_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_ODBCTimeout_Proxy( 
    _Application * This,
    /* [in] */ long RHS);


void __RPC_STUB _Application_put_ODBCTimeout_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_OnCalculate_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB _Application_get_OnCalculate_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_OnCalculate_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [in] */ BSTR RHS);


void __RPC_STUB _Application_put_OnCalculate_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_OnData_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB _Application_get_OnData_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_OnData_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [in] */ BSTR RHS);


void __RPC_STUB _Application_put_OnData_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_OnDoubleClick_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB _Application_get_OnDoubleClick_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_OnDoubleClick_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [in] */ BSTR RHS);


void __RPC_STUB _Application_put_OnDoubleClick_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_OnEntry_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB _Application_get_OnEntry_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_OnEntry_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [in] */ BSTR RHS);


void __RPC_STUB _Application_put_OnEntry_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Application_OnKey_Proxy( 
    _Application * This,
    /* [in] */ BSTR Key,
    /* [optional][in] */ VARIANT Procedure,
    /* [lcid][in] */ long lcid);


void __RPC_STUB _Application_OnKey_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Application_OnRepeat_Proxy( 
    _Application * This,
    /* [in] */ BSTR Text,
    /* [in] */ BSTR Procedure,
    /* [lcid][in] */ long lcid);


void __RPC_STUB _Application_OnRepeat_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_OnSheetActivate_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB _Application_get_OnSheetActivate_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_OnSheetActivate_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [in] */ BSTR RHS);


void __RPC_STUB _Application_put_OnSheetActivate_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_OnSheetDeactivate_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB _Application_get_OnSheetDeactivate_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_OnSheetDeactivate_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [in] */ BSTR RHS);


void __RPC_STUB _Application_put_OnSheetDeactivate_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Application_OnTime_Proxy( 
    _Application * This,
    /* [in] */ VARIANT EarliestTime,
    /* [in] */ BSTR Procedure,
    /* [optional][in] */ VARIANT LatestTime,
    /* [optional][in] */ VARIANT Schedule,
    /* [lcid][in] */ long lcid);


void __RPC_STUB _Application_OnTime_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Application_OnUndo_Proxy( 
    _Application * This,
    /* [in] */ BSTR Text,
    /* [in] */ BSTR Procedure,
    /* [lcid][in] */ long lcid);


void __RPC_STUB _Application_OnUndo_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_OnWindow_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB _Application_get_OnWindow_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_OnWindow_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [in] */ BSTR RHS);


void __RPC_STUB _Application_put_OnWindow_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_OperatingSystem_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB _Application_get_OperatingSystem_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_OrganizationName_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB _Application_get_OrganizationName_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_Path_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB _Application_get_Path_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_PathSeparator_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB _Application_get_PathSeparator_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_PreviousSelections_Proxy( 
    _Application * This,
    /* [optional][in] */ VARIANT Index,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB _Application_get_PreviousSelections_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_PivotTableSelection_Proxy( 
    _Application * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_PivotTableSelection_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_PivotTableSelection_Proxy( 
    _Application * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Application_put_PivotTableSelection_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_PromptForSummaryInfo_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_PromptForSummaryInfo_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_PromptForSummaryInfo_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Application_put_PromptForSummaryInfo_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Application_Quit_Proxy( 
    _Application * This);


void __RPC_STUB _Application_Quit_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Application_RecordMacro_Proxy( 
    _Application * This,
    /* [optional][in] */ VARIANT BasicCode,
    /* [optional][in] */ VARIANT XlmCode,
    /* [lcid][in] */ long lcid);


void __RPC_STUB _Application_RecordMacro_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_RecordRelative_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_RecordRelative_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_ReferenceStyle_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ XlReferenceStyle *RHS);


void __RPC_STUB _Application_get_ReferenceStyle_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_ReferenceStyle_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [in] */ XlReferenceStyle RHS);


void __RPC_STUB _Application_put_ReferenceStyle_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_RegisteredFunctions_Proxy( 
    _Application * This,
    /* [optional][in] */ VARIANT Index1,
    /* [optional][in] */ VARIANT Index2,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB _Application_get_RegisteredFunctions_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Application_RegisterXLL_Proxy( 
    _Application * This,
    /* [in] */ BSTR Filename,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_RegisterXLL_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Application_Repeat_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid);


void __RPC_STUB _Application_Repeat_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE _Application_ResetTipWizard_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid);


void __RPC_STUB _Application_ResetTipWizard_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_RollZoom_Proxy( 
    _Application * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_RollZoom_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_RollZoom_Proxy( 
    _Application * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Application_put_RollZoom_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE _Application_Save_Proxy( 
    _Application * This,
    /* [optional][in] */ VARIANT Filename,
    /* [lcid][in] */ long lcid);


void __RPC_STUB _Application_Save_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE _Application_SaveWorkspace_Proxy( 
    _Application * This,
    /* [optional][in] */ VARIANT Filename,
    /* [lcid][in] */ long lcid);


void __RPC_STUB _Application_SaveWorkspace_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_ScreenUpdating_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_ScreenUpdating_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_ScreenUpdating_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Application_put_ScreenUpdating_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE _Application_SetDefaultChart_Proxy( 
    _Application * This,
    /* [optional][in] */ VARIANT FormatName,
    /* [optional][in] */ VARIANT Gallery);


void __RPC_STUB _Application_SetDefaultChart_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_SheetsInNewWorkbook_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ long *RHS);


void __RPC_STUB _Application_get_SheetsInNewWorkbook_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_SheetsInNewWorkbook_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [in] */ long RHS);


void __RPC_STUB _Application_put_SheetsInNewWorkbook_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_ShowChartTipNames_Proxy( 
    _Application * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_ShowChartTipNames_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_ShowChartTipNames_Proxy( 
    _Application * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Application_put_ShowChartTipNames_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_ShowChartTipValues_Proxy( 
    _Application * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_ShowChartTipValues_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_ShowChartTipValues_Proxy( 
    _Application * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Application_put_ShowChartTipValues_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_StandardFont_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB _Application_get_StandardFont_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_StandardFont_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [in] */ BSTR RHS);


void __RPC_STUB _Application_put_StandardFont_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_StandardFontSize_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ double *RHS);


void __RPC_STUB _Application_get_StandardFontSize_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_StandardFontSize_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [in] */ double RHS);


void __RPC_STUB _Application_put_StandardFontSize_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_StartupPath_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB _Application_get_StartupPath_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_StatusBar_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB _Application_get_StatusBar_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_StatusBar_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [in] */ VARIANT RHS);


void __RPC_STUB _Application_put_StatusBar_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_TemplatesPath_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB _Application_get_TemplatesPath_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_ShowToolTips_Proxy( 
    _Application * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_ShowToolTips_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_ShowToolTips_Proxy( 
    _Application * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Application_put_ShowToolTips_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_Top_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ double *RHS);


void __RPC_STUB _Application_get_Top_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_Top_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [in] */ double RHS);


void __RPC_STUB _Application_put_Top_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_DefaultSaveFormat_Proxy( 
    _Application * This,
    /* [retval][out] */ XlFileFormat *RHS);


void __RPC_STUB _Application_get_DefaultSaveFormat_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_DefaultSaveFormat_Proxy( 
    _Application * This,
    /* [in] */ XlFileFormat RHS);


void __RPC_STUB _Application_put_DefaultSaveFormat_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_TransitionMenuKey_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB _Application_get_TransitionMenuKey_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_TransitionMenuKey_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [in] */ BSTR RHS);


void __RPC_STUB _Application_put_TransitionMenuKey_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_TransitionMenuKeyAction_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ long *RHS);


void __RPC_STUB _Application_get_TransitionMenuKeyAction_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_TransitionMenuKeyAction_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [in] */ long RHS);


void __RPC_STUB _Application_put_TransitionMenuKeyAction_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_TransitionNavigKeys_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_TransitionNavigKeys_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_TransitionNavigKeys_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Application_put_TransitionNavigKeys_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Application_Undo_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid);


void __RPC_STUB _Application_Undo_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_UsableHeight_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ double *RHS);


void __RPC_STUB _Application_get_UsableHeight_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_UsableWidth_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ double *RHS);


void __RPC_STUB _Application_get_UsableWidth_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_UserControl_Proxy( 
    _Application * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_UserControl_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_UserControl_Proxy( 
    _Application * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Application_put_UserControl_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_UserName_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB _Application_get_UserName_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_UserName_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [in] */ BSTR RHS);


void __RPC_STUB _Application_put_UserName_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_Value_Proxy( 
    _Application * This,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB _Application_get_Value_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_VBE_Proxy( 
    _Application * This,
    /* [retval][out] */ /* external definition not present */ VBE **RHS);


void __RPC_STUB _Application_get_VBE_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_Version_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB _Application_get_Version_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_Visible_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_Visible_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_Visible_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Application_put_Visible_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Application_Volatile_Proxy( 
    _Application * This,
    /* [optional][in] */ VARIANT Volatile,
    /* [lcid][in] */ long lcid);


void __RPC_STUB _Application_Volatile_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE _Application__Wait_Proxy( 
    _Application * This,
    /* [in] */ VARIANT Time,
    /* [lcid][in] */ long lcid);


void __RPC_STUB _Application__Wait_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_Width_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ double *RHS);


void __RPC_STUB _Application_get_Width_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_Width_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [in] */ double RHS);


void __RPC_STUB _Application_put_Width_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_WindowsForPens_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_WindowsForPens_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_WindowState_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ XlWindowState *RHS);


void __RPC_STUB _Application_get_WindowState_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_WindowState_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [in] */ XlWindowState RHS);


void __RPC_STUB _Application_put_WindowState_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_UILanguage_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ long *RHS);


void __RPC_STUB _Application_get_UILanguage_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_UILanguage_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [in] */ long RHS);


void __RPC_STUB _Application_put_UILanguage_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_DefaultSheetDirection_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ long *RHS);


void __RPC_STUB _Application_get_DefaultSheetDirection_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_DefaultSheetDirection_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [in] */ long RHS);


void __RPC_STUB _Application_put_DefaultSheetDirection_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_CursorMovement_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ long *RHS);


void __RPC_STUB _Application_get_CursorMovement_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_CursorMovement_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [in] */ long RHS);


void __RPC_STUB _Application_put_CursorMovement_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_ControlCharacters_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_ControlCharacters_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_ControlCharacters_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Application_put_ControlCharacters_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE _Application__WSFunction_Proxy( 
    _Application * This,
    /* [optional][in] */ VARIANT Arg1,
    /* [optional][in] */ VARIANT Arg2,
    /* [optional][in] */ VARIANT Arg3,
    /* [optional][in] */ VARIANT Arg4,
    /* [optional][in] */ VARIANT Arg5,
    /* [optional][in] */ VARIANT Arg6,
    /* [optional][in] */ VARIANT Arg7,
    /* [optional][in] */ VARIANT Arg8,
    /* [optional][in] */ VARIANT Arg9,
    /* [optional][in] */ VARIANT Arg10,
    /* [optional][in] */ VARIANT Arg11,
    /* [optional][in] */ VARIANT Arg12,
    /* [optional][in] */ VARIANT Arg13,
    /* [optional][in] */ VARIANT Arg14,
    /* [optional][in] */ VARIANT Arg15,
    /* [optional][in] */ VARIANT Arg16,
    /* [optional][in] */ VARIANT Arg17,
    /* [optional][in] */ VARIANT Arg18,
    /* [optional][in] */ VARIANT Arg19,
    /* [optional][in] */ VARIANT Arg20,
    /* [optional][in] */ VARIANT Arg21,
    /* [optional][in] */ VARIANT Arg22,
    /* [optional][in] */ VARIANT Arg23,
    /* [optional][in] */ VARIANT Arg24,
    /* [optional][in] */ VARIANT Arg25,
    /* [optional][in] */ VARIANT Arg26,
    /* [optional][in] */ VARIANT Arg27,
    /* [optional][in] */ VARIANT Arg28,
    /* [optional][in] */ VARIANT Arg29,
    /* [optional][in] */ VARIANT Arg30,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB _Application__WSFunction_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_EnableEvents_Proxy( 
    _Application * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_EnableEvents_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_EnableEvents_Proxy( 
    _Application * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Application_put_EnableEvents_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_DisplayInfoWindow_Proxy( 
    _Application * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_DisplayInfoWindow_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_DisplayInfoWindow_Proxy( 
    _Application * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Application_put_DisplayInfoWindow_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Application_Wait_Proxy( 
    _Application * This,
    /* [in] */ VARIANT Time,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_Wait_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_ExtendList_Proxy( 
    _Application * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_ExtendList_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_ExtendList_Proxy( 
    _Application * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Application_put_ExtendList_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_OLEDBErrors_Proxy( 
    _Application * This,
    /* [retval][out] */ OLEDBErrors	**RHS);


void __RPC_STUB _Application_get_OLEDBErrors_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Application_GetPhonetic_Proxy( 
    _Application * This,
    /* [optional][in] */ VARIANT Text,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB _Application_GetPhonetic_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_COMAddIns_Proxy( 
    _Application * This,
    /* [retval][out] */ /* external definition not present */ COMAddIns **RHS);


void __RPC_STUB _Application_get_COMAddIns_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_DefaultWebOptions_Proxy( 
    _Application * This,
    /* [retval][out] */ DefaultWebOptions **RHS);


void __RPC_STUB _Application_get_DefaultWebOptions_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_ProductCode_Proxy( 
    _Application * This,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB _Application_get_ProductCode_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_UserLibraryPath_Proxy( 
    _Application * This,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB _Application_get_UserLibraryPath_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_AutoPercentEntry_Proxy( 
    _Application * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_AutoPercentEntry_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_AutoPercentEntry_Proxy( 
    _Application * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Application_put_AutoPercentEntry_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_LanguageSettings_Proxy( 
    _Application * This,
    /* [retval][out] */ /* external definition not present */ LanguageSettings **RHS);


void __RPC_STUB _Application_get_LanguageSettings_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_Dummy101_Proxy( 
    _Application * This,
    /* [retval][out] */ IDispatch **RHS);


void __RPC_STUB _Application_get_Dummy101_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE _Application_Dummy12_Proxy( 
    _Application * This,
    /* [in] */ PivotTable	*p1,
    /* [in] */ PivotTable	*p2);


void __RPC_STUB _Application_Dummy12_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_AnswerWizard_Proxy( 
    _Application * This,
    /* [retval][out] */ /* external definition not present */ AnswerWizard **RHS);


void __RPC_STUB _Application_get_AnswerWizard_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Application_CalculateFull_Proxy( 
    _Application * This);


void __RPC_STUB _Application_CalculateFull_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Application_FindFile_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_FindFile_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_CalculationVersion_Proxy( 
    _Application * This,
    /* [retval][out] */ long *RHS);


void __RPC_STUB _Application_get_CalculationVersion_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_ShowWindowsInTaskbar_Proxy( 
    _Application * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_ShowWindowsInTaskbar_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_ShowWindowsInTaskbar_Proxy( 
    _Application * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Application_put_ShowWindowsInTaskbar_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_FeatureInstall_Proxy( 
    _Application * This,
    /* [retval][out] */ MsoFeatureInstall *RHS);


void __RPC_STUB _Application_get_FeatureInstall_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_FeatureInstall_Proxy( 
    _Application * This,
    /* [in] */ MsoFeatureInstall RHS);


void __RPC_STUB _Application_put_FeatureInstall_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_Ready_Proxy( 
    _Application * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_Ready_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE _Application_Dummy13_Proxy( 
    _Application * This,
    /* [in] */ VARIANT Arg1,
    /* [optional][in] */ VARIANT Arg2,
    /* [optional][in] */ VARIANT Arg3,
    /* [optional][in] */ VARIANT Arg4,
    /* [optional][in] */ VARIANT Arg5,
    /* [optional][in] */ VARIANT Arg6,
    /* [optional][in] */ VARIANT Arg7,
    /* [optional][in] */ VARIANT Arg8,
    /* [optional][in] */ VARIANT Arg9,
    /* [optional][in] */ VARIANT Arg10,
    /* [optional][in] */ VARIANT Arg11,
    /* [optional][in] */ VARIANT Arg12,
    /* [optional][in] */ VARIANT Arg13,
    /* [optional][in] */ VARIANT Arg14,
    /* [optional][in] */ VARIANT Arg15,
    /* [optional][in] */ VARIANT Arg16,
    /* [optional][in] */ VARIANT Arg17,
    /* [optional][in] */ VARIANT Arg18,
    /* [optional][in] */ VARIANT Arg19,
    /* [optional][in] */ VARIANT Arg20,
    /* [optional][in] */ VARIANT Arg21,
    /* [optional][in] */ VARIANT Arg22,
    /* [optional][in] */ VARIANT Arg23,
    /* [optional][in] */ VARIANT Arg24,
    /* [optional][in] */ VARIANT Arg25,
    /* [optional][in] */ VARIANT Arg26,
    /* [optional][in] */ VARIANT Arg27,
    /* [optional][in] */ VARIANT Arg28,
    /* [optional][in] */ VARIANT Arg29,
    /* [optional][in] */ VARIANT Arg30,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB _Application_Dummy13_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_FindFormat_Proxy( 
    _Application * This,
    /* [retval][out] */ CellFormat	**RHS);


void __RPC_STUB _Application_get_FindFormat_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propputref][id] */ HRESULT STDMETHODCALLTYPE _Application_putref_FindFormat_Proxy( 
    _Application * This,
    /* [in] */ CellFormat	*RHS);


void __RPC_STUB _Application_putref_FindFormat_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_ReplaceFormat_Proxy( 
    _Application * This,
    /* [retval][out] */ CellFormat	**RHS);


void __RPC_STUB _Application_get_ReplaceFormat_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propputref][id] */ HRESULT STDMETHODCALLTYPE _Application_putref_ReplaceFormat_Proxy( 
    _Application * This,
    /* [in] */ CellFormat	*RHS);


void __RPC_STUB _Application_putref_ReplaceFormat_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_UsedObjects_Proxy( 
    _Application * This,
    /* [retval][out] */ UsedObjects	**RHS);


void __RPC_STUB _Application_get_UsedObjects_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_CalculationState_Proxy( 
    _Application * This,
    /* [retval][out] */ XlCalculationState *RHS);


void __RPC_STUB _Application_get_CalculationState_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_CalculationInterruptKey_Proxy( 
    _Application * This,
    /* [retval][out] */ XlCalculationInterruptKey *RHS);


void __RPC_STUB _Application_get_CalculationInterruptKey_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_CalculationInterruptKey_Proxy( 
    _Application * This,
    /* [in] */ XlCalculationInterruptKey RHS);


void __RPC_STUB _Application_put_CalculationInterruptKey_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_Watches_Proxy( 
    _Application * This,
    /* [retval][out] */ Watches	**RHS);


void __RPC_STUB _Application_get_Watches_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_DisplayFunctionToolTips_Proxy( 
    _Application * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_DisplayFunctionToolTips_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_DisplayFunctionToolTips_Proxy( 
    _Application * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Application_put_DisplayFunctionToolTips_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_AutomationSecurity_Proxy( 
    _Application * This,
    /* [retval][out] */ MsoAutomationSecurity *RHS);


void __RPC_STUB _Application_get_AutomationSecurity_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_AutomationSecurity_Proxy( 
    _Application * This,
    /* [in] */ MsoAutomationSecurity RHS);


void __RPC_STUB _Application_put_AutomationSecurity_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_FileDialog_Proxy( 
    _Application * This,
    /* [in] */ MsoFileDialogType fileDialogType,
    /* [retval][out] */ /* external definition not present */ FileDialog **RHS);


void __RPC_STUB _Application_get_FileDialog_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE _Application_Dummy14_Proxy( 
    _Application * This);


void __RPC_STUB _Application_Dummy14_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Application_CalculateFullRebuild_Proxy( 
    _Application * This);


void __RPC_STUB _Application_CalculateFullRebuild_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_DisplayPasteOptions_Proxy( 
    _Application * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_DisplayPasteOptions_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_DisplayPasteOptions_Proxy( 
    _Application * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Application_put_DisplayPasteOptions_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_DisplayInsertOptions_Proxy( 
    _Application * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_DisplayInsertOptions_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_DisplayInsertOptions_Proxy( 
    _Application * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Application_put_DisplayInsertOptions_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_GenerateGetPivotData_Proxy( 
    _Application * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_GenerateGetPivotData_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_GenerateGetPivotData_Proxy( 
    _Application * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Application_put_GenerateGetPivotData_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_AutoRecover_Proxy( 
    _Application * This,
    /* [retval][out] */ AutoRecover	**RHS);


void __RPC_STUB _Application_get_AutoRecover_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_Hwnd_Proxy( 
    _Application * This,
    /* [retval][out] */ long *RHS);


void __RPC_STUB _Application_get_Hwnd_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_Hinstance_Proxy( 
    _Application * This,
    /* [retval][out] */ long *RHS);


void __RPC_STUB _Application_get_Hinstance_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Application_CheckAbort_Proxy( 
    _Application * This,
    /* [optional][in] */ VARIANT KeepAbort);


void __RPC_STUB _Application_CheckAbort_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_ErrorCheckingOptions_Proxy( 
    _Application * This,
    /* [retval][out] */ ErrorCheckingOptions	**RHS);


void __RPC_STUB _Application_get_ErrorCheckingOptions_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_AutoFormatAsYouTypeReplaceHyperlinks_Proxy( 
    _Application * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_AutoFormatAsYouTypeReplaceHyperlinks_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_AutoFormatAsYouTypeReplaceHyperlinks_Proxy( 
    _Application * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Application_put_AutoFormatAsYouTypeReplaceHyperlinks_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_SmartTagRecognizers_Proxy( 
    _Application * This,
    /* [retval][out] */ SmartTagRecognizers	**RHS);


void __RPC_STUB _Application_get_SmartTagRecognizers_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_NewWorkbook_Proxy( 
    _Application * This,
    /* [retval][out] */ /* external definition not present */ NewFile **RHS);


void __RPC_STUB _Application_get_NewWorkbook_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_SpellingOptions_Proxy( 
    _Application * This,
    /* [retval][out] */ SpellingOptions	**RHS);


void __RPC_STUB _Application_get_SpellingOptions_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_Speech_Proxy( 
    _Application * This,
    /* [retval][out] */ Speech	**RHS);


void __RPC_STUB _Application_get_Speech_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_MapPaperSize_Proxy( 
    _Application * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_MapPaperSize_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_MapPaperSize_Proxy( 
    _Application * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Application_put_MapPaperSize_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_ShowStartupDialog_Proxy( 
    _Application * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_ShowStartupDialog_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_ShowStartupDialog_Proxy( 
    _Application * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Application_put_ShowStartupDialog_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_DecimalSeparator_Proxy( 
    _Application * This,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB _Application_get_DecimalSeparator_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_DecimalSeparator_Proxy( 
    _Application * This,
    /* [in] */ BSTR RHS);


void __RPC_STUB _Application_put_DecimalSeparator_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_ThousandsSeparator_Proxy( 
    _Application * This,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB _Application_get_ThousandsSeparator_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_ThousandsSeparator_Proxy( 
    _Application * This,
    /* [in] */ BSTR RHS);


void __RPC_STUB _Application_put_ThousandsSeparator_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_UseSystemSeparators_Proxy( 
    _Application * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_UseSystemSeparators_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_UseSystemSeparators_Proxy( 
    _Application * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Application_put_UseSystemSeparators_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_ThisCell_Proxy( 
    _Application * This,
    /* [retval][out] */ Range	**RHS);


void __RPC_STUB _Application_get_ThisCell_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_RTD_Proxy( 
    _Application * This,
    /* [retval][out] */ RTD	**RHS);


void __RPC_STUB _Application_get_RTD_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_DisplayDocumentActionTaskPane_Proxy( 
    _Application * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_DisplayDocumentActionTaskPane_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_DisplayDocumentActionTaskPane_Proxy( 
    _Application * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Application_put_DisplayDocumentActionTaskPane_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Application_DisplayXMLSourcePane_Proxy( 
    _Application * This,
    /* [optional][in] */ VARIANT XmlMap);


void __RPC_STUB _Application_DisplayXMLSourcePane_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_ArbitraryXMLSupportAvailable_Proxy( 
    _Application * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_ArbitraryXMLSupportAvailable_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE _Application_Support_Proxy( 
    _Application * This,
    /* [in] */ IDispatch *Object,
    /* [in] */ long ID,
    /* [optional][in] */ VARIANT arg,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB _Application_Support_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE _Application_Dummy20_Proxy( 
    _Application * This,
    /* [in] */ long grfCompareFunctions,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB _Application_Dummy20_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_MeasurementUnit_Proxy( 
    _Application * This,
    /* [retval][out] */ long *RHS);


void __RPC_STUB _Application_get_MeasurementUnit_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_MeasurementUnit_Proxy( 
    _Application * This,
    /* [in] */ long RHS);


void __RPC_STUB _Application_put_MeasurementUnit_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_ShowSelectionFloaties_Proxy( 
    _Application * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_ShowSelectionFloaties_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_ShowSelectionFloaties_Proxy( 
    _Application * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Application_put_ShowSelectionFloaties_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_ShowMenuFloaties_Proxy( 
    _Application * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_ShowMenuFloaties_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_ShowMenuFloaties_Proxy( 
    _Application * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Application_put_ShowMenuFloaties_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_ShowDevTools_Proxy( 
    _Application * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_ShowDevTools_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_ShowDevTools_Proxy( 
    _Application * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Application_put_ShowDevTools_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_EnableLivePreview_Proxy( 
    _Application * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_EnableLivePreview_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_EnableLivePreview_Proxy( 
    _Application * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Application_put_EnableLivePreview_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_DisplayDocumentInformationPanel_Proxy( 
    _Application * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_DisplayDocumentInformationPanel_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_DisplayDocumentInformationPanel_Proxy( 
    _Application * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Application_put_DisplayDocumentInformationPanel_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_AlwaysUseClearType_Proxy( 
    _Application * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_AlwaysUseClearType_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_AlwaysUseClearType_Proxy( 
    _Application * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Application_put_AlwaysUseClearType_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_WarnOnFunctionNameConflict_Proxy( 
    _Application * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_WarnOnFunctionNameConflict_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_WarnOnFunctionNameConflict_Proxy( 
    _Application * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Application_put_WarnOnFunctionNameConflict_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_FormulaBarHeight_Proxy( 
    _Application * This,
    /* [retval][out] */ long *RHS);


void __RPC_STUB _Application_get_FormulaBarHeight_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_FormulaBarHeight_Proxy( 
    _Application * This,
    /* [in] */ long RHS);


void __RPC_STUB _Application_put_FormulaBarHeight_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_DisplayFormulaAutoComplete_Proxy( 
    _Application * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_DisplayFormulaAutoComplete_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_DisplayFormulaAutoComplete_Proxy( 
    _Application * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Application_put_DisplayFormulaAutoComplete_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_GenerateTableRefs_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ XlGenerateTableRefs *RHS);


void __RPC_STUB _Application_get_GenerateTableRefs_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_GenerateTableRefs_Proxy( 
    _Application * This,
    /* [lcid][in] */ long lcid,
    /* [in] */ XlGenerateTableRefs RHS);


void __RPC_STUB _Application_put_GenerateTableRefs_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_Assistance_Proxy( 
    _Application * This,
    /* [retval][out] */ /* external definition not present */ IAssistance **RHS);


void __RPC_STUB _Application_get_Assistance_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Application_CalculateUntilAsyncQueriesDone_Proxy( 
    _Application * This);


void __RPC_STUB _Application_CalculateUntilAsyncQueriesDone_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_EnableLargeOperationAlert_Proxy( 
    _Application * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_EnableLargeOperationAlert_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_EnableLargeOperationAlert_Proxy( 
    _Application * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Application_put_EnableLargeOperationAlert_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_LargeOperationCellThousandCount_Proxy( 
    _Application * This,
    /* [retval][out] */ long *RHS);


void __RPC_STUB _Application_get_LargeOperationCellThousandCount_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_LargeOperationCellThousandCount_Proxy( 
    _Application * This,
    /* [in] */ long RHS);


void __RPC_STUB _Application_put_LargeOperationCellThousandCount_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_DeferAsyncQueries_Proxy( 
    _Application * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_DeferAsyncQueries_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_DeferAsyncQueries_Proxy( 
    _Application * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Application_put_DeferAsyncQueries_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_MultiThreadedCalculation_Proxy( 
    _Application * This,
    /* [retval][out] */ MultiThreadedCalculation	**RHS);


void __RPC_STUB _Application_get_MultiThreadedCalculation_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Application_SharePointVersion_Proxy( 
    _Application * This,
    /* [in] */ BSTR bstrUrl,
    /* [retval][out] */ long *RHS);


void __RPC_STUB _Application_SharePointVersion_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_ActiveEncryptionSession_Proxy( 
    _Application * This,
    /* [retval][out] */ long *RHS);


void __RPC_STUB _Application_get_ActiveEncryptionSession_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_HighQualityModeForGraphics_Proxy( 
    _Application * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_HighQualityModeForGraphics_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_HighQualityModeForGraphics_Proxy( 
    _Application * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Application_put_HighQualityModeForGraphics_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_FileExportConverters_Proxy( 
    _Application * This,
    /* [retval][out] */ FileExportConverters	**RHS);


void __RPC_STUB _Application_get_FileExportConverters_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_SmartArtLayouts_Proxy( 
    _Application * This,
    /* [retval][out] */ /* external definition not present */ SmartArtLayouts **RHS);


void __RPC_STUB _Application_get_SmartArtLayouts_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_SmartArtQuickStyles_Proxy( 
    _Application * This,
    /* [retval][out] */ /* external definition not present */ SmartArtQuickStyles **RHS);


void __RPC_STUB _Application_get_SmartArtQuickStyles_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_SmartArtColors_Proxy( 
    _Application * This,
    /* [retval][out] */ /* external definition not present */ SmartArtColors **RHS);


void __RPC_STUB _Application_get_SmartArtColors_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_AddIns2_Proxy( 
    _Application * This,
    /* [retval][out] */ AddIns2	**RHS);


void __RPC_STUB _Application_get_AddIns2_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_PrintCommunication_Proxy( 
    _Application * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_PrintCommunication_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_PrintCommunication_Proxy( 
    _Application * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Application_put_PrintCommunication_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [custom][helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Application_MacroOptions_Proxy( 
    _Application * This,
    /* [optional][in] */ VARIANT Macro,
    /* [optional][in] */ VARIANT Description,
    /* [optional][in] */ VARIANT HasMenu,
    /* [optional][in] */ VARIANT MenuText,
    /* [optional][in] */ VARIANT HasShortcutKey,
    /* [optional][in] */ VARIANT ShortcutKey,
    /* [optional][in] */ VARIANT Category,
    /* [optional][in] */ VARIANT StatusBar,
    /* [optional][in] */ VARIANT HelpContextID,
    /* [optional][in] */ VARIANT HelpFile,
    /* [optional][in] */ VARIANT ArgumentDescriptions,
    /* [lcid][in] */ long lcid);


void __RPC_STUB _Application_MacroOptions_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_UseClusterConnector_Proxy( 
    _Application * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_UseClusterConnector_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_UseClusterConnector_Proxy( 
    _Application * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Application_put_UseClusterConnector_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_ClusterConnector_Proxy( 
    _Application * This,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB _Application_get_ClusterConnector_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_ClusterConnector_Proxy( 
    _Application * This,
    /* [in] */ BSTR RHS);


void __RPC_STUB _Application_put_ClusterConnector_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_Quitting_Proxy( 
    _Application * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_Quitting_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_Dummy22_Proxy( 
    _Application * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_Dummy22_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_Dummy22_Proxy( 
    _Application * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Application_put_Dummy22_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_Dummy23_Proxy( 
    _Application * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_Dummy23_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_Dummy23_Proxy( 
    _Application * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Application_put_Dummy23_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_ProtectedViewWindows_Proxy( 
    _Application * This,
    /* [retval][out] */ ProtectedViewWindows	**RHS);


void __RPC_STUB _Application_get_ProtectedViewWindows_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_ActiveProtectedViewWindow_Proxy( 
    _Application * This,
    /* [retval][out] */ ProtectedViewWindow	**RHS);


void __RPC_STUB _Application_get_ActiveProtectedViewWindow_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_IsSandboxed_Proxy( 
    _Application * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_IsSandboxed_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_SaveISO8601Dates_Proxy( 
    _Application * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_SaveISO8601Dates_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_SaveISO8601Dates_Proxy( 
    _Application * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Application_put_SaveISO8601Dates_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_HinstancePtr_Proxy( 
    _Application * This,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB _Application_get_HinstancePtr_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_FileValidation_Proxy( 
    _Application * This,
    /* [retval][out] */ MsoFileValidationMode *RHS);


void __RPC_STUB _Application_get_FileValidation_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_FileValidation_Proxy( 
    _Application * This,
    /* [in] */ MsoFileValidationMode RHS);


void __RPC_STUB _Application_put_FileValidation_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_FileValidationPivot_Proxy( 
    _Application * This,
    /* [retval][out] */ XlFileValidationPivotMode *RHS);


void __RPC_STUB _Application_get_FileValidationPivot_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_FileValidationPivot_Proxy( 
    _Application * This,
    /* [in] */ XlFileValidationPivotMode RHS);


void __RPC_STUB _Application_put_FileValidationPivot_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_ShowQuickAnalysis_Proxy( 
    _Application * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_ShowQuickAnalysis_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_ShowQuickAnalysis_Proxy( 
    _Application * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Application_put_ShowQuickAnalysis_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_QuickAnalysis_Proxy( 
    _Application * This,
    /* [retval][out] */ QuickAnalysis	**RHS);


void __RPC_STUB _Application_get_QuickAnalysis_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_FlashFill_Proxy( 
    _Application * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_FlashFill_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_FlashFill_Proxy( 
    _Application * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Application_put_FlashFill_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_EnableMacroAnimations_Proxy( 
    _Application * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_EnableMacroAnimations_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_EnableMacroAnimations_Proxy( 
    _Application * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Application_put_EnableMacroAnimations_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_ChartDataPointTrack_Proxy( 
    _Application * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_ChartDataPointTrack_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_ChartDataPointTrack_Proxy( 
    _Application * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Application_put_ChartDataPointTrack_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_FlashFillMode_Proxy( 
    _Application * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_FlashFillMode_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_FlashFillMode_Proxy( 
    _Application * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Application_put_FlashFillMode_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_MergeInstances_Proxy( 
    _Application * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_MergeInstances_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_MergeInstances_Proxy( 
    _Application * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Application_put_MergeInstances_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_EnableCheckFileExtensions_Proxy( 
    _Application * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Application_get_EnableCheckFileExtensions_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Application_put_EnableCheckFileExtensions_Proxy( 
    _Application * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Application_put_EnableCheckFileExtensions_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [propget][id] */ HRESULT STDMETHODCALLTYPE _Application_get_DebugTools_Proxy( 
    _Application * This,
    /* [retval][out] */ _DebugTools **RHS);


void __RPC_STUB _Application_get_DebugTools_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);



#endif 	/* ___Application_INTERFACE_DEFINED__ */


#ifndef __IWorksheetFunction_INTERFACE_DEFINED__
#define __IWorksheetFunction_INTERFACE_DEFINED__

/* interface IWorksheetFunction */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IWorksheetFunction;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00020845-0001-0000-C000-000000000046")
    IWorksheetFunction : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall _WSFunction( 
            /* [optional][in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Count( 
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall IsNA( 
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall IsError( 
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Sum( 
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Average( 
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Min( 
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Max( 
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Npv( 
            /* [in] */ double Arg1,
            /* [in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall StDev( 
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Dollar( 
            /* [in] */ double Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Fixed( 
            /* [in] */ double Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Pi( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Ln( 
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Log10( 
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Round( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Lookup( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Index( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ double Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Rept( 
            /* [in] */ BSTR Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall And( 
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Or( 
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall DCount( 
            /* [in] */ Range	*Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall DSum( 
            /* [in] */ Range	*Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall DAverage( 
            /* [in] */ Range	*Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall DMin( 
            /* [in] */ Range	*Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall DMax( 
            /* [in] */ Range	*Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall DStDev( 
            /* [in] */ Range	*Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Var( 
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall DVar( 
            /* [in] */ Range	*Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Text( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ BSTR Arg2,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall LinEst( 
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Trend( 
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall LogEst( 
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Growth( 
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Pv( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Fv( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall NPer( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Pmt( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Rate( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall MIrr( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Irr( 
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Match( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Weekday( 
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Search( 
            /* [in] */ BSTR Arg1,
            /* [in] */ BSTR Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Transpose( 
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Atan2( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Asin( 
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Acos( 
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Choose( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall HLookup( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall VLookup( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Log( 
            /* [in] */ double Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Proper( 
            /* [in] */ BSTR Arg1,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Trim( 
            /* [in] */ BSTR Arg1,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Replace( 
            /* [in] */ BSTR Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [in] */ BSTR Arg4,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Substitute( 
            /* [in] */ BSTR Arg1,
            /* [in] */ BSTR Arg2,
            /* [in] */ BSTR Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Find( 
            /* [in] */ BSTR Arg1,
            /* [in] */ BSTR Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall IsErr( 
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall IsText( 
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall IsNumber( 
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Sln( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Syd( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [in] */ double Arg4,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Ddb( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [in] */ double Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Clean( 
            /* [in] */ BSTR Arg1,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall MDeterm( 
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall MInverse( 
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall MMult( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Ipmt( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [in] */ double Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Ppmt( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [in] */ double Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CountA( 
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Product( 
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Fact( 
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall DProduct( 
            /* [in] */ Range	*Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall IsNonText( 
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall StDevP( 
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall VarP( 
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall DStDevP( 
            /* [in] */ Range	*Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall DVarP( 
            /* [in] */ Range	*Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall IsLogical( 
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall DCountA( 
            /* [in] */ Range	*Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall USDollar( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall FindB( 
            /* [in] */ BSTR Arg1,
            /* [in] */ BSTR Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SearchB( 
            /* [in] */ BSTR Arg1,
            /* [in] */ BSTR Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ReplaceB( 
            /* [in] */ BSTR Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [in] */ BSTR Arg4,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall RoundUp( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall RoundDown( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Rank( 
            /* [in] */ double Arg1,
            /* [in] */ Range	*Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Days360( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Vdb( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [in] */ double Arg4,
            /* [in] */ double Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Median( 
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SumProduct( 
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Sinh( 
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Cosh( 
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Tanh( 
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Asinh( 
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Acosh( 
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Atanh( 
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall DGet( 
            /* [in] */ Range	*Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Db( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [in] */ double Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Frequency( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall AveDev( 
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall BetaDist( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall GammaLn( 
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall BetaInv( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall BinomDist( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [in] */ VARIANT_BOOL Arg4,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ChiDist( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ChiInv( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Combin( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Confidence( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CritBinom( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Even( 
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ExponDist( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ VARIANT_BOOL Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall FDist( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall FInv( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Fisher( 
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall FisherInv( 
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Floor( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall GammaDist( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [in] */ VARIANT_BOOL Arg4,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall GammaInv( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Ceiling( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall HypGeomDist( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [in] */ double Arg4,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall LogNormDist( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall LogInv( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall NegBinomDist( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall NormDist( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [in] */ VARIANT_BOOL Arg4,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall NormSDist( 
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall NormInv( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall NormSInv( 
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Standardize( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Odd( 
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Permut( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Poisson( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ VARIANT_BOOL Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall TDist( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Weibull( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [in] */ VARIANT_BOOL Arg4,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SumXMY2( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SumX2MY2( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SumX2PY2( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ChiTest( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Correl( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Covar( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Forecast( 
            /* [in] */ double Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall FTest( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Intercept( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Pearson( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall RSq( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall StEyx( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Slope( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall TTest( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ double Arg3,
            /* [in] */ double Arg4,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Prob( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ double Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall DevSq( 
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall GeoMean( 
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall HarMean( 
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SumSq( 
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Kurt( 
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Skew( 
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ZTest( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ double Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Large( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Small( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Quartile( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Percentile( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall PercentRank( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ double Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Mode( 
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall TrimMean( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall TInv( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Power( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Radians( 
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Degrees( 
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Subtotal( 
            /* [in] */ double Arg1,
            /* [in] */ Range	*Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SumIf( 
            /* [in] */ Range	*Arg1,
            /* [in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CountIf( 
            /* [in] */ Range	*Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CountBlank( 
            /* [in] */ Range	*Arg1,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Ispmt( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [in] */ double Arg4,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Roman( 
            /* [in] */ double Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Asc( 
            /* [in] */ BSTR Arg1,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Dbcs( 
            /* [in] */ BSTR Arg1,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Phonetic( 
            /* [in] */ Range	*Arg1,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall BahtText( 
            /* [in] */ double Arg1,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall ThaiDayOfWeek( 
            /* [in] */ double Arg1,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall ThaiDigit( 
            /* [in] */ BSTR Arg1,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall ThaiMonthOfYear( 
            /* [in] */ double Arg1,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall ThaiNumSound( 
            /* [in] */ double Arg1,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall ThaiNumString( 
            /* [in] */ double Arg1,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall ThaiStringLength( 
            /* [in] */ BSTR Arg1,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall IsThaiDigit( 
            /* [in] */ BSTR Arg1,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall RoundBahtDown( 
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall RoundBahtUp( 
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall ThaiYear( 
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall RTD( 
            /* [in] */ VARIANT progID,
            /* [in] */ VARIANT server,
            /* [in] */ VARIANT topic1,
            /* [optional][in] */ VARIANT topic2,
            /* [optional][in] */ VARIANT topic3,
            /* [optional][in] */ VARIANT topic4,
            /* [optional][in] */ VARIANT topic5,
            /* [optional][in] */ VARIANT topic6,
            /* [optional][in] */ VARIANT topic7,
            /* [optional][in] */ VARIANT topic8,
            /* [optional][in] */ VARIANT topic9,
            /* [optional][in] */ VARIANT topic10,
            /* [optional][in] */ VARIANT topic11,
            /* [optional][in] */ VARIANT topic12,
            /* [optional][in] */ VARIANT topic13,
            /* [optional][in] */ VARIANT topic14,
            /* [optional][in] */ VARIANT topic15,
            /* [optional][in] */ VARIANT topic16,
            /* [optional][in] */ VARIANT topic17,
            /* [optional][in] */ VARIANT topic18,
            /* [optional][in] */ VARIANT topic19,
            /* [optional][in] */ VARIANT topic20,
            /* [optional][in] */ VARIANT topic21,
            /* [optional][in] */ VARIANT topic22,
            /* [optional][in] */ VARIANT topic23,
            /* [optional][in] */ VARIANT topic24,
            /* [optional][in] */ VARIANT topic25,
            /* [optional][in] */ VARIANT topic26,
            /* [optional][in] */ VARIANT topic27,
            /* [optional][in] */ VARIANT topic28,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Hex2Bin( 
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Hex2Dec( 
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Hex2Oct( 
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Dec2Bin( 
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Dec2Hex( 
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Dec2Oct( 
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Oct2Bin( 
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Oct2Hex( 
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Oct2Dec( 
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Bin2Dec( 
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Bin2Oct( 
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Bin2Hex( 
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ImSub( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ImDiv( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ImPower( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ImAbs( 
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ImSqrt( 
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ImLn( 
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ImLog2( 
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ImLog10( 
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ImSin( 
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ImCos( 
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ImExp( 
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ImArgument( 
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ImConjugate( 
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Imaginary( 
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ImReal( 
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Complex( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ImSum( 
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ImProduct( 
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SeriesSum( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [in] */ VARIANT Arg4,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall FactDouble( 
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SqrtPi( 
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Quotient( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delta( 
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall GeStep( 
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall IsEven( 
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall IsOdd( 
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall MRound( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Erf( 
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ErfC( 
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall BesselJ( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall BesselK( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall BesselY( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall BesselI( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Xirr( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Xnpv( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall PriceMat( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [in] */ VARIANT Arg4,
            /* [in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall YieldMat( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [in] */ VARIANT Arg4,
            /* [in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall IntRate( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Received( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Disc( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall PriceDisc( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall YieldDisc( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall TBillEq( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall TBillPrice( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall TBillYield( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Price( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [in] */ VARIANT Arg4,
            /* [in] */ VARIANT Arg5,
            /* [in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall DollarDe( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall DollarFr( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Nominal( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Effect( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CumPrinc( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [in] */ VARIANT Arg4,
            /* [in] */ VARIANT Arg5,
            /* [in] */ VARIANT Arg6,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CumIPmt( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [in] */ VARIANT Arg4,
            /* [in] */ VARIANT Arg5,
            /* [in] */ VARIANT Arg6,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall EDate( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall EoMonth( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall YearFrac( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CoupDayBs( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CoupDays( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CoupDaysNc( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CoupNcd( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CoupNum( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CoupPcd( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Duration( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [in] */ VARIANT Arg4,
            /* [in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall MDuration( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [in] */ VARIANT Arg4,
            /* [in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall OddLPrice( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [in] */ VARIANT Arg4,
            /* [in] */ VARIANT Arg5,
            /* [in] */ VARIANT Arg6,
            /* [in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall OddLYield( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [in] */ VARIANT Arg4,
            /* [in] */ VARIANT Arg5,
            /* [in] */ VARIANT Arg6,
            /* [in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall OddFPrice( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [in] */ VARIANT Arg4,
            /* [in] */ VARIANT Arg5,
            /* [in] */ VARIANT Arg6,
            /* [in] */ VARIANT Arg7,
            /* [in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall OddFYield( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [in] */ VARIANT Arg4,
            /* [in] */ VARIANT Arg5,
            /* [in] */ VARIANT Arg6,
            /* [in] */ VARIANT Arg7,
            /* [in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall RandBetween( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall WeekNum( 
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall AmorDegrc( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [in] */ VARIANT Arg4,
            /* [in] */ VARIANT Arg5,
            /* [in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall AmorLinc( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [in] */ VARIANT Arg4,
            /* [in] */ VARIANT Arg5,
            /* [in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Convert( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall AccrInt( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [in] */ VARIANT Arg4,
            /* [in] */ VARIANT Arg5,
            /* [in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall AccrIntM( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall WorkDay( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall NetworkDays( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Gcd( 
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall MultiNomial( 
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Lcm( 
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall FVSchedule( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SumIfs( 
            /* [in] */ Range	*Arg1,
            /* [in] */ Range	*Arg2,
            /* [in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CountIfs( 
            /* [in] */ Range	*Arg1,
            /* [in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall AverageIf( 
            /* [in] */ Range	*Arg1,
            /* [in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall AverageIfs( 
            /* [in] */ Range	*Arg1,
            /* [in] */ Range	*Arg2,
            /* [in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall IfError( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Aggregate( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ Range	*Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Confidence_Norm( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Confidence_T( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ChiSq_Test( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall F_Test( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Covariance_P( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Covariance_S( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Expon_Dist( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ VARIANT_BOOL Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Gamma_Dist( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [in] */ VARIANT_BOOL Arg4,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Gamma_Inv( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Mode_Mult( 
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Mode_Sngl( 
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Norm_Dist( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [in] */ VARIANT_BOOL Arg4,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Norm_Inv( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Percentile_Exc( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Percentile_Inc( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall PercentRank_Exc( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ double Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall PercentRank_Inc( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ double Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Poisson_Dist( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ VARIANT_BOOL Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Quartile_Exc( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Quartile_Inc( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Rank_Avg( 
            /* [in] */ double Arg1,
            /* [in] */ Range	*Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Rank_Eq( 
            /* [in] */ double Arg1,
            /* [in] */ Range	*Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall StDev_S( 
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall StDev_P( 
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall T_Dist( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ VARIANT_BOOL Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall T_Dist_2T( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall T_Dist_RT( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall T_Inv( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall T_Inv_2T( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Var_S( 
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Var_P( 
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Weibull_Dist( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [in] */ VARIANT_BOOL Arg4,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall NetworkDays_Intl( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall WorkDay_Intl( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ISO_Ceiling( 
            /* [in] */ double Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall Dummy21( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall Dummy19( 
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Beta_Dist( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [in] */ VARIANT_BOOL Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Beta_Inv( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ChiSq_Dist( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ VARIANT_BOOL Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ChiSq_Dist_RT( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ChiSq_Inv( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ChiSq_Inv_RT( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall F_Dist( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [in] */ VARIANT_BOOL Arg4,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall F_Dist_RT( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall F_Inv( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall F_Inv_RT( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall HypGeom_Dist( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [in] */ double Arg4,
            /* [in] */ VARIANT_BOOL Arg5,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall LogNorm_Dist( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [in] */ VARIANT_BOOL Arg4,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall LogNorm_Inv( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall NegBinom_Dist( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [in] */ VARIANT_BOOL Arg4,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Norm_S_Dist( 
            /* [in] */ double Arg1,
            /* [in] */ VARIANT_BOOL Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Norm_S_Inv( 
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall T_Test( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ double Arg3,
            /* [in] */ double Arg4,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Z_Test( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ double Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Binom_Dist( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [in] */ VARIANT_BOOL Arg4,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Binom_Inv( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Erf_Precise( 
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ErfC_Precise( 
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall GammaLn_Precise( 
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Ceiling_Precise( 
            /* [in] */ double Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Floor_Precise( 
            /* [in] */ double Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Acot( 
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Acoth( 
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Cot( 
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Coth( 
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Csc( 
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Csch( 
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Sec( 
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Sech( 
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ImCot( 
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ImTan( 
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ImCsc( 
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ImCsch( 
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ImSec( 
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ImSech( 
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Bitand( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Bitor( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Bitxor( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Bitlshift( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Bitrshift( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Xor( 
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Combina( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Permutationa( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall PDuration( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Base( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Decimal( 
            /* [in] */ BSTR Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Days( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Binom_Dist_Range( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Gamma( 
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Gauss( 
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Phi( 
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Skew_p( 
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Rri( 
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Unichar( 
            /* [in] */ double Arg1,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Unicode( 
            /* [in] */ BSTR Arg1,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Munit( 
            /* [in] */ double Arg1,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Arabic( 
            /* [in] */ BSTR Arg1,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall IsoWeekNum( 
            /* [in] */ double Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall NumberValue( 
            /* [in] */ BSTR Arg1,
            /* [in] */ BSTR Arg2,
            /* [in] */ BSTR Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall IsFormula( 
            /* [in] */ Range	*Arg1,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall IfNa( 
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Ceiling_Math( 
            /* [in] */ double Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Floor_Math( 
            /* [in] */ double Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ImSinh( 
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ImCosh( 
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall FilterXML( 
            /* [in] */ BSTR Arg1,
            /* [in] */ BSTR Arg2,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall WebService( 
            /* [in] */ BSTR Arg1,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall EncodeURL( 
            /* [in] */ BSTR Arg1,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IWorksheetFunctionVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IWorksheetFunction * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IWorksheetFunction * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IWorksheetFunction * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IWorksheetFunction * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IWorksheetFunction * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IWorksheetFunction * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IWorksheetFunction * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IWorksheetFunction * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IWorksheetFunction * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IWorksheetFunction * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *_WSFunction )( 
            IWorksheetFunction * This,
            /* [optional][in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Count )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *IsNA )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *IsError )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Sum )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Average )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Min )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Max )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Npv )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *StDev )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Dollar )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Fixed )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Pi )( 
            IWorksheetFunction * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Ln )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Log10 )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Round )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Lookup )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Index )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ double Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Rept )( 
            IWorksheetFunction * This,
            /* [in] */ BSTR Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *And )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Or )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *DCount )( 
            IWorksheetFunction * This,
            /* [in] */ Range	*Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *DSum )( 
            IWorksheetFunction * This,
            /* [in] */ Range	*Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *DAverage )( 
            IWorksheetFunction * This,
            /* [in] */ Range	*Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *DMin )( 
            IWorksheetFunction * This,
            /* [in] */ Range	*Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *DMax )( 
            IWorksheetFunction * This,
            /* [in] */ Range	*Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *DStDev )( 
            IWorksheetFunction * This,
            /* [in] */ Range	*Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Var )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *DVar )( 
            IWorksheetFunction * This,
            /* [in] */ Range	*Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Text )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ BSTR Arg2,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *LinEst )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Trend )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *LogEst )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Growth )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Pv )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Fv )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *NPer )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Pmt )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Rate )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *MIrr )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Irr )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Match )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Weekday )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Search )( 
            IWorksheetFunction * This,
            /* [in] */ BSTR Arg1,
            /* [in] */ BSTR Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Transpose )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Atan2 )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Asin )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Acos )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Choose )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *HLookup )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *VLookup )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Log )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Proper )( 
            IWorksheetFunction * This,
            /* [in] */ BSTR Arg1,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Trim )( 
            IWorksheetFunction * This,
            /* [in] */ BSTR Arg1,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Replace )( 
            IWorksheetFunction * This,
            /* [in] */ BSTR Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [in] */ BSTR Arg4,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Substitute )( 
            IWorksheetFunction * This,
            /* [in] */ BSTR Arg1,
            /* [in] */ BSTR Arg2,
            /* [in] */ BSTR Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Find )( 
            IWorksheetFunction * This,
            /* [in] */ BSTR Arg1,
            /* [in] */ BSTR Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *IsErr )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *IsText )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *IsNumber )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Sln )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Syd )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [in] */ double Arg4,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Ddb )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [in] */ double Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Clean )( 
            IWorksheetFunction * This,
            /* [in] */ BSTR Arg1,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *MDeterm )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *MInverse )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *MMult )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Ipmt )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [in] */ double Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Ppmt )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [in] */ double Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CountA )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Product )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Fact )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *DProduct )( 
            IWorksheetFunction * This,
            /* [in] */ Range	*Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *IsNonText )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *StDevP )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *VarP )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *DStDevP )( 
            IWorksheetFunction * This,
            /* [in] */ Range	*Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *DVarP )( 
            IWorksheetFunction * This,
            /* [in] */ Range	*Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *IsLogical )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *DCountA )( 
            IWorksheetFunction * This,
            /* [in] */ Range	*Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *USDollar )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *FindB )( 
            IWorksheetFunction * This,
            /* [in] */ BSTR Arg1,
            /* [in] */ BSTR Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SearchB )( 
            IWorksheetFunction * This,
            /* [in] */ BSTR Arg1,
            /* [in] */ BSTR Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ReplaceB )( 
            IWorksheetFunction * This,
            /* [in] */ BSTR Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [in] */ BSTR Arg4,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *RoundUp )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *RoundDown )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Rank )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ Range	*Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Days360 )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Vdb )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [in] */ double Arg4,
            /* [in] */ double Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Median )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SumProduct )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Sinh )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Cosh )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Tanh )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Asinh )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Acosh )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Atanh )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *DGet )( 
            IWorksheetFunction * This,
            /* [in] */ Range	*Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Db )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [in] */ double Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Frequency )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *AveDev )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *BetaDist )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *GammaLn )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *BetaInv )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *BinomDist )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [in] */ VARIANT_BOOL Arg4,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ChiDist )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ChiInv )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Combin )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Confidence )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CritBinom )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Even )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ExponDist )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ VARIANT_BOOL Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *FDist )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *FInv )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Fisher )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *FisherInv )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Floor )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *GammaDist )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [in] */ VARIANT_BOOL Arg4,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *GammaInv )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Ceiling )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *HypGeomDist )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [in] */ double Arg4,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *LogNormDist )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *LogInv )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *NegBinomDist )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *NormDist )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [in] */ VARIANT_BOOL Arg4,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *NormSDist )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *NormInv )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *NormSInv )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Standardize )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Odd )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Permut )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Poisson )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ VARIANT_BOOL Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *TDist )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Weibull )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [in] */ VARIANT_BOOL Arg4,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SumXMY2 )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SumX2MY2 )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SumX2PY2 )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ChiTest )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Correl )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Covar )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Forecast )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *FTest )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Intercept )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Pearson )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *RSq )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *StEyx )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Slope )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *TTest )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ double Arg3,
            /* [in] */ double Arg4,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Prob )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ double Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *DevSq )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *GeoMean )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *HarMean )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SumSq )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Kurt )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Skew )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ZTest )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ double Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Large )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Small )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Quartile )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Percentile )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *PercentRank )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ double Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Mode )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *TrimMean )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *TInv )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Power )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Radians )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Degrees )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Subtotal )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ Range	*Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SumIf )( 
            IWorksheetFunction * This,
            /* [in] */ Range	*Arg1,
            /* [in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CountIf )( 
            IWorksheetFunction * This,
            /* [in] */ Range	*Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CountBlank )( 
            IWorksheetFunction * This,
            /* [in] */ Range	*Arg1,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Ispmt )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [in] */ double Arg4,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Roman )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Asc )( 
            IWorksheetFunction * This,
            /* [in] */ BSTR Arg1,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Dbcs )( 
            IWorksheetFunction * This,
            /* [in] */ BSTR Arg1,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Phonetic )( 
            IWorksheetFunction * This,
            /* [in] */ Range	*Arg1,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *BahtText )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *ThaiDayOfWeek )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *ThaiDigit )( 
            IWorksheetFunction * This,
            /* [in] */ BSTR Arg1,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *ThaiMonthOfYear )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *ThaiNumSound )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *ThaiNumString )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *ThaiStringLength )( 
            IWorksheetFunction * This,
            /* [in] */ BSTR Arg1,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *IsThaiDigit )( 
            IWorksheetFunction * This,
            /* [in] */ BSTR Arg1,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *RoundBahtDown )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *RoundBahtUp )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *ThaiYear )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *RTD )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT progID,
            /* [in] */ VARIANT server,
            /* [in] */ VARIANT topic1,
            /* [optional][in] */ VARIANT topic2,
            /* [optional][in] */ VARIANT topic3,
            /* [optional][in] */ VARIANT topic4,
            /* [optional][in] */ VARIANT topic5,
            /* [optional][in] */ VARIANT topic6,
            /* [optional][in] */ VARIANT topic7,
            /* [optional][in] */ VARIANT topic8,
            /* [optional][in] */ VARIANT topic9,
            /* [optional][in] */ VARIANT topic10,
            /* [optional][in] */ VARIANT topic11,
            /* [optional][in] */ VARIANT topic12,
            /* [optional][in] */ VARIANT topic13,
            /* [optional][in] */ VARIANT topic14,
            /* [optional][in] */ VARIANT topic15,
            /* [optional][in] */ VARIANT topic16,
            /* [optional][in] */ VARIANT topic17,
            /* [optional][in] */ VARIANT topic18,
            /* [optional][in] */ VARIANT topic19,
            /* [optional][in] */ VARIANT topic20,
            /* [optional][in] */ VARIANT topic21,
            /* [optional][in] */ VARIANT topic22,
            /* [optional][in] */ VARIANT topic23,
            /* [optional][in] */ VARIANT topic24,
            /* [optional][in] */ VARIANT topic25,
            /* [optional][in] */ VARIANT topic26,
            /* [optional][in] */ VARIANT topic27,
            /* [optional][in] */ VARIANT topic28,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Hex2Bin )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Hex2Dec )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Hex2Oct )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Dec2Bin )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Dec2Hex )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Dec2Oct )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Oct2Bin )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Oct2Hex )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Oct2Dec )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Bin2Dec )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Bin2Oct )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Bin2Hex )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ImSub )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ImDiv )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ImPower )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ImAbs )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ImSqrt )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ImLn )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ImLog2 )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ImLog10 )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ImSin )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ImCos )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ImExp )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ImArgument )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ImConjugate )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Imaginary )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ImReal )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Complex )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ImSum )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ImProduct )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SeriesSum )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [in] */ VARIANT Arg4,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *FactDouble )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SqrtPi )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Quotient )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delta )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *GeStep )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *IsEven )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *IsOdd )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *MRound )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Erf )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ErfC )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *BesselJ )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *BesselK )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *BesselY )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *BesselI )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Xirr )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Xnpv )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *PriceMat )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [in] */ VARIANT Arg4,
            /* [in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *YieldMat )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [in] */ VARIANT Arg4,
            /* [in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *IntRate )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Received )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Disc )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *PriceDisc )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *YieldDisc )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *TBillEq )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *TBillPrice )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *TBillYield )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Price )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [in] */ VARIANT Arg4,
            /* [in] */ VARIANT Arg5,
            /* [in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *DollarDe )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *DollarFr )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Nominal )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Effect )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CumPrinc )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [in] */ VARIANT Arg4,
            /* [in] */ VARIANT Arg5,
            /* [in] */ VARIANT Arg6,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CumIPmt )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [in] */ VARIANT Arg4,
            /* [in] */ VARIANT Arg5,
            /* [in] */ VARIANT Arg6,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *EDate )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *EoMonth )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *YearFrac )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CoupDayBs )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CoupDays )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CoupDaysNc )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CoupNcd )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CoupNum )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CoupPcd )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Duration )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [in] */ VARIANT Arg4,
            /* [in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *MDuration )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [in] */ VARIANT Arg4,
            /* [in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *OddLPrice )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [in] */ VARIANT Arg4,
            /* [in] */ VARIANT Arg5,
            /* [in] */ VARIANT Arg6,
            /* [in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *OddLYield )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [in] */ VARIANT Arg4,
            /* [in] */ VARIANT Arg5,
            /* [in] */ VARIANT Arg6,
            /* [in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *OddFPrice )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [in] */ VARIANT Arg4,
            /* [in] */ VARIANT Arg5,
            /* [in] */ VARIANT Arg6,
            /* [in] */ VARIANT Arg7,
            /* [in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *OddFYield )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [in] */ VARIANT Arg4,
            /* [in] */ VARIANT Arg5,
            /* [in] */ VARIANT Arg6,
            /* [in] */ VARIANT Arg7,
            /* [in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *RandBetween )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *WeekNum )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *AmorDegrc )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [in] */ VARIANT Arg4,
            /* [in] */ VARIANT Arg5,
            /* [in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *AmorLinc )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [in] */ VARIANT Arg4,
            /* [in] */ VARIANT Arg5,
            /* [in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Convert )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *AccrInt )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [in] */ VARIANT Arg4,
            /* [in] */ VARIANT Arg5,
            /* [in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *AccrIntM )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ VARIANT Arg3,
            /* [in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *WorkDay )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *NetworkDays )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Gcd )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *MultiNomial )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Lcm )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *FVSchedule )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SumIfs )( 
            IWorksheetFunction * This,
            /* [in] */ Range	*Arg1,
            /* [in] */ Range	*Arg2,
            /* [in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CountIfs )( 
            IWorksheetFunction * This,
            /* [in] */ Range	*Arg1,
            /* [in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *AverageIf )( 
            IWorksheetFunction * This,
            /* [in] */ Range	*Arg1,
            /* [in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *AverageIfs )( 
            IWorksheetFunction * This,
            /* [in] */ Range	*Arg1,
            /* [in] */ Range	*Arg2,
            /* [in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *IfError )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Aggregate )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ Range	*Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Confidence_Norm )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Confidence_T )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ChiSq_Test )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *F_Test )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Covariance_P )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Covariance_S )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Expon_Dist )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ VARIANT_BOOL Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Gamma_Dist )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [in] */ VARIANT_BOOL Arg4,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Gamma_Inv )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Mode_Mult )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Mode_Sngl )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Norm_Dist )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [in] */ VARIANT_BOOL Arg4,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Norm_Inv )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Percentile_Exc )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Percentile_Inc )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *PercentRank_Exc )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ double Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *PercentRank_Inc )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ double Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Poisson_Dist )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ VARIANT_BOOL Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Quartile_Exc )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Quartile_Inc )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Rank_Avg )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ Range	*Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Rank_Eq )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ Range	*Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *StDev_S )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *StDev_P )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *T_Dist )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ VARIANT_BOOL Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *T_Dist_2T )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *T_Dist_RT )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *T_Inv )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *T_Inv_2T )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Var_S )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Var_P )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Weibull_Dist )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [in] */ VARIANT_BOOL Arg4,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *NetworkDays_Intl )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *WorkDay_Intl )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ISO_Ceiling )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *Dummy21 )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *Dummy19 )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Beta_Dist )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [in] */ VARIANT_BOOL Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Beta_Inv )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ChiSq_Dist )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ VARIANT_BOOL Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ChiSq_Dist_RT )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ChiSq_Inv )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ChiSq_Inv_RT )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *F_Dist )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [in] */ VARIANT_BOOL Arg4,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *F_Dist_RT )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *F_Inv )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *F_Inv_RT )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *HypGeom_Dist )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [in] */ double Arg4,
            /* [in] */ VARIANT_BOOL Arg5,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *LogNorm_Dist )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [in] */ VARIANT_BOOL Arg4,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *LogNorm_Inv )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *NegBinom_Dist )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [in] */ VARIANT_BOOL Arg4,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Norm_S_Dist )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ VARIANT_BOOL Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Norm_S_Inv )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *T_Test )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [in] */ double Arg3,
            /* [in] */ double Arg4,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Z_Test )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ double Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Binom_Dist )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [in] */ VARIANT_BOOL Arg4,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Binom_Inv )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Erf_Precise )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ErfC_Precise )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *GammaLn_Precise )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Ceiling_Precise )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Floor_Precise )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Acot )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Acoth )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Cot )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Coth )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Csc )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Csch )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Sec )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Sech )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ImCot )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ImTan )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ImCsc )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ImCsch )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ImSec )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ImSech )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Bitand )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Bitor )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Bitxor )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Bitlshift )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Bitrshift )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Xor )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Combina )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Permutationa )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *PDuration )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Base )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Decimal )( 
            IWorksheetFunction * This,
            /* [in] */ BSTR Arg1,
            /* [in] */ double Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Days )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Binom_Dist_Range )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Gamma )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Gauss )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Phi )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Skew_p )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Rri )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [in] */ double Arg2,
            /* [in] */ double Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Unichar )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Unicode )( 
            IWorksheetFunction * This,
            /* [in] */ BSTR Arg1,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Munit )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Arabic )( 
            IWorksheetFunction * This,
            /* [in] */ BSTR Arg1,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *IsoWeekNum )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *NumberValue )( 
            IWorksheetFunction * This,
            /* [in] */ BSTR Arg1,
            /* [in] */ BSTR Arg2,
            /* [in] */ BSTR Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *IsFormula )( 
            IWorksheetFunction * This,
            /* [in] */ Range	*Arg1,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *IfNa )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [in] */ VARIANT Arg2,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Ceiling_Math )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Floor_Math )( 
            IWorksheetFunction * This,
            /* [in] */ double Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ImSinh )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ImCosh )( 
            IWorksheetFunction * This,
            /* [in] */ VARIANT Arg1,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *FilterXML )( 
            IWorksheetFunction * This,
            /* [in] */ BSTR Arg1,
            /* [in] */ BSTR Arg2,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *WebService )( 
            IWorksheetFunction * This,
            /* [in] */ BSTR Arg1,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *EncodeURL )( 
            IWorksheetFunction * This,
            /* [in] */ BSTR Arg1,
            /* [retval][out] */ VARIANT *RHS);
        
        END_INTERFACE
    } IWorksheetFunctionVtbl;

    interface IWorksheetFunction
    {
        CONST_VTBL struct IWorksheetFunctionVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IWorksheetFunction_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IWorksheetFunction_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IWorksheetFunction_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IWorksheetFunction_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IWorksheetFunction_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IWorksheetFunction_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IWorksheetFunction_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IWorksheetFunction_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IWorksheetFunction_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IWorksheetFunction_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IWorksheetFunction__WSFunction(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS)	\
    ( (This)->lpVtbl -> _WSFunction(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS) ) 

#define IWorksheetFunction_Count(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS)	\
    ( (This)->lpVtbl -> Count(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS) ) 

#define IWorksheetFunction_IsNA(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> IsNA(This,Arg1,RHS) ) 

#define IWorksheetFunction_IsError(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> IsError(This,Arg1,RHS) ) 

#define IWorksheetFunction_Sum(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS)	\
    ( (This)->lpVtbl -> Sum(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS) ) 

#define IWorksheetFunction_Average(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS)	\
    ( (This)->lpVtbl -> Average(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS) ) 

#define IWorksheetFunction_Min(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS)	\
    ( (This)->lpVtbl -> Min(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS) ) 

#define IWorksheetFunction_Max(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS)	\
    ( (This)->lpVtbl -> Max(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS) ) 

#define IWorksheetFunction_Npv(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS)	\
    ( (This)->lpVtbl -> Npv(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS) ) 

#define IWorksheetFunction_StDev(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS)	\
    ( (This)->lpVtbl -> StDev(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS) ) 

#define IWorksheetFunction_Dollar(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> Dollar(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_Fixed(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> Fixed(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_Pi(This,RHS)	\
    ( (This)->lpVtbl -> Pi(This,RHS) ) 

#define IWorksheetFunction_Ln(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> Ln(This,Arg1,RHS) ) 

#define IWorksheetFunction_Log10(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> Log10(This,Arg1,RHS) ) 

#define IWorksheetFunction_Round(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> Round(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_Lookup(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> Lookup(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_Index(This,Arg1,Arg2,Arg3,Arg4,RHS)	\
    ( (This)->lpVtbl -> Index(This,Arg1,Arg2,Arg3,Arg4,RHS) ) 

#define IWorksheetFunction_Rept(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> Rept(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_And(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS)	\
    ( (This)->lpVtbl -> And(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS) ) 

#define IWorksheetFunction_Or(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS)	\
    ( (This)->lpVtbl -> Or(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS) ) 

#define IWorksheetFunction_DCount(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> DCount(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_DSum(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> DSum(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_DAverage(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> DAverage(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_DMin(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> DMin(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_DMax(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> DMax(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_DStDev(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> DStDev(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_Var(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS)	\
    ( (This)->lpVtbl -> Var(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS) ) 

#define IWorksheetFunction_DVar(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> DVar(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_Text(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> Text(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_LinEst(This,Arg1,Arg2,Arg3,Arg4,RHS)	\
    ( (This)->lpVtbl -> LinEst(This,Arg1,Arg2,Arg3,Arg4,RHS) ) 

#define IWorksheetFunction_Trend(This,Arg1,Arg2,Arg3,Arg4,RHS)	\
    ( (This)->lpVtbl -> Trend(This,Arg1,Arg2,Arg3,Arg4,RHS) ) 

#define IWorksheetFunction_LogEst(This,Arg1,Arg2,Arg3,Arg4,RHS)	\
    ( (This)->lpVtbl -> LogEst(This,Arg1,Arg2,Arg3,Arg4,RHS) ) 

#define IWorksheetFunction_Growth(This,Arg1,Arg2,Arg3,Arg4,RHS)	\
    ( (This)->lpVtbl -> Growth(This,Arg1,Arg2,Arg3,Arg4,RHS) ) 

#define IWorksheetFunction_Pv(This,Arg1,Arg2,Arg3,Arg4,Arg5,RHS)	\
    ( (This)->lpVtbl -> Pv(This,Arg1,Arg2,Arg3,Arg4,Arg5,RHS) ) 

#define IWorksheetFunction_Fv(This,Arg1,Arg2,Arg3,Arg4,Arg5,RHS)	\
    ( (This)->lpVtbl -> Fv(This,Arg1,Arg2,Arg3,Arg4,Arg5,RHS) ) 

#define IWorksheetFunction_NPer(This,Arg1,Arg2,Arg3,Arg4,Arg5,RHS)	\
    ( (This)->lpVtbl -> NPer(This,Arg1,Arg2,Arg3,Arg4,Arg5,RHS) ) 

#define IWorksheetFunction_Pmt(This,Arg1,Arg2,Arg3,Arg4,Arg5,RHS)	\
    ( (This)->lpVtbl -> Pmt(This,Arg1,Arg2,Arg3,Arg4,Arg5,RHS) ) 

#define IWorksheetFunction_Rate(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,RHS)	\
    ( (This)->lpVtbl -> Rate(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,RHS) ) 

#define IWorksheetFunction_MIrr(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> MIrr(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_Irr(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> Irr(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_Match(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> Match(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_Weekday(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> Weekday(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_Search(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> Search(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_Transpose(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> Transpose(This,Arg1,RHS) ) 

#define IWorksheetFunction_Atan2(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> Atan2(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_Asin(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> Asin(This,Arg1,RHS) ) 

#define IWorksheetFunction_Acos(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> Acos(This,Arg1,RHS) ) 

#define IWorksheetFunction_Choose(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS)	\
    ( (This)->lpVtbl -> Choose(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS) ) 

#define IWorksheetFunction_HLookup(This,Arg1,Arg2,Arg3,Arg4,RHS)	\
    ( (This)->lpVtbl -> HLookup(This,Arg1,Arg2,Arg3,Arg4,RHS) ) 

#define IWorksheetFunction_VLookup(This,Arg1,Arg2,Arg3,Arg4,RHS)	\
    ( (This)->lpVtbl -> VLookup(This,Arg1,Arg2,Arg3,Arg4,RHS) ) 

#define IWorksheetFunction_Log(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> Log(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_Proper(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> Proper(This,Arg1,RHS) ) 

#define IWorksheetFunction_Trim(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> Trim(This,Arg1,RHS) ) 

#define IWorksheetFunction_Replace(This,Arg1,Arg2,Arg3,Arg4,RHS)	\
    ( (This)->lpVtbl -> Replace(This,Arg1,Arg2,Arg3,Arg4,RHS) ) 

#define IWorksheetFunction_Substitute(This,Arg1,Arg2,Arg3,Arg4,RHS)	\
    ( (This)->lpVtbl -> Substitute(This,Arg1,Arg2,Arg3,Arg4,RHS) ) 

#define IWorksheetFunction_Find(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> Find(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_IsErr(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> IsErr(This,Arg1,RHS) ) 

#define IWorksheetFunction_IsText(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> IsText(This,Arg1,RHS) ) 

#define IWorksheetFunction_IsNumber(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> IsNumber(This,Arg1,RHS) ) 

#define IWorksheetFunction_Sln(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> Sln(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_Syd(This,Arg1,Arg2,Arg3,Arg4,RHS)	\
    ( (This)->lpVtbl -> Syd(This,Arg1,Arg2,Arg3,Arg4,RHS) ) 

#define IWorksheetFunction_Ddb(This,Arg1,Arg2,Arg3,Arg4,Arg5,RHS)	\
    ( (This)->lpVtbl -> Ddb(This,Arg1,Arg2,Arg3,Arg4,Arg5,RHS) ) 

#define IWorksheetFunction_Clean(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> Clean(This,Arg1,RHS) ) 

#define IWorksheetFunction_MDeterm(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> MDeterm(This,Arg1,RHS) ) 

#define IWorksheetFunction_MInverse(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> MInverse(This,Arg1,RHS) ) 

#define IWorksheetFunction_MMult(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> MMult(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_Ipmt(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,RHS)	\
    ( (This)->lpVtbl -> Ipmt(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,RHS) ) 

#define IWorksheetFunction_Ppmt(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,RHS)	\
    ( (This)->lpVtbl -> Ppmt(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,RHS) ) 

#define IWorksheetFunction_CountA(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS)	\
    ( (This)->lpVtbl -> CountA(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS) ) 

#define IWorksheetFunction_Product(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS)	\
    ( (This)->lpVtbl -> Product(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS) ) 

#define IWorksheetFunction_Fact(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> Fact(This,Arg1,RHS) ) 

#define IWorksheetFunction_DProduct(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> DProduct(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_IsNonText(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> IsNonText(This,Arg1,RHS) ) 

#define IWorksheetFunction_StDevP(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS)	\
    ( (This)->lpVtbl -> StDevP(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS) ) 

#define IWorksheetFunction_VarP(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS)	\
    ( (This)->lpVtbl -> VarP(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS) ) 

#define IWorksheetFunction_DStDevP(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> DStDevP(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_DVarP(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> DVarP(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_IsLogical(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> IsLogical(This,Arg1,RHS) ) 

#define IWorksheetFunction_DCountA(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> DCountA(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_USDollar(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> USDollar(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_FindB(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> FindB(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_SearchB(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> SearchB(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_ReplaceB(This,Arg1,Arg2,Arg3,Arg4,RHS)	\
    ( (This)->lpVtbl -> ReplaceB(This,Arg1,Arg2,Arg3,Arg4,RHS) ) 

#define IWorksheetFunction_RoundUp(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> RoundUp(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_RoundDown(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> RoundDown(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_Rank(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> Rank(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_Days360(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> Days360(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_Vdb(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,RHS)	\
    ( (This)->lpVtbl -> Vdb(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,RHS) ) 

#define IWorksheetFunction_Median(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS)	\
    ( (This)->lpVtbl -> Median(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS) ) 

#define IWorksheetFunction_SumProduct(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS)	\
    ( (This)->lpVtbl -> SumProduct(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS) ) 

#define IWorksheetFunction_Sinh(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> Sinh(This,Arg1,RHS) ) 

#define IWorksheetFunction_Cosh(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> Cosh(This,Arg1,RHS) ) 

#define IWorksheetFunction_Tanh(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> Tanh(This,Arg1,RHS) ) 

#define IWorksheetFunction_Asinh(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> Asinh(This,Arg1,RHS) ) 

#define IWorksheetFunction_Acosh(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> Acosh(This,Arg1,RHS) ) 

#define IWorksheetFunction_Atanh(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> Atanh(This,Arg1,RHS) ) 

#define IWorksheetFunction_DGet(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> DGet(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_Db(This,Arg1,Arg2,Arg3,Arg4,Arg5,RHS)	\
    ( (This)->lpVtbl -> Db(This,Arg1,Arg2,Arg3,Arg4,Arg5,RHS) ) 

#define IWorksheetFunction_Frequency(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> Frequency(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_AveDev(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS)	\
    ( (This)->lpVtbl -> AveDev(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS) ) 

#define IWorksheetFunction_BetaDist(This,Arg1,Arg2,Arg3,Arg4,Arg5,RHS)	\
    ( (This)->lpVtbl -> BetaDist(This,Arg1,Arg2,Arg3,Arg4,Arg5,RHS) ) 

#define IWorksheetFunction_GammaLn(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> GammaLn(This,Arg1,RHS) ) 

#define IWorksheetFunction_BetaInv(This,Arg1,Arg2,Arg3,Arg4,Arg5,RHS)	\
    ( (This)->lpVtbl -> BetaInv(This,Arg1,Arg2,Arg3,Arg4,Arg5,RHS) ) 

#define IWorksheetFunction_BinomDist(This,Arg1,Arg2,Arg3,Arg4,RHS)	\
    ( (This)->lpVtbl -> BinomDist(This,Arg1,Arg2,Arg3,Arg4,RHS) ) 

#define IWorksheetFunction_ChiDist(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> ChiDist(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_ChiInv(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> ChiInv(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_Combin(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> Combin(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_Confidence(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> Confidence(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_CritBinom(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> CritBinom(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_Even(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> Even(This,Arg1,RHS) ) 

#define IWorksheetFunction_ExponDist(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> ExponDist(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_FDist(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> FDist(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_FInv(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> FInv(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_Fisher(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> Fisher(This,Arg1,RHS) ) 

#define IWorksheetFunction_FisherInv(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> FisherInv(This,Arg1,RHS) ) 

#define IWorksheetFunction_Floor(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> Floor(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_GammaDist(This,Arg1,Arg2,Arg3,Arg4,RHS)	\
    ( (This)->lpVtbl -> GammaDist(This,Arg1,Arg2,Arg3,Arg4,RHS) ) 

#define IWorksheetFunction_GammaInv(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> GammaInv(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_Ceiling(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> Ceiling(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_HypGeomDist(This,Arg1,Arg2,Arg3,Arg4,RHS)	\
    ( (This)->lpVtbl -> HypGeomDist(This,Arg1,Arg2,Arg3,Arg4,RHS) ) 

#define IWorksheetFunction_LogNormDist(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> LogNormDist(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_LogInv(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> LogInv(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_NegBinomDist(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> NegBinomDist(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_NormDist(This,Arg1,Arg2,Arg3,Arg4,RHS)	\
    ( (This)->lpVtbl -> NormDist(This,Arg1,Arg2,Arg3,Arg4,RHS) ) 

#define IWorksheetFunction_NormSDist(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> NormSDist(This,Arg1,RHS) ) 

#define IWorksheetFunction_NormInv(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> NormInv(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_NormSInv(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> NormSInv(This,Arg1,RHS) ) 

#define IWorksheetFunction_Standardize(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> Standardize(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_Odd(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> Odd(This,Arg1,RHS) ) 

#define IWorksheetFunction_Permut(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> Permut(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_Poisson(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> Poisson(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_TDist(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> TDist(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_Weibull(This,Arg1,Arg2,Arg3,Arg4,RHS)	\
    ( (This)->lpVtbl -> Weibull(This,Arg1,Arg2,Arg3,Arg4,RHS) ) 

#define IWorksheetFunction_SumXMY2(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> SumXMY2(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_SumX2MY2(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> SumX2MY2(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_SumX2PY2(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> SumX2PY2(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_ChiTest(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> ChiTest(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_Correl(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> Correl(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_Covar(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> Covar(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_Forecast(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> Forecast(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_FTest(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> FTest(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_Intercept(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> Intercept(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_Pearson(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> Pearson(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_RSq(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> RSq(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_StEyx(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> StEyx(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_Slope(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> Slope(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_TTest(This,Arg1,Arg2,Arg3,Arg4,RHS)	\
    ( (This)->lpVtbl -> TTest(This,Arg1,Arg2,Arg3,Arg4,RHS) ) 

#define IWorksheetFunction_Prob(This,Arg1,Arg2,Arg3,Arg4,RHS)	\
    ( (This)->lpVtbl -> Prob(This,Arg1,Arg2,Arg3,Arg4,RHS) ) 

#define IWorksheetFunction_DevSq(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS)	\
    ( (This)->lpVtbl -> DevSq(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS) ) 

#define IWorksheetFunction_GeoMean(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS)	\
    ( (This)->lpVtbl -> GeoMean(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS) ) 

#define IWorksheetFunction_HarMean(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS)	\
    ( (This)->lpVtbl -> HarMean(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS) ) 

#define IWorksheetFunction_SumSq(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS)	\
    ( (This)->lpVtbl -> SumSq(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS) ) 

#define IWorksheetFunction_Kurt(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS)	\
    ( (This)->lpVtbl -> Kurt(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS) ) 

#define IWorksheetFunction_Skew(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS)	\
    ( (This)->lpVtbl -> Skew(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS) ) 

#define IWorksheetFunction_ZTest(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> ZTest(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_Large(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> Large(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_Small(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> Small(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_Quartile(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> Quartile(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_Percentile(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> Percentile(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_PercentRank(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> PercentRank(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_Mode(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS)	\
    ( (This)->lpVtbl -> Mode(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS) ) 

#define IWorksheetFunction_TrimMean(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> TrimMean(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_TInv(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> TInv(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_Power(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> Power(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_Radians(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> Radians(This,Arg1,RHS) ) 

#define IWorksheetFunction_Degrees(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> Degrees(This,Arg1,RHS) ) 

#define IWorksheetFunction_Subtotal(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS)	\
    ( (This)->lpVtbl -> Subtotal(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS) ) 

#define IWorksheetFunction_SumIf(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> SumIf(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_CountIf(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> CountIf(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_CountBlank(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> CountBlank(This,Arg1,RHS) ) 

#define IWorksheetFunction_Ispmt(This,Arg1,Arg2,Arg3,Arg4,RHS)	\
    ( (This)->lpVtbl -> Ispmt(This,Arg1,Arg2,Arg3,Arg4,RHS) ) 

#define IWorksheetFunction_Roman(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> Roman(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_Asc(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> Asc(This,Arg1,RHS) ) 

#define IWorksheetFunction_Dbcs(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> Dbcs(This,Arg1,RHS) ) 

#define IWorksheetFunction_Phonetic(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> Phonetic(This,Arg1,RHS) ) 

#define IWorksheetFunction_BahtText(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> BahtText(This,Arg1,RHS) ) 

#define IWorksheetFunction_ThaiDayOfWeek(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> ThaiDayOfWeek(This,Arg1,RHS) ) 

#define IWorksheetFunction_ThaiDigit(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> ThaiDigit(This,Arg1,RHS) ) 

#define IWorksheetFunction_ThaiMonthOfYear(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> ThaiMonthOfYear(This,Arg1,RHS) ) 

#define IWorksheetFunction_ThaiNumSound(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> ThaiNumSound(This,Arg1,RHS) ) 

#define IWorksheetFunction_ThaiNumString(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> ThaiNumString(This,Arg1,RHS) ) 

#define IWorksheetFunction_ThaiStringLength(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> ThaiStringLength(This,Arg1,RHS) ) 

#define IWorksheetFunction_IsThaiDigit(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> IsThaiDigit(This,Arg1,RHS) ) 

#define IWorksheetFunction_RoundBahtDown(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> RoundBahtDown(This,Arg1,RHS) ) 

#define IWorksheetFunction_RoundBahtUp(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> RoundBahtUp(This,Arg1,RHS) ) 

#define IWorksheetFunction_ThaiYear(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> ThaiYear(This,Arg1,RHS) ) 

#define IWorksheetFunction_RTD(This,progID,server,topic1,topic2,topic3,topic4,topic5,topic6,topic7,topic8,topic9,topic10,topic11,topic12,topic13,topic14,topic15,topic16,topic17,topic18,topic19,topic20,topic21,topic22,topic23,topic24,topic25,topic26,topic27,topic28,RHS)	\
    ( (This)->lpVtbl -> RTD(This,progID,server,topic1,topic2,topic3,topic4,topic5,topic6,topic7,topic8,topic9,topic10,topic11,topic12,topic13,topic14,topic15,topic16,topic17,topic18,topic19,topic20,topic21,topic22,topic23,topic24,topic25,topic26,topic27,topic28,RHS) ) 

#define IWorksheetFunction_Hex2Bin(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> Hex2Bin(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_Hex2Dec(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> Hex2Dec(This,Arg1,RHS) ) 

#define IWorksheetFunction_Hex2Oct(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> Hex2Oct(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_Dec2Bin(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> Dec2Bin(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_Dec2Hex(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> Dec2Hex(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_Dec2Oct(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> Dec2Oct(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_Oct2Bin(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> Oct2Bin(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_Oct2Hex(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> Oct2Hex(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_Oct2Dec(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> Oct2Dec(This,Arg1,RHS) ) 

#define IWorksheetFunction_Bin2Dec(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> Bin2Dec(This,Arg1,RHS) ) 

#define IWorksheetFunction_Bin2Oct(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> Bin2Oct(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_Bin2Hex(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> Bin2Hex(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_ImSub(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> ImSub(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_ImDiv(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> ImDiv(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_ImPower(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> ImPower(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_ImAbs(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> ImAbs(This,Arg1,RHS) ) 

#define IWorksheetFunction_ImSqrt(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> ImSqrt(This,Arg1,RHS) ) 

#define IWorksheetFunction_ImLn(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> ImLn(This,Arg1,RHS) ) 

#define IWorksheetFunction_ImLog2(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> ImLog2(This,Arg1,RHS) ) 

#define IWorksheetFunction_ImLog10(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> ImLog10(This,Arg1,RHS) ) 

#define IWorksheetFunction_ImSin(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> ImSin(This,Arg1,RHS) ) 

#define IWorksheetFunction_ImCos(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> ImCos(This,Arg1,RHS) ) 

#define IWorksheetFunction_ImExp(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> ImExp(This,Arg1,RHS) ) 

#define IWorksheetFunction_ImArgument(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> ImArgument(This,Arg1,RHS) ) 

#define IWorksheetFunction_ImConjugate(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> ImConjugate(This,Arg1,RHS) ) 

#define IWorksheetFunction_Imaginary(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> Imaginary(This,Arg1,RHS) ) 

#define IWorksheetFunction_ImReal(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> ImReal(This,Arg1,RHS) ) 

#define IWorksheetFunction_Complex(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> Complex(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_ImSum(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS)	\
    ( (This)->lpVtbl -> ImSum(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS) ) 

#define IWorksheetFunction_ImProduct(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS)	\
    ( (This)->lpVtbl -> ImProduct(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS) ) 

#define IWorksheetFunction_SeriesSum(This,Arg1,Arg2,Arg3,Arg4,RHS)	\
    ( (This)->lpVtbl -> SeriesSum(This,Arg1,Arg2,Arg3,Arg4,RHS) ) 

#define IWorksheetFunction_FactDouble(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> FactDouble(This,Arg1,RHS) ) 

#define IWorksheetFunction_SqrtPi(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> SqrtPi(This,Arg1,RHS) ) 

#define IWorksheetFunction_Quotient(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> Quotient(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_Delta(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> Delta(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_GeStep(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> GeStep(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_IsEven(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> IsEven(This,Arg1,RHS) ) 

#define IWorksheetFunction_IsOdd(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> IsOdd(This,Arg1,RHS) ) 

#define IWorksheetFunction_MRound(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> MRound(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_Erf(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> Erf(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_ErfC(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> ErfC(This,Arg1,RHS) ) 

#define IWorksheetFunction_BesselJ(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> BesselJ(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_BesselK(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> BesselK(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_BesselY(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> BesselY(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_BesselI(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> BesselI(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_Xirr(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> Xirr(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_Xnpv(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> Xnpv(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_PriceMat(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,RHS)	\
    ( (This)->lpVtbl -> PriceMat(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,RHS) ) 

#define IWorksheetFunction_YieldMat(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,RHS)	\
    ( (This)->lpVtbl -> YieldMat(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,RHS) ) 

#define IWorksheetFunction_IntRate(This,Arg1,Arg2,Arg3,Arg4,Arg5,RHS)	\
    ( (This)->lpVtbl -> IntRate(This,Arg1,Arg2,Arg3,Arg4,Arg5,RHS) ) 

#define IWorksheetFunction_Received(This,Arg1,Arg2,Arg3,Arg4,Arg5,RHS)	\
    ( (This)->lpVtbl -> Received(This,Arg1,Arg2,Arg3,Arg4,Arg5,RHS) ) 

#define IWorksheetFunction_Disc(This,Arg1,Arg2,Arg3,Arg4,Arg5,RHS)	\
    ( (This)->lpVtbl -> Disc(This,Arg1,Arg2,Arg3,Arg4,Arg5,RHS) ) 

#define IWorksheetFunction_PriceDisc(This,Arg1,Arg2,Arg3,Arg4,Arg5,RHS)	\
    ( (This)->lpVtbl -> PriceDisc(This,Arg1,Arg2,Arg3,Arg4,Arg5,RHS) ) 

#define IWorksheetFunction_YieldDisc(This,Arg1,Arg2,Arg3,Arg4,Arg5,RHS)	\
    ( (This)->lpVtbl -> YieldDisc(This,Arg1,Arg2,Arg3,Arg4,Arg5,RHS) ) 

#define IWorksheetFunction_TBillEq(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> TBillEq(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_TBillPrice(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> TBillPrice(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_TBillYield(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> TBillYield(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_Price(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,RHS)	\
    ( (This)->lpVtbl -> Price(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,RHS) ) 

#define IWorksheetFunction_DollarDe(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> DollarDe(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_DollarFr(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> DollarFr(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_Nominal(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> Nominal(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_Effect(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> Effect(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_CumPrinc(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,RHS)	\
    ( (This)->lpVtbl -> CumPrinc(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,RHS) ) 

#define IWorksheetFunction_CumIPmt(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,RHS)	\
    ( (This)->lpVtbl -> CumIPmt(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,RHS) ) 

#define IWorksheetFunction_EDate(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> EDate(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_EoMonth(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> EoMonth(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_YearFrac(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> YearFrac(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_CoupDayBs(This,Arg1,Arg2,Arg3,Arg4,RHS)	\
    ( (This)->lpVtbl -> CoupDayBs(This,Arg1,Arg2,Arg3,Arg4,RHS) ) 

#define IWorksheetFunction_CoupDays(This,Arg1,Arg2,Arg3,Arg4,RHS)	\
    ( (This)->lpVtbl -> CoupDays(This,Arg1,Arg2,Arg3,Arg4,RHS) ) 

#define IWorksheetFunction_CoupDaysNc(This,Arg1,Arg2,Arg3,Arg4,RHS)	\
    ( (This)->lpVtbl -> CoupDaysNc(This,Arg1,Arg2,Arg3,Arg4,RHS) ) 

#define IWorksheetFunction_CoupNcd(This,Arg1,Arg2,Arg3,Arg4,RHS)	\
    ( (This)->lpVtbl -> CoupNcd(This,Arg1,Arg2,Arg3,Arg4,RHS) ) 

#define IWorksheetFunction_CoupNum(This,Arg1,Arg2,Arg3,Arg4,RHS)	\
    ( (This)->lpVtbl -> CoupNum(This,Arg1,Arg2,Arg3,Arg4,RHS) ) 

#define IWorksheetFunction_CoupPcd(This,Arg1,Arg2,Arg3,Arg4,RHS)	\
    ( (This)->lpVtbl -> CoupPcd(This,Arg1,Arg2,Arg3,Arg4,RHS) ) 

#define IWorksheetFunction_Duration(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,RHS)	\
    ( (This)->lpVtbl -> Duration(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,RHS) ) 

#define IWorksheetFunction_MDuration(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,RHS)	\
    ( (This)->lpVtbl -> MDuration(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,RHS) ) 

#define IWorksheetFunction_OddLPrice(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,RHS)	\
    ( (This)->lpVtbl -> OddLPrice(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,RHS) ) 

#define IWorksheetFunction_OddLYield(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,RHS)	\
    ( (This)->lpVtbl -> OddLYield(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,RHS) ) 

#define IWorksheetFunction_OddFPrice(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,RHS)	\
    ( (This)->lpVtbl -> OddFPrice(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,RHS) ) 

#define IWorksheetFunction_OddFYield(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,RHS)	\
    ( (This)->lpVtbl -> OddFYield(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,RHS) ) 

#define IWorksheetFunction_RandBetween(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> RandBetween(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_WeekNum(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> WeekNum(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_AmorDegrc(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,RHS)	\
    ( (This)->lpVtbl -> AmorDegrc(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,RHS) ) 

#define IWorksheetFunction_AmorLinc(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,RHS)	\
    ( (This)->lpVtbl -> AmorLinc(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,RHS) ) 

#define IWorksheetFunction_Convert(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> Convert(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_AccrInt(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,RHS)	\
    ( (This)->lpVtbl -> AccrInt(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,RHS) ) 

#define IWorksheetFunction_AccrIntM(This,Arg1,Arg2,Arg3,Arg4,Arg5,RHS)	\
    ( (This)->lpVtbl -> AccrIntM(This,Arg1,Arg2,Arg3,Arg4,Arg5,RHS) ) 

#define IWorksheetFunction_WorkDay(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> WorkDay(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_NetworkDays(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> NetworkDays(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_Gcd(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS)	\
    ( (This)->lpVtbl -> Gcd(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS) ) 

#define IWorksheetFunction_MultiNomial(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS)	\
    ( (This)->lpVtbl -> MultiNomial(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS) ) 

#define IWorksheetFunction_Lcm(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS)	\
    ( (This)->lpVtbl -> Lcm(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS) ) 

#define IWorksheetFunction_FVSchedule(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> FVSchedule(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_SumIfs(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,RHS)	\
    ( (This)->lpVtbl -> SumIfs(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,RHS) ) 

#define IWorksheetFunction_CountIfs(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS)	\
    ( (This)->lpVtbl -> CountIfs(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS) ) 

#define IWorksheetFunction_AverageIf(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> AverageIf(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_AverageIfs(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,RHS)	\
    ( (This)->lpVtbl -> AverageIfs(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,RHS) ) 

#define IWorksheetFunction_IfError(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> IfError(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_Aggregate(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS)	\
    ( (This)->lpVtbl -> Aggregate(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS) ) 

#define IWorksheetFunction_Confidence_Norm(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> Confidence_Norm(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_Confidence_T(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> Confidence_T(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_ChiSq_Test(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> ChiSq_Test(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_F_Test(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> F_Test(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_Covariance_P(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> Covariance_P(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_Covariance_S(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> Covariance_S(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_Expon_Dist(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> Expon_Dist(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_Gamma_Dist(This,Arg1,Arg2,Arg3,Arg4,RHS)	\
    ( (This)->lpVtbl -> Gamma_Dist(This,Arg1,Arg2,Arg3,Arg4,RHS) ) 

#define IWorksheetFunction_Gamma_Inv(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> Gamma_Inv(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_Mode_Mult(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS)	\
    ( (This)->lpVtbl -> Mode_Mult(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS) ) 

#define IWorksheetFunction_Mode_Sngl(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS)	\
    ( (This)->lpVtbl -> Mode_Sngl(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS) ) 

#define IWorksheetFunction_Norm_Dist(This,Arg1,Arg2,Arg3,Arg4,RHS)	\
    ( (This)->lpVtbl -> Norm_Dist(This,Arg1,Arg2,Arg3,Arg4,RHS) ) 

#define IWorksheetFunction_Norm_Inv(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> Norm_Inv(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_Percentile_Exc(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> Percentile_Exc(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_Percentile_Inc(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> Percentile_Inc(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_PercentRank_Exc(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> PercentRank_Exc(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_PercentRank_Inc(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> PercentRank_Inc(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_Poisson_Dist(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> Poisson_Dist(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_Quartile_Exc(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> Quartile_Exc(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_Quartile_Inc(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> Quartile_Inc(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_Rank_Avg(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> Rank_Avg(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_Rank_Eq(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> Rank_Eq(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_StDev_S(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS)	\
    ( (This)->lpVtbl -> StDev_S(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS) ) 

#define IWorksheetFunction_StDev_P(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS)	\
    ( (This)->lpVtbl -> StDev_P(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS) ) 

#define IWorksheetFunction_T_Dist(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> T_Dist(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_T_Dist_2T(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> T_Dist_2T(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_T_Dist_RT(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> T_Dist_RT(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_T_Inv(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> T_Inv(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_T_Inv_2T(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> T_Inv_2T(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_Var_S(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS)	\
    ( (This)->lpVtbl -> Var_S(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS) ) 

#define IWorksheetFunction_Var_P(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS)	\
    ( (This)->lpVtbl -> Var_P(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS) ) 

#define IWorksheetFunction_Weibull_Dist(This,Arg1,Arg2,Arg3,Arg4,RHS)	\
    ( (This)->lpVtbl -> Weibull_Dist(This,Arg1,Arg2,Arg3,Arg4,RHS) ) 

#define IWorksheetFunction_NetworkDays_Intl(This,Arg1,Arg2,Arg3,Arg4,RHS)	\
    ( (This)->lpVtbl -> NetworkDays_Intl(This,Arg1,Arg2,Arg3,Arg4,RHS) ) 

#define IWorksheetFunction_WorkDay_Intl(This,Arg1,Arg2,Arg3,Arg4,RHS)	\
    ( (This)->lpVtbl -> WorkDay_Intl(This,Arg1,Arg2,Arg3,Arg4,RHS) ) 

#define IWorksheetFunction_ISO_Ceiling(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> ISO_Ceiling(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_Dummy21(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> Dummy21(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_Dummy19(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS)	\
    ( (This)->lpVtbl -> Dummy19(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS) ) 

#define IWorksheetFunction_Beta_Dist(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,RHS)	\
    ( (This)->lpVtbl -> Beta_Dist(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,RHS) ) 

#define IWorksheetFunction_Beta_Inv(This,Arg1,Arg2,Arg3,Arg4,Arg5,RHS)	\
    ( (This)->lpVtbl -> Beta_Inv(This,Arg1,Arg2,Arg3,Arg4,Arg5,RHS) ) 

#define IWorksheetFunction_ChiSq_Dist(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> ChiSq_Dist(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_ChiSq_Dist_RT(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> ChiSq_Dist_RT(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_ChiSq_Inv(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> ChiSq_Inv(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_ChiSq_Inv_RT(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> ChiSq_Inv_RT(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_F_Dist(This,Arg1,Arg2,Arg3,Arg4,RHS)	\
    ( (This)->lpVtbl -> F_Dist(This,Arg1,Arg2,Arg3,Arg4,RHS) ) 

#define IWorksheetFunction_F_Dist_RT(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> F_Dist_RT(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_F_Inv(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> F_Inv(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_F_Inv_RT(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> F_Inv_RT(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_HypGeom_Dist(This,Arg1,Arg2,Arg3,Arg4,Arg5,RHS)	\
    ( (This)->lpVtbl -> HypGeom_Dist(This,Arg1,Arg2,Arg3,Arg4,Arg5,RHS) ) 

#define IWorksheetFunction_LogNorm_Dist(This,Arg1,Arg2,Arg3,Arg4,RHS)	\
    ( (This)->lpVtbl -> LogNorm_Dist(This,Arg1,Arg2,Arg3,Arg4,RHS) ) 

#define IWorksheetFunction_LogNorm_Inv(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> LogNorm_Inv(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_NegBinom_Dist(This,Arg1,Arg2,Arg3,Arg4,RHS)	\
    ( (This)->lpVtbl -> NegBinom_Dist(This,Arg1,Arg2,Arg3,Arg4,RHS) ) 

#define IWorksheetFunction_Norm_S_Dist(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> Norm_S_Dist(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_Norm_S_Inv(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> Norm_S_Inv(This,Arg1,RHS) ) 

#define IWorksheetFunction_T_Test(This,Arg1,Arg2,Arg3,Arg4,RHS)	\
    ( (This)->lpVtbl -> T_Test(This,Arg1,Arg2,Arg3,Arg4,RHS) ) 

#define IWorksheetFunction_Z_Test(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> Z_Test(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_Binom_Dist(This,Arg1,Arg2,Arg3,Arg4,RHS)	\
    ( (This)->lpVtbl -> Binom_Dist(This,Arg1,Arg2,Arg3,Arg4,RHS) ) 

#define IWorksheetFunction_Binom_Inv(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> Binom_Inv(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_Erf_Precise(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> Erf_Precise(This,Arg1,RHS) ) 

#define IWorksheetFunction_ErfC_Precise(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> ErfC_Precise(This,Arg1,RHS) ) 

#define IWorksheetFunction_GammaLn_Precise(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> GammaLn_Precise(This,Arg1,RHS) ) 

#define IWorksheetFunction_Ceiling_Precise(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> Ceiling_Precise(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_Floor_Precise(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> Floor_Precise(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_Acot(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> Acot(This,Arg1,RHS) ) 

#define IWorksheetFunction_Acoth(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> Acoth(This,Arg1,RHS) ) 

#define IWorksheetFunction_Cot(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> Cot(This,Arg1,RHS) ) 

#define IWorksheetFunction_Coth(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> Coth(This,Arg1,RHS) ) 

#define IWorksheetFunction_Csc(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> Csc(This,Arg1,RHS) ) 

#define IWorksheetFunction_Csch(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> Csch(This,Arg1,RHS) ) 

#define IWorksheetFunction_Sec(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> Sec(This,Arg1,RHS) ) 

#define IWorksheetFunction_Sech(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> Sech(This,Arg1,RHS) ) 

#define IWorksheetFunction_ImCot(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> ImCot(This,Arg1,RHS) ) 

#define IWorksheetFunction_ImTan(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> ImTan(This,Arg1,RHS) ) 

#define IWorksheetFunction_ImCsc(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> ImCsc(This,Arg1,RHS) ) 

#define IWorksheetFunction_ImCsch(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> ImCsch(This,Arg1,RHS) ) 

#define IWorksheetFunction_ImSec(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> ImSec(This,Arg1,RHS) ) 

#define IWorksheetFunction_ImSech(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> ImSech(This,Arg1,RHS) ) 

#define IWorksheetFunction_Bitand(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> Bitand(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_Bitor(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> Bitor(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_Bitxor(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> Bitxor(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_Bitlshift(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> Bitlshift(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_Bitrshift(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> Bitrshift(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_Xor(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS)	\
    ( (This)->lpVtbl -> Xor(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS) ) 

#define IWorksheetFunction_Combina(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> Combina(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_Permutationa(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> Permutationa(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_PDuration(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> PDuration(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_Base(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> Base(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_Decimal(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> Decimal(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_Days(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> Days(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_Binom_Dist_Range(This,Arg1,Arg2,Arg3,Arg4,RHS)	\
    ( (This)->lpVtbl -> Binom_Dist_Range(This,Arg1,Arg2,Arg3,Arg4,RHS) ) 

#define IWorksheetFunction_Gamma(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> Gamma(This,Arg1,RHS) ) 

#define IWorksheetFunction_Gauss(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> Gauss(This,Arg1,RHS) ) 

#define IWorksheetFunction_Phi(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> Phi(This,Arg1,RHS) ) 

#define IWorksheetFunction_Skew_p(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS)	\
    ( (This)->lpVtbl -> Skew_p(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS) ) 

#define IWorksheetFunction_Rri(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> Rri(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_Unichar(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> Unichar(This,Arg1,RHS) ) 

#define IWorksheetFunction_Unicode(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> Unicode(This,Arg1,RHS) ) 

#define IWorksheetFunction_Munit(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> Munit(This,Arg1,RHS) ) 

#define IWorksheetFunction_Arabic(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> Arabic(This,Arg1,RHS) ) 

#define IWorksheetFunction_IsoWeekNum(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> IsoWeekNum(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_NumberValue(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> NumberValue(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_IsFormula(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> IsFormula(This,Arg1,RHS) ) 

#define IWorksheetFunction_IfNa(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> IfNa(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_Ceiling_Math(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> Ceiling_Math(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_Floor_Math(This,Arg1,Arg2,Arg3,RHS)	\
    ( (This)->lpVtbl -> Floor_Math(This,Arg1,Arg2,Arg3,RHS) ) 

#define IWorksheetFunction_ImSinh(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> ImSinh(This,Arg1,RHS) ) 

#define IWorksheetFunction_ImCosh(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> ImCosh(This,Arg1,RHS) ) 

#define IWorksheetFunction_FilterXML(This,Arg1,Arg2,RHS)	\
    ( (This)->lpVtbl -> FilterXML(This,Arg1,Arg2,RHS) ) 

#define IWorksheetFunction_WebService(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> WebService(This,Arg1,RHS) ) 

#define IWorksheetFunction_EncodeURL(This,Arg1,RHS)	\
    ( (This)->lpVtbl -> EncodeURL(This,Arg1,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */



/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_GammaInv_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [in] */ double Arg2,
    /* [in] */ double Arg3,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_GammaInv_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Ceiling_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [in] */ double Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Ceiling_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_HypGeomDist_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [in] */ double Arg2,
    /* [in] */ double Arg3,
    /* [in] */ double Arg4,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_HypGeomDist_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_LogNormDist_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [in] */ double Arg2,
    /* [in] */ double Arg3,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_LogNormDist_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_LogInv_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [in] */ double Arg2,
    /* [in] */ double Arg3,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_LogInv_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_NegBinomDist_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [in] */ double Arg2,
    /* [in] */ double Arg3,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_NegBinomDist_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_NormDist_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [in] */ double Arg2,
    /* [in] */ double Arg3,
    /* [in] */ VARIANT_BOOL Arg4,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_NormDist_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_NormSDist_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_NormSDist_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_NormInv_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [in] */ double Arg2,
    /* [in] */ double Arg3,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_NormInv_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_NormSInv_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_NormSInv_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Standardize_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [in] */ double Arg2,
    /* [in] */ double Arg3,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Standardize_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Odd_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Odd_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Permut_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [in] */ double Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Permut_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Poisson_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [in] */ double Arg2,
    /* [in] */ VARIANT_BOOL Arg3,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Poisson_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_TDist_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [in] */ double Arg2,
    /* [in] */ double Arg3,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_TDist_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Weibull_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [in] */ double Arg2,
    /* [in] */ double Arg3,
    /* [in] */ VARIANT_BOOL Arg4,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Weibull_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_SumXMY2_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_SumXMY2_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_SumX2MY2_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_SumX2MY2_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_SumX2PY2_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_SumX2PY2_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_ChiTest_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_ChiTest_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Correl_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Correl_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Covar_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Covar_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Forecast_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [in] */ VARIANT Arg2,
    /* [in] */ VARIANT Arg3,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Forecast_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_FTest_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_FTest_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Intercept_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Intercept_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Pearson_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Pearson_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_RSq_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_RSq_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_StEyx_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_StEyx_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Slope_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Slope_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_TTest_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [in] */ double Arg3,
    /* [in] */ double Arg4,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_TTest_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Prob_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [in] */ double Arg3,
    /* [optional][in] */ VARIANT Arg4,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Prob_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_DevSq_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [optional][in] */ VARIANT Arg2,
    /* [optional][in] */ VARIANT Arg3,
    /* [optional][in] */ VARIANT Arg4,
    /* [optional][in] */ VARIANT Arg5,
    /* [optional][in] */ VARIANT Arg6,
    /* [optional][in] */ VARIANT Arg7,
    /* [optional][in] */ VARIANT Arg8,
    /* [optional][in] */ VARIANT Arg9,
    /* [optional][in] */ VARIANT Arg10,
    /* [optional][in] */ VARIANT Arg11,
    /* [optional][in] */ VARIANT Arg12,
    /* [optional][in] */ VARIANT Arg13,
    /* [optional][in] */ VARIANT Arg14,
    /* [optional][in] */ VARIANT Arg15,
    /* [optional][in] */ VARIANT Arg16,
    /* [optional][in] */ VARIANT Arg17,
    /* [optional][in] */ VARIANT Arg18,
    /* [optional][in] */ VARIANT Arg19,
    /* [optional][in] */ VARIANT Arg20,
    /* [optional][in] */ VARIANT Arg21,
    /* [optional][in] */ VARIANT Arg22,
    /* [optional][in] */ VARIANT Arg23,
    /* [optional][in] */ VARIANT Arg24,
    /* [optional][in] */ VARIANT Arg25,
    /* [optional][in] */ VARIANT Arg26,
    /* [optional][in] */ VARIANT Arg27,
    /* [optional][in] */ VARIANT Arg28,
    /* [optional][in] */ VARIANT Arg29,
    /* [optional][in] */ VARIANT Arg30,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_DevSq_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_GeoMean_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [optional][in] */ VARIANT Arg2,
    /* [optional][in] */ VARIANT Arg3,
    /* [optional][in] */ VARIANT Arg4,
    /* [optional][in] */ VARIANT Arg5,
    /* [optional][in] */ VARIANT Arg6,
    /* [optional][in] */ VARIANT Arg7,
    /* [optional][in] */ VARIANT Arg8,
    /* [optional][in] */ VARIANT Arg9,
    /* [optional][in] */ VARIANT Arg10,
    /* [optional][in] */ VARIANT Arg11,
    /* [optional][in] */ VARIANT Arg12,
    /* [optional][in] */ VARIANT Arg13,
    /* [optional][in] */ VARIANT Arg14,
    /* [optional][in] */ VARIANT Arg15,
    /* [optional][in] */ VARIANT Arg16,
    /* [optional][in] */ VARIANT Arg17,
    /* [optional][in] */ VARIANT Arg18,
    /* [optional][in] */ VARIANT Arg19,
    /* [optional][in] */ VARIANT Arg20,
    /* [optional][in] */ VARIANT Arg21,
    /* [optional][in] */ VARIANT Arg22,
    /* [optional][in] */ VARIANT Arg23,
    /* [optional][in] */ VARIANT Arg24,
    /* [optional][in] */ VARIANT Arg25,
    /* [optional][in] */ VARIANT Arg26,
    /* [optional][in] */ VARIANT Arg27,
    /* [optional][in] */ VARIANT Arg28,
    /* [optional][in] */ VARIANT Arg29,
    /* [optional][in] */ VARIANT Arg30,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_GeoMean_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_HarMean_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [optional][in] */ VARIANT Arg2,
    /* [optional][in] */ VARIANT Arg3,
    /* [optional][in] */ VARIANT Arg4,
    /* [optional][in] */ VARIANT Arg5,
    /* [optional][in] */ VARIANT Arg6,
    /* [optional][in] */ VARIANT Arg7,
    /* [optional][in] */ VARIANT Arg8,
    /* [optional][in] */ VARIANT Arg9,
    /* [optional][in] */ VARIANT Arg10,
    /* [optional][in] */ VARIANT Arg11,
    /* [optional][in] */ VARIANT Arg12,
    /* [optional][in] */ VARIANT Arg13,
    /* [optional][in] */ VARIANT Arg14,
    /* [optional][in] */ VARIANT Arg15,
    /* [optional][in] */ VARIANT Arg16,
    /* [optional][in] */ VARIANT Arg17,
    /* [optional][in] */ VARIANT Arg18,
    /* [optional][in] */ VARIANT Arg19,
    /* [optional][in] */ VARIANT Arg20,
    /* [optional][in] */ VARIANT Arg21,
    /* [optional][in] */ VARIANT Arg22,
    /* [optional][in] */ VARIANT Arg23,
    /* [optional][in] */ VARIANT Arg24,
    /* [optional][in] */ VARIANT Arg25,
    /* [optional][in] */ VARIANT Arg26,
    /* [optional][in] */ VARIANT Arg27,
    /* [optional][in] */ VARIANT Arg28,
    /* [optional][in] */ VARIANT Arg29,
    /* [optional][in] */ VARIANT Arg30,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_HarMean_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_SumSq_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [optional][in] */ VARIANT Arg2,
    /* [optional][in] */ VARIANT Arg3,
    /* [optional][in] */ VARIANT Arg4,
    /* [optional][in] */ VARIANT Arg5,
    /* [optional][in] */ VARIANT Arg6,
    /* [optional][in] */ VARIANT Arg7,
    /* [optional][in] */ VARIANT Arg8,
    /* [optional][in] */ VARIANT Arg9,
    /* [optional][in] */ VARIANT Arg10,
    /* [optional][in] */ VARIANT Arg11,
    /* [optional][in] */ VARIANT Arg12,
    /* [optional][in] */ VARIANT Arg13,
    /* [optional][in] */ VARIANT Arg14,
    /* [optional][in] */ VARIANT Arg15,
    /* [optional][in] */ VARIANT Arg16,
    /* [optional][in] */ VARIANT Arg17,
    /* [optional][in] */ VARIANT Arg18,
    /* [optional][in] */ VARIANT Arg19,
    /* [optional][in] */ VARIANT Arg20,
    /* [optional][in] */ VARIANT Arg21,
    /* [optional][in] */ VARIANT Arg22,
    /* [optional][in] */ VARIANT Arg23,
    /* [optional][in] */ VARIANT Arg24,
    /* [optional][in] */ VARIANT Arg25,
    /* [optional][in] */ VARIANT Arg26,
    /* [optional][in] */ VARIANT Arg27,
    /* [optional][in] */ VARIANT Arg28,
    /* [optional][in] */ VARIANT Arg29,
    /* [optional][in] */ VARIANT Arg30,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_SumSq_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Kurt_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [optional][in] */ VARIANT Arg2,
    /* [optional][in] */ VARIANT Arg3,
    /* [optional][in] */ VARIANT Arg4,
    /* [optional][in] */ VARIANT Arg5,
    /* [optional][in] */ VARIANT Arg6,
    /* [optional][in] */ VARIANT Arg7,
    /* [optional][in] */ VARIANT Arg8,
    /* [optional][in] */ VARIANT Arg9,
    /* [optional][in] */ VARIANT Arg10,
    /* [optional][in] */ VARIANT Arg11,
    /* [optional][in] */ VARIANT Arg12,
    /* [optional][in] */ VARIANT Arg13,
    /* [optional][in] */ VARIANT Arg14,
    /* [optional][in] */ VARIANT Arg15,
    /* [optional][in] */ VARIANT Arg16,
    /* [optional][in] */ VARIANT Arg17,
    /* [optional][in] */ VARIANT Arg18,
    /* [optional][in] */ VARIANT Arg19,
    /* [optional][in] */ VARIANT Arg20,
    /* [optional][in] */ VARIANT Arg21,
    /* [optional][in] */ VARIANT Arg22,
    /* [optional][in] */ VARIANT Arg23,
    /* [optional][in] */ VARIANT Arg24,
    /* [optional][in] */ VARIANT Arg25,
    /* [optional][in] */ VARIANT Arg26,
    /* [optional][in] */ VARIANT Arg27,
    /* [optional][in] */ VARIANT Arg28,
    /* [optional][in] */ VARIANT Arg29,
    /* [optional][in] */ VARIANT Arg30,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Kurt_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Skew_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [optional][in] */ VARIANT Arg2,
    /* [optional][in] */ VARIANT Arg3,
    /* [optional][in] */ VARIANT Arg4,
    /* [optional][in] */ VARIANT Arg5,
    /* [optional][in] */ VARIANT Arg6,
    /* [optional][in] */ VARIANT Arg7,
    /* [optional][in] */ VARIANT Arg8,
    /* [optional][in] */ VARIANT Arg9,
    /* [optional][in] */ VARIANT Arg10,
    /* [optional][in] */ VARIANT Arg11,
    /* [optional][in] */ VARIANT Arg12,
    /* [optional][in] */ VARIANT Arg13,
    /* [optional][in] */ VARIANT Arg14,
    /* [optional][in] */ VARIANT Arg15,
    /* [optional][in] */ VARIANT Arg16,
    /* [optional][in] */ VARIANT Arg17,
    /* [optional][in] */ VARIANT Arg18,
    /* [optional][in] */ VARIANT Arg19,
    /* [optional][in] */ VARIANT Arg20,
    /* [optional][in] */ VARIANT Arg21,
    /* [optional][in] */ VARIANT Arg22,
    /* [optional][in] */ VARIANT Arg23,
    /* [optional][in] */ VARIANT Arg24,
    /* [optional][in] */ VARIANT Arg25,
    /* [optional][in] */ VARIANT Arg26,
    /* [optional][in] */ VARIANT Arg27,
    /* [optional][in] */ VARIANT Arg28,
    /* [optional][in] */ VARIANT Arg29,
    /* [optional][in] */ VARIANT Arg30,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Skew_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_ZTest_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ double Arg2,
    /* [optional][in] */ VARIANT Arg3,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_ZTest_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Large_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ double Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Large_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Small_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ double Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Small_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Quartile_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ double Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Quartile_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Percentile_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ double Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Percentile_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_PercentRank_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ double Arg2,
    /* [optional][in] */ VARIANT Arg3,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_PercentRank_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Mode_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [optional][in] */ VARIANT Arg2,
    /* [optional][in] */ VARIANT Arg3,
    /* [optional][in] */ VARIANT Arg4,
    /* [optional][in] */ VARIANT Arg5,
    /* [optional][in] */ VARIANT Arg6,
    /* [optional][in] */ VARIANT Arg7,
    /* [optional][in] */ VARIANT Arg8,
    /* [optional][in] */ VARIANT Arg9,
    /* [optional][in] */ VARIANT Arg10,
    /* [optional][in] */ VARIANT Arg11,
    /* [optional][in] */ VARIANT Arg12,
    /* [optional][in] */ VARIANT Arg13,
    /* [optional][in] */ VARIANT Arg14,
    /* [optional][in] */ VARIANT Arg15,
    /* [optional][in] */ VARIANT Arg16,
    /* [optional][in] */ VARIANT Arg17,
    /* [optional][in] */ VARIANT Arg18,
    /* [optional][in] */ VARIANT Arg19,
    /* [optional][in] */ VARIANT Arg20,
    /* [optional][in] */ VARIANT Arg21,
    /* [optional][in] */ VARIANT Arg22,
    /* [optional][in] */ VARIANT Arg23,
    /* [optional][in] */ VARIANT Arg24,
    /* [optional][in] */ VARIANT Arg25,
    /* [optional][in] */ VARIANT Arg26,
    /* [optional][in] */ VARIANT Arg27,
    /* [optional][in] */ VARIANT Arg28,
    /* [optional][in] */ VARIANT Arg29,
    /* [optional][in] */ VARIANT Arg30,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Mode_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_TrimMean_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ double Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_TrimMean_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_TInv_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [in] */ double Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_TInv_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Power_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [in] */ double Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Power_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Radians_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Radians_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Degrees_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Degrees_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Subtotal_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [in] */ Range	*Arg2,
    /* [optional][in] */ VARIANT Arg3,
    /* [optional][in] */ VARIANT Arg4,
    /* [optional][in] */ VARIANT Arg5,
    /* [optional][in] */ VARIANT Arg6,
    /* [optional][in] */ VARIANT Arg7,
    /* [optional][in] */ VARIANT Arg8,
    /* [optional][in] */ VARIANT Arg9,
    /* [optional][in] */ VARIANT Arg10,
    /* [optional][in] */ VARIANT Arg11,
    /* [optional][in] */ VARIANT Arg12,
    /* [optional][in] */ VARIANT Arg13,
    /* [optional][in] */ VARIANT Arg14,
    /* [optional][in] */ VARIANT Arg15,
    /* [optional][in] */ VARIANT Arg16,
    /* [optional][in] */ VARIANT Arg17,
    /* [optional][in] */ VARIANT Arg18,
    /* [optional][in] */ VARIANT Arg19,
    /* [optional][in] */ VARIANT Arg20,
    /* [optional][in] */ VARIANT Arg21,
    /* [optional][in] */ VARIANT Arg22,
    /* [optional][in] */ VARIANT Arg23,
    /* [optional][in] */ VARIANT Arg24,
    /* [optional][in] */ VARIANT Arg25,
    /* [optional][in] */ VARIANT Arg26,
    /* [optional][in] */ VARIANT Arg27,
    /* [optional][in] */ VARIANT Arg28,
    /* [optional][in] */ VARIANT Arg29,
    /* [optional][in] */ VARIANT Arg30,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Subtotal_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_SumIf_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ Range	*Arg1,
    /* [in] */ VARIANT Arg2,
    /* [optional][in] */ VARIANT Arg3,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_SumIf_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_CountIf_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ Range	*Arg1,
    /* [in] */ VARIANT Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_CountIf_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_CountBlank_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ Range	*Arg1,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_CountBlank_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Ispmt_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [in] */ double Arg2,
    /* [in] */ double Arg3,
    /* [in] */ double Arg4,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Ispmt_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Roman_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [optional][in] */ VARIANT Arg2,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB IWorksheetFunction_Roman_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Asc_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ BSTR Arg1,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB IWorksheetFunction_Asc_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Dbcs_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ BSTR Arg1,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB IWorksheetFunction_Dbcs_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Phonetic_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ Range	*Arg1,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB IWorksheetFunction_Phonetic_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_BahtText_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB IWorksheetFunction_BahtText_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][id] */ HRESULT __stdcall IWorksheetFunction_ThaiDayOfWeek_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB IWorksheetFunction_ThaiDayOfWeek_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][id] */ HRESULT __stdcall IWorksheetFunction_ThaiDigit_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ BSTR Arg1,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB IWorksheetFunction_ThaiDigit_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][id] */ HRESULT __stdcall IWorksheetFunction_ThaiMonthOfYear_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB IWorksheetFunction_ThaiMonthOfYear_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][id] */ HRESULT __stdcall IWorksheetFunction_ThaiNumSound_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB IWorksheetFunction_ThaiNumSound_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][id] */ HRESULT __stdcall IWorksheetFunction_ThaiNumString_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB IWorksheetFunction_ThaiNumString_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][id] */ HRESULT __stdcall IWorksheetFunction_ThaiStringLength_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ BSTR Arg1,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_ThaiStringLength_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][id] */ HRESULT __stdcall IWorksheetFunction_IsThaiDigit_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ BSTR Arg1,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB IWorksheetFunction_IsThaiDigit_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][id] */ HRESULT __stdcall IWorksheetFunction_RoundBahtDown_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_RoundBahtDown_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][id] */ HRESULT __stdcall IWorksheetFunction_RoundBahtUp_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_RoundBahtUp_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][id] */ HRESULT __stdcall IWorksheetFunction_ThaiYear_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_ThaiYear_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_RTD_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT progID,
    /* [in] */ VARIANT server,
    /* [in] */ VARIANT topic1,
    /* [optional][in] */ VARIANT topic2,
    /* [optional][in] */ VARIANT topic3,
    /* [optional][in] */ VARIANT topic4,
    /* [optional][in] */ VARIANT topic5,
    /* [optional][in] */ VARIANT topic6,
    /* [optional][in] */ VARIANT topic7,
    /* [optional][in] */ VARIANT topic8,
    /* [optional][in] */ VARIANT topic9,
    /* [optional][in] */ VARIANT topic10,
    /* [optional][in] */ VARIANT topic11,
    /* [optional][in] */ VARIANT topic12,
    /* [optional][in] */ VARIANT topic13,
    /* [optional][in] */ VARIANT topic14,
    /* [optional][in] */ VARIANT topic15,
    /* [optional][in] */ VARIANT topic16,
    /* [optional][in] */ VARIANT topic17,
    /* [optional][in] */ VARIANT topic18,
    /* [optional][in] */ VARIANT topic19,
    /* [optional][in] */ VARIANT topic20,
    /* [optional][in] */ VARIANT topic21,
    /* [optional][in] */ VARIANT topic22,
    /* [optional][in] */ VARIANT topic23,
    /* [optional][in] */ VARIANT topic24,
    /* [optional][in] */ VARIANT topic25,
    /* [optional][in] */ VARIANT topic26,
    /* [optional][in] */ VARIANT topic27,
    /* [optional][in] */ VARIANT topic28,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB IWorksheetFunction_RTD_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Hex2Bin_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [optional][in] */ VARIANT Arg2,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB IWorksheetFunction_Hex2Bin_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Hex2Dec_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB IWorksheetFunction_Hex2Dec_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Hex2Oct_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [optional][in] */ VARIANT Arg2,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB IWorksheetFunction_Hex2Oct_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Dec2Bin_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [optional][in] */ VARIANT Arg2,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB IWorksheetFunction_Dec2Bin_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Dec2Hex_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [optional][in] */ VARIANT Arg2,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB IWorksheetFunction_Dec2Hex_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Dec2Oct_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [optional][in] */ VARIANT Arg2,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB IWorksheetFunction_Dec2Oct_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Oct2Bin_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [optional][in] */ VARIANT Arg2,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB IWorksheetFunction_Oct2Bin_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Oct2Hex_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [optional][in] */ VARIANT Arg2,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB IWorksheetFunction_Oct2Hex_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Oct2Dec_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB IWorksheetFunction_Oct2Dec_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Bin2Dec_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB IWorksheetFunction_Bin2Dec_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Bin2Oct_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [optional][in] */ VARIANT Arg2,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB IWorksheetFunction_Bin2Oct_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Bin2Hex_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [optional][in] */ VARIANT Arg2,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB IWorksheetFunction_Bin2Hex_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_ImSub_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB IWorksheetFunction_ImSub_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_ImDiv_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB IWorksheetFunction_ImDiv_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_ImPower_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB IWorksheetFunction_ImPower_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_ImAbs_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB IWorksheetFunction_ImAbs_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_ImSqrt_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB IWorksheetFunction_ImSqrt_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_ImLn_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB IWorksheetFunction_ImLn_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_ImLog2_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB IWorksheetFunction_ImLog2_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_ImLog10_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB IWorksheetFunction_ImLog10_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_ImSin_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB IWorksheetFunction_ImSin_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_ImCos_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB IWorksheetFunction_ImCos_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_ImExp_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB IWorksheetFunction_ImExp_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_ImArgument_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB IWorksheetFunction_ImArgument_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_ImConjugate_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB IWorksheetFunction_ImConjugate_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Imaginary_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Imaginary_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_ImReal_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_ImReal_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Complex_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [optional][in] */ VARIANT Arg3,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB IWorksheetFunction_Complex_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_ImSum_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [optional][in] */ VARIANT Arg2,
    /* [optional][in] */ VARIANT Arg3,
    /* [optional][in] */ VARIANT Arg4,
    /* [optional][in] */ VARIANT Arg5,
    /* [optional][in] */ VARIANT Arg6,
    /* [optional][in] */ VARIANT Arg7,
    /* [optional][in] */ VARIANT Arg8,
    /* [optional][in] */ VARIANT Arg9,
    /* [optional][in] */ VARIANT Arg10,
    /* [optional][in] */ VARIANT Arg11,
    /* [optional][in] */ VARIANT Arg12,
    /* [optional][in] */ VARIANT Arg13,
    /* [optional][in] */ VARIANT Arg14,
    /* [optional][in] */ VARIANT Arg15,
    /* [optional][in] */ VARIANT Arg16,
    /* [optional][in] */ VARIANT Arg17,
    /* [optional][in] */ VARIANT Arg18,
    /* [optional][in] */ VARIANT Arg19,
    /* [optional][in] */ VARIANT Arg20,
    /* [optional][in] */ VARIANT Arg21,
    /* [optional][in] */ VARIANT Arg22,
    /* [optional][in] */ VARIANT Arg23,
    /* [optional][in] */ VARIANT Arg24,
    /* [optional][in] */ VARIANT Arg25,
    /* [optional][in] */ VARIANT Arg26,
    /* [optional][in] */ VARIANT Arg27,
    /* [optional][in] */ VARIANT Arg28,
    /* [optional][in] */ VARIANT Arg29,
    /* [optional][in] */ VARIANT Arg30,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB IWorksheetFunction_ImSum_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_ImProduct_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [optional][in] */ VARIANT Arg2,
    /* [optional][in] */ VARIANT Arg3,
    /* [optional][in] */ VARIANT Arg4,
    /* [optional][in] */ VARIANT Arg5,
    /* [optional][in] */ VARIANT Arg6,
    /* [optional][in] */ VARIANT Arg7,
    /* [optional][in] */ VARIANT Arg8,
    /* [optional][in] */ VARIANT Arg9,
    /* [optional][in] */ VARIANT Arg10,
    /* [optional][in] */ VARIANT Arg11,
    /* [optional][in] */ VARIANT Arg12,
    /* [optional][in] */ VARIANT Arg13,
    /* [optional][in] */ VARIANT Arg14,
    /* [optional][in] */ VARIANT Arg15,
    /* [optional][in] */ VARIANT Arg16,
    /* [optional][in] */ VARIANT Arg17,
    /* [optional][in] */ VARIANT Arg18,
    /* [optional][in] */ VARIANT Arg19,
    /* [optional][in] */ VARIANT Arg20,
    /* [optional][in] */ VARIANT Arg21,
    /* [optional][in] */ VARIANT Arg22,
    /* [optional][in] */ VARIANT Arg23,
    /* [optional][in] */ VARIANT Arg24,
    /* [optional][in] */ VARIANT Arg25,
    /* [optional][in] */ VARIANT Arg26,
    /* [optional][in] */ VARIANT Arg27,
    /* [optional][in] */ VARIANT Arg28,
    /* [optional][in] */ VARIANT Arg29,
    /* [optional][in] */ VARIANT Arg30,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB IWorksheetFunction_ImProduct_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_SeriesSum_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [in] */ VARIANT Arg3,
    /* [in] */ VARIANT Arg4,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_SeriesSum_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_FactDouble_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_FactDouble_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_SqrtPi_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_SqrtPi_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Quotient_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Quotient_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Delta_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [optional][in] */ VARIANT Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Delta_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_GeStep_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [optional][in] */ VARIANT Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_GeStep_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_IsEven_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB IWorksheetFunction_IsEven_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_IsOdd_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB IWorksheetFunction_IsOdd_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_MRound_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_MRound_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Erf_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [optional][in] */ VARIANT Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Erf_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_ErfC_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_ErfC_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_BesselJ_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_BesselJ_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_BesselK_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_BesselK_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_BesselY_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_BesselY_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_BesselI_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_BesselI_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Xirr_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [optional][in] */ VARIANT Arg3,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Xirr_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Xnpv_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Xnpv_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_PriceMat_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [in] */ VARIANT Arg3,
    /* [in] */ VARIANT Arg4,
    /* [in] */ VARIANT Arg5,
    /* [optional][in] */ VARIANT Arg6,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_PriceMat_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_YieldMat_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [in] */ VARIANT Arg3,
    /* [in] */ VARIANT Arg4,
    /* [in] */ VARIANT Arg5,
    /* [optional][in] */ VARIANT Arg6,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_YieldMat_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_IntRate_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [in] */ VARIANT Arg3,
    /* [in] */ VARIANT Arg4,
    /* [optional][in] */ VARIANT Arg5,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_IntRate_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Received_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [in] */ VARIANT Arg3,
    /* [in] */ VARIANT Arg4,
    /* [optional][in] */ VARIANT Arg5,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Received_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Disc_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [in] */ VARIANT Arg3,
    /* [in] */ VARIANT Arg4,
    /* [optional][in] */ VARIANT Arg5,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Disc_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_PriceDisc_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [in] */ VARIANT Arg3,
    /* [in] */ VARIANT Arg4,
    /* [optional][in] */ VARIANT Arg5,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_PriceDisc_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_YieldDisc_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [in] */ VARIANT Arg3,
    /* [in] */ VARIANT Arg4,
    /* [optional][in] */ VARIANT Arg5,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_YieldDisc_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_TBillEq_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [optional][in] */ VARIANT Arg3,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_TBillEq_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_TBillPrice_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [optional][in] */ VARIANT Arg3,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_TBillPrice_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_TBillYield_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [optional][in] */ VARIANT Arg3,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_TBillYield_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Price_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [in] */ VARIANT Arg3,
    /* [in] */ VARIANT Arg4,
    /* [in] */ VARIANT Arg5,
    /* [in] */ VARIANT Arg6,
    /* [optional][in] */ VARIANT Arg7,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Price_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_DollarDe_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_DollarDe_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_DollarFr_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_DollarFr_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Nominal_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Nominal_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Effect_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Effect_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_CumPrinc_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [in] */ VARIANT Arg3,
    /* [in] */ VARIANT Arg4,
    /* [in] */ VARIANT Arg5,
    /* [in] */ VARIANT Arg6,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_CumPrinc_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_CumIPmt_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [in] */ VARIANT Arg3,
    /* [in] */ VARIANT Arg4,
    /* [in] */ VARIANT Arg5,
    /* [in] */ VARIANT Arg6,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_CumIPmt_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_EDate_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_EDate_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_EoMonth_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_EoMonth_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_YearFrac_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [optional][in] */ VARIANT Arg3,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_YearFrac_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_CoupDayBs_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [in] */ VARIANT Arg3,
    /* [optional][in] */ VARIANT Arg4,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_CoupDayBs_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_CoupDays_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [in] */ VARIANT Arg3,
    /* [optional][in] */ VARIANT Arg4,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_CoupDays_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_CoupDaysNc_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [in] */ VARIANT Arg3,
    /* [optional][in] */ VARIANT Arg4,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_CoupDaysNc_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_CoupNcd_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [in] */ VARIANT Arg3,
    /* [optional][in] */ VARIANT Arg4,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_CoupNcd_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_CoupNum_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [in] */ VARIANT Arg3,
    /* [optional][in] */ VARIANT Arg4,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_CoupNum_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_CoupPcd_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [in] */ VARIANT Arg3,
    /* [optional][in] */ VARIANT Arg4,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_CoupPcd_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Duration_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [in] */ VARIANT Arg3,
    /* [in] */ VARIANT Arg4,
    /* [in] */ VARIANT Arg5,
    /* [optional][in] */ VARIANT Arg6,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Duration_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_MDuration_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [in] */ VARIANT Arg3,
    /* [in] */ VARIANT Arg4,
    /* [in] */ VARIANT Arg5,
    /* [optional][in] */ VARIANT Arg6,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_MDuration_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_OddLPrice_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [in] */ VARIANT Arg3,
    /* [in] */ VARIANT Arg4,
    /* [in] */ VARIANT Arg5,
    /* [in] */ VARIANT Arg6,
    /* [in] */ VARIANT Arg7,
    /* [optional][in] */ VARIANT Arg8,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_OddLPrice_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_OddLYield_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [in] */ VARIANT Arg3,
    /* [in] */ VARIANT Arg4,
    /* [in] */ VARIANT Arg5,
    /* [in] */ VARIANT Arg6,
    /* [in] */ VARIANT Arg7,
    /* [optional][in] */ VARIANT Arg8,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_OddLYield_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_OddFPrice_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [in] */ VARIANT Arg3,
    /* [in] */ VARIANT Arg4,
    /* [in] */ VARIANT Arg5,
    /* [in] */ VARIANT Arg6,
    /* [in] */ VARIANT Arg7,
    /* [in] */ VARIANT Arg8,
    /* [optional][in] */ VARIANT Arg9,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_OddFPrice_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_OddFYield_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [in] */ VARIANT Arg3,
    /* [in] */ VARIANT Arg4,
    /* [in] */ VARIANT Arg5,
    /* [in] */ VARIANT Arg6,
    /* [in] */ VARIANT Arg7,
    /* [in] */ VARIANT Arg8,
    /* [optional][in] */ VARIANT Arg9,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_OddFYield_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_RandBetween_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_RandBetween_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_WeekNum_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [optional][in] */ VARIANT Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_WeekNum_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_AmorDegrc_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [in] */ VARIANT Arg3,
    /* [in] */ VARIANT Arg4,
    /* [in] */ VARIANT Arg5,
    /* [in] */ VARIANT Arg6,
    /* [optional][in] */ VARIANT Arg7,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_AmorDegrc_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_AmorLinc_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [in] */ VARIANT Arg3,
    /* [in] */ VARIANT Arg4,
    /* [in] */ VARIANT Arg5,
    /* [in] */ VARIANT Arg6,
    /* [optional][in] */ VARIANT Arg7,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_AmorLinc_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Convert_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [in] */ VARIANT Arg3,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Convert_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_AccrInt_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [in] */ VARIANT Arg3,
    /* [in] */ VARIANT Arg4,
    /* [in] */ VARIANT Arg5,
    /* [in] */ VARIANT Arg6,
    /* [optional][in] */ VARIANT Arg7,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_AccrInt_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_AccrIntM_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [in] */ VARIANT Arg3,
    /* [in] */ VARIANT Arg4,
    /* [optional][in] */ VARIANT Arg5,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_AccrIntM_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_WorkDay_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [optional][in] */ VARIANT Arg3,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_WorkDay_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_NetworkDays_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [optional][in] */ VARIANT Arg3,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_NetworkDays_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Gcd_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [optional][in] */ VARIANT Arg2,
    /* [optional][in] */ VARIANT Arg3,
    /* [optional][in] */ VARIANT Arg4,
    /* [optional][in] */ VARIANT Arg5,
    /* [optional][in] */ VARIANT Arg6,
    /* [optional][in] */ VARIANT Arg7,
    /* [optional][in] */ VARIANT Arg8,
    /* [optional][in] */ VARIANT Arg9,
    /* [optional][in] */ VARIANT Arg10,
    /* [optional][in] */ VARIANT Arg11,
    /* [optional][in] */ VARIANT Arg12,
    /* [optional][in] */ VARIANT Arg13,
    /* [optional][in] */ VARIANT Arg14,
    /* [optional][in] */ VARIANT Arg15,
    /* [optional][in] */ VARIANT Arg16,
    /* [optional][in] */ VARIANT Arg17,
    /* [optional][in] */ VARIANT Arg18,
    /* [optional][in] */ VARIANT Arg19,
    /* [optional][in] */ VARIANT Arg20,
    /* [optional][in] */ VARIANT Arg21,
    /* [optional][in] */ VARIANT Arg22,
    /* [optional][in] */ VARIANT Arg23,
    /* [optional][in] */ VARIANT Arg24,
    /* [optional][in] */ VARIANT Arg25,
    /* [optional][in] */ VARIANT Arg26,
    /* [optional][in] */ VARIANT Arg27,
    /* [optional][in] */ VARIANT Arg28,
    /* [optional][in] */ VARIANT Arg29,
    /* [optional][in] */ VARIANT Arg30,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Gcd_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_MultiNomial_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [optional][in] */ VARIANT Arg2,
    /* [optional][in] */ VARIANT Arg3,
    /* [optional][in] */ VARIANT Arg4,
    /* [optional][in] */ VARIANT Arg5,
    /* [optional][in] */ VARIANT Arg6,
    /* [optional][in] */ VARIANT Arg7,
    /* [optional][in] */ VARIANT Arg8,
    /* [optional][in] */ VARIANT Arg9,
    /* [optional][in] */ VARIANT Arg10,
    /* [optional][in] */ VARIANT Arg11,
    /* [optional][in] */ VARIANT Arg12,
    /* [optional][in] */ VARIANT Arg13,
    /* [optional][in] */ VARIANT Arg14,
    /* [optional][in] */ VARIANT Arg15,
    /* [optional][in] */ VARIANT Arg16,
    /* [optional][in] */ VARIANT Arg17,
    /* [optional][in] */ VARIANT Arg18,
    /* [optional][in] */ VARIANT Arg19,
    /* [optional][in] */ VARIANT Arg20,
    /* [optional][in] */ VARIANT Arg21,
    /* [optional][in] */ VARIANT Arg22,
    /* [optional][in] */ VARIANT Arg23,
    /* [optional][in] */ VARIANT Arg24,
    /* [optional][in] */ VARIANT Arg25,
    /* [optional][in] */ VARIANT Arg26,
    /* [optional][in] */ VARIANT Arg27,
    /* [optional][in] */ VARIANT Arg28,
    /* [optional][in] */ VARIANT Arg29,
    /* [optional][in] */ VARIANT Arg30,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_MultiNomial_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Lcm_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [optional][in] */ VARIANT Arg2,
    /* [optional][in] */ VARIANT Arg3,
    /* [optional][in] */ VARIANT Arg4,
    /* [optional][in] */ VARIANT Arg5,
    /* [optional][in] */ VARIANT Arg6,
    /* [optional][in] */ VARIANT Arg7,
    /* [optional][in] */ VARIANT Arg8,
    /* [optional][in] */ VARIANT Arg9,
    /* [optional][in] */ VARIANT Arg10,
    /* [optional][in] */ VARIANT Arg11,
    /* [optional][in] */ VARIANT Arg12,
    /* [optional][in] */ VARIANT Arg13,
    /* [optional][in] */ VARIANT Arg14,
    /* [optional][in] */ VARIANT Arg15,
    /* [optional][in] */ VARIANT Arg16,
    /* [optional][in] */ VARIANT Arg17,
    /* [optional][in] */ VARIANT Arg18,
    /* [optional][in] */ VARIANT Arg19,
    /* [optional][in] */ VARIANT Arg20,
    /* [optional][in] */ VARIANT Arg21,
    /* [optional][in] */ VARIANT Arg22,
    /* [optional][in] */ VARIANT Arg23,
    /* [optional][in] */ VARIANT Arg24,
    /* [optional][in] */ VARIANT Arg25,
    /* [optional][in] */ VARIANT Arg26,
    /* [optional][in] */ VARIANT Arg27,
    /* [optional][in] */ VARIANT Arg28,
    /* [optional][in] */ VARIANT Arg29,
    /* [optional][in] */ VARIANT Arg30,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Lcm_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_FVSchedule_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_FVSchedule_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_SumIfs_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ Range	*Arg1,
    /* [in] */ Range	*Arg2,
    /* [in] */ VARIANT Arg3,
    /* [optional][in] */ VARIANT Arg4,
    /* [optional][in] */ VARIANT Arg5,
    /* [optional][in] */ VARIANT Arg6,
    /* [optional][in] */ VARIANT Arg7,
    /* [optional][in] */ VARIANT Arg8,
    /* [optional][in] */ VARIANT Arg9,
    /* [optional][in] */ VARIANT Arg10,
    /* [optional][in] */ VARIANT Arg11,
    /* [optional][in] */ VARIANT Arg12,
    /* [optional][in] */ VARIANT Arg13,
    /* [optional][in] */ VARIANT Arg14,
    /* [optional][in] */ VARIANT Arg15,
    /* [optional][in] */ VARIANT Arg16,
    /* [optional][in] */ VARIANT Arg17,
    /* [optional][in] */ VARIANT Arg18,
    /* [optional][in] */ VARIANT Arg19,
    /* [optional][in] */ VARIANT Arg20,
    /* [optional][in] */ VARIANT Arg21,
    /* [optional][in] */ VARIANT Arg22,
    /* [optional][in] */ VARIANT Arg23,
    /* [optional][in] */ VARIANT Arg24,
    /* [optional][in] */ VARIANT Arg25,
    /* [optional][in] */ VARIANT Arg26,
    /* [optional][in] */ VARIANT Arg27,
    /* [optional][in] */ VARIANT Arg28,
    /* [optional][in] */ VARIANT Arg29,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_SumIfs_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_CountIfs_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ Range	*Arg1,
    /* [in] */ VARIANT Arg2,
    /* [optional][in] */ VARIANT Arg3,
    /* [optional][in] */ VARIANT Arg4,
    /* [optional][in] */ VARIANT Arg5,
    /* [optional][in] */ VARIANT Arg6,
    /* [optional][in] */ VARIANT Arg7,
    /* [optional][in] */ VARIANT Arg8,
    /* [optional][in] */ VARIANT Arg9,
    /* [optional][in] */ VARIANT Arg10,
    /* [optional][in] */ VARIANT Arg11,
    /* [optional][in] */ VARIANT Arg12,
    /* [optional][in] */ VARIANT Arg13,
    /* [optional][in] */ VARIANT Arg14,
    /* [optional][in] */ VARIANT Arg15,
    /* [optional][in] */ VARIANT Arg16,
    /* [optional][in] */ VARIANT Arg17,
    /* [optional][in] */ VARIANT Arg18,
    /* [optional][in] */ VARIANT Arg19,
    /* [optional][in] */ VARIANT Arg20,
    /* [optional][in] */ VARIANT Arg21,
    /* [optional][in] */ VARIANT Arg22,
    /* [optional][in] */ VARIANT Arg23,
    /* [optional][in] */ VARIANT Arg24,
    /* [optional][in] */ VARIANT Arg25,
    /* [optional][in] */ VARIANT Arg26,
    /* [optional][in] */ VARIANT Arg27,
    /* [optional][in] */ VARIANT Arg28,
    /* [optional][in] */ VARIANT Arg29,
    /* [optional][in] */ VARIANT Arg30,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_CountIfs_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_AverageIf_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ Range	*Arg1,
    /* [in] */ VARIANT Arg2,
    /* [optional][in] */ VARIANT Arg3,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_AverageIf_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_AverageIfs_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ Range	*Arg1,
    /* [in] */ Range	*Arg2,
    /* [in] */ VARIANT Arg3,
    /* [optional][in] */ VARIANT Arg4,
    /* [optional][in] */ VARIANT Arg5,
    /* [optional][in] */ VARIANT Arg6,
    /* [optional][in] */ VARIANT Arg7,
    /* [optional][in] */ VARIANT Arg8,
    /* [optional][in] */ VARIANT Arg9,
    /* [optional][in] */ VARIANT Arg10,
    /* [optional][in] */ VARIANT Arg11,
    /* [optional][in] */ VARIANT Arg12,
    /* [optional][in] */ VARIANT Arg13,
    /* [optional][in] */ VARIANT Arg14,
    /* [optional][in] */ VARIANT Arg15,
    /* [optional][in] */ VARIANT Arg16,
    /* [optional][in] */ VARIANT Arg17,
    /* [optional][in] */ VARIANT Arg18,
    /* [optional][in] */ VARIANT Arg19,
    /* [optional][in] */ VARIANT Arg20,
    /* [optional][in] */ VARIANT Arg21,
    /* [optional][in] */ VARIANT Arg22,
    /* [optional][in] */ VARIANT Arg23,
    /* [optional][in] */ VARIANT Arg24,
    /* [optional][in] */ VARIANT Arg25,
    /* [optional][in] */ VARIANT Arg26,
    /* [optional][in] */ VARIANT Arg27,
    /* [optional][in] */ VARIANT Arg28,
    /* [optional][in] */ VARIANT Arg29,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_AverageIfs_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_IfError_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB IWorksheetFunction_IfError_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Aggregate_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [in] */ double Arg2,
    /* [in] */ Range	*Arg3,
    /* [optional][in] */ VARIANT Arg4,
    /* [optional][in] */ VARIANT Arg5,
    /* [optional][in] */ VARIANT Arg6,
    /* [optional][in] */ VARIANT Arg7,
    /* [optional][in] */ VARIANT Arg8,
    /* [optional][in] */ VARIANT Arg9,
    /* [optional][in] */ VARIANT Arg10,
    /* [optional][in] */ VARIANT Arg11,
    /* [optional][in] */ VARIANT Arg12,
    /* [optional][in] */ VARIANT Arg13,
    /* [optional][in] */ VARIANT Arg14,
    /* [optional][in] */ VARIANT Arg15,
    /* [optional][in] */ VARIANT Arg16,
    /* [optional][in] */ VARIANT Arg17,
    /* [optional][in] */ VARIANT Arg18,
    /* [optional][in] */ VARIANT Arg19,
    /* [optional][in] */ VARIANT Arg20,
    /* [optional][in] */ VARIANT Arg21,
    /* [optional][in] */ VARIANT Arg22,
    /* [optional][in] */ VARIANT Arg23,
    /* [optional][in] */ VARIANT Arg24,
    /* [optional][in] */ VARIANT Arg25,
    /* [optional][in] */ VARIANT Arg26,
    /* [optional][in] */ VARIANT Arg27,
    /* [optional][in] */ VARIANT Arg28,
    /* [optional][in] */ VARIANT Arg29,
    /* [optional][in] */ VARIANT Arg30,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Aggregate_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Confidence_Norm_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [in] */ double Arg2,
    /* [in] */ double Arg3,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Confidence_Norm_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Confidence_T_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [in] */ double Arg2,
    /* [in] */ double Arg3,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Confidence_T_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_ChiSq_Test_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_ChiSq_Test_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_F_Test_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_F_Test_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Covariance_P_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Covariance_P_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Covariance_S_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Covariance_S_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Expon_Dist_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [in] */ double Arg2,
    /* [in] */ VARIANT_BOOL Arg3,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Expon_Dist_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Gamma_Dist_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [in] */ double Arg2,
    /* [in] */ double Arg3,
    /* [in] */ VARIANT_BOOL Arg4,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Gamma_Dist_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Gamma_Inv_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [in] */ double Arg2,
    /* [in] */ double Arg3,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Gamma_Inv_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Mode_Mult_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [optional][in] */ VARIANT Arg2,
    /* [optional][in] */ VARIANT Arg3,
    /* [optional][in] */ VARIANT Arg4,
    /* [optional][in] */ VARIANT Arg5,
    /* [optional][in] */ VARIANT Arg6,
    /* [optional][in] */ VARIANT Arg7,
    /* [optional][in] */ VARIANT Arg8,
    /* [optional][in] */ VARIANT Arg9,
    /* [optional][in] */ VARIANT Arg10,
    /* [optional][in] */ VARIANT Arg11,
    /* [optional][in] */ VARIANT Arg12,
    /* [optional][in] */ VARIANT Arg13,
    /* [optional][in] */ VARIANT Arg14,
    /* [optional][in] */ VARIANT Arg15,
    /* [optional][in] */ VARIANT Arg16,
    /* [optional][in] */ VARIANT Arg17,
    /* [optional][in] */ VARIANT Arg18,
    /* [optional][in] */ VARIANT Arg19,
    /* [optional][in] */ VARIANT Arg20,
    /* [optional][in] */ VARIANT Arg21,
    /* [optional][in] */ VARIANT Arg22,
    /* [optional][in] */ VARIANT Arg23,
    /* [optional][in] */ VARIANT Arg24,
    /* [optional][in] */ VARIANT Arg25,
    /* [optional][in] */ VARIANT Arg26,
    /* [optional][in] */ VARIANT Arg27,
    /* [optional][in] */ VARIANT Arg28,
    /* [optional][in] */ VARIANT Arg29,
    /* [optional][in] */ VARIANT Arg30,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB IWorksheetFunction_Mode_Mult_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Mode_Sngl_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [optional][in] */ VARIANT Arg2,
    /* [optional][in] */ VARIANT Arg3,
    /* [optional][in] */ VARIANT Arg4,
    /* [optional][in] */ VARIANT Arg5,
    /* [optional][in] */ VARIANT Arg6,
    /* [optional][in] */ VARIANT Arg7,
    /* [optional][in] */ VARIANT Arg8,
    /* [optional][in] */ VARIANT Arg9,
    /* [optional][in] */ VARIANT Arg10,
    /* [optional][in] */ VARIANT Arg11,
    /* [optional][in] */ VARIANT Arg12,
    /* [optional][in] */ VARIANT Arg13,
    /* [optional][in] */ VARIANT Arg14,
    /* [optional][in] */ VARIANT Arg15,
    /* [optional][in] */ VARIANT Arg16,
    /* [optional][in] */ VARIANT Arg17,
    /* [optional][in] */ VARIANT Arg18,
    /* [optional][in] */ VARIANT Arg19,
    /* [optional][in] */ VARIANT Arg20,
    /* [optional][in] */ VARIANT Arg21,
    /* [optional][in] */ VARIANT Arg22,
    /* [optional][in] */ VARIANT Arg23,
    /* [optional][in] */ VARIANT Arg24,
    /* [optional][in] */ VARIANT Arg25,
    /* [optional][in] */ VARIANT Arg26,
    /* [optional][in] */ VARIANT Arg27,
    /* [optional][in] */ VARIANT Arg28,
    /* [optional][in] */ VARIANT Arg29,
    /* [optional][in] */ VARIANT Arg30,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Mode_Sngl_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Norm_Dist_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [in] */ double Arg2,
    /* [in] */ double Arg3,
    /* [in] */ VARIANT_BOOL Arg4,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Norm_Dist_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Norm_Inv_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [in] */ double Arg2,
    /* [in] */ double Arg3,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Norm_Inv_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Percentile_Exc_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ double Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Percentile_Exc_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Percentile_Inc_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ double Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Percentile_Inc_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_PercentRank_Exc_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ double Arg2,
    /* [optional][in] */ VARIANT Arg3,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_PercentRank_Exc_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_PercentRank_Inc_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ double Arg2,
    /* [optional][in] */ VARIANT Arg3,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_PercentRank_Inc_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Poisson_Dist_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [in] */ double Arg2,
    /* [in] */ VARIANT_BOOL Arg3,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Poisson_Dist_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Quartile_Exc_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ double Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Quartile_Exc_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Quartile_Inc_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ double Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Quartile_Inc_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Rank_Avg_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [in] */ Range	*Arg2,
    /* [optional][in] */ VARIANT Arg3,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Rank_Avg_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Rank_Eq_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [in] */ Range	*Arg2,
    /* [optional][in] */ VARIANT Arg3,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Rank_Eq_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_StDev_S_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [optional][in] */ VARIANT Arg2,
    /* [optional][in] */ VARIANT Arg3,
    /* [optional][in] */ VARIANT Arg4,
    /* [optional][in] */ VARIANT Arg5,
    /* [optional][in] */ VARIANT Arg6,
    /* [optional][in] */ VARIANT Arg7,
    /* [optional][in] */ VARIANT Arg8,
    /* [optional][in] */ VARIANT Arg9,
    /* [optional][in] */ VARIANT Arg10,
    /* [optional][in] */ VARIANT Arg11,
    /* [optional][in] */ VARIANT Arg12,
    /* [optional][in] */ VARIANT Arg13,
    /* [optional][in] */ VARIANT Arg14,
    /* [optional][in] */ VARIANT Arg15,
    /* [optional][in] */ VARIANT Arg16,
    /* [optional][in] */ VARIANT Arg17,
    /* [optional][in] */ VARIANT Arg18,
    /* [optional][in] */ VARIANT Arg19,
    /* [optional][in] */ VARIANT Arg20,
    /* [optional][in] */ VARIANT Arg21,
    /* [optional][in] */ VARIANT Arg22,
    /* [optional][in] */ VARIANT Arg23,
    /* [optional][in] */ VARIANT Arg24,
    /* [optional][in] */ VARIANT Arg25,
    /* [optional][in] */ VARIANT Arg26,
    /* [optional][in] */ VARIANT Arg27,
    /* [optional][in] */ VARIANT Arg28,
    /* [optional][in] */ VARIANT Arg29,
    /* [optional][in] */ VARIANT Arg30,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_StDev_S_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_StDev_P_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [optional][in] */ VARIANT Arg2,
    /* [optional][in] */ VARIANT Arg3,
    /* [optional][in] */ VARIANT Arg4,
    /* [optional][in] */ VARIANT Arg5,
    /* [optional][in] */ VARIANT Arg6,
    /* [optional][in] */ VARIANT Arg7,
    /* [optional][in] */ VARIANT Arg8,
    /* [optional][in] */ VARIANT Arg9,
    /* [optional][in] */ VARIANT Arg10,
    /* [optional][in] */ VARIANT Arg11,
    /* [optional][in] */ VARIANT Arg12,
    /* [optional][in] */ VARIANT Arg13,
    /* [optional][in] */ VARIANT Arg14,
    /* [optional][in] */ VARIANT Arg15,
    /* [optional][in] */ VARIANT Arg16,
    /* [optional][in] */ VARIANT Arg17,
    /* [optional][in] */ VARIANT Arg18,
    /* [optional][in] */ VARIANT Arg19,
    /* [optional][in] */ VARIANT Arg20,
    /* [optional][in] */ VARIANT Arg21,
    /* [optional][in] */ VARIANT Arg22,
    /* [optional][in] */ VARIANT Arg23,
    /* [optional][in] */ VARIANT Arg24,
    /* [optional][in] */ VARIANT Arg25,
    /* [optional][in] */ VARIANT Arg26,
    /* [optional][in] */ VARIANT Arg27,
    /* [optional][in] */ VARIANT Arg28,
    /* [optional][in] */ VARIANT Arg29,
    /* [optional][in] */ VARIANT Arg30,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_StDev_P_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_T_Dist_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [in] */ double Arg2,
    /* [in] */ VARIANT_BOOL Arg3,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_T_Dist_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_T_Dist_2T_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [in] */ double Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_T_Dist_2T_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_T_Dist_RT_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [in] */ double Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_T_Dist_RT_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_T_Inv_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [in] */ double Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_T_Inv_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_T_Inv_2T_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [in] */ double Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_T_Inv_2T_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Var_S_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [optional][in] */ VARIANT Arg2,
    /* [optional][in] */ VARIANT Arg3,
    /* [optional][in] */ VARIANT Arg4,
    /* [optional][in] */ VARIANT Arg5,
    /* [optional][in] */ VARIANT Arg6,
    /* [optional][in] */ VARIANT Arg7,
    /* [optional][in] */ VARIANT Arg8,
    /* [optional][in] */ VARIANT Arg9,
    /* [optional][in] */ VARIANT Arg10,
    /* [optional][in] */ VARIANT Arg11,
    /* [optional][in] */ VARIANT Arg12,
    /* [optional][in] */ VARIANT Arg13,
    /* [optional][in] */ VARIANT Arg14,
    /* [optional][in] */ VARIANT Arg15,
    /* [optional][in] */ VARIANT Arg16,
    /* [optional][in] */ VARIANT Arg17,
    /* [optional][in] */ VARIANT Arg18,
    /* [optional][in] */ VARIANT Arg19,
    /* [optional][in] */ VARIANT Arg20,
    /* [optional][in] */ VARIANT Arg21,
    /* [optional][in] */ VARIANT Arg22,
    /* [optional][in] */ VARIANT Arg23,
    /* [optional][in] */ VARIANT Arg24,
    /* [optional][in] */ VARIANT Arg25,
    /* [optional][in] */ VARIANT Arg26,
    /* [optional][in] */ VARIANT Arg27,
    /* [optional][in] */ VARIANT Arg28,
    /* [optional][in] */ VARIANT Arg29,
    /* [optional][in] */ VARIANT Arg30,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Var_S_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Var_P_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [optional][in] */ VARIANT Arg2,
    /* [optional][in] */ VARIANT Arg3,
    /* [optional][in] */ VARIANT Arg4,
    /* [optional][in] */ VARIANT Arg5,
    /* [optional][in] */ VARIANT Arg6,
    /* [optional][in] */ VARIANT Arg7,
    /* [optional][in] */ VARIANT Arg8,
    /* [optional][in] */ VARIANT Arg9,
    /* [optional][in] */ VARIANT Arg10,
    /* [optional][in] */ VARIANT Arg11,
    /* [optional][in] */ VARIANT Arg12,
    /* [optional][in] */ VARIANT Arg13,
    /* [optional][in] */ VARIANT Arg14,
    /* [optional][in] */ VARIANT Arg15,
    /* [optional][in] */ VARIANT Arg16,
    /* [optional][in] */ VARIANT Arg17,
    /* [optional][in] */ VARIANT Arg18,
    /* [optional][in] */ VARIANT Arg19,
    /* [optional][in] */ VARIANT Arg20,
    /* [optional][in] */ VARIANT Arg21,
    /* [optional][in] */ VARIANT Arg22,
    /* [optional][in] */ VARIANT Arg23,
    /* [optional][in] */ VARIANT Arg24,
    /* [optional][in] */ VARIANT Arg25,
    /* [optional][in] */ VARIANT Arg26,
    /* [optional][in] */ VARIANT Arg27,
    /* [optional][in] */ VARIANT Arg28,
    /* [optional][in] */ VARIANT Arg29,
    /* [optional][in] */ VARIANT Arg30,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Var_P_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Weibull_Dist_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [in] */ double Arg2,
    /* [in] */ double Arg3,
    /* [in] */ VARIANT_BOOL Arg4,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Weibull_Dist_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_NetworkDays_Intl_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [optional][in] */ VARIANT Arg3,
    /* [optional][in] */ VARIANT Arg4,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_NetworkDays_Intl_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_WorkDay_Intl_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [optional][in] */ VARIANT Arg3,
    /* [optional][in] */ VARIANT Arg4,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_WorkDay_Intl_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_ISO_Ceiling_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [optional][in] */ VARIANT Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_ISO_Ceiling_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][id] */ HRESULT __stdcall IWorksheetFunction_Dummy21_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [in] */ double Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Dummy21_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][id] */ HRESULT __stdcall IWorksheetFunction_Dummy19_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [optional][in] */ VARIANT Arg2,
    /* [optional][in] */ VARIANT Arg3,
    /* [optional][in] */ VARIANT Arg4,
    /* [optional][in] */ VARIANT Arg5,
    /* [optional][in] */ VARIANT Arg6,
    /* [optional][in] */ VARIANT Arg7,
    /* [optional][in] */ VARIANT Arg8,
    /* [optional][in] */ VARIANT Arg9,
    /* [optional][in] */ VARIANT Arg10,
    /* [optional][in] */ VARIANT Arg11,
    /* [optional][in] */ VARIANT Arg12,
    /* [optional][in] */ VARIANT Arg13,
    /* [optional][in] */ VARIANT Arg14,
    /* [optional][in] */ VARIANT Arg15,
    /* [optional][in] */ VARIANT Arg16,
    /* [optional][in] */ VARIANT Arg17,
    /* [optional][in] */ VARIANT Arg18,
    /* [optional][in] */ VARIANT Arg19,
    /* [optional][in] */ VARIANT Arg20,
    /* [optional][in] */ VARIANT Arg21,
    /* [optional][in] */ VARIANT Arg22,
    /* [optional][in] */ VARIANT Arg23,
    /* [optional][in] */ VARIANT Arg24,
    /* [optional][in] */ VARIANT Arg25,
    /* [optional][in] */ VARIANT Arg26,
    /* [optional][in] */ VARIANT Arg27,
    /* [optional][in] */ VARIANT Arg28,
    /* [optional][in] */ VARIANT Arg29,
    /* [optional][in] */ VARIANT Arg30,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB IWorksheetFunction_Dummy19_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Beta_Dist_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [in] */ double Arg2,
    /* [in] */ double Arg3,
    /* [in] */ VARIANT_BOOL Arg4,
    /* [optional][in] */ VARIANT Arg5,
    /* [optional][in] */ VARIANT Arg6,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Beta_Dist_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Beta_Inv_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [in] */ double Arg2,
    /* [in] */ double Arg3,
    /* [optional][in] */ VARIANT Arg4,
    /* [optional][in] */ VARIANT Arg5,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Beta_Inv_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_ChiSq_Dist_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [in] */ double Arg2,
    /* [in] */ VARIANT_BOOL Arg3,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_ChiSq_Dist_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_ChiSq_Dist_RT_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [in] */ double Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_ChiSq_Dist_RT_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_ChiSq_Inv_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [in] */ double Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_ChiSq_Inv_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_ChiSq_Inv_RT_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [in] */ double Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_ChiSq_Inv_RT_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_F_Dist_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [in] */ double Arg2,
    /* [in] */ double Arg3,
    /* [in] */ VARIANT_BOOL Arg4,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_F_Dist_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_F_Dist_RT_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [in] */ double Arg2,
    /* [in] */ double Arg3,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_F_Dist_RT_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_F_Inv_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [in] */ double Arg2,
    /* [in] */ double Arg3,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_F_Inv_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_F_Inv_RT_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [in] */ double Arg2,
    /* [in] */ double Arg3,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_F_Inv_RT_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_HypGeom_Dist_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [in] */ double Arg2,
    /* [in] */ double Arg3,
    /* [in] */ double Arg4,
    /* [in] */ VARIANT_BOOL Arg5,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_HypGeom_Dist_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_LogNorm_Dist_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [in] */ double Arg2,
    /* [in] */ double Arg3,
    /* [in] */ VARIANT_BOOL Arg4,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_LogNorm_Dist_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_LogNorm_Inv_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [in] */ double Arg2,
    /* [in] */ double Arg3,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_LogNorm_Inv_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_NegBinom_Dist_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [in] */ double Arg2,
    /* [in] */ double Arg3,
    /* [in] */ VARIANT_BOOL Arg4,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_NegBinom_Dist_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Norm_S_Dist_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [in] */ VARIANT_BOOL Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Norm_S_Dist_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Norm_S_Inv_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Norm_S_Inv_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_T_Test_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [in] */ double Arg3,
    /* [in] */ double Arg4,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_T_Test_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Z_Test_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ double Arg2,
    /* [optional][in] */ VARIANT Arg3,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Z_Test_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Binom_Dist_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [in] */ double Arg2,
    /* [in] */ double Arg3,
    /* [in] */ VARIANT_BOOL Arg4,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Binom_Dist_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Binom_Inv_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [in] */ double Arg2,
    /* [in] */ double Arg3,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Binom_Inv_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Erf_Precise_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Erf_Precise_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_ErfC_Precise_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_ErfC_Precise_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_GammaLn_Precise_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_GammaLn_Precise_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Ceiling_Precise_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [optional][in] */ VARIANT Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Ceiling_Precise_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Floor_Precise_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [optional][in] */ VARIANT Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Floor_Precise_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Acot_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Acot_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Acoth_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Acoth_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Cot_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Cot_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Coth_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Coth_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Csc_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Csc_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Csch_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Csch_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Sec_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Sec_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Sech_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Sech_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_ImCot_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB IWorksheetFunction_ImCot_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_ImTan_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB IWorksheetFunction_ImTan_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_ImCsc_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB IWorksheetFunction_ImCsc_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_ImCsch_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB IWorksheetFunction_ImCsch_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_ImSec_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB IWorksheetFunction_ImSec_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_ImSech_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB IWorksheetFunction_ImSech_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Bitand_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [in] */ double Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Bitand_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Bitor_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [in] */ double Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Bitor_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Bitxor_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [in] */ double Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Bitxor_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Bitlshift_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [in] */ double Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Bitlshift_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Bitrshift_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [in] */ double Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Bitrshift_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Xor_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [optional][in] */ VARIANT Arg2,
    /* [optional][in] */ VARIANT Arg3,
    /* [optional][in] */ VARIANT Arg4,
    /* [optional][in] */ VARIANT Arg5,
    /* [optional][in] */ VARIANT Arg6,
    /* [optional][in] */ VARIANT Arg7,
    /* [optional][in] */ VARIANT Arg8,
    /* [optional][in] */ VARIANT Arg9,
    /* [optional][in] */ VARIANT Arg10,
    /* [optional][in] */ VARIANT Arg11,
    /* [optional][in] */ VARIANT Arg12,
    /* [optional][in] */ VARIANT Arg13,
    /* [optional][in] */ VARIANT Arg14,
    /* [optional][in] */ VARIANT Arg15,
    /* [optional][in] */ VARIANT Arg16,
    /* [optional][in] */ VARIANT Arg17,
    /* [optional][in] */ VARIANT Arg18,
    /* [optional][in] */ VARIANT Arg19,
    /* [optional][in] */ VARIANT Arg20,
    /* [optional][in] */ VARIANT Arg21,
    /* [optional][in] */ VARIANT Arg22,
    /* [optional][in] */ VARIANT Arg23,
    /* [optional][in] */ VARIANT Arg24,
    /* [optional][in] */ VARIANT Arg25,
    /* [optional][in] */ VARIANT Arg26,
    /* [optional][in] */ VARIANT Arg27,
    /* [optional][in] */ VARIANT Arg28,
    /* [optional][in] */ VARIANT Arg29,
    /* [optional][in] */ VARIANT Arg30,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB IWorksheetFunction_Xor_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Combina_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [in] */ double Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Combina_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Permutationa_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [in] */ double Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Permutationa_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_PDuration_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [in] */ double Arg2,
    /* [in] */ double Arg3,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_PDuration_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Base_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [in] */ double Arg2,
    /* [optional][in] */ VARIANT Arg3,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB IWorksheetFunction_Base_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Decimal_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ BSTR Arg1,
    /* [in] */ double Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Decimal_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Days_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Days_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Binom_Dist_Range_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [in] */ double Arg2,
    /* [in] */ double Arg3,
    /* [optional][in] */ VARIANT Arg4,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Binom_Dist_Range_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Gamma_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Gamma_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Gauss_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Gauss_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Phi_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Phi_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Skew_p_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [optional][in] */ VARIANT Arg2,
    /* [optional][in] */ VARIANT Arg3,
    /* [optional][in] */ VARIANT Arg4,
    /* [optional][in] */ VARIANT Arg5,
    /* [optional][in] */ VARIANT Arg6,
    /* [optional][in] */ VARIANT Arg7,
    /* [optional][in] */ VARIANT Arg8,
    /* [optional][in] */ VARIANT Arg9,
    /* [optional][in] */ VARIANT Arg10,
    /* [optional][in] */ VARIANT Arg11,
    /* [optional][in] */ VARIANT Arg12,
    /* [optional][in] */ VARIANT Arg13,
    /* [optional][in] */ VARIANT Arg14,
    /* [optional][in] */ VARIANT Arg15,
    /* [optional][in] */ VARIANT Arg16,
    /* [optional][in] */ VARIANT Arg17,
    /* [optional][in] */ VARIANT Arg18,
    /* [optional][in] */ VARIANT Arg19,
    /* [optional][in] */ VARIANT Arg20,
    /* [optional][in] */ VARIANT Arg21,
    /* [optional][in] */ VARIANT Arg22,
    /* [optional][in] */ VARIANT Arg23,
    /* [optional][in] */ VARIANT Arg24,
    /* [optional][in] */ VARIANT Arg25,
    /* [optional][in] */ VARIANT Arg26,
    /* [optional][in] */ VARIANT Arg27,
    /* [optional][in] */ VARIANT Arg28,
    /* [optional][in] */ VARIANT Arg29,
    /* [optional][in] */ VARIANT Arg30,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Skew_p_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Rri_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [in] */ double Arg2,
    /* [in] */ double Arg3,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Rri_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Unichar_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB IWorksheetFunction_Unichar_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Unicode_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ BSTR Arg1,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Unicode_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Munit_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB IWorksheetFunction_Munit_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Arabic_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ BSTR Arg1,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Arabic_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_IsoWeekNum_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [optional][in] */ VARIANT Arg2,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_IsoWeekNum_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_NumberValue_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ BSTR Arg1,
    /* [in] */ BSTR Arg2,
    /* [in] */ BSTR Arg3,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_NumberValue_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_IsFormula_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ Range	*Arg1,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB IWorksheetFunction_IsFormula_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_IfNa_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [in] */ VARIANT Arg2,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB IWorksheetFunction_IfNa_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Ceiling_Math_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [optional][in] */ VARIANT Arg2,
    /* [optional][in] */ VARIANT Arg3,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Ceiling_Math_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_Floor_Math_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ double Arg1,
    /* [optional][in] */ VARIANT Arg2,
    /* [optional][in] */ VARIANT Arg3,
    /* [retval][out] */ double *RHS);


void __RPC_STUB IWorksheetFunction_Floor_Math_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_ImSinh_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB IWorksheetFunction_ImSinh_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_ImCosh_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ VARIANT Arg1,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB IWorksheetFunction_ImCosh_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_FilterXML_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ BSTR Arg1,
    /* [in] */ BSTR Arg2,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB IWorksheetFunction_FilterXML_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_WebService_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ BSTR Arg1,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB IWorksheetFunction_WebService_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IWorksheetFunction_EncodeURL_Proxy( 
    IWorksheetFunction * This,
    /* [in] */ BSTR Arg1,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB IWorksheetFunction_EncodeURL_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);



#endif 	/* __IWorksheetFunction_INTERFACE_DEFINED__ */


#ifndef __IRange_INTERFACE_DEFINED__
#define __IRange_INTERFACE_DEFINED__

/* interface IRange */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IRange;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00020846-0001-0000-C000-000000000046")
    IRange : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Activate( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AddIndent( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AddIndent( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Address( 
            /* [optional][in] */ VARIANT RowAbsolute,
            /* [optional][in] */ VARIANT ColumnAbsolute,
            /* [defaultvalue][optional][in] */ XlReferenceStyle ReferenceStyle,
            /* [optional][in] */ VARIANT External,
            /* [optional][in] */ VARIANT RelativeTo,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AddressLocal( 
            /* [optional][in] */ VARIANT RowAbsolute,
            /* [optional][in] */ VARIANT ColumnAbsolute,
            /* [defaultvalue][optional][in] */ XlReferenceStyle ReferenceStyle,
            /* [optional][in] */ VARIANT External,
            /* [optional][in] */ VARIANT RelativeTo,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall AdvancedFilter( 
            /* [in] */ XlFilterAction Action,
            /* [optional][in] */ VARIANT CriteriaRange,
            /* [optional][in] */ VARIANT CopyToRange,
            /* [optional][in] */ VARIANT Unique,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ApplyNames( 
            /* [optional][in] */ VARIANT Names,
            /* [optional][in] */ VARIANT IgnoreRelativeAbsolute,
            /* [optional][in] */ VARIANT UseRowColumnNames,
            /* [optional][in] */ VARIANT OmitColumn,
            /* [optional][in] */ VARIANT OmitRow,
            /* [defaultvalue][optional][in] */ XlApplyNamesOrder Order,
            /* [optional][in] */ VARIANT AppendLast,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ApplyOutlineStyles( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Areas( 
            /* [retval][out] */ Areas	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall AutoComplete( 
            /* [in] */ BSTR String,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall AutoFill( 
            /* [in] */ Range	*Destination,
            /* [defaultvalue][optional][in] */ XlAutoFillType Type,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall AutoFilter( 
            /* [optional][in] */ VARIANT Field,
            /* [optional][in] */ VARIANT Criteria1,
            /* [defaultvalue][optional][in] */ XlAutoFilterOperator Operator,
            /* [optional][in] */ VARIANT Criteria2,
            /* [optional][in] */ VARIANT VisibleDropDown,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall AutoFit( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall AutoFormat( 
            /* [defaultvalue][optional][in] */ XlRangeAutoFormat Format,
            /* [optional][in] */ VARIANT Number,
            /* [optional][in] */ VARIANT Font,
            /* [optional][in] */ VARIANT Alignment,
            /* [optional][in] */ VARIANT Border,
            /* [optional][in] */ VARIANT Pattern,
            /* [optional][in] */ VARIANT Width,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall AutoOutline( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [custom][helpcontext][hidden][id] */ HRESULT __stdcall _BorderAround( 
            /* [optional][in] */ VARIANT LineStyle,
            /* [defaultvalue][optional][in] */ XlBorderWeight Weight,
            /* [defaultvalue][optional][in] */ XlColorIndex ColorIndex,
            /* [optional][in] */ VARIANT Color,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Borders( 
            /* [retval][out] */ Borders	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Calculate( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Cells( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Characters( 
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Length,
            /* [retval][out] */ Characters	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CheckSpelling( 
            /* [optional][in] */ VARIANT CustomDictionary,
            /* [optional][in] */ VARIANT IgnoreUppercase,
            /* [optional][in] */ VARIANT AlwaysSuggest,
            /* [optional][in] */ VARIANT SpellLang,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Clear( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ClearContents( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ClearFormats( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ClearNotes( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ClearOutline( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Column( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ColumnDifferences( 
            /* [in] */ VARIANT Comparison,
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Columns( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ColumnWidth( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ColumnWidth( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Consolidate( 
            /* [optional][in] */ VARIANT Sources,
            /* [optional][in] */ VARIANT Function,
            /* [optional][in] */ VARIANT TopRow,
            /* [optional][in] */ VARIANT LeftColumn,
            /* [optional][in] */ VARIANT CreateLinks,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Copy( 
            /* [optional][in] */ VARIANT Destination,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CopyFromRecordset( 
            /* [in] */ IUnknown *Data,
            /* [optional][in] */ VARIANT MaxRows,
            /* [optional][in] */ VARIANT MaxColumns,
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CopyPicture( 
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CreateNames( 
            /* [optional][in] */ VARIANT Top,
            /* [optional][in] */ VARIANT Left,
            /* [optional][in] */ VARIANT Bottom,
            /* [optional][in] */ VARIANT Right,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall CreatePublisher( 
            /* [optional][in] */ VARIANT Edition,
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [optional][in] */ VARIANT ContainsPICT,
            /* [optional][in] */ VARIANT ContainsBIFF,
            /* [optional][in] */ VARIANT ContainsRTF,
            /* [optional][in] */ VARIANT ContainsVALU,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CurrentArray( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CurrentRegion( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Cut( 
            /* [optional][in] */ VARIANT Destination,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall DataSeries( 
            /* [optional][in] */ VARIANT Rowcol,
            /* [defaultvalue][optional][in] */ XlDataSeriesType Type,
            /* [defaultvalue][optional][in] */ XlDataSeriesDate Date,
            /* [optional][in] */ VARIANT Step,
            /* [optional][in] */ VARIANT Stop,
            /* [optional][in] */ VARIANT Trend,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [optional][in] */ VARIANT RowIndex,
            /* [optional][in] */ VARIANT ColumnIndex,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put__Default( 
            /* [optional][in] */ VARIANT RowIndex,
            /* [optional][in] */ VARIANT ColumnIndex,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [optional][in] */ VARIANT Shift,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Dependents( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall DialogBox( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DirectDependents( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DirectPrecedents( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall EditionOptions( 
            /* [in] */ XlEditionType Type,
            /* [in] */ XlEditionOptionsOption Option,
            /* [optional][in] */ VARIANT Name,
            /* [optional][in] */ VARIANT Reference,
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlPictureAppearance ChartSize,
            /* [optional][in] */ VARIANT Format,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_End( 
            /* [in] */ XlDirection Direction,
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_EntireColumn( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_EntireRow( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall FillDown( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall FillLeft( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall FillRight( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall FillUp( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Find( 
            /* [in] */ VARIANT What,
            /* [optional][in] */ VARIANT After,
            /* [optional][in] */ VARIANT LookIn,
            /* [optional][in] */ VARIANT LookAt,
            /* [optional][in] */ VARIANT SearchOrder,
            /* [defaultvalue][optional][in] */ XlSearchDirection SearchDirection,
            /* [optional][in] */ VARIANT MatchCase,
            /* [optional][in] */ VARIANT MatchByte,
            /* [optional][in] */ VARIANT SearchFormat,
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall FindNext( 
            /* [optional][in] */ VARIANT After,
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall FindPrevious( 
            /* [optional][in] */ VARIANT After,
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Font( 
            /* [retval][out] */ Font	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Formula( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Formula( 
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_FormulaArray( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_FormulaArray( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_FormulaLabel( 
            /* [retval][out] */ XlFormulaLabel *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_FormulaLabel( 
            /* [in] */ XlFormulaLabel RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_FormulaHidden( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_FormulaHidden( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_FormulaLocal( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_FormulaLocal( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_FormulaR1C1( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_FormulaR1C1( 
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_FormulaR1C1Local( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_FormulaR1C1Local( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall FunctionWizard( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall GoalSeek( 
            /* [in] */ VARIANT Goal,
            /* [in] */ Range	*ChangingCell,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Group( 
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT End,
            /* [optional][in] */ VARIANT By,
            /* [optional][in] */ VARIANT Periods,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HasArray( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HasFormula( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Height( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Hidden( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Hidden( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HorizontalAlignment( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_HorizontalAlignment( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_IndentLevel( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_IndentLevel( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall InsertIndent( 
            /* [in] */ long InsertAmount) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Insert( 
            /* [optional][in] */ VARIANT Shift,
            /* [optional][in] */ VARIANT CopyOrigin,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Interior( 
            /* [retval][out] */ Interior	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Item( 
            /* [in] */ VARIANT RowIndex,
            /* [optional][in] */ VARIANT ColumnIndex,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Item( 
            /* [in] */ VARIANT RowIndex,
            /* [optional][in] */ VARIANT ColumnIndex,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Justify( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Left( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ListHeaderRows( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ListNames( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LocationInTable( 
            /* [retval][out] */ XlLocationInTable *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Locked( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Locked( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Merge( 
            /* [optional][in] */ VARIANT Across) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall UnMerge( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MergeArea( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MergeCells( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_MergeCells( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Name( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall NavigateArrow( 
            /* [optional][in] */ VARIANT TowardPrecedent,
            /* [optional][in] */ VARIANT ArrowNumber,
            /* [optional][in] */ VARIANT LinkNumber,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Next( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall NoteText( 
            /* [optional][in] */ VARIANT Text,
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Length,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_NumberFormat( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_NumberFormat( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_NumberFormatLocal( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_NumberFormatLocal( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Offset( 
            /* [optional][in] */ VARIANT RowOffset,
            /* [optional][in] */ VARIANT ColumnOffset,
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Orientation( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Orientation( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_OutlineLevel( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_OutlineLevel( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PageBreak( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PageBreak( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Parse( 
            /* [optional][in] */ VARIANT ParseLine,
            /* [optional][in] */ VARIANT Destination,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall _PasteSpecial( 
            /* [defaultvalue][optional][in] */ XlPasteType Paste,
            /* [defaultvalue][optional][in] */ XlPasteSpecialOperation Operation,
            /* [optional][in] */ VARIANT SkipBlanks,
            /* [optional][in] */ VARIANT Transpose,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PivotField( 
            /* [retval][out] */ PivotField	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PivotItem( 
            /* [retval][out] */ PivotItem	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PivotTable( 
            /* [retval][out] */ PivotTable	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Precedents( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PrefixCharacter( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Previous( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [custom][helpcontext][hidden][id] */ HRESULT __stdcall __PrintOut( 
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall PrintPreview( 
            /* [optional][in] */ VARIANT EnableChanges,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_QueryTable( 
            /* [retval][out] */ QueryTable	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Range( 
            /* [in] */ VARIANT Cell1,
            /* [optional][in] */ VARIANT Cell2,
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall RemoveSubtotal( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Replace( 
            /* [in] */ VARIANT What,
            /* [in] */ VARIANT Replacement,
            /* [optional][in] */ VARIANT LookAt,
            /* [optional][in] */ VARIANT SearchOrder,
            /* [optional][in] */ VARIANT MatchCase,
            /* [optional][in] */ VARIANT MatchByte,
            /* [optional][in] */ VARIANT SearchFormat,
            /* [optional][in] */ VARIANT ReplaceFormat,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Resize( 
            /* [optional][in] */ VARIANT RowSize,
            /* [optional][in] */ VARIANT ColumnSize,
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Row( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall RowDifferences( 
            /* [in] */ VARIANT Comparison,
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RowHeight( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_RowHeight( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Rows( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Run( 
            /* [optional][in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Show( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ShowDependents( 
            /* [optional][in] */ VARIANT Remove,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShowDetail( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ShowDetail( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ShowErrors( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ShowPrecedents( 
            /* [optional][in] */ VARIANT Remove,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShrinkToFit( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ShrinkToFit( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Sort( 
            /* [optional][in] */ VARIANT Key1,
            /* [defaultvalue][optional][in] */ XlSortOrder Order1,
            /* [optional][in] */ VARIANT Key2,
            /* [optional][in] */ VARIANT Type,
            /* [defaultvalue][optional][in] */ XlSortOrder Order2,
            /* [optional][in] */ VARIANT Key3,
            /* [defaultvalue][optional][in] */ XlSortOrder Order3,
            /* [defaultvalue][optional][in] */ XlYesNoGuess Header,
            /* [optional][in] */ VARIANT OrderCustom,
            /* [optional][in] */ VARIANT MatchCase,
            /* [defaultvalue][optional][in] */ XlSortOrientation Orientation,
            /* [defaultvalue][optional][in] */ XlSortMethod SortMethod,
            /* [defaultvalue][optional][in] */ XlSortDataOption DataOption1,
            /* [defaultvalue][optional][in] */ XlSortDataOption DataOption2,
            /* [defaultvalue][optional][in] */ XlSortDataOption DataOption3,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SortSpecial( 
            /* [defaultvalue][optional][in] */ XlSortMethod SortMethod,
            /* [optional][in] */ VARIANT Key1,
            /* [defaultvalue][optional][in] */ XlSortOrder Order1,
            /* [optional][in] */ VARIANT Type,
            /* [optional][in] */ VARIANT Key2,
            /* [defaultvalue][optional][in] */ XlSortOrder Order2,
            /* [optional][in] */ VARIANT Key3,
            /* [defaultvalue][optional][in] */ XlSortOrder Order3,
            /* [defaultvalue][optional][in] */ XlYesNoGuess Header,
            /* [optional][in] */ VARIANT OrderCustom,
            /* [optional][in] */ VARIANT MatchCase,
            /* [defaultvalue][optional][in] */ XlSortOrientation Orientation,
            /* [defaultvalue][optional][in] */ XlSortDataOption DataOption1,
            /* [defaultvalue][optional][in] */ XlSortDataOption DataOption2,
            /* [defaultvalue][optional][in] */ XlSortDataOption DataOption3,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SoundNote( 
            /* [retval][out] */ SoundNote	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SpecialCells( 
            /* [in] */ XlCellType Type,
            /* [optional][in] */ VARIANT Value,
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Style( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Style( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SubscribeTo( 
            /* [in] */ BSTR Edition,
            /* [defaultvalue][optional][in] */ XlSubscribeToFormat Format,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Subtotal( 
            /* [in] */ long GroupBy,
            /* [in] */ XlConsolidationFunction Function,
            /* [in] */ VARIANT TotalList,
            /* [optional][in] */ VARIANT Replace,
            /* [optional][in] */ VARIANT PageBreaks,
            /* [defaultvalue][optional][in] */ XlSummaryRow SummaryBelowData,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Summary( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Table( 
            /* [optional][in] */ VARIANT RowInput,
            /* [optional][in] */ VARIANT ColumnInput,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Text( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall TextToColumns( 
            /* [optional][in] */ VARIANT Destination,
            /* [defaultvalue][optional][in] */ XlTextParsingType DataType,
            /* [defaultvalue][optional][in] */ XlTextQualifier TextQualifier,
            /* [optional][in] */ VARIANT ConsecutiveDelimiter,
            /* [optional][in] */ VARIANT Tab,
            /* [optional][in] */ VARIANT Semicolon,
            /* [optional][in] */ VARIANT Comma,
            /* [optional][in] */ VARIANT Space,
            /* [optional][in] */ VARIANT Other,
            /* [optional][in] */ VARIANT OtherChar,
            /* [optional][in] */ VARIANT FieldInfo,
            /* [optional][in] */ VARIANT DecimalSeparator,
            /* [optional][in] */ VARIANT ThousandsSeparator,
            /* [optional][in] */ VARIANT TrailingMinusNumbers,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Top( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Ungroup( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_UseStandardHeight( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_UseStandardHeight( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_UseStandardWidth( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_UseStandardWidth( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Validation( 
            /* [retval][out] */ Validation	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Value( 
            /* [optional][in] */ VARIANT RangeValueDataType,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Value( 
            /* [optional][in] */ VARIANT RangeValueDataType,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Value2( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Value2( 
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_VerticalAlignment( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_VerticalAlignment( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Width( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Worksheet( 
            /* [retval][out] */ Worksheet	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_WrapText( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_WrapText( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall AddComment( 
            /* [optional][in] */ VARIANT Text,
            /* [retval][out] */ Comment	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Comment( 
            /* [retval][out] */ Comment	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ClearComments( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Phonetic( 
            /* [retval][out] */ Phonetic	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_FormatConditions( 
            /* [retval][out] */ FormatConditions	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ReadingOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ReadingOrder( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Hyperlinks( 
            /* [retval][out] */ Hyperlinks	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Phonetics( 
            /* [retval][out] */ Phonetics	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SetPhonetic( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ID( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ID( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [custom][helpcontext][hidden][id] */ HRESULT __stdcall _PrintOut( 
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate,
            /* [optional][in] */ VARIANT PrToFileName,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PivotCell( 
            /* [retval][out] */ PivotCell	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Dirty( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Errors( 
            /* [retval][out] */ Errors	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_SmartTags( 
            /* [retval][out] */ SmartTags	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Speak( 
            /* [optional][in] */ VARIANT SpeakDirection,
            /* [optional][in] */ VARIANT SpeakFormulas) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall PasteSpecial( 
            /* [defaultvalue][optional][in] */ XlPasteType Paste,
            /* [defaultvalue][optional][in] */ XlPasteSpecialOperation Operation,
            /* [optional][in] */ VARIANT SkipBlanks,
            /* [optional][in] */ VARIANT Transpose,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AllowEdit( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ListObject( 
            /* [retval][out] */ ListObject	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_XPath( 
            /* [retval][out] */ XPath	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ServerActions( 
            /* [retval][out] */ Actions	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall RemoveDuplicates( 
            /* [optional][in] */ VARIANT Columns,
            /* [defaultvalue][optional][in] */ XlYesNoGuess Header = xlNo) = 0;
        
        virtual /* [custom][helpcontext][id] */ HRESULT __stdcall PrintOut( 
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate,
            /* [optional][in] */ VARIANT PrToFileName,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MDX( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ExportAsFixedFormat( 
            /* [in] */ XlFixedFormatType Type,
            /* [optional][in] */ VARIANT Filename,
            /* [optional][in] */ VARIANT Quality,
            /* [optional][in] */ VARIANT IncludeDocProperties,
            /* [optional][in] */ VARIANT IgnorePrintAreas,
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT OpenAfterPublish,
            /* [optional][in] */ VARIANT FixedFormatExtClassPtr) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CountLarge( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CalculateRowMajorOrder( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SparklineGroups( 
            /* [retval][out] */ SparklineGroups	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ClearHyperlinks( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DisplayFormat( 
            /* [retval][out] */ DisplayFormat	**RHS) = 0;
        
        virtual /* [custom][helpcontext][id] */ HRESULT __stdcall BorderAround( 
            /* [optional][in] */ VARIANT LineStyle,
            /* [defaultvalue][optional][in] */ XlBorderWeight Weight,
            /* [defaultvalue][optional][in] */ XlColorIndex ColorIndex,
            /* [optional][in] */ VARIANT Color,
            /* [optional][in] */ VARIANT ThemeColor,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall AllocateChanges( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall DiscardChanges( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall FlashFill( void) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IRangeVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IRange * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IRange * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IRange * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IRange * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IRange * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IRange * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IRange * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IRange * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IRange * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IRange * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Activate )( 
            IRange * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AddIndent )( 
            IRange * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AddIndent )( 
            IRange * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Address )( 
            IRange * This,
            /* [optional][in] */ VARIANT RowAbsolute,
            /* [optional][in] */ VARIANT ColumnAbsolute,
            /* [defaultvalue][optional][in] */ XlReferenceStyle ReferenceStyle,
            /* [optional][in] */ VARIANT External,
            /* [optional][in] */ VARIANT RelativeTo,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AddressLocal )( 
            IRange * This,
            /* [optional][in] */ VARIANT RowAbsolute,
            /* [optional][in] */ VARIANT ColumnAbsolute,
            /* [defaultvalue][optional][in] */ XlReferenceStyle ReferenceStyle,
            /* [optional][in] */ VARIANT External,
            /* [optional][in] */ VARIANT RelativeTo,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *AdvancedFilter )( 
            IRange * This,
            /* [in] */ XlFilterAction Action,
            /* [optional][in] */ VARIANT CriteriaRange,
            /* [optional][in] */ VARIANT CopyToRange,
            /* [optional][in] */ VARIANT Unique,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ApplyNames )( 
            IRange * This,
            /* [optional][in] */ VARIANT Names,
            /* [optional][in] */ VARIANT IgnoreRelativeAbsolute,
            /* [optional][in] */ VARIANT UseRowColumnNames,
            /* [optional][in] */ VARIANT OmitColumn,
            /* [optional][in] */ VARIANT OmitRow,
            /* [defaultvalue][optional][in] */ XlApplyNamesOrder Order,
            /* [optional][in] */ VARIANT AppendLast,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ApplyOutlineStyles )( 
            IRange * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Areas )( 
            IRange * This,
            /* [retval][out] */ Areas	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *AutoComplete )( 
            IRange * This,
            /* [in] */ BSTR String,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *AutoFill )( 
            IRange * This,
            /* [in] */ Range	*Destination,
            /* [defaultvalue][optional][in] */ XlAutoFillType Type,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *AutoFilter )( 
            IRange * This,
            /* [optional][in] */ VARIANT Field,
            /* [optional][in] */ VARIANT Criteria1,
            /* [defaultvalue][optional][in] */ XlAutoFilterOperator Operator,
            /* [optional][in] */ VARIANT Criteria2,
            /* [optional][in] */ VARIANT VisibleDropDown,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *AutoFit )( 
            IRange * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *AutoFormat )( 
            IRange * This,
            /* [defaultvalue][optional][in] */ XlRangeAutoFormat Format,
            /* [optional][in] */ VARIANT Number,
            /* [optional][in] */ VARIANT Font,
            /* [optional][in] */ VARIANT Alignment,
            /* [optional][in] */ VARIANT Border,
            /* [optional][in] */ VARIANT Pattern,
            /* [optional][in] */ VARIANT Width,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *AutoOutline )( 
            IRange * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [custom][helpcontext][hidden][id] */ HRESULT ( __stdcall *_BorderAround )( 
            IRange * This,
            /* [optional][in] */ VARIANT LineStyle,
            /* [defaultvalue][optional][in] */ XlBorderWeight Weight,
            /* [defaultvalue][optional][in] */ XlColorIndex ColorIndex,
            /* [optional][in] */ VARIANT Color,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Borders )( 
            IRange * This,
            /* [retval][out] */ Borders	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Calculate )( 
            IRange * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Cells )( 
            IRange * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Characters )( 
            IRange * This,
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Length,
            /* [retval][out] */ Characters	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CheckSpelling )( 
            IRange * This,
            /* [optional][in] */ VARIANT CustomDictionary,
            /* [optional][in] */ VARIANT IgnoreUppercase,
            /* [optional][in] */ VARIANT AlwaysSuggest,
            /* [optional][in] */ VARIANT SpellLang,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Clear )( 
            IRange * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ClearContents )( 
            IRange * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ClearFormats )( 
            IRange * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ClearNotes )( 
            IRange * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ClearOutline )( 
            IRange * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Column )( 
            IRange * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ColumnDifferences )( 
            IRange * This,
            /* [in] */ VARIANT Comparison,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Columns )( 
            IRange * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ColumnWidth )( 
            IRange * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ColumnWidth )( 
            IRange * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Consolidate )( 
            IRange * This,
            /* [optional][in] */ VARIANT Sources,
            /* [optional][in] */ VARIANT Function,
            /* [optional][in] */ VARIANT TopRow,
            /* [optional][in] */ VARIANT LeftColumn,
            /* [optional][in] */ VARIANT CreateLinks,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Copy )( 
            IRange * This,
            /* [optional][in] */ VARIANT Destination,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CopyFromRecordset )( 
            IRange * This,
            /* [in] */ IUnknown *Data,
            /* [optional][in] */ VARIANT MaxRows,
            /* [optional][in] */ VARIANT MaxColumns,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CopyPicture )( 
            IRange * This,
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IRange * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CreateNames )( 
            IRange * This,
            /* [optional][in] */ VARIANT Top,
            /* [optional][in] */ VARIANT Left,
            /* [optional][in] */ VARIANT Bottom,
            /* [optional][in] */ VARIANT Right,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *CreatePublisher )( 
            IRange * This,
            /* [optional][in] */ VARIANT Edition,
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [optional][in] */ VARIANT ContainsPICT,
            /* [optional][in] */ VARIANT ContainsBIFF,
            /* [optional][in] */ VARIANT ContainsRTF,
            /* [optional][in] */ VARIANT ContainsVALU,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CurrentArray )( 
            IRange * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CurrentRegion )( 
            IRange * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Cut )( 
            IRange * This,
            /* [optional][in] */ VARIANT Destination,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *DataSeries )( 
            IRange * This,
            /* [optional][in] */ VARIANT Rowcol,
            /* [defaultvalue][optional][in] */ XlDataSeriesType Type,
            /* [defaultvalue][optional][in] */ XlDataSeriesDate Date,
            /* [optional][in] */ VARIANT Step,
            /* [optional][in] */ VARIANT Stop,
            /* [optional][in] */ VARIANT Trend,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IRange * This,
            /* [optional][in] */ VARIANT RowIndex,
            /* [optional][in] */ VARIANT ColumnIndex,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put__Default )( 
            IRange * This,
            /* [optional][in] */ VARIANT RowIndex,
            /* [optional][in] */ VARIANT ColumnIndex,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IRange * This,
            /* [optional][in] */ VARIANT Shift,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Dependents )( 
            IRange * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *DialogBox )( 
            IRange * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DirectDependents )( 
            IRange * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DirectPrecedents )( 
            IRange * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *EditionOptions )( 
            IRange * This,
            /* [in] */ XlEditionType Type,
            /* [in] */ XlEditionOptionsOption Option,
            /* [optional][in] */ VARIANT Name,
            /* [optional][in] */ VARIANT Reference,
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlPictureAppearance ChartSize,
            /* [optional][in] */ VARIANT Format,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_End )( 
            IRange * This,
            /* [in] */ XlDirection Direction,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_EntireColumn )( 
            IRange * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_EntireRow )( 
            IRange * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *FillDown )( 
            IRange * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *FillLeft )( 
            IRange * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *FillRight )( 
            IRange * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *FillUp )( 
            IRange * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Find )( 
            IRange * This,
            /* [in] */ VARIANT What,
            /* [optional][in] */ VARIANT After,
            /* [optional][in] */ VARIANT LookIn,
            /* [optional][in] */ VARIANT LookAt,
            /* [optional][in] */ VARIANT SearchOrder,
            /* [defaultvalue][optional][in] */ XlSearchDirection SearchDirection,
            /* [optional][in] */ VARIANT MatchCase,
            /* [optional][in] */ VARIANT MatchByte,
            /* [optional][in] */ VARIANT SearchFormat,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *FindNext )( 
            IRange * This,
            /* [optional][in] */ VARIANT After,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *FindPrevious )( 
            IRange * This,
            /* [optional][in] */ VARIANT After,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Font )( 
            IRange * This,
            /* [retval][out] */ Font	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Formula )( 
            IRange * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Formula )( 
            IRange * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_FormulaArray )( 
            IRange * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_FormulaArray )( 
            IRange * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_FormulaLabel )( 
            IRange * This,
            /* [retval][out] */ XlFormulaLabel *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_FormulaLabel )( 
            IRange * This,
            /* [in] */ XlFormulaLabel RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_FormulaHidden )( 
            IRange * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_FormulaHidden )( 
            IRange * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_FormulaLocal )( 
            IRange * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_FormulaLocal )( 
            IRange * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_FormulaR1C1 )( 
            IRange * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_FormulaR1C1 )( 
            IRange * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_FormulaR1C1Local )( 
            IRange * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_FormulaR1C1Local )( 
            IRange * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *FunctionWizard )( 
            IRange * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *GoalSeek )( 
            IRange * This,
            /* [in] */ VARIANT Goal,
            /* [in] */ Range	*ChangingCell,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Group )( 
            IRange * This,
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT End,
            /* [optional][in] */ VARIANT By,
            /* [optional][in] */ VARIANT Periods,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HasArray )( 
            IRange * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HasFormula )( 
            IRange * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Height )( 
            IRange * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Hidden )( 
            IRange * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Hidden )( 
            IRange * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HorizontalAlignment )( 
            IRange * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_HorizontalAlignment )( 
            IRange * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_IndentLevel )( 
            IRange * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_IndentLevel )( 
            IRange * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *InsertIndent )( 
            IRange * This,
            /* [in] */ long InsertAmount);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Insert )( 
            IRange * This,
            /* [optional][in] */ VARIANT Shift,
            /* [optional][in] */ VARIANT CopyOrigin,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Interior )( 
            IRange * This,
            /* [retval][out] */ Interior	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Item )( 
            IRange * This,
            /* [in] */ VARIANT RowIndex,
            /* [optional][in] */ VARIANT ColumnIndex,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Item )( 
            IRange * This,
            /* [in] */ VARIANT RowIndex,
            /* [optional][in] */ VARIANT ColumnIndex,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Justify )( 
            IRange * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Left )( 
            IRange * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ListHeaderRows )( 
            IRange * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ListNames )( 
            IRange * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LocationInTable )( 
            IRange * This,
            /* [retval][out] */ XlLocationInTable *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Locked )( 
            IRange * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Locked )( 
            IRange * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Merge )( 
            IRange * This,
            /* [optional][in] */ VARIANT Across);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *UnMerge )( 
            IRange * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MergeArea )( 
            IRange * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MergeCells )( 
            IRange * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_MergeCells )( 
            IRange * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            IRange * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Name )( 
            IRange * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *NavigateArrow )( 
            IRange * This,
            /* [optional][in] */ VARIANT TowardPrecedent,
            /* [optional][in] */ VARIANT ArrowNumber,
            /* [optional][in] */ VARIANT LinkNumber,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            IRange * This,
            /* [retval][out] */ IUnknown **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Next )( 
            IRange * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *NoteText )( 
            IRange * This,
            /* [optional][in] */ VARIANT Text,
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Length,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_NumberFormat )( 
            IRange * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_NumberFormat )( 
            IRange * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_NumberFormatLocal )( 
            IRange * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_NumberFormatLocal )( 
            IRange * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Offset )( 
            IRange * This,
            /* [optional][in] */ VARIANT RowOffset,
            /* [optional][in] */ VARIANT ColumnOffset,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Orientation )( 
            IRange * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Orientation )( 
            IRange * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_OutlineLevel )( 
            IRange * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_OutlineLevel )( 
            IRange * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PageBreak )( 
            IRange * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PageBreak )( 
            IRange * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Parse )( 
            IRange * This,
            /* [optional][in] */ VARIANT ParseLine,
            /* [optional][in] */ VARIANT Destination,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *_PasteSpecial )( 
            IRange * This,
            /* [defaultvalue][optional][in] */ XlPasteType Paste,
            /* [defaultvalue][optional][in] */ XlPasteSpecialOperation Operation,
            /* [optional][in] */ VARIANT SkipBlanks,
            /* [optional][in] */ VARIANT Transpose,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PivotField )( 
            IRange * This,
            /* [retval][out] */ PivotField	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PivotItem )( 
            IRange * This,
            /* [retval][out] */ PivotItem	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PivotTable )( 
            IRange * This,
            /* [retval][out] */ PivotTable	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Precedents )( 
            IRange * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PrefixCharacter )( 
            IRange * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Previous )( 
            IRange * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [custom][helpcontext][hidden][id] */ HRESULT ( __stdcall *__PrintOut )( 
            IRange * This,
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *PrintPreview )( 
            IRange * This,
            /* [optional][in] */ VARIANT EnableChanges,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_QueryTable )( 
            IRange * This,
            /* [retval][out] */ QueryTable	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Range )( 
            IRange * This,
            /* [in] */ VARIANT Cell1,
            /* [optional][in] */ VARIANT Cell2,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *RemoveSubtotal )( 
            IRange * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Replace )( 
            IRange * This,
            /* [in] */ VARIANT What,
            /* [in] */ VARIANT Replacement,
            /* [optional][in] */ VARIANT LookAt,
            /* [optional][in] */ VARIANT SearchOrder,
            /* [optional][in] */ VARIANT MatchCase,
            /* [optional][in] */ VARIANT MatchByte,
            /* [optional][in] */ VARIANT SearchFormat,
            /* [optional][in] */ VARIANT ReplaceFormat,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Resize )( 
            IRange * This,
            /* [optional][in] */ VARIANT RowSize,
            /* [optional][in] */ VARIANT ColumnSize,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Row )( 
            IRange * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *RowDifferences )( 
            IRange * This,
            /* [in] */ VARIANT Comparison,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RowHeight )( 
            IRange * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_RowHeight )( 
            IRange * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Rows )( 
            IRange * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Run )( 
            IRange * This,
            /* [optional][in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            IRange * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Show )( 
            IRange * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ShowDependents )( 
            IRange * This,
            /* [optional][in] */ VARIANT Remove,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShowDetail )( 
            IRange * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ShowDetail )( 
            IRange * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ShowErrors )( 
            IRange * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ShowPrecedents )( 
            IRange * This,
            /* [optional][in] */ VARIANT Remove,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShrinkToFit )( 
            IRange * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ShrinkToFit )( 
            IRange * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Sort )( 
            IRange * This,
            /* [optional][in] */ VARIANT Key1,
            /* [defaultvalue][optional][in] */ XlSortOrder Order1,
            /* [optional][in] */ VARIANT Key2,
            /* [optional][in] */ VARIANT Type,
            /* [defaultvalue][optional][in] */ XlSortOrder Order2,
            /* [optional][in] */ VARIANT Key3,
            /* [defaultvalue][optional][in] */ XlSortOrder Order3,
            /* [defaultvalue][optional][in] */ XlYesNoGuess Header,
            /* [optional][in] */ VARIANT OrderCustom,
            /* [optional][in] */ VARIANT MatchCase,
            /* [defaultvalue][optional][in] */ XlSortOrientation Orientation,
            /* [defaultvalue][optional][in] */ XlSortMethod SortMethod,
            /* [defaultvalue][optional][in] */ XlSortDataOption DataOption1,
            /* [defaultvalue][optional][in] */ XlSortDataOption DataOption2,
            /* [defaultvalue][optional][in] */ XlSortDataOption DataOption3,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SortSpecial )( 
            IRange * This,
            /* [defaultvalue][optional][in] */ XlSortMethod SortMethod,
            /* [optional][in] */ VARIANT Key1,
            /* [defaultvalue][optional][in] */ XlSortOrder Order1,
            /* [optional][in] */ VARIANT Type,
            /* [optional][in] */ VARIANT Key2,
            /* [defaultvalue][optional][in] */ XlSortOrder Order2,
            /* [optional][in] */ VARIANT Key3,
            /* [defaultvalue][optional][in] */ XlSortOrder Order3,
            /* [defaultvalue][optional][in] */ XlYesNoGuess Header,
            /* [optional][in] */ VARIANT OrderCustom,
            /* [optional][in] */ VARIANT MatchCase,
            /* [defaultvalue][optional][in] */ XlSortOrientation Orientation,
            /* [defaultvalue][optional][in] */ XlSortDataOption DataOption1,
            /* [defaultvalue][optional][in] */ XlSortDataOption DataOption2,
            /* [defaultvalue][optional][in] */ XlSortDataOption DataOption3,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SoundNote )( 
            IRange * This,
            /* [retval][out] */ SoundNote	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SpecialCells )( 
            IRange * This,
            /* [in] */ XlCellType Type,
            /* [optional][in] */ VARIANT Value,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Style )( 
            IRange * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Style )( 
            IRange * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SubscribeTo )( 
            IRange * This,
            /* [in] */ BSTR Edition,
            /* [defaultvalue][optional][in] */ XlSubscribeToFormat Format,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Subtotal )( 
            IRange * This,
            /* [in] */ long GroupBy,
            /* [in] */ XlConsolidationFunction Function,
            /* [in] */ VARIANT TotalList,
            /* [optional][in] */ VARIANT Replace,
            /* [optional][in] */ VARIANT PageBreaks,
            /* [defaultvalue][optional][in] */ XlSummaryRow SummaryBelowData,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Summary )( 
            IRange * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Table )( 
            IRange * This,
            /* [optional][in] */ VARIANT RowInput,
            /* [optional][in] */ VARIANT ColumnInput,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Text )( 
            IRange * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *TextToColumns )( 
            IRange * This,
            /* [optional][in] */ VARIANT Destination,
            /* [defaultvalue][optional][in] */ XlTextParsingType DataType,
            /* [defaultvalue][optional][in] */ XlTextQualifier TextQualifier,
            /* [optional][in] */ VARIANT ConsecutiveDelimiter,
            /* [optional][in] */ VARIANT Tab,
            /* [optional][in] */ VARIANT Semicolon,
            /* [optional][in] */ VARIANT Comma,
            /* [optional][in] */ VARIANT Space,
            /* [optional][in] */ VARIANT Other,
            /* [optional][in] */ VARIANT OtherChar,
            /* [optional][in] */ VARIANT FieldInfo,
            /* [optional][in] */ VARIANT DecimalSeparator,
            /* [optional][in] */ VARIANT ThousandsSeparator,
            /* [optional][in] */ VARIANT TrailingMinusNumbers,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Top )( 
            IRange * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Ungroup )( 
            IRange * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_UseStandardHeight )( 
            IRange * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_UseStandardHeight )( 
            IRange * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_UseStandardWidth )( 
            IRange * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_UseStandardWidth )( 
            IRange * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Validation )( 
            IRange * This,
            /* [retval][out] */ Validation	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Value )( 
            IRange * This,
            /* [optional][in] */ VARIANT RangeValueDataType,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Value )( 
            IRange * This,
            /* [optional][in] */ VARIANT RangeValueDataType,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Value2 )( 
            IRange * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Value2 )( 
            IRange * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_VerticalAlignment )( 
            IRange * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_VerticalAlignment )( 
            IRange * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Width )( 
            IRange * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Worksheet )( 
            IRange * This,
            /* [retval][out] */ Worksheet	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_WrapText )( 
            IRange * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_WrapText )( 
            IRange * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *AddComment )( 
            IRange * This,
            /* [optional][in] */ VARIANT Text,
            /* [retval][out] */ Comment	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Comment )( 
            IRange * This,
            /* [retval][out] */ Comment	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ClearComments )( 
            IRange * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Phonetic )( 
            IRange * This,
            /* [retval][out] */ Phonetic	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_FormatConditions )( 
            IRange * This,
            /* [retval][out] */ FormatConditions	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ReadingOrder )( 
            IRange * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ReadingOrder )( 
            IRange * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Hyperlinks )( 
            IRange * This,
            /* [retval][out] */ Hyperlinks	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Phonetics )( 
            IRange * This,
            /* [retval][out] */ Phonetics	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SetPhonetic )( 
            IRange * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ID )( 
            IRange * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ID )( 
            IRange * This,
            /* [in] */ BSTR RHS);
        
        /* [custom][helpcontext][hidden][id] */ HRESULT ( __stdcall *_PrintOut )( 
            IRange * This,
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate,
            /* [optional][in] */ VARIANT PrToFileName,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PivotCell )( 
            IRange * This,
            /* [retval][out] */ PivotCell	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Dirty )( 
            IRange * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Errors )( 
            IRange * This,
            /* [retval][out] */ Errors	**RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_SmartTags )( 
            IRange * This,
            /* [retval][out] */ SmartTags	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Speak )( 
            IRange * This,
            /* [optional][in] */ VARIANT SpeakDirection,
            /* [optional][in] */ VARIANT SpeakFormulas);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *PasteSpecial )( 
            IRange * This,
            /* [defaultvalue][optional][in] */ XlPasteType Paste,
            /* [defaultvalue][optional][in] */ XlPasteSpecialOperation Operation,
            /* [optional][in] */ VARIANT SkipBlanks,
            /* [optional][in] */ VARIANT Transpose,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AllowEdit )( 
            IRange * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ListObject )( 
            IRange * This,
            /* [retval][out] */ ListObject	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_XPath )( 
            IRange * This,
            /* [retval][out] */ XPath	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ServerActions )( 
            IRange * This,
            /* [retval][out] */ Actions	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *RemoveDuplicates )( 
            IRange * This,
            /* [optional][in] */ VARIANT Columns,
            /* [defaultvalue][optional][in] */ XlYesNoGuess Header);
        
        /* [custom][helpcontext][id] */ HRESULT ( __stdcall *PrintOut )( 
            IRange * This,
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate,
            /* [optional][in] */ VARIANT PrToFileName,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MDX )( 
            IRange * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ExportAsFixedFormat )( 
            IRange * This,
            /* [in] */ XlFixedFormatType Type,
            /* [optional][in] */ VARIANT Filename,
            /* [optional][in] */ VARIANT Quality,
            /* [optional][in] */ VARIANT IncludeDocProperties,
            /* [optional][in] */ VARIANT IgnorePrintAreas,
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT OpenAfterPublish,
            /* [optional][in] */ VARIANT FixedFormatExtClassPtr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CountLarge )( 
            IRange * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CalculateRowMajorOrder )( 
            IRange * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SparklineGroups )( 
            IRange * This,
            /* [retval][out] */ SparklineGroups	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ClearHyperlinks )( 
            IRange * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DisplayFormat )( 
            IRange * This,
            /* [retval][out] */ DisplayFormat	**RHS);
        
        /* [custom][helpcontext][id] */ HRESULT ( __stdcall *BorderAround )( 
            IRange * This,
            /* [optional][in] */ VARIANT LineStyle,
            /* [defaultvalue][optional][in] */ XlBorderWeight Weight,
            /* [defaultvalue][optional][in] */ XlColorIndex ColorIndex,
            /* [optional][in] */ VARIANT Color,
            /* [optional][in] */ VARIANT ThemeColor,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *AllocateChanges )( 
            IRange * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *DiscardChanges )( 
            IRange * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *FlashFill )( 
            IRange * This);
        
        END_INTERFACE
    } IRangeVtbl;

    interface IRange
    {
        CONST_VTBL struct IRangeVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IRange_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IRange_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IRange_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IRange_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IRange_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IRange_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IRange_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IRange_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IRange_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IRange_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IRange_Activate(This,RHS)	\
    ( (This)->lpVtbl -> Activate(This,RHS) ) 

#define IRange_get_AddIndent(This,RHS)	\
    ( (This)->lpVtbl -> get_AddIndent(This,RHS) ) 

#define IRange_put_AddIndent(This,RHS)	\
    ( (This)->lpVtbl -> put_AddIndent(This,RHS) ) 

#define IRange_get_Address(This,RowAbsolute,ColumnAbsolute,ReferenceStyle,External,RelativeTo,lcid,RHS)	\
    ( (This)->lpVtbl -> get_Address(This,RowAbsolute,ColumnAbsolute,ReferenceStyle,External,RelativeTo,lcid,RHS) ) 

#define IRange_get_AddressLocal(This,RowAbsolute,ColumnAbsolute,ReferenceStyle,External,RelativeTo,RHS)	\
    ( (This)->lpVtbl -> get_AddressLocal(This,RowAbsolute,ColumnAbsolute,ReferenceStyle,External,RelativeTo,RHS) ) 

#define IRange_AdvancedFilter(This,Action,CriteriaRange,CopyToRange,Unique,RHS)	\
    ( (This)->lpVtbl -> AdvancedFilter(This,Action,CriteriaRange,CopyToRange,Unique,RHS) ) 

#define IRange_ApplyNames(This,Names,IgnoreRelativeAbsolute,UseRowColumnNames,OmitColumn,OmitRow,Order,AppendLast,RHS)	\
    ( (This)->lpVtbl -> ApplyNames(This,Names,IgnoreRelativeAbsolute,UseRowColumnNames,OmitColumn,OmitRow,Order,AppendLast,RHS) ) 

#define IRange_ApplyOutlineStyles(This,RHS)	\
    ( (This)->lpVtbl -> ApplyOutlineStyles(This,RHS) ) 

#define IRange_get_Areas(This,RHS)	\
    ( (This)->lpVtbl -> get_Areas(This,RHS) ) 

#define IRange_AutoComplete(This,String,RHS)	\
    ( (This)->lpVtbl -> AutoComplete(This,String,RHS) ) 

#define IRange_AutoFill(This,Destination,Type,RHS)	\
    ( (This)->lpVtbl -> AutoFill(This,Destination,Type,RHS) ) 

#define IRange_AutoFilter(This,Field,Criteria1,Operator,Criteria2,VisibleDropDown,RHS)	\
    ( (This)->lpVtbl -> AutoFilter(This,Field,Criteria1,Operator,Criteria2,VisibleDropDown,RHS) ) 

#define IRange_AutoFit(This,RHS)	\
    ( (This)->lpVtbl -> AutoFit(This,RHS) ) 

#define IRange_AutoFormat(This,Format,Number,Font,Alignment,Border,Pattern,Width,RHS)	\
    ( (This)->lpVtbl -> AutoFormat(This,Format,Number,Font,Alignment,Border,Pattern,Width,RHS) ) 

#define IRange_AutoOutline(This,RHS)	\
    ( (This)->lpVtbl -> AutoOutline(This,RHS) ) 

#define IRange__BorderAround(This,LineStyle,Weight,ColorIndex,Color,RHS)	\
    ( (This)->lpVtbl -> _BorderAround(This,LineStyle,Weight,ColorIndex,Color,RHS) ) 

#define IRange_get_Borders(This,RHS)	\
    ( (This)->lpVtbl -> get_Borders(This,RHS) ) 

#define IRange_Calculate(This,RHS)	\
    ( (This)->lpVtbl -> Calculate(This,RHS) ) 

#define IRange_get_Cells(This,RHS)	\
    ( (This)->lpVtbl -> get_Cells(This,RHS) ) 

#define IRange_get_Characters(This,Start,Length,RHS)	\
    ( (This)->lpVtbl -> get_Characters(This,Start,Length,RHS) ) 

#define IRange_CheckSpelling(This,CustomDictionary,IgnoreUppercase,AlwaysSuggest,SpellLang,RHS)	\
    ( (This)->lpVtbl -> CheckSpelling(This,CustomDictionary,IgnoreUppercase,AlwaysSuggest,SpellLang,RHS) ) 

#define IRange_Clear(This,RHS)	\
    ( (This)->lpVtbl -> Clear(This,RHS) ) 

#define IRange_ClearContents(This,RHS)	\
    ( (This)->lpVtbl -> ClearContents(This,RHS) ) 

#define IRange_ClearFormats(This,RHS)	\
    ( (This)->lpVtbl -> ClearFormats(This,RHS) ) 

#define IRange_ClearNotes(This,RHS)	\
    ( (This)->lpVtbl -> ClearNotes(This,RHS) ) 

#define IRange_ClearOutline(This,RHS)	\
    ( (This)->lpVtbl -> ClearOutline(This,RHS) ) 

#define IRange_get_Column(This,RHS)	\
    ( (This)->lpVtbl -> get_Column(This,RHS) ) 

#define IRange_ColumnDifferences(This,Comparison,RHS)	\
    ( (This)->lpVtbl -> ColumnDifferences(This,Comparison,RHS) ) 

#define IRange_get_Columns(This,RHS)	\
    ( (This)->lpVtbl -> get_Columns(This,RHS) ) 

#define IRange_get_ColumnWidth(This,RHS)	\
    ( (This)->lpVtbl -> get_ColumnWidth(This,RHS) ) 

#define IRange_put_ColumnWidth(This,RHS)	\
    ( (This)->lpVtbl -> put_ColumnWidth(This,RHS) ) 

#define IRange_Consolidate(This,Sources,Function,TopRow,LeftColumn,CreateLinks,RHS)	\
    ( (This)->lpVtbl -> Consolidate(This,Sources,Function,TopRow,LeftColumn,CreateLinks,RHS) ) 

#define IRange_Copy(This,Destination,RHS)	\
    ( (This)->lpVtbl -> Copy(This,Destination,RHS) ) 

#define IRange_CopyFromRecordset(This,Data,MaxRows,MaxColumns,RHS)	\
    ( (This)->lpVtbl -> CopyFromRecordset(This,Data,MaxRows,MaxColumns,RHS) ) 

#define IRange_CopyPicture(This,Appearance,Format,RHS)	\
    ( (This)->lpVtbl -> CopyPicture(This,Appearance,Format,RHS) ) 

#define IRange_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IRange_CreateNames(This,Top,Left,Bottom,Right,RHS)	\
    ( (This)->lpVtbl -> CreateNames(This,Top,Left,Bottom,Right,RHS) ) 

#define IRange_CreatePublisher(This,Edition,Appearance,ContainsPICT,ContainsBIFF,ContainsRTF,ContainsVALU,RHS)	\
    ( (This)->lpVtbl -> CreatePublisher(This,Edition,Appearance,ContainsPICT,ContainsBIFF,ContainsRTF,ContainsVALU,RHS) ) 

#define IRange_get_CurrentArray(This,RHS)	\
    ( (This)->lpVtbl -> get_CurrentArray(This,RHS) ) 

#define IRange_get_CurrentRegion(This,RHS)	\
    ( (This)->lpVtbl -> get_CurrentRegion(This,RHS) ) 

#define IRange_Cut(This,Destination,RHS)	\
    ( (This)->lpVtbl -> Cut(This,Destination,RHS) ) 

#define IRange_DataSeries(This,Rowcol,Type,Date,Step,Stop,Trend,RHS)	\
    ( (This)->lpVtbl -> DataSeries(This,Rowcol,Type,Date,Step,Stop,Trend,RHS) ) 

#define IRange_get__Default(This,RowIndex,ColumnIndex,lcid,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,RowIndex,ColumnIndex,lcid,RHS) ) 

#define IRange_put__Default(This,RowIndex,ColumnIndex,lcid,RHS)	\
    ( (This)->lpVtbl -> put__Default(This,RowIndex,ColumnIndex,lcid,RHS) ) 

#define IRange_Delete(This,Shift,RHS)	\
    ( (This)->lpVtbl -> Delete(This,Shift,RHS) ) 

#define IRange_get_Dependents(This,RHS)	\
    ( (This)->lpVtbl -> get_Dependents(This,RHS) ) 

#define IRange_DialogBox(This,RHS)	\
    ( (This)->lpVtbl -> DialogBox(This,RHS) ) 

#define IRange_get_DirectDependents(This,RHS)	\
    ( (This)->lpVtbl -> get_DirectDependents(This,RHS) ) 

#define IRange_get_DirectPrecedents(This,RHS)	\
    ( (This)->lpVtbl -> get_DirectPrecedents(This,RHS) ) 

#define IRange_EditionOptions(This,Type,Option,Name,Reference,Appearance,ChartSize,Format,RHS)	\
    ( (This)->lpVtbl -> EditionOptions(This,Type,Option,Name,Reference,Appearance,ChartSize,Format,RHS) ) 

#define IRange_get_End(This,Direction,RHS)	\
    ( (This)->lpVtbl -> get_End(This,Direction,RHS) ) 

#define IRange_get_EntireColumn(This,RHS)	\
    ( (This)->lpVtbl -> get_EntireColumn(This,RHS) ) 

#define IRange_get_EntireRow(This,RHS)	\
    ( (This)->lpVtbl -> get_EntireRow(This,RHS) ) 

#define IRange_FillDown(This,RHS)	\
    ( (This)->lpVtbl -> FillDown(This,RHS) ) 

#define IRange_FillLeft(This,RHS)	\
    ( (This)->lpVtbl -> FillLeft(This,RHS) ) 

#define IRange_FillRight(This,RHS)	\
    ( (This)->lpVtbl -> FillRight(This,RHS) ) 

#define IRange_FillUp(This,RHS)	\
    ( (This)->lpVtbl -> FillUp(This,RHS) ) 

#define IRange_Find(This,What,After,LookIn,LookAt,SearchOrder,SearchDirection,MatchCase,MatchByte,SearchFormat,RHS)	\
    ( (This)->lpVtbl -> Find(This,What,After,LookIn,LookAt,SearchOrder,SearchDirection,MatchCase,MatchByte,SearchFormat,RHS) ) 

#define IRange_FindNext(This,After,RHS)	\
    ( (This)->lpVtbl -> FindNext(This,After,RHS) ) 

#define IRange_FindPrevious(This,After,RHS)	\
    ( (This)->lpVtbl -> FindPrevious(This,After,RHS) ) 

#define IRange_get_Font(This,RHS)	\
    ( (This)->lpVtbl -> get_Font(This,RHS) ) 

#define IRange_get_Formula(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_Formula(This,lcid,RHS) ) 

#define IRange_put_Formula(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_Formula(This,lcid,RHS) ) 

#define IRange_get_FormulaArray(This,RHS)	\
    ( (This)->lpVtbl -> get_FormulaArray(This,RHS) ) 

#define IRange_put_FormulaArray(This,RHS)	\
    ( (This)->lpVtbl -> put_FormulaArray(This,RHS) ) 

#define IRange_get_FormulaLabel(This,RHS)	\
    ( (This)->lpVtbl -> get_FormulaLabel(This,RHS) ) 

#define IRange_put_FormulaLabel(This,RHS)	\
    ( (This)->lpVtbl -> put_FormulaLabel(This,RHS) ) 

#define IRange_get_FormulaHidden(This,RHS)	\
    ( (This)->lpVtbl -> get_FormulaHidden(This,RHS) ) 

#define IRange_put_FormulaHidden(This,RHS)	\
    ( (This)->lpVtbl -> put_FormulaHidden(This,RHS) ) 

#define IRange_get_FormulaLocal(This,RHS)	\
    ( (This)->lpVtbl -> get_FormulaLocal(This,RHS) ) 

#define IRange_put_FormulaLocal(This,RHS)	\
    ( (This)->lpVtbl -> put_FormulaLocal(This,RHS) ) 

#define IRange_get_FormulaR1C1(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_FormulaR1C1(This,lcid,RHS) ) 

#define IRange_put_FormulaR1C1(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_FormulaR1C1(This,lcid,RHS) ) 

#define IRange_get_FormulaR1C1Local(This,RHS)	\
    ( (This)->lpVtbl -> get_FormulaR1C1Local(This,RHS) ) 

#define IRange_put_FormulaR1C1Local(This,RHS)	\
    ( (This)->lpVtbl -> put_FormulaR1C1Local(This,RHS) ) 

#define IRange_FunctionWizard(This,RHS)	\
    ( (This)->lpVtbl -> FunctionWizard(This,RHS) ) 

#define IRange_GoalSeek(This,Goal,ChangingCell,RHS)	\
    ( (This)->lpVtbl -> GoalSeek(This,Goal,ChangingCell,RHS) ) 

#define IRange_Group(This,Start,End,By,Periods,RHS)	\
    ( (This)->lpVtbl -> Group(This,Start,End,By,Periods,RHS) ) 

#define IRange_get_HasArray(This,RHS)	\
    ( (This)->lpVtbl -> get_HasArray(This,RHS) ) 

#define IRange_get_HasFormula(This,RHS)	\
    ( (This)->lpVtbl -> get_HasFormula(This,RHS) ) 

#define IRange_get_Height(This,RHS)	\
    ( (This)->lpVtbl -> get_Height(This,RHS) ) 

#define IRange_get_Hidden(This,RHS)	\
    ( (This)->lpVtbl -> get_Hidden(This,RHS) ) 

#define IRange_put_Hidden(This,RHS)	\
    ( (This)->lpVtbl -> put_Hidden(This,RHS) ) 

#define IRange_get_HorizontalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> get_HorizontalAlignment(This,RHS) ) 

#define IRange_put_HorizontalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> put_HorizontalAlignment(This,RHS) ) 

#define IRange_get_IndentLevel(This,RHS)	\
    ( (This)->lpVtbl -> get_IndentLevel(This,RHS) ) 

#define IRange_put_IndentLevel(This,RHS)	\
    ( (This)->lpVtbl -> put_IndentLevel(This,RHS) ) 

#define IRange_InsertIndent(This,InsertAmount)	\
    ( (This)->lpVtbl -> InsertIndent(This,InsertAmount) ) 

#define IRange_Insert(This,Shift,CopyOrigin,RHS)	\
    ( (This)->lpVtbl -> Insert(This,Shift,CopyOrigin,RHS) ) 

#define IRange_get_Interior(This,RHS)	\
    ( (This)->lpVtbl -> get_Interior(This,RHS) ) 

#define IRange_get_Item(This,RowIndex,ColumnIndex,lcid,RHS)	\
    ( (This)->lpVtbl -> get_Item(This,RowIndex,ColumnIndex,lcid,RHS) ) 

#define IRange_put_Item(This,RowIndex,ColumnIndex,lcid,RHS)	\
    ( (This)->lpVtbl -> put_Item(This,RowIndex,ColumnIndex,lcid,RHS) ) 

#define IRange_Justify(This,RHS)	\
    ( (This)->lpVtbl -> Justify(This,RHS) ) 

#define IRange_get_Left(This,RHS)	\
    ( (This)->lpVtbl -> get_Left(This,RHS) ) 

#define IRange_get_ListHeaderRows(This,RHS)	\
    ( (This)->lpVtbl -> get_ListHeaderRows(This,RHS) ) 

#define IRange_ListNames(This,RHS)	\
    ( (This)->lpVtbl -> ListNames(This,RHS) ) 

#define IRange_get_LocationInTable(This,RHS)	\
    ( (This)->lpVtbl -> get_LocationInTable(This,RHS) ) 

#define IRange_get_Locked(This,RHS)	\
    ( (This)->lpVtbl -> get_Locked(This,RHS) ) 

#define IRange_put_Locked(This,RHS)	\
    ( (This)->lpVtbl -> put_Locked(This,RHS) ) 

#define IRange_Merge(This,Across)	\
    ( (This)->lpVtbl -> Merge(This,Across) ) 

#define IRange_UnMerge(This)	\
    ( (This)->lpVtbl -> UnMerge(This) ) 

#define IRange_get_MergeArea(This,RHS)	\
    ( (This)->lpVtbl -> get_MergeArea(This,RHS) ) 

#define IRange_get_MergeCells(This,RHS)	\
    ( (This)->lpVtbl -> get_MergeCells(This,RHS) ) 

#define IRange_put_MergeCells(This,RHS)	\
    ( (This)->lpVtbl -> put_MergeCells(This,RHS) ) 

#define IRange_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define IRange_put_Name(This,RHS)	\
    ( (This)->lpVtbl -> put_Name(This,RHS) ) 

#define IRange_NavigateArrow(This,TowardPrecedent,ArrowNumber,LinkNumber,RHS)	\
    ( (This)->lpVtbl -> NavigateArrow(This,TowardPrecedent,ArrowNumber,LinkNumber,RHS) ) 

#define IRange_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#define IRange_get_Next(This,RHS)	\
    ( (This)->lpVtbl -> get_Next(This,RHS) ) 

#define IRange_NoteText(This,Text,Start,Length,RHS)	\
    ( (This)->lpVtbl -> NoteText(This,Text,Start,Length,RHS) ) 

#define IRange_get_NumberFormat(This,RHS)	\
    ( (This)->lpVtbl -> get_NumberFormat(This,RHS) ) 

#define IRange_put_NumberFormat(This,RHS)	\
    ( (This)->lpVtbl -> put_NumberFormat(This,RHS) ) 

#define IRange_get_NumberFormatLocal(This,RHS)	\
    ( (This)->lpVtbl -> get_NumberFormatLocal(This,RHS) ) 

#define IRange_put_NumberFormatLocal(This,RHS)	\
    ( (This)->lpVtbl -> put_NumberFormatLocal(This,RHS) ) 

#define IRange_get_Offset(This,RowOffset,ColumnOffset,RHS)	\
    ( (This)->lpVtbl -> get_Offset(This,RowOffset,ColumnOffset,RHS) ) 

#define IRange_get_Orientation(This,RHS)	\
    ( (This)->lpVtbl -> get_Orientation(This,RHS) ) 

#define IRange_put_Orientation(This,RHS)	\
    ( (This)->lpVtbl -> put_Orientation(This,RHS) ) 

#define IRange_get_OutlineLevel(This,RHS)	\
    ( (This)->lpVtbl -> get_OutlineLevel(This,RHS) ) 

#define IRange_put_OutlineLevel(This,RHS)	\
    ( (This)->lpVtbl -> put_OutlineLevel(This,RHS) ) 

#define IRange_get_PageBreak(This,RHS)	\
    ( (This)->lpVtbl -> get_PageBreak(This,RHS) ) 

#define IRange_put_PageBreak(This,RHS)	\
    ( (This)->lpVtbl -> put_PageBreak(This,RHS) ) 

#define IRange_Parse(This,ParseLine,Destination,RHS)	\
    ( (This)->lpVtbl -> Parse(This,ParseLine,Destination,RHS) ) 

#define IRange__PasteSpecial(This,Paste,Operation,SkipBlanks,Transpose,RHS)	\
    ( (This)->lpVtbl -> _PasteSpecial(This,Paste,Operation,SkipBlanks,Transpose,RHS) ) 

#define IRange_get_PivotField(This,RHS)	\
    ( (This)->lpVtbl -> get_PivotField(This,RHS) ) 

#define IRange_get_PivotItem(This,RHS)	\
    ( (This)->lpVtbl -> get_PivotItem(This,RHS) ) 

#define IRange_get_PivotTable(This,RHS)	\
    ( (This)->lpVtbl -> get_PivotTable(This,RHS) ) 

#define IRange_get_Precedents(This,RHS)	\
    ( (This)->lpVtbl -> get_Precedents(This,RHS) ) 

#define IRange_get_PrefixCharacter(This,RHS)	\
    ( (This)->lpVtbl -> get_PrefixCharacter(This,RHS) ) 

#define IRange_get_Previous(This,RHS)	\
    ( (This)->lpVtbl -> get_Previous(This,RHS) ) 

#define IRange___PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate,RHS)	\
    ( (This)->lpVtbl -> __PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate,RHS) ) 

#define IRange_PrintPreview(This,EnableChanges,RHS)	\
    ( (This)->lpVtbl -> PrintPreview(This,EnableChanges,RHS) ) 

#define IRange_get_QueryTable(This,RHS)	\
    ( (This)->lpVtbl -> get_QueryTable(This,RHS) ) 

#define IRange_get_Range(This,Cell1,Cell2,RHS)	\
    ( (This)->lpVtbl -> get_Range(This,Cell1,Cell2,RHS) ) 

#define IRange_RemoveSubtotal(This,RHS)	\
    ( (This)->lpVtbl -> RemoveSubtotal(This,RHS) ) 

#define IRange_Replace(This,What,Replacement,LookAt,SearchOrder,MatchCase,MatchByte,SearchFormat,ReplaceFormat,RHS)	\
    ( (This)->lpVtbl -> Replace(This,What,Replacement,LookAt,SearchOrder,MatchCase,MatchByte,SearchFormat,ReplaceFormat,RHS) ) 

#define IRange_get_Resize(This,RowSize,ColumnSize,RHS)	\
    ( (This)->lpVtbl -> get_Resize(This,RowSize,ColumnSize,RHS) ) 

#define IRange_get_Row(This,RHS)	\
    ( (This)->lpVtbl -> get_Row(This,RHS) ) 

#define IRange_RowDifferences(This,Comparison,RHS)	\
    ( (This)->lpVtbl -> RowDifferences(This,Comparison,RHS) ) 

#define IRange_get_RowHeight(This,RHS)	\
    ( (This)->lpVtbl -> get_RowHeight(This,RHS) ) 

#define IRange_put_RowHeight(This,RHS)	\
    ( (This)->lpVtbl -> put_RowHeight(This,RHS) ) 

#define IRange_get_Rows(This,RHS)	\
    ( (This)->lpVtbl -> get_Rows(This,RHS) ) 

#define IRange_Run(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS)	\
    ( (This)->lpVtbl -> Run(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS) ) 

#define IRange_Select(This,RHS)	\
    ( (This)->lpVtbl -> Select(This,RHS) ) 

#define IRange_Show(This,RHS)	\
    ( (This)->lpVtbl -> Show(This,RHS) ) 

#define IRange_ShowDependents(This,Remove,RHS)	\
    ( (This)->lpVtbl -> ShowDependents(This,Remove,RHS) ) 

#define IRange_get_ShowDetail(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowDetail(This,RHS) ) 

#define IRange_put_ShowDetail(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowDetail(This,RHS) ) 

#define IRange_ShowErrors(This,RHS)	\
    ( (This)->lpVtbl -> ShowErrors(This,RHS) ) 

#define IRange_ShowPrecedents(This,Remove,RHS)	\
    ( (This)->lpVtbl -> ShowPrecedents(This,Remove,RHS) ) 

#define IRange_get_ShrinkToFit(This,RHS)	\
    ( (This)->lpVtbl -> get_ShrinkToFit(This,RHS) ) 

#define IRange_put_ShrinkToFit(This,RHS)	\
    ( (This)->lpVtbl -> put_ShrinkToFit(This,RHS) ) 

#define IRange_Sort(This,Key1,Order1,Key2,Type,Order2,Key3,Order3,Header,OrderCustom,MatchCase,Orientation,SortMethod,DataOption1,DataOption2,DataOption3,RHS)	\
    ( (This)->lpVtbl -> Sort(This,Key1,Order1,Key2,Type,Order2,Key3,Order3,Header,OrderCustom,MatchCase,Orientation,SortMethod,DataOption1,DataOption2,DataOption3,RHS) ) 

#define IRange_SortSpecial(This,SortMethod,Key1,Order1,Type,Key2,Order2,Key3,Order3,Header,OrderCustom,MatchCase,Orientation,DataOption1,DataOption2,DataOption3,RHS)	\
    ( (This)->lpVtbl -> SortSpecial(This,SortMethod,Key1,Order1,Type,Key2,Order2,Key3,Order3,Header,OrderCustom,MatchCase,Orientation,DataOption1,DataOption2,DataOption3,RHS) ) 

#define IRange_get_SoundNote(This,RHS)	\
    ( (This)->lpVtbl -> get_SoundNote(This,RHS) ) 

#define IRange_SpecialCells(This,Type,Value,RHS)	\
    ( (This)->lpVtbl -> SpecialCells(This,Type,Value,RHS) ) 

#define IRange_get_Style(This,RHS)	\
    ( (This)->lpVtbl -> get_Style(This,RHS) ) 

#define IRange_put_Style(This,RHS)	\
    ( (This)->lpVtbl -> put_Style(This,RHS) ) 

#define IRange_SubscribeTo(This,Edition,Format,RHS)	\
    ( (This)->lpVtbl -> SubscribeTo(This,Edition,Format,RHS) ) 

#define IRange_Subtotal(This,GroupBy,Function,TotalList,Replace,PageBreaks,SummaryBelowData,RHS)	\
    ( (This)->lpVtbl -> Subtotal(This,GroupBy,Function,TotalList,Replace,PageBreaks,SummaryBelowData,RHS) ) 

#define IRange_get_Summary(This,RHS)	\
    ( (This)->lpVtbl -> get_Summary(This,RHS) ) 

#define IRange_Table(This,RowInput,ColumnInput,RHS)	\
    ( (This)->lpVtbl -> Table(This,RowInput,ColumnInput,RHS) ) 

#define IRange_get_Text(This,RHS)	\
    ( (This)->lpVtbl -> get_Text(This,RHS) ) 

#define IRange_TextToColumns(This,Destination,DataType,TextQualifier,ConsecutiveDelimiter,Tab,Semicolon,Comma,Space,Other,OtherChar,FieldInfo,DecimalSeparator,ThousandsSeparator,TrailingMinusNumbers,RHS)	\
    ( (This)->lpVtbl -> TextToColumns(This,Destination,DataType,TextQualifier,ConsecutiveDelimiter,Tab,Semicolon,Comma,Space,Other,OtherChar,FieldInfo,DecimalSeparator,ThousandsSeparator,TrailingMinusNumbers,RHS) ) 

#define IRange_get_Top(This,RHS)	\
    ( (This)->lpVtbl -> get_Top(This,RHS) ) 

#define IRange_Ungroup(This,RHS)	\
    ( (This)->lpVtbl -> Ungroup(This,RHS) ) 

#define IRange_get_UseStandardHeight(This,RHS)	\
    ( (This)->lpVtbl -> get_UseStandardHeight(This,RHS) ) 

#define IRange_put_UseStandardHeight(This,RHS)	\
    ( (This)->lpVtbl -> put_UseStandardHeight(This,RHS) ) 

#define IRange_get_UseStandardWidth(This,RHS)	\
    ( (This)->lpVtbl -> get_UseStandardWidth(This,RHS) ) 

#define IRange_put_UseStandardWidth(This,RHS)	\
    ( (This)->lpVtbl -> put_UseStandardWidth(This,RHS) ) 

#define IRange_get_Validation(This,RHS)	\
    ( (This)->lpVtbl -> get_Validation(This,RHS) ) 

#define IRange_get_Value(This,RangeValueDataType,lcid,RHS)	\
    ( (This)->lpVtbl -> get_Value(This,RangeValueDataType,lcid,RHS) ) 

#define IRange_put_Value(This,RangeValueDataType,lcid,RHS)	\
    ( (This)->lpVtbl -> put_Value(This,RangeValueDataType,lcid,RHS) ) 

#define IRange_get_Value2(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_Value2(This,lcid,RHS) ) 

#define IRange_put_Value2(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_Value2(This,lcid,RHS) ) 

#define IRange_get_VerticalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> get_VerticalAlignment(This,RHS) ) 

#define IRange_put_VerticalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> put_VerticalAlignment(This,RHS) ) 

#define IRange_get_Width(This,RHS)	\
    ( (This)->lpVtbl -> get_Width(This,RHS) ) 

#define IRange_get_Worksheet(This,RHS)	\
    ( (This)->lpVtbl -> get_Worksheet(This,RHS) ) 

#define IRange_get_WrapText(This,RHS)	\
    ( (This)->lpVtbl -> get_WrapText(This,RHS) ) 

#define IRange_put_WrapText(This,RHS)	\
    ( (This)->lpVtbl -> put_WrapText(This,RHS) ) 

#define IRange_AddComment(This,Text,RHS)	\
    ( (This)->lpVtbl -> AddComment(This,Text,RHS) ) 

#define IRange_get_Comment(This,RHS)	\
    ( (This)->lpVtbl -> get_Comment(This,RHS) ) 

#define IRange_ClearComments(This)	\
    ( (This)->lpVtbl -> ClearComments(This) ) 

#define IRange_get_Phonetic(This,RHS)	\
    ( (This)->lpVtbl -> get_Phonetic(This,RHS) ) 

#define IRange_get_FormatConditions(This,RHS)	\
    ( (This)->lpVtbl -> get_FormatConditions(This,RHS) ) 

#define IRange_get_ReadingOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_ReadingOrder(This,RHS) ) 

#define IRange_put_ReadingOrder(This,RHS)	\
    ( (This)->lpVtbl -> put_ReadingOrder(This,RHS) ) 

#define IRange_get_Hyperlinks(This,RHS)	\
    ( (This)->lpVtbl -> get_Hyperlinks(This,RHS) ) 

#define IRange_get_Phonetics(This,RHS)	\
    ( (This)->lpVtbl -> get_Phonetics(This,RHS) ) 

#define IRange_SetPhonetic(This)	\
    ( (This)->lpVtbl -> SetPhonetic(This) ) 

#define IRange_get_ID(This,RHS)	\
    ( (This)->lpVtbl -> get_ID(This,RHS) ) 

#define IRange_put_ID(This,RHS)	\
    ( (This)->lpVtbl -> put_ID(This,RHS) ) 

#define IRange__PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate,PrToFileName,RHS)	\
    ( (This)->lpVtbl -> _PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate,PrToFileName,RHS) ) 

#define IRange_get_PivotCell(This,RHS)	\
    ( (This)->lpVtbl -> get_PivotCell(This,RHS) ) 

#define IRange_Dirty(This)	\
    ( (This)->lpVtbl -> Dirty(This) ) 

#define IRange_get_Errors(This,RHS)	\
    ( (This)->lpVtbl -> get_Errors(This,RHS) ) 

#define IRange_get_SmartTags(This,RHS)	\
    ( (This)->lpVtbl -> get_SmartTags(This,RHS) ) 

#define IRange_Speak(This,SpeakDirection,SpeakFormulas)	\
    ( (This)->lpVtbl -> Speak(This,SpeakDirection,SpeakFormulas) ) 

#define IRange_PasteSpecial(This,Paste,Operation,SkipBlanks,Transpose,RHS)	\
    ( (This)->lpVtbl -> PasteSpecial(This,Paste,Operation,SkipBlanks,Transpose,RHS) ) 

#define IRange_get_AllowEdit(This,RHS)	\
    ( (This)->lpVtbl -> get_AllowEdit(This,RHS) ) 

#define IRange_get_ListObject(This,RHS)	\
    ( (This)->lpVtbl -> get_ListObject(This,RHS) ) 

#define IRange_get_XPath(This,RHS)	\
    ( (This)->lpVtbl -> get_XPath(This,RHS) ) 

#define IRange_get_ServerActions(This,RHS)	\
    ( (This)->lpVtbl -> get_ServerActions(This,RHS) ) 

#define IRange_RemoveDuplicates(This,Columns,Header)	\
    ( (This)->lpVtbl -> RemoveDuplicates(This,Columns,Header) ) 

#define IRange_PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate,PrToFileName,RHS)	\
    ( (This)->lpVtbl -> PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate,PrToFileName,RHS) ) 

#define IRange_get_MDX(This,RHS)	\
    ( (This)->lpVtbl -> get_MDX(This,RHS) ) 

#define IRange_ExportAsFixedFormat(This,Type,Filename,Quality,IncludeDocProperties,IgnorePrintAreas,From,To,OpenAfterPublish,FixedFormatExtClassPtr)	\
    ( (This)->lpVtbl -> ExportAsFixedFormat(This,Type,Filename,Quality,IncludeDocProperties,IgnorePrintAreas,From,To,OpenAfterPublish,FixedFormatExtClassPtr) ) 

#define IRange_get_CountLarge(This,RHS)	\
    ( (This)->lpVtbl -> get_CountLarge(This,RHS) ) 

#define IRange_CalculateRowMajorOrder(This,RHS)	\
    ( (This)->lpVtbl -> CalculateRowMajorOrder(This,RHS) ) 

#define IRange_get_SparklineGroups(This,RHS)	\
    ( (This)->lpVtbl -> get_SparklineGroups(This,RHS) ) 

#define IRange_ClearHyperlinks(This)	\
    ( (This)->lpVtbl -> ClearHyperlinks(This) ) 

#define IRange_get_DisplayFormat(This,RHS)	\
    ( (This)->lpVtbl -> get_DisplayFormat(This,RHS) ) 

#define IRange_BorderAround(This,LineStyle,Weight,ColorIndex,Color,ThemeColor,RHS)	\
    ( (This)->lpVtbl -> BorderAround(This,LineStyle,Weight,ColorIndex,Color,ThemeColor,RHS) ) 

#define IRange_AllocateChanges(This)	\
    ( (This)->lpVtbl -> AllocateChanges(This) ) 

#define IRange_DiscardChanges(This)	\
    ( (This)->lpVtbl -> DiscardChanges(This) ) 

#define IRange_FlashFill(This)	\
    ( (This)->lpVtbl -> FlashFill(This) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */



/* [helpcontext][propput][id] */ HRESULT __stdcall IRange_put_OutlineLevel_Proxy( 
    IRange * This,
    /* [in] */ VARIANT RHS);


void __RPC_STUB IRange_put_OutlineLevel_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IRange_get_PageBreak_Proxy( 
    IRange * This,
    /* [retval][out] */ long *RHS);


void __RPC_STUB IRange_get_PageBreak_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT __stdcall IRange_put_PageBreak_Proxy( 
    IRange * This,
    /* [in] */ long RHS);


void __RPC_STUB IRange_put_PageBreak_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IRange_Parse_Proxy( 
    IRange * This,
    /* [optional][in] */ VARIANT ParseLine,
    /* [optional][in] */ VARIANT Destination,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB IRange_Parse_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][id] */ HRESULT __stdcall IRange__PasteSpecial_Proxy( 
    IRange * This,
    /* [defaultvalue][optional][in] */ XlPasteType Paste,
    /* [defaultvalue][optional][in] */ XlPasteSpecialOperation Operation,
    /* [optional][in] */ VARIANT SkipBlanks,
    /* [optional][in] */ VARIANT Transpose,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB IRange__PasteSpecial_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IRange_get_PivotField_Proxy( 
    IRange * This,
    /* [retval][out] */ PivotField	**RHS);


void __RPC_STUB IRange_get_PivotField_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IRange_get_PivotItem_Proxy( 
    IRange * This,
    /* [retval][out] */ PivotItem	**RHS);


void __RPC_STUB IRange_get_PivotItem_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IRange_get_PivotTable_Proxy( 
    IRange * This,
    /* [retval][out] */ PivotTable	**RHS);


void __RPC_STUB IRange_get_PivotTable_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IRange_get_Precedents_Proxy( 
    IRange * This,
    /* [retval][out] */ Range	**RHS);


void __RPC_STUB IRange_get_Precedents_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IRange_get_PrefixCharacter_Proxy( 
    IRange * This,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB IRange_get_PrefixCharacter_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IRange_get_Previous_Proxy( 
    IRange * This,
    /* [retval][out] */ Range	**RHS);


void __RPC_STUB IRange_get_Previous_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [custom][helpcontext][hidden][id] */ HRESULT __stdcall IRange___PrintOut_Proxy( 
    IRange * This,
    /* [optional][in] */ VARIANT From,
    /* [optional][in] */ VARIANT To,
    /* [optional][in] */ VARIANT Copies,
    /* [optional][in] */ VARIANT Preview,
    /* [optional][in] */ VARIANT ActivePrinter,
    /* [optional][in] */ VARIANT PrintToFile,
    /* [optional][in] */ VARIANT Collate,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB IRange___PrintOut_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IRange_PrintPreview_Proxy( 
    IRange * This,
    /* [optional][in] */ VARIANT EnableChanges,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB IRange_PrintPreview_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IRange_get_QueryTable_Proxy( 
    IRange * This,
    /* [retval][out] */ QueryTable	**RHS);


void __RPC_STUB IRange_get_QueryTable_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IRange_get_Range_Proxy( 
    IRange * This,
    /* [in] */ VARIANT Cell1,
    /* [optional][in] */ VARIANT Cell2,
    /* [retval][out] */ Range	**RHS);


void __RPC_STUB IRange_get_Range_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IRange_RemoveSubtotal_Proxy( 
    IRange * This,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB IRange_RemoveSubtotal_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IRange_Replace_Proxy( 
    IRange * This,
    /* [in] */ VARIANT What,
    /* [in] */ VARIANT Replacement,
    /* [optional][in] */ VARIANT LookAt,
    /* [optional][in] */ VARIANT SearchOrder,
    /* [optional][in] */ VARIANT MatchCase,
    /* [optional][in] */ VARIANT MatchByte,
    /* [optional][in] */ VARIANT SearchFormat,
    /* [optional][in] */ VARIANT ReplaceFormat,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB IRange_Replace_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IRange_get_Resize_Proxy( 
    IRange * This,
    /* [optional][in] */ VARIANT RowSize,
    /* [optional][in] */ VARIANT ColumnSize,
    /* [retval][out] */ Range	**RHS);


void __RPC_STUB IRange_get_Resize_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IRange_get_Row_Proxy( 
    IRange * This,
    /* [retval][out] */ long *RHS);


void __RPC_STUB IRange_get_Row_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IRange_RowDifferences_Proxy( 
    IRange * This,
    /* [in] */ VARIANT Comparison,
    /* [retval][out] */ Range	**RHS);


void __RPC_STUB IRange_RowDifferences_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IRange_get_RowHeight_Proxy( 
    IRange * This,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB IRange_get_RowHeight_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT __stdcall IRange_put_RowHeight_Proxy( 
    IRange * This,
    /* [in] */ VARIANT RHS);


void __RPC_STUB IRange_put_RowHeight_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IRange_get_Rows_Proxy( 
    IRange * This,
    /* [retval][out] */ Range	**RHS);


void __RPC_STUB IRange_get_Rows_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IRange_Run_Proxy( 
    IRange * This,
    /* [optional][in] */ VARIANT Arg1,
    /* [optional][in] */ VARIANT Arg2,
    /* [optional][in] */ VARIANT Arg3,
    /* [optional][in] */ VARIANT Arg4,
    /* [optional][in] */ VARIANT Arg5,
    /* [optional][in] */ VARIANT Arg6,
    /* [optional][in] */ VARIANT Arg7,
    /* [optional][in] */ VARIANT Arg8,
    /* [optional][in] */ VARIANT Arg9,
    /* [optional][in] */ VARIANT Arg10,
    /* [optional][in] */ VARIANT Arg11,
    /* [optional][in] */ VARIANT Arg12,
    /* [optional][in] */ VARIANT Arg13,
    /* [optional][in] */ VARIANT Arg14,
    /* [optional][in] */ VARIANT Arg15,
    /* [optional][in] */ VARIANT Arg16,
    /* [optional][in] */ VARIANT Arg17,
    /* [optional][in] */ VARIANT Arg18,
    /* [optional][in] */ VARIANT Arg19,
    /* [optional][in] */ VARIANT Arg20,
    /* [optional][in] */ VARIANT Arg21,
    /* [optional][in] */ VARIANT Arg22,
    /* [optional][in] */ VARIANT Arg23,
    /* [optional][in] */ VARIANT Arg24,
    /* [optional][in] */ VARIANT Arg25,
    /* [optional][in] */ VARIANT Arg26,
    /* [optional][in] */ VARIANT Arg27,
    /* [optional][in] */ VARIANT Arg28,
    /* [optional][in] */ VARIANT Arg29,
    /* [optional][in] */ VARIANT Arg30,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB IRange_Run_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IRange_Select_Proxy( 
    IRange * This,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB IRange_Select_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IRange_Show_Proxy( 
    IRange * This,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB IRange_Show_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IRange_ShowDependents_Proxy( 
    IRange * This,
    /* [optional][in] */ VARIANT Remove,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB IRange_ShowDependents_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IRange_get_ShowDetail_Proxy( 
    IRange * This,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB IRange_get_ShowDetail_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT __stdcall IRange_put_ShowDetail_Proxy( 
    IRange * This,
    /* [in] */ VARIANT RHS);


void __RPC_STUB IRange_put_ShowDetail_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IRange_ShowErrors_Proxy( 
    IRange * This,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB IRange_ShowErrors_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IRange_ShowPrecedents_Proxy( 
    IRange * This,
    /* [optional][in] */ VARIANT Remove,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB IRange_ShowPrecedents_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IRange_get_ShrinkToFit_Proxy( 
    IRange * This,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB IRange_get_ShrinkToFit_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT __stdcall IRange_put_ShrinkToFit_Proxy( 
    IRange * This,
    /* [in] */ VARIANT RHS);


void __RPC_STUB IRange_put_ShrinkToFit_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IRange_Sort_Proxy( 
    IRange * This,
    /* [optional][in] */ VARIANT Key1,
    /* [defaultvalue][optional][in] */ XlSortOrder Order1,
    /* [optional][in] */ VARIANT Key2,
    /* [optional][in] */ VARIANT Type,
    /* [defaultvalue][optional][in] */ XlSortOrder Order2,
    /* [optional][in] */ VARIANT Key3,
    /* [defaultvalue][optional][in] */ XlSortOrder Order3,
    /* [defaultvalue][optional][in] */ XlYesNoGuess Header,
    /* [optional][in] */ VARIANT OrderCustom,
    /* [optional][in] */ VARIANT MatchCase,
    /* [defaultvalue][optional][in] */ XlSortOrientation Orientation,
    /* [defaultvalue][optional][in] */ XlSortMethod SortMethod,
    /* [defaultvalue][optional][in] */ XlSortDataOption DataOption1,
    /* [defaultvalue][optional][in] */ XlSortDataOption DataOption2,
    /* [defaultvalue][optional][in] */ XlSortDataOption DataOption3,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB IRange_Sort_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IRange_SortSpecial_Proxy( 
    IRange * This,
    /* [defaultvalue][optional][in] */ XlSortMethod SortMethod,
    /* [optional][in] */ VARIANT Key1,
    /* [defaultvalue][optional][in] */ XlSortOrder Order1,
    /* [optional][in] */ VARIANT Type,
    /* [optional][in] */ VARIANT Key2,
    /* [defaultvalue][optional][in] */ XlSortOrder Order2,
    /* [optional][in] */ VARIANT Key3,
    /* [defaultvalue][optional][in] */ XlSortOrder Order3,
    /* [defaultvalue][optional][in] */ XlYesNoGuess Header,
    /* [optional][in] */ VARIANT OrderCustom,
    /* [optional][in] */ VARIANT MatchCase,
    /* [defaultvalue][optional][in] */ XlSortOrientation Orientation,
    /* [defaultvalue][optional][in] */ XlSortDataOption DataOption1,
    /* [defaultvalue][optional][in] */ XlSortDataOption DataOption2,
    /* [defaultvalue][optional][in] */ XlSortDataOption DataOption3,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB IRange_SortSpecial_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IRange_get_SoundNote_Proxy( 
    IRange * This,
    /* [retval][out] */ SoundNote	**RHS);


void __RPC_STUB IRange_get_SoundNote_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IRange_SpecialCells_Proxy( 
    IRange * This,
    /* [in] */ XlCellType Type,
    /* [optional][in] */ VARIANT Value,
    /* [retval][out] */ Range	**RHS);


void __RPC_STUB IRange_SpecialCells_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IRange_get_Style_Proxy( 
    IRange * This,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB IRange_get_Style_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT __stdcall IRange_put_Style_Proxy( 
    IRange * This,
    /* [in] */ VARIANT RHS);


void __RPC_STUB IRange_put_Style_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IRange_SubscribeTo_Proxy( 
    IRange * This,
    /* [in] */ BSTR Edition,
    /* [defaultvalue][optional][in] */ XlSubscribeToFormat Format,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB IRange_SubscribeTo_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IRange_Subtotal_Proxy( 
    IRange * This,
    /* [in] */ long GroupBy,
    /* [in] */ XlConsolidationFunction Function,
    /* [in] */ VARIANT TotalList,
    /* [optional][in] */ VARIANT Replace,
    /* [optional][in] */ VARIANT PageBreaks,
    /* [defaultvalue][optional][in] */ XlSummaryRow SummaryBelowData,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB IRange_Subtotal_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IRange_get_Summary_Proxy( 
    IRange * This,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB IRange_get_Summary_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IRange_Table_Proxy( 
    IRange * This,
    /* [optional][in] */ VARIANT RowInput,
    /* [optional][in] */ VARIANT ColumnInput,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB IRange_Table_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IRange_get_Text_Proxy( 
    IRange * This,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB IRange_get_Text_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IRange_TextToColumns_Proxy( 
    IRange * This,
    /* [optional][in] */ VARIANT Destination,
    /* [defaultvalue][optional][in] */ XlTextParsingType DataType,
    /* [defaultvalue][optional][in] */ XlTextQualifier TextQualifier,
    /* [optional][in] */ VARIANT ConsecutiveDelimiter,
    /* [optional][in] */ VARIANT Tab,
    /* [optional][in] */ VARIANT Semicolon,
    /* [optional][in] */ VARIANT Comma,
    /* [optional][in] */ VARIANT Space,
    /* [optional][in] */ VARIANT Other,
    /* [optional][in] */ VARIANT OtherChar,
    /* [optional][in] */ VARIANT FieldInfo,
    /* [optional][in] */ VARIANT DecimalSeparator,
    /* [optional][in] */ VARIANT ThousandsSeparator,
    /* [optional][in] */ VARIANT TrailingMinusNumbers,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB IRange_TextToColumns_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IRange_get_Top_Proxy( 
    IRange * This,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB IRange_get_Top_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IRange_Ungroup_Proxy( 
    IRange * This,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB IRange_Ungroup_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IRange_get_UseStandardHeight_Proxy( 
    IRange * This,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB IRange_get_UseStandardHeight_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT __stdcall IRange_put_UseStandardHeight_Proxy( 
    IRange * This,
    /* [in] */ VARIANT RHS);


void __RPC_STUB IRange_put_UseStandardHeight_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IRange_get_UseStandardWidth_Proxy( 
    IRange * This,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB IRange_get_UseStandardWidth_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT __stdcall IRange_put_UseStandardWidth_Proxy( 
    IRange * This,
    /* [in] */ VARIANT RHS);


void __RPC_STUB IRange_put_UseStandardWidth_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IRange_get_Validation_Proxy( 
    IRange * This,
    /* [retval][out] */ Validation	**RHS);


void __RPC_STUB IRange_get_Validation_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IRange_get_Value_Proxy( 
    IRange * This,
    /* [optional][in] */ VARIANT RangeValueDataType,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB IRange_get_Value_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT __stdcall IRange_put_Value_Proxy( 
    IRange * This,
    /* [optional][in] */ VARIANT RangeValueDataType,
    /* [lcid][in] */ long lcid,
    /* [in] */ VARIANT RHS);


void __RPC_STUB IRange_put_Value_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IRange_get_Value2_Proxy( 
    IRange * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB IRange_get_Value2_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT __stdcall IRange_put_Value2_Proxy( 
    IRange * This,
    /* [lcid][in] */ long lcid,
    /* [in] */ VARIANT RHS);


void __RPC_STUB IRange_put_Value2_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IRange_get_VerticalAlignment_Proxy( 
    IRange * This,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB IRange_get_VerticalAlignment_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT __stdcall IRange_put_VerticalAlignment_Proxy( 
    IRange * This,
    /* [in] */ VARIANT RHS);


void __RPC_STUB IRange_put_VerticalAlignment_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IRange_get_Width_Proxy( 
    IRange * This,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB IRange_get_Width_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IRange_get_Worksheet_Proxy( 
    IRange * This,
    /* [retval][out] */ Worksheet	**RHS);


void __RPC_STUB IRange_get_Worksheet_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IRange_get_WrapText_Proxy( 
    IRange * This,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB IRange_get_WrapText_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT __stdcall IRange_put_WrapText_Proxy( 
    IRange * This,
    /* [in] */ VARIANT RHS);


void __RPC_STUB IRange_put_WrapText_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IRange_AddComment_Proxy( 
    IRange * This,
    /* [optional][in] */ VARIANT Text,
    /* [retval][out] */ Comment	**RHS);


void __RPC_STUB IRange_AddComment_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IRange_get_Comment_Proxy( 
    IRange * This,
    /* [retval][out] */ Comment	**RHS);


void __RPC_STUB IRange_get_Comment_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IRange_ClearComments_Proxy( 
    IRange * This);


void __RPC_STUB IRange_ClearComments_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IRange_get_Phonetic_Proxy( 
    IRange * This,
    /* [retval][out] */ Phonetic	**RHS);


void __RPC_STUB IRange_get_Phonetic_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IRange_get_FormatConditions_Proxy( 
    IRange * This,
    /* [retval][out] */ FormatConditions	**RHS);


void __RPC_STUB IRange_get_FormatConditions_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IRange_get_ReadingOrder_Proxy( 
    IRange * This,
    /* [retval][out] */ long *RHS);


void __RPC_STUB IRange_get_ReadingOrder_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT __stdcall IRange_put_ReadingOrder_Proxy( 
    IRange * This,
    /* [in] */ long RHS);


void __RPC_STUB IRange_put_ReadingOrder_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IRange_get_Hyperlinks_Proxy( 
    IRange * This,
    /* [retval][out] */ Hyperlinks	**RHS);


void __RPC_STUB IRange_get_Hyperlinks_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IRange_get_Phonetics_Proxy( 
    IRange * This,
    /* [retval][out] */ Phonetics	**RHS);


void __RPC_STUB IRange_get_Phonetics_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IRange_SetPhonetic_Proxy( 
    IRange * This);


void __RPC_STUB IRange_SetPhonetic_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IRange_get_ID_Proxy( 
    IRange * This,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB IRange_get_ID_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT __stdcall IRange_put_ID_Proxy( 
    IRange * This,
    /* [in] */ BSTR RHS);


void __RPC_STUB IRange_put_ID_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [custom][helpcontext][hidden][id] */ HRESULT __stdcall IRange__PrintOut_Proxy( 
    IRange * This,
    /* [optional][in] */ VARIANT From,
    /* [optional][in] */ VARIANT To,
    /* [optional][in] */ VARIANT Copies,
    /* [optional][in] */ VARIANT Preview,
    /* [optional][in] */ VARIANT ActivePrinter,
    /* [optional][in] */ VARIANT PrintToFile,
    /* [optional][in] */ VARIANT Collate,
    /* [optional][in] */ VARIANT PrToFileName,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB IRange__PrintOut_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IRange_get_PivotCell_Proxy( 
    IRange * This,
    /* [retval][out] */ PivotCell	**RHS);


void __RPC_STUB IRange_get_PivotCell_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IRange_Dirty_Proxy( 
    IRange * This);


void __RPC_STUB IRange_Dirty_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IRange_get_Errors_Proxy( 
    IRange * This,
    /* [retval][out] */ Errors	**RHS);


void __RPC_STUB IRange_get_Errors_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][propget][id] */ HRESULT __stdcall IRange_get_SmartTags_Proxy( 
    IRange * This,
    /* [retval][out] */ SmartTags	**RHS);


void __RPC_STUB IRange_get_SmartTags_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IRange_Speak_Proxy( 
    IRange * This,
    /* [optional][in] */ VARIANT SpeakDirection,
    /* [optional][in] */ VARIANT SpeakFormulas);


void __RPC_STUB IRange_Speak_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IRange_PasteSpecial_Proxy( 
    IRange * This,
    /* [defaultvalue][optional][in] */ XlPasteType Paste,
    /* [defaultvalue][optional][in] */ XlPasteSpecialOperation Operation,
    /* [optional][in] */ VARIANT SkipBlanks,
    /* [optional][in] */ VARIANT Transpose,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB IRange_PasteSpecial_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IRange_get_AllowEdit_Proxy( 
    IRange * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB IRange_get_AllowEdit_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IRange_get_ListObject_Proxy( 
    IRange * This,
    /* [retval][out] */ ListObject	**RHS);


void __RPC_STUB IRange_get_ListObject_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IRange_get_XPath_Proxy( 
    IRange * This,
    /* [retval][out] */ XPath	**RHS);


void __RPC_STUB IRange_get_XPath_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IRange_get_ServerActions_Proxy( 
    IRange * This,
    /* [retval][out] */ Actions	**RHS);


void __RPC_STUB IRange_get_ServerActions_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IRange_RemoveDuplicates_Proxy( 
    IRange * This,
    /* [optional][in] */ VARIANT Columns,
    /* [defaultvalue][optional][in] */ XlYesNoGuess Header);


void __RPC_STUB IRange_RemoveDuplicates_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [custom][helpcontext][id] */ HRESULT __stdcall IRange_PrintOut_Proxy( 
    IRange * This,
    /* [optional][in] */ VARIANT From,
    /* [optional][in] */ VARIANT To,
    /* [optional][in] */ VARIANT Copies,
    /* [optional][in] */ VARIANT Preview,
    /* [optional][in] */ VARIANT ActivePrinter,
    /* [optional][in] */ VARIANT PrintToFile,
    /* [optional][in] */ VARIANT Collate,
    /* [optional][in] */ VARIANT PrToFileName,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB IRange_PrintOut_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IRange_get_MDX_Proxy( 
    IRange * This,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB IRange_get_MDX_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IRange_ExportAsFixedFormat_Proxy( 
    IRange * This,
    /* [in] */ XlFixedFormatType Type,
    /* [optional][in] */ VARIANT Filename,
    /* [optional][in] */ VARIANT Quality,
    /* [optional][in] */ VARIANT IncludeDocProperties,
    /* [optional][in] */ VARIANT IgnorePrintAreas,
    /* [optional][in] */ VARIANT From,
    /* [optional][in] */ VARIANT To,
    /* [optional][in] */ VARIANT OpenAfterPublish,
    /* [optional][in] */ VARIANT FixedFormatExtClassPtr);


void __RPC_STUB IRange_ExportAsFixedFormat_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IRange_get_CountLarge_Proxy( 
    IRange * This,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB IRange_get_CountLarge_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IRange_CalculateRowMajorOrder_Proxy( 
    IRange * This,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB IRange_CalculateRowMajorOrder_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IRange_get_SparklineGroups_Proxy( 
    IRange * This,
    /* [retval][out] */ SparklineGroups	**RHS);


void __RPC_STUB IRange_get_SparklineGroups_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IRange_ClearHyperlinks_Proxy( 
    IRange * This);


void __RPC_STUB IRange_ClearHyperlinks_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IRange_get_DisplayFormat_Proxy( 
    IRange * This,
    /* [retval][out] */ DisplayFormat	**RHS);


void __RPC_STUB IRange_get_DisplayFormat_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [custom][helpcontext][id] */ HRESULT __stdcall IRange_BorderAround_Proxy( 
    IRange * This,
    /* [optional][in] */ VARIANT LineStyle,
    /* [defaultvalue][optional][in] */ XlBorderWeight Weight,
    /* [defaultvalue][optional][in] */ XlColorIndex ColorIndex,
    /* [optional][in] */ VARIANT Color,
    /* [optional][in] */ VARIANT ThemeColor,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB IRange_BorderAround_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IRange_AllocateChanges_Proxy( 
    IRange * This);


void __RPC_STUB IRange_AllocateChanges_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IRange_DiscardChanges_Proxy( 
    IRange * This);


void __RPC_STUB IRange_DiscardChanges_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IRange_FlashFill_Proxy( 
    IRange * This);


void __RPC_STUB IRange_FlashFill_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);



#endif 	/* __IRange_INTERFACE_DEFINED__ */


#ifndef __IChartEvents_INTERFACE_DEFINED__
#define __IChartEvents_INTERFACE_DEFINED__

/* interface IChartEvents */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IChartEvents;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002440F-0001-0000-C000-000000000046")
    IChartEvents : public IDispatch
    {
    public:
        virtual /* [helpcontext][id] */ HRESULT __stdcall Activate( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Deactivate( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Resize( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall MouseDown( 
            /* [in] */ long Button,
            /* [in] */ long Shift,
            /* [in] */ long x,
            /* [in] */ long y) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall MouseUp( 
            /* [in] */ long Button,
            /* [in] */ long Shift,
            /* [in] */ long x,
            /* [in] */ long y) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall MouseMove( 
            /* [in] */ long Button,
            /* [in] */ long Shift,
            /* [in] */ long x,
            /* [in] */ long y) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall BeforeRightClick( 
            /* [out][in] */ VARIANT_BOOL *Cancel) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall DragPlot( void) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall DragOver( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall BeforeDoubleClick( 
            /* [in] */ long ElementID,
            /* [in] */ long Arg1,
            /* [in] */ long Arg2,
            /* [out][in] */ VARIANT_BOOL *Cancel) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [in] */ long ElementID,
            /* [in] */ long Arg1,
            /* [in] */ long Arg2) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SeriesChange( 
            /* [in] */ long SeriesIndex,
            /* [in] */ long PointIndex) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Calculate( void) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IChartEventsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IChartEvents * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IChartEvents * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IChartEvents * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IChartEvents * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IChartEvents * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IChartEvents * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IChartEvents * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Activate )( 
            IChartEvents * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Deactivate )( 
            IChartEvents * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Resize )( 
            IChartEvents * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *MouseDown )( 
            IChartEvents * This,
            /* [in] */ long Button,
            /* [in] */ long Shift,
            /* [in] */ long x,
            /* [in] */ long y);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *MouseUp )( 
            IChartEvents * This,
            /* [in] */ long Button,
            /* [in] */ long Shift,
            /* [in] */ long x,
            /* [in] */ long y);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *MouseMove )( 
            IChartEvents * This,
            /* [in] */ long Button,
            /* [in] */ long Shift,
            /* [in] */ long x,
            /* [in] */ long y);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *BeforeRightClick )( 
            IChartEvents * This,
            /* [out][in] */ VARIANT_BOOL *Cancel);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *DragPlot )( 
            IChartEvents * This);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *DragOver )( 
            IChartEvents * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *BeforeDoubleClick )( 
            IChartEvents * This,
            /* [in] */ long ElementID,
            /* [in] */ long Arg1,
            /* [in] */ long Arg2,
            /* [out][in] */ VARIANT_BOOL *Cancel);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            IChartEvents * This,
            /* [in] */ long ElementID,
            /* [in] */ long Arg1,
            /* [in] */ long Arg2);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SeriesChange )( 
            IChartEvents * This,
            /* [in] */ long SeriesIndex,
            /* [in] */ long PointIndex);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Calculate )( 
            IChartEvents * This);
        
        END_INTERFACE
    } IChartEventsVtbl;

    interface IChartEvents
    {
        CONST_VTBL struct IChartEventsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IChartEvents_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IChartEvents_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IChartEvents_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IChartEvents_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IChartEvents_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IChartEvents_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IChartEvents_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IChartEvents_Activate(This)	\
    ( (This)->lpVtbl -> Activate(This) ) 

#define IChartEvents_Deactivate(This)	\
    ( (This)->lpVtbl -> Deactivate(This) ) 

#define IChartEvents_Resize(This)	\
    ( (This)->lpVtbl -> Resize(This) ) 

#define IChartEvents_MouseDown(This,Button,Shift,x,y)	\
    ( (This)->lpVtbl -> MouseDown(This,Button,Shift,x,y) ) 

#define IChartEvents_MouseUp(This,Button,Shift,x,y)	\
    ( (This)->lpVtbl -> MouseUp(This,Button,Shift,x,y) ) 

#define IChartEvents_MouseMove(This,Button,Shift,x,y)	\
    ( (This)->lpVtbl -> MouseMove(This,Button,Shift,x,y) ) 

#define IChartEvents_BeforeRightClick(This,Cancel)	\
    ( (This)->lpVtbl -> BeforeRightClick(This,Cancel) ) 

#define IChartEvents_DragPlot(This)	\
    ( (This)->lpVtbl -> DragPlot(This) ) 

#define IChartEvents_DragOver(This)	\
    ( (This)->lpVtbl -> DragOver(This) ) 

#define IChartEvents_BeforeDoubleClick(This,ElementID,Arg1,Arg2,Cancel)	\
    ( (This)->lpVtbl -> BeforeDoubleClick(This,ElementID,Arg1,Arg2,Cancel) ) 

#define IChartEvents_Select(This,ElementID,Arg1,Arg2)	\
    ( (This)->lpVtbl -> Select(This,ElementID,Arg1,Arg2) ) 

#define IChartEvents_SeriesChange(This,SeriesIndex,PointIndex)	\
    ( (This)->lpVtbl -> SeriesChange(This,SeriesIndex,PointIndex) ) 

#define IChartEvents_Calculate(This)	\
    ( (This)->lpVtbl -> Calculate(This) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IChartEvents_INTERFACE_DEFINED__ */


#ifndef ___Chart_INTERFACE_DEFINED__
#define ___Chart_INTERFACE_DEFINED__

/* interface _Chart */
/* [object][oleautomation][nonextensible][dual][helpcontext][uuid] */ 


EXTERN_C const IID IID__Chart;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000208D6-0000-0000-C000-000000000046")
    _Chart : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Activate( 
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Copy( 
            /* [optional][in] */ VARIANT Before,
            /* [optional][in] */ VARIANT After,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Delete( 
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_CodeName( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get__CodeName( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put__CodeName( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Index( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Move( 
            /* [optional][in] */ VARIANT Before,
            /* [optional][in] */ VARIANT After,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_Name( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Next( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_OnDoubleClick( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE put_OnDoubleClick( 
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_OnSheetActivate( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE put_OnSheetActivate( 
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_OnSheetDeactivate( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE put_OnSheetDeactivate( 
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_PageSetup( 
            /* [retval][out] */ PageSetup	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Previous( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [custom][helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE __PrintOut( 
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE PrintPreview( 
            /* [optional][in] */ VARIANT EnableChanges,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE _Protect( 
            /* [optional][in] */ VARIANT Password,
            /* [optional][in] */ VARIANT DrawingObjects,
            /* [optional][in] */ VARIANT Contents,
            /* [optional][in] */ VARIANT Scenarios,
            /* [optional][in] */ VARIANT UserInterfaceOnly,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ProtectContents( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ProtectDrawingObjects( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ProtectionMode( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [hidden][restricted][id] */ void STDMETHODCALLTYPE _Dummy23( void) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE _SaveAs( 
            /* [in] */ BSTR Filename,
            /* [optional][in] */ VARIANT FileFormat,
            /* [optional][in] */ VARIANT Password,
            /* [optional][in] */ VARIANT WriteResPassword,
            /* [optional][in] */ VARIANT ReadOnlyRecommended,
            /* [optional][in] */ VARIANT CreateBackup,
            /* [optional][in] */ VARIANT AddToMru,
            /* [optional][in] */ VARIANT TextCodepage,
            /* [optional][in] */ VARIANT TextVisualLayout,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Select( 
            /* [optional][in] */ VARIANT Replace,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Unprotect( 
            /* [optional][in] */ VARIANT Password,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Visible( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ XlSheetVisibility *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_Visible( 
            /* [lcid][in] */ long lcid,
            /* [in] */ XlSheetVisibility RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Shapes( 
            /* [retval][out] */ Shapes	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE _ApplyDataLabels( 
            /* [defaultvalue][optional][in] */ XlDataLabelsType Type,
            /* [optional][in] */ VARIANT LegendKey,
            /* [optional][in] */ VARIANT AutoText,
            /* [optional][in] */ VARIANT HasLeaderLines,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE Arcs( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_Area3DGroup( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ ChartGroup	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE AreaGroups( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE AutoFormat( 
            /* [in] */ long Gallery,
            /* [optional][in] */ VARIANT Format) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_AutoScaling( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_AutoScaling( 
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Axes( 
            /* [optional][in] */ VARIANT Type,
            /* [defaultvalue][optional][in] */ XlAxisGroup AxisGroup,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE SetBackgroundPicture( 
            /* [in] */ BSTR Filename) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_Bar3DGroup( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ ChartGroup	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE BarGroups( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE Buttons( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ChartArea( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ ChartArea	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE ChartGroups( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE ChartObjects( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ChartTitle( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ ChartTitle	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE ChartWizard( 
            /* [optional][in] */ VARIANT Source,
            /* [optional][in] */ VARIANT Gallery,
            /* [optional][in] */ VARIANT Format,
            /* [optional][in] */ VARIANT PlotBy,
            /* [optional][in] */ VARIANT CategoryLabels,
            /* [optional][in] */ VARIANT SeriesLabels,
            /* [optional][in] */ VARIANT HasLegend,
            /* [optional][in] */ VARIANT Title,
            /* [optional][in] */ VARIANT CategoryTitle,
            /* [optional][in] */ VARIANT ValueTitle,
            /* [optional][in] */ VARIANT ExtraTitle,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE CheckBoxes( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE CheckSpelling( 
            /* [optional][in] */ VARIANT CustomDictionary,
            /* [optional][in] */ VARIANT IgnoreUppercase,
            /* [optional][in] */ VARIANT AlwaysSuggest,
            /* [optional][in] */ VARIANT SpellLang,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_Column3DGroup( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ ChartGroup	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE ColumnGroups( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE CopyPicture( 
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [defaultvalue][optional][in] */ XlPictureAppearance Size,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_Corners( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ Corners	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE CreatePublisher( 
            /* [optional][in] */ VARIANT Edition,
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlPictureAppearance Size,
            /* [optional][in] */ VARIANT ContainsPICT,
            /* [optional][in] */ VARIANT ContainsBIFF,
            /* [optional][in] */ VARIANT ContainsRTF,
            /* [optional][in] */ VARIANT ContainsVALU,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_DataTable( 
            /* [retval][out] */ DataTable	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_DepthPercent( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_DepthPercent( 
            /* [lcid][in] */ long lcid,
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE Deselect( 
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_DisplayBlanksAs( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ XlDisplayBlanksAs *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_DisplayBlanksAs( 
            /* [lcid][in] */ long lcid,
            /* [in] */ XlDisplayBlanksAs RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE DoughnutGroups( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE Drawings( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE DrawingObjects( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE DropDowns( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Elevation( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_Elevation( 
            /* [lcid][in] */ long lcid,
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Evaluate( 
            /* [in] */ VARIANT Name,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Evaluate( 
            /* [in] */ VARIANT Name,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Floor( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ Floor	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_GapDepth( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_GapDepth( 
            /* [lcid][in] */ long lcid,
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE GroupBoxes( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE GroupObjects( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_HasAxis( 
            /* [optional][in] */ VARIANT Index1,
            /* [optional][in] */ VARIANT Index2,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_HasAxis( 
            /* [optional][in] */ VARIANT Index1,
            /* [optional][in] */ VARIANT Index2,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_HasDataTable( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_HasDataTable( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_HasLegend( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_HasLegend( 
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_HasTitle( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_HasTitle( 
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_HeightPercent( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_HeightPercent( 
            /* [lcid][in] */ long lcid,
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Hyperlinks( 
            /* [retval][out] */ Hyperlinks	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE Labels( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Legend( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ Legend	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_Line3DGroup( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ ChartGroup	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE LineGroups( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE Lines( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE ListBoxes( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Location( 
            /* [in] */ XlChartLocation Where,
            /* [optional][in] */ VARIANT Name,
            /* [retval][out] */ Chart	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE OLEObjects( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE OptionButtons( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE Ovals( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Paste( 
            /* [optional][in] */ VARIANT Type,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Perspective( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_Perspective( 
            /* [lcid][in] */ long lcid,
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE Pictures( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_Pie3DGroup( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ ChartGroup	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE PieGroups( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_PlotArea( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ PlotArea	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_PlotVisibleOnly( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_PlotVisibleOnly( 
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE RadarGroups( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE Rectangles( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_RightAngleAxes( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_RightAngleAxes( 
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Rotation( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_Rotation( 
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE ScrollBars( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE SeriesCollection( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_SizeWithWindow( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE put_SizeWithWindow( 
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_ShowWindow( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE put_ShowWindow( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE Spinners( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_SubType( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE put_SubType( 
            /* [lcid][in] */ long lcid,
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_SurfaceGroup( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ ChartGroup	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE TextBoxes( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_Type( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE put_Type( 
            /* [lcid][in] */ long lcid,
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ChartType( 
            /* [retval][out] */ XlChartType *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_ChartType( 
            /* [in] */ XlChartType RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE ApplyCustomType( 
            /* [in] */ XlChartType ChartType,
            /* [optional][in] */ VARIANT TypeName) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Walls( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ Walls	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_WallsAndGridlines2D( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE put_WallsAndGridlines2D( 
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE XYGroups( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_BarShape( 
            /* [retval][out] */ XlBarShape *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_BarShape( 
            /* [in] */ XlBarShape RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_PlotBy( 
            /* [retval][out] */ XlRowCol *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_PlotBy( 
            /* [in] */ XlRowCol RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE CopyChartBuild( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ProtectFormatting( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_ProtectFormatting( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ProtectData( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_ProtectData( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_ProtectGoalSeek( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE put_ProtectGoalSeek( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ProtectSelection( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_ProtectSelection( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE GetChartElement( 
            /* [in] */ long x,
            /* [in] */ long y,
            /* [in] */ long *ElementID,
            /* [in] */ long *Arg1,
            /* [in] */ long *Arg2) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE SetSourceData( 
            /* [in] */ Range	*Source,
            /* [optional][in] */ VARIANT PlotBy) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Export( 
            /* [in] */ BSTR Filename,
            /* [optional][in] */ VARIANT FilterName,
            /* [optional][in] */ VARIANT Interactive,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Refresh( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_PivotLayout( 
            /* [retval][out] */ PivotLayout	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_HasPivotFields( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE put_HasPivotFields( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_Scripts( 
            /* [retval][out] */ /* external definition not present */ Scripts **RHS) = 0;
        
        virtual /* [custom][helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE _PrintOut( 
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate,
            /* [optional][in] */ VARIANT PrToFileName,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Tab( 
            /* [retval][out] */ Tab	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_MailEnvelope( 
            /* [retval][out] */ /* external definition not present */ MsoEnvelope **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE ApplyDataLabels( 
            /* [defaultvalue][optional][in] */ XlDataLabelsType Type,
            /* [optional][in] */ VARIANT LegendKey,
            /* [optional][in] */ VARIANT AutoText,
            /* [optional][in] */ VARIANT HasLeaderLines,
            /* [optional][in] */ VARIANT ShowSeriesName,
            /* [optional][in] */ VARIANT ShowCategoryName,
            /* [optional][in] */ VARIANT ShowValue,
            /* [optional][in] */ VARIANT ShowPercentage,
            /* [optional][in] */ VARIANT ShowBubbleSize,
            /* [optional][in] */ VARIANT Separator,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE SaveAs( 
            /* [in] */ BSTR Filename,
            /* [optional][in] */ VARIANT FileFormat,
            /* [optional][in] */ VARIANT Password,
            /* [optional][in] */ VARIANT WriteResPassword,
            /* [optional][in] */ VARIANT ReadOnlyRecommended,
            /* [optional][in] */ VARIANT CreateBackup,
            /* [optional][in] */ VARIANT AddToMru,
            /* [optional][in] */ VARIANT TextCodepage,
            /* [optional][in] */ VARIANT TextVisualLayout,
            /* [optional][in] */ VARIANT Local) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Protect( 
            /* [optional][in] */ VARIANT Password,
            /* [optional][in] */ VARIANT DrawingObjects,
            /* [optional][in] */ VARIANT Contents,
            /* [optional][in] */ VARIANT Scenarios,
            /* [optional][in] */ VARIANT UserInterfaceOnly) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE ApplyLayout( 
            /* [in] */ long Layout,
            /* [optional][in] */ VARIANT ChartType) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE SetElement( 
            /* [in] */ MsoChartElementType Element) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ShowDataLabelsOverMaximum( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_ShowDataLabelsOverMaximum( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_SideWall( 
            /* [retval][out] */ Walls	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_BackWall( 
            /* [retval][out] */ Walls	**RHS) = 0;
        
        virtual /* [custom][helpcontext][id] */ HRESULT STDMETHODCALLTYPE PrintOut( 
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate,
            /* [optional][in] */ VARIANT PrToFileName,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE ApplyChartTemplate( 
            /* [in] */ BSTR Filename) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE SaveChartTemplate( 
            /* [in] */ BSTR Filename) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE SetDefaultChart( 
            /* [in] */ VARIANT Name) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE ExportAsFixedFormat( 
            /* [in] */ XlFixedFormatType Type,
            /* [optional][in] */ VARIANT Filename,
            /* [optional][in] */ VARIANT Quality,
            /* [optional][in] */ VARIANT IncludeDocProperties,
            /* [optional][in] */ VARIANT IgnorePrintAreas,
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT OpenAfterPublish,
            /* [optional][in] */ VARIANT FixedFormatExtClassPtr) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ChartStyle( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_ChartStyle( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE ClearToMatchStyle( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_PrintedCommentPages( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_Dummy24( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE put_Dummy24( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_Dummy25( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE put_Dummy25( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ShowReportFilterFieldButtons( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_ShowReportFilterFieldButtons( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ShowLegendFieldButtons( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_ShowLegendFieldButtons( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ShowAxisFieldButtons( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_ShowAxisFieldButtons( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ShowValueFieldButtons( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_ShowValueFieldButtons( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ShowAllFieldButtons( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_ShowAllFieldButtons( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE FullSeriesCollection( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_CategoryLabelLevel( 
            /* [retval][out] */ XlCategoryLabelLevel *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_CategoryLabelLevel( 
            /* [in] */ XlCategoryLabelLevel RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_SeriesNameLevel( 
            /* [retval][out] */ XlSeriesNameLevel *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_SeriesNameLevel( 
            /* [in] */ XlSeriesNameLevel RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_HasHiddenContent( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE DeleteHiddenContent( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ChartColor( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_ChartColor( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE ClearToMatchColorStyle( void) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct _ChartVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            _Chart * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            _Chart * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            _Chart * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            _Chart * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            _Chart * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            _Chart * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            _Chart * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Application )( 
            _Chart * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Creator )( 
            _Chart * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Parent )( 
            _Chart * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Activate )( 
            _Chart * This,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Copy )( 
            _Chart * This,
            /* [optional][in] */ VARIANT Before,
            /* [optional][in] */ VARIANT After,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Delete )( 
            _Chart * This,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_CodeName )( 
            _Chart * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get__CodeName )( 
            _Chart * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put__CodeName )( 
            _Chart * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Index )( 
            _Chart * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Move )( 
            _Chart * This,
            /* [optional][in] */ VARIANT Before,
            /* [optional][in] */ VARIANT After,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Name )( 
            _Chart * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Name )( 
            _Chart * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Next )( 
            _Chart * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_OnDoubleClick )( 
            _Chart * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_OnDoubleClick )( 
            _Chart * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_OnSheetActivate )( 
            _Chart * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_OnSheetActivate )( 
            _Chart * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_OnSheetDeactivate )( 
            _Chart * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_OnSheetDeactivate )( 
            _Chart * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_PageSetup )( 
            _Chart * This,
            /* [retval][out] */ PageSetup	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Previous )( 
            _Chart * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [custom][helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *__PrintOut )( 
            _Chart * This,
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *PrintPreview )( 
            _Chart * This,
            /* [optional][in] */ VARIANT EnableChanges,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *_Protect )( 
            _Chart * This,
            /* [optional][in] */ VARIANT Password,
            /* [optional][in] */ VARIANT DrawingObjects,
            /* [optional][in] */ VARIANT Contents,
            /* [optional][in] */ VARIANT Scenarios,
            /* [optional][in] */ VARIANT UserInterfaceOnly,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ProtectContents )( 
            _Chart * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ProtectDrawingObjects )( 
            _Chart * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ProtectionMode )( 
            _Chart * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [hidden][restricted][id] */ void ( STDMETHODCALLTYPE *_Dummy23 )( 
            _Chart * This);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *_SaveAs )( 
            _Chart * This,
            /* [in] */ BSTR Filename,
            /* [optional][in] */ VARIANT FileFormat,
            /* [optional][in] */ VARIANT Password,
            /* [optional][in] */ VARIANT WriteResPassword,
            /* [optional][in] */ VARIANT ReadOnlyRecommended,
            /* [optional][in] */ VARIANT CreateBackup,
            /* [optional][in] */ VARIANT AddToMru,
            /* [optional][in] */ VARIANT TextCodepage,
            /* [optional][in] */ VARIANT TextVisualLayout,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Select )( 
            _Chart * This,
            /* [optional][in] */ VARIANT Replace,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Unprotect )( 
            _Chart * This,
            /* [optional][in] */ VARIANT Password,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Visible )( 
            _Chart * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ XlSheetVisibility *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Visible )( 
            _Chart * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ XlSheetVisibility RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Shapes )( 
            _Chart * This,
            /* [retval][out] */ Shapes	**RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *_ApplyDataLabels )( 
            _Chart * This,
            /* [defaultvalue][optional][in] */ XlDataLabelsType Type,
            /* [optional][in] */ VARIANT LegendKey,
            /* [optional][in] */ VARIANT AutoText,
            /* [optional][in] */ VARIANT HasLeaderLines,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *Arcs )( 
            _Chart * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Area3DGroup )( 
            _Chart * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ ChartGroup	**RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *AreaGroups )( 
            _Chart * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *AutoFormat )( 
            _Chart * This,
            /* [in] */ long Gallery,
            /* [optional][in] */ VARIANT Format);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_AutoScaling )( 
            _Chart * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_AutoScaling )( 
            _Chart * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Axes )( 
            _Chart * This,
            /* [optional][in] */ VARIANT Type,
            /* [defaultvalue][optional][in] */ XlAxisGroup AxisGroup,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *SetBackgroundPicture )( 
            _Chart * This,
            /* [in] */ BSTR Filename);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Bar3DGroup )( 
            _Chart * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ ChartGroup	**RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *BarGroups )( 
            _Chart * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *Buttons )( 
            _Chart * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ChartArea )( 
            _Chart * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ ChartArea	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *ChartGroups )( 
            _Chart * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *ChartObjects )( 
            _Chart * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ChartTitle )( 
            _Chart * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ ChartTitle	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *ChartWizard )( 
            _Chart * This,
            /* [optional][in] */ VARIANT Source,
            /* [optional][in] */ VARIANT Gallery,
            /* [optional][in] */ VARIANT Format,
            /* [optional][in] */ VARIANT PlotBy,
            /* [optional][in] */ VARIANT CategoryLabels,
            /* [optional][in] */ VARIANT SeriesLabels,
            /* [optional][in] */ VARIANT HasLegend,
            /* [optional][in] */ VARIANT Title,
            /* [optional][in] */ VARIANT CategoryTitle,
            /* [optional][in] */ VARIANT ValueTitle,
            /* [optional][in] */ VARIANT ExtraTitle,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *CheckBoxes )( 
            _Chart * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *CheckSpelling )( 
            _Chart * This,
            /* [optional][in] */ VARIANT CustomDictionary,
            /* [optional][in] */ VARIANT IgnoreUppercase,
            /* [optional][in] */ VARIANT AlwaysSuggest,
            /* [optional][in] */ VARIANT SpellLang,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Column3DGroup )( 
            _Chart * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ ChartGroup	**RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *ColumnGroups )( 
            _Chart * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *CopyPicture )( 
            _Chart * This,
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [defaultvalue][optional][in] */ XlPictureAppearance Size,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Corners )( 
            _Chart * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ Corners	**RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *CreatePublisher )( 
            _Chart * This,
            /* [optional][in] */ VARIANT Edition,
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlPictureAppearance Size,
            /* [optional][in] */ VARIANT ContainsPICT,
            /* [optional][in] */ VARIANT ContainsBIFF,
            /* [optional][in] */ VARIANT ContainsRTF,
            /* [optional][in] */ VARIANT ContainsVALU,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_DataTable )( 
            _Chart * This,
            /* [retval][out] */ DataTable	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_DepthPercent )( 
            _Chart * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_DepthPercent )( 
            _Chart * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ long RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *Deselect )( 
            _Chart * This,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_DisplayBlanksAs )( 
            _Chart * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ XlDisplayBlanksAs *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_DisplayBlanksAs )( 
            _Chart * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ XlDisplayBlanksAs RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *DoughnutGroups )( 
            _Chart * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *Drawings )( 
            _Chart * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *DrawingObjects )( 
            _Chart * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *DropDowns )( 
            _Chart * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Elevation )( 
            _Chart * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Elevation )( 
            _Chart * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ long RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Evaluate )( 
            _Chart * This,
            /* [in] */ VARIANT Name,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *_Evaluate )( 
            _Chart * This,
            /* [in] */ VARIANT Name,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Floor )( 
            _Chart * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ Floor	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_GapDepth )( 
            _Chart * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_GapDepth )( 
            _Chart * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ long RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *GroupBoxes )( 
            _Chart * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *GroupObjects )( 
            _Chart * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_HasAxis )( 
            _Chart * This,
            /* [optional][in] */ VARIANT Index1,
            /* [optional][in] */ VARIANT Index2,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_HasAxis )( 
            _Chart * This,
            /* [optional][in] */ VARIANT Index1,
            /* [optional][in] */ VARIANT Index2,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_HasDataTable )( 
            _Chart * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_HasDataTable )( 
            _Chart * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_HasLegend )( 
            _Chart * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_HasLegend )( 
            _Chart * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_HasTitle )( 
            _Chart * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_HasTitle )( 
            _Chart * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_HeightPercent )( 
            _Chart * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_HeightPercent )( 
            _Chart * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Hyperlinks )( 
            _Chart * This,
            /* [retval][out] */ Hyperlinks	**RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *Labels )( 
            _Chart * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Legend )( 
            _Chart * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ Legend	**RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Line3DGroup )( 
            _Chart * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ ChartGroup	**RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *LineGroups )( 
            _Chart * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *Lines )( 
            _Chart * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *ListBoxes )( 
            _Chart * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Location )( 
            _Chart * This,
            /* [in] */ XlChartLocation Where,
            /* [optional][in] */ VARIANT Name,
            /* [retval][out] */ Chart	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *OLEObjects )( 
            _Chart * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *OptionButtons )( 
            _Chart * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *Ovals )( 
            _Chart * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Paste )( 
            _Chart * This,
            /* [optional][in] */ VARIANT Type,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Perspective )( 
            _Chart * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Perspective )( 
            _Chart * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ long RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *Pictures )( 
            _Chart * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Pie3DGroup )( 
            _Chart * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ ChartGroup	**RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *PieGroups )( 
            _Chart * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_PlotArea )( 
            _Chart * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ PlotArea	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_PlotVisibleOnly )( 
            _Chart * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_PlotVisibleOnly )( 
            _Chart * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *RadarGroups )( 
            _Chart * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *Rectangles )( 
            _Chart * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_RightAngleAxes )( 
            _Chart * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_RightAngleAxes )( 
            _Chart * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Rotation )( 
            _Chart * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Rotation )( 
            _Chart * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *ScrollBars )( 
            _Chart * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *SeriesCollection )( 
            _Chart * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_SizeWithWindow )( 
            _Chart * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_SizeWithWindow )( 
            _Chart * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ShowWindow )( 
            _Chart * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_ShowWindow )( 
            _Chart * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *Spinners )( 
            _Chart * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_SubType )( 
            _Chart * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_SubType )( 
            _Chart * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ long RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_SurfaceGroup )( 
            _Chart * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ ChartGroup	**RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *TextBoxes )( 
            _Chart * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Type )( 
            _Chart * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Type )( 
            _Chart * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ChartType )( 
            _Chart * This,
            /* [retval][out] */ XlChartType *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_ChartType )( 
            _Chart * This,
            /* [in] */ XlChartType RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *ApplyCustomType )( 
            _Chart * This,
            /* [in] */ XlChartType ChartType,
            /* [optional][in] */ VARIANT TypeName);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Walls )( 
            _Chart * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ Walls	**RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_WallsAndGridlines2D )( 
            _Chart * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_WallsAndGridlines2D )( 
            _Chart * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *XYGroups )( 
            _Chart * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_BarShape )( 
            _Chart * This,
            /* [retval][out] */ XlBarShape *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_BarShape )( 
            _Chart * This,
            /* [in] */ XlBarShape RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_PlotBy )( 
            _Chart * This,
            /* [retval][out] */ XlRowCol *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_PlotBy )( 
            _Chart * This,
            /* [in] */ XlRowCol RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *CopyChartBuild )( 
            _Chart * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ProtectFormatting )( 
            _Chart * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_ProtectFormatting )( 
            _Chart * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ProtectData )( 
            _Chart * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_ProtectData )( 
            _Chart * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ProtectGoalSeek )( 
            _Chart * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_ProtectGoalSeek )( 
            _Chart * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ProtectSelection )( 
            _Chart * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_ProtectSelection )( 
            _Chart * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *GetChartElement )( 
            _Chart * This,
            /* [in] */ long x,
            /* [in] */ long y,
            /* [in] */ long *ElementID,
            /* [in] */ long *Arg1,
            /* [in] */ long *Arg2);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *SetSourceData )( 
            _Chart * This,
            /* [in] */ Range	*Source,
            /* [optional][in] */ VARIANT PlotBy);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Export )( 
            _Chart * This,
            /* [in] */ BSTR Filename,
            /* [optional][in] */ VARIANT FilterName,
            /* [optional][in] */ VARIANT Interactive,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Refresh )( 
            _Chart * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_PivotLayout )( 
            _Chart * This,
            /* [retval][out] */ PivotLayout	**RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_HasPivotFields )( 
            _Chart * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_HasPivotFields )( 
            _Chart * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Scripts )( 
            _Chart * This,
            /* [retval][out] */ /* external definition not present */ Scripts **RHS);
        
        /* [custom][helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *_PrintOut )( 
            _Chart * This,
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate,
            /* [optional][in] */ VARIANT PrToFileName,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Tab )( 
            _Chart * This,
            /* [retval][out] */ Tab	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_MailEnvelope )( 
            _Chart * This,
            /* [retval][out] */ /* external definition not present */ MsoEnvelope **RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *ApplyDataLabels )( 
            _Chart * This,
            /* [defaultvalue][optional][in] */ XlDataLabelsType Type,
            /* [optional][in] */ VARIANT LegendKey,
            /* [optional][in] */ VARIANT AutoText,
            /* [optional][in] */ VARIANT HasLeaderLines,
            /* [optional][in] */ VARIANT ShowSeriesName,
            /* [optional][in] */ VARIANT ShowCategoryName,
            /* [optional][in] */ VARIANT ShowValue,
            /* [optional][in] */ VARIANT ShowPercentage,
            /* [optional][in] */ VARIANT ShowBubbleSize,
            /* [optional][in] */ VARIANT Separator,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *SaveAs )( 
            _Chart * This,
            /* [in] */ BSTR Filename,
            /* [optional][in] */ VARIANT FileFormat,
            /* [optional][in] */ VARIANT Password,
            /* [optional][in] */ VARIANT WriteResPassword,
            /* [optional][in] */ VARIANT ReadOnlyRecommended,
            /* [optional][in] */ VARIANT CreateBackup,
            /* [optional][in] */ VARIANT AddToMru,
            /* [optional][in] */ VARIANT TextCodepage,
            /* [optional][in] */ VARIANT TextVisualLayout,
            /* [optional][in] */ VARIANT Local);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Protect )( 
            _Chart * This,
            /* [optional][in] */ VARIANT Password,
            /* [optional][in] */ VARIANT DrawingObjects,
            /* [optional][in] */ VARIANT Contents,
            /* [optional][in] */ VARIANT Scenarios,
            /* [optional][in] */ VARIANT UserInterfaceOnly);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *ApplyLayout )( 
            _Chart * This,
            /* [in] */ long Layout,
            /* [optional][in] */ VARIANT ChartType);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *SetElement )( 
            _Chart * This,
            /* [in] */ MsoChartElementType Element);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ShowDataLabelsOverMaximum )( 
            _Chart * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_ShowDataLabelsOverMaximum )( 
            _Chart * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_SideWall )( 
            _Chart * This,
            /* [retval][out] */ Walls	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_BackWall )( 
            _Chart * This,
            /* [retval][out] */ Walls	**RHS);
        
        /* [custom][helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *PrintOut )( 
            _Chart * This,
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate,
            /* [optional][in] */ VARIANT PrToFileName,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *ApplyChartTemplate )( 
            _Chart * This,
            /* [in] */ BSTR Filename);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *SaveChartTemplate )( 
            _Chart * This,
            /* [in] */ BSTR Filename);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *SetDefaultChart )( 
            _Chart * This,
            /* [in] */ VARIANT Name);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *ExportAsFixedFormat )( 
            _Chart * This,
            /* [in] */ XlFixedFormatType Type,
            /* [optional][in] */ VARIANT Filename,
            /* [optional][in] */ VARIANT Quality,
            /* [optional][in] */ VARIANT IncludeDocProperties,
            /* [optional][in] */ VARIANT IgnorePrintAreas,
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT OpenAfterPublish,
            /* [optional][in] */ VARIANT FixedFormatExtClassPtr);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ChartStyle )( 
            _Chart * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_ChartStyle )( 
            _Chart * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *ClearToMatchStyle )( 
            _Chart * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_PrintedCommentPages )( 
            _Chart * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Dummy24 )( 
            _Chart * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Dummy24 )( 
            _Chart * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Dummy25 )( 
            _Chart * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Dummy25 )( 
            _Chart * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ShowReportFilterFieldButtons )( 
            _Chart * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_ShowReportFilterFieldButtons )( 
            _Chart * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ShowLegendFieldButtons )( 
            _Chart * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_ShowLegendFieldButtons )( 
            _Chart * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ShowAxisFieldButtons )( 
            _Chart * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_ShowAxisFieldButtons )( 
            _Chart * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ShowValueFieldButtons )( 
            _Chart * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_ShowValueFieldButtons )( 
            _Chart * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ShowAllFieldButtons )( 
            _Chart * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_ShowAllFieldButtons )( 
            _Chart * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *FullSeriesCollection )( 
            _Chart * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_CategoryLabelLevel )( 
            _Chart * This,
            /* [retval][out] */ XlCategoryLabelLevel *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_CategoryLabelLevel )( 
            _Chart * This,
            /* [in] */ XlCategoryLabelLevel RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_SeriesNameLevel )( 
            _Chart * This,
            /* [retval][out] */ XlSeriesNameLevel *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_SeriesNameLevel )( 
            _Chart * This,
            /* [in] */ XlSeriesNameLevel RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_HasHiddenContent )( 
            _Chart * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *DeleteHiddenContent )( 
            _Chart * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ChartColor )( 
            _Chart * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_ChartColor )( 
            _Chart * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *ClearToMatchColorStyle )( 
            _Chart * This);
        
        END_INTERFACE
    } _ChartVtbl;

    interface _Chart
    {
        CONST_VTBL struct _ChartVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define _Chart_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define _Chart_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define _Chart_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define _Chart_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define _Chart_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define _Chart_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define _Chart_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define _Chart_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define _Chart_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define _Chart_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define _Chart_Activate(This,lcid)	\
    ( (This)->lpVtbl -> Activate(This,lcid) ) 

#define _Chart_Copy(This,Before,After,lcid)	\
    ( (This)->lpVtbl -> Copy(This,Before,After,lcid) ) 

#define _Chart_Delete(This,lcid)	\
    ( (This)->lpVtbl -> Delete(This,lcid) ) 

#define _Chart_get_CodeName(This,RHS)	\
    ( (This)->lpVtbl -> get_CodeName(This,RHS) ) 

#define _Chart_get__CodeName(This,RHS)	\
    ( (This)->lpVtbl -> get__CodeName(This,RHS) ) 

#define _Chart_put__CodeName(This,RHS)	\
    ( (This)->lpVtbl -> put__CodeName(This,RHS) ) 

#define _Chart_get_Index(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_Index(This,lcid,RHS) ) 

#define _Chart_Move(This,Before,After,lcid)	\
    ( (This)->lpVtbl -> Move(This,Before,After,lcid) ) 

#define _Chart_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define _Chart_put_Name(This,RHS)	\
    ( (This)->lpVtbl -> put_Name(This,RHS) ) 

#define _Chart_get_Next(This,RHS)	\
    ( (This)->lpVtbl -> get_Next(This,RHS) ) 

#define _Chart_get_OnDoubleClick(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_OnDoubleClick(This,lcid,RHS) ) 

#define _Chart_put_OnDoubleClick(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_OnDoubleClick(This,lcid,RHS) ) 

#define _Chart_get_OnSheetActivate(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_OnSheetActivate(This,lcid,RHS) ) 

#define _Chart_put_OnSheetActivate(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_OnSheetActivate(This,lcid,RHS) ) 

#define _Chart_get_OnSheetDeactivate(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_OnSheetDeactivate(This,lcid,RHS) ) 

#define _Chart_put_OnSheetDeactivate(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_OnSheetDeactivate(This,lcid,RHS) ) 

#define _Chart_get_PageSetup(This,RHS)	\
    ( (This)->lpVtbl -> get_PageSetup(This,RHS) ) 

#define _Chart_get_Previous(This,RHS)	\
    ( (This)->lpVtbl -> get_Previous(This,RHS) ) 

#define _Chart___PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate,lcid)	\
    ( (This)->lpVtbl -> __PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate,lcid) ) 

#define _Chart_PrintPreview(This,EnableChanges,lcid)	\
    ( (This)->lpVtbl -> PrintPreview(This,EnableChanges,lcid) ) 

#define _Chart__Protect(This,Password,DrawingObjects,Contents,Scenarios,UserInterfaceOnly,lcid)	\
    ( (This)->lpVtbl -> _Protect(This,Password,DrawingObjects,Contents,Scenarios,UserInterfaceOnly,lcid) ) 

#define _Chart_get_ProtectContents(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_ProtectContents(This,lcid,RHS) ) 

#define _Chart_get_ProtectDrawingObjects(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_ProtectDrawingObjects(This,lcid,RHS) ) 

#define _Chart_get_ProtectionMode(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_ProtectionMode(This,lcid,RHS) ) 

#define _Chart__Dummy23(This)	\
    ( (This)->lpVtbl -> _Dummy23(This) ) 

#define _Chart__SaveAs(This,Filename,FileFormat,Password,WriteResPassword,ReadOnlyRecommended,CreateBackup,AddToMru,TextCodepage,TextVisualLayout,lcid)	\
    ( (This)->lpVtbl -> _SaveAs(This,Filename,FileFormat,Password,WriteResPassword,ReadOnlyRecommended,CreateBackup,AddToMru,TextCodepage,TextVisualLayout,lcid) ) 

#define _Chart_Select(This,Replace,lcid)	\
    ( (This)->lpVtbl -> Select(This,Replace,lcid) ) 

#define _Chart_Unprotect(This,Password,lcid)	\
    ( (This)->lpVtbl -> Unprotect(This,Password,lcid) ) 

#define _Chart_get_Visible(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_Visible(This,lcid,RHS) ) 

#define _Chart_put_Visible(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_Visible(This,lcid,RHS) ) 

#define _Chart_get_Shapes(This,RHS)	\
    ( (This)->lpVtbl -> get_Shapes(This,RHS) ) 

#define _Chart__ApplyDataLabels(This,Type,LegendKey,AutoText,HasLeaderLines,lcid)	\
    ( (This)->lpVtbl -> _ApplyDataLabels(This,Type,LegendKey,AutoText,HasLeaderLines,lcid) ) 

#define _Chart_Arcs(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> Arcs(This,Index,lcid,RHS) ) 

#define _Chart_get_Area3DGroup(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_Area3DGroup(This,lcid,RHS) ) 

#define _Chart_AreaGroups(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> AreaGroups(This,Index,lcid,RHS) ) 

#define _Chart_AutoFormat(This,Gallery,Format)	\
    ( (This)->lpVtbl -> AutoFormat(This,Gallery,Format) ) 

#define _Chart_get_AutoScaling(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_AutoScaling(This,lcid,RHS) ) 

#define _Chart_put_AutoScaling(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_AutoScaling(This,lcid,RHS) ) 

#define _Chart_Axes(This,Type,AxisGroup,lcid,RHS)	\
    ( (This)->lpVtbl -> Axes(This,Type,AxisGroup,lcid,RHS) ) 

#define _Chart_SetBackgroundPicture(This,Filename)	\
    ( (This)->lpVtbl -> SetBackgroundPicture(This,Filename) ) 

#define _Chart_get_Bar3DGroup(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_Bar3DGroup(This,lcid,RHS) ) 

#define _Chart_BarGroups(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> BarGroups(This,Index,lcid,RHS) ) 

#define _Chart_Buttons(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> Buttons(This,Index,lcid,RHS) ) 

#define _Chart_get_ChartArea(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_ChartArea(This,lcid,RHS) ) 

#define _Chart_ChartGroups(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> ChartGroups(This,Index,lcid,RHS) ) 

#define _Chart_ChartObjects(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> ChartObjects(This,Index,lcid,RHS) ) 

#define _Chart_get_ChartTitle(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_ChartTitle(This,lcid,RHS) ) 

#define _Chart_ChartWizard(This,Source,Gallery,Format,PlotBy,CategoryLabels,SeriesLabels,HasLegend,Title,CategoryTitle,ValueTitle,ExtraTitle,lcid)	\
    ( (This)->lpVtbl -> ChartWizard(This,Source,Gallery,Format,PlotBy,CategoryLabels,SeriesLabels,HasLegend,Title,CategoryTitle,ValueTitle,ExtraTitle,lcid) ) 

#define _Chart_CheckBoxes(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> CheckBoxes(This,Index,lcid,RHS) ) 

#define _Chart_CheckSpelling(This,CustomDictionary,IgnoreUppercase,AlwaysSuggest,SpellLang,lcid)	\
    ( (This)->lpVtbl -> CheckSpelling(This,CustomDictionary,IgnoreUppercase,AlwaysSuggest,SpellLang,lcid) ) 

#define _Chart_get_Column3DGroup(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_Column3DGroup(This,lcid,RHS) ) 

#define _Chart_ColumnGroups(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> ColumnGroups(This,Index,lcid,RHS) ) 

#define _Chart_CopyPicture(This,Appearance,Format,Size,lcid)	\
    ( (This)->lpVtbl -> CopyPicture(This,Appearance,Format,Size,lcid) ) 

#define _Chart_get_Corners(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_Corners(This,lcid,RHS) ) 

#define _Chart_CreatePublisher(This,Edition,Appearance,Size,ContainsPICT,ContainsBIFF,ContainsRTF,ContainsVALU,lcid)	\
    ( (This)->lpVtbl -> CreatePublisher(This,Edition,Appearance,Size,ContainsPICT,ContainsBIFF,ContainsRTF,ContainsVALU,lcid) ) 

#define _Chart_get_DataTable(This,RHS)	\
    ( (This)->lpVtbl -> get_DataTable(This,RHS) ) 

#define _Chart_get_DepthPercent(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_DepthPercent(This,lcid,RHS) ) 

#define _Chart_put_DepthPercent(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_DepthPercent(This,lcid,RHS) ) 

#define _Chart_Deselect(This,lcid)	\
    ( (This)->lpVtbl -> Deselect(This,lcid) ) 

#define _Chart_get_DisplayBlanksAs(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_DisplayBlanksAs(This,lcid,RHS) ) 

#define _Chart_put_DisplayBlanksAs(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_DisplayBlanksAs(This,lcid,RHS) ) 

#define _Chart_DoughnutGroups(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> DoughnutGroups(This,Index,lcid,RHS) ) 

#define _Chart_Drawings(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> Drawings(This,Index,lcid,RHS) ) 

#define _Chart_DrawingObjects(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> DrawingObjects(This,Index,lcid,RHS) ) 

#define _Chart_DropDowns(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> DropDowns(This,Index,lcid,RHS) ) 

#define _Chart_get_Elevation(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_Elevation(This,lcid,RHS) ) 

#define _Chart_put_Elevation(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_Elevation(This,lcid,RHS) ) 

#define _Chart_Evaluate(This,Name,lcid,RHS)	\
    ( (This)->lpVtbl -> Evaluate(This,Name,lcid,RHS) ) 

#define _Chart__Evaluate(This,Name,lcid,RHS)	\
    ( (This)->lpVtbl -> _Evaluate(This,Name,lcid,RHS) ) 

#define _Chart_get_Floor(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_Floor(This,lcid,RHS) ) 

#define _Chart_get_GapDepth(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_GapDepth(This,lcid,RHS) ) 

#define _Chart_put_GapDepth(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_GapDepth(This,lcid,RHS) ) 

#define _Chart_GroupBoxes(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> GroupBoxes(This,Index,lcid,RHS) ) 

#define _Chart_GroupObjects(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> GroupObjects(This,Index,lcid,RHS) ) 

#define _Chart_get_HasAxis(This,Index1,Index2,lcid,RHS)	\
    ( (This)->lpVtbl -> get_HasAxis(This,Index1,Index2,lcid,RHS) ) 

#define _Chart_put_HasAxis(This,Index1,Index2,lcid,RHS)	\
    ( (This)->lpVtbl -> put_HasAxis(This,Index1,Index2,lcid,RHS) ) 

#define _Chart_get_HasDataTable(This,RHS)	\
    ( (This)->lpVtbl -> get_HasDataTable(This,RHS) ) 

#define _Chart_put_HasDataTable(This,RHS)	\
    ( (This)->lpVtbl -> put_HasDataTable(This,RHS) ) 

#define _Chart_get_HasLegend(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_HasLegend(This,lcid,RHS) ) 

#define _Chart_put_HasLegend(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_HasLegend(This,lcid,RHS) ) 

#define _Chart_get_HasTitle(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_HasTitle(This,lcid,RHS) ) 

#define _Chart_put_HasTitle(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_HasTitle(This,lcid,RHS) ) 

#define _Chart_get_HeightPercent(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_HeightPercent(This,lcid,RHS) ) 

#define _Chart_put_HeightPercent(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_HeightPercent(This,lcid,RHS) ) 

#define _Chart_get_Hyperlinks(This,RHS)	\
    ( (This)->lpVtbl -> get_Hyperlinks(This,RHS) ) 

#define _Chart_Labels(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> Labels(This,Index,lcid,RHS) ) 

#define _Chart_get_Legend(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_Legend(This,lcid,RHS) ) 

#define _Chart_get_Line3DGroup(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_Line3DGroup(This,lcid,RHS) ) 

#define _Chart_LineGroups(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> LineGroups(This,Index,lcid,RHS) ) 

#define _Chart_Lines(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> Lines(This,Index,lcid,RHS) ) 

#define _Chart_ListBoxes(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> ListBoxes(This,Index,lcid,RHS) ) 

#define _Chart_Location(This,Where,Name,RHS)	\
    ( (This)->lpVtbl -> Location(This,Where,Name,RHS) ) 

#define _Chart_OLEObjects(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> OLEObjects(This,Index,lcid,RHS) ) 

#define _Chart_OptionButtons(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> OptionButtons(This,Index,lcid,RHS) ) 

#define _Chart_Ovals(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> Ovals(This,Index,lcid,RHS) ) 

#define _Chart_Paste(This,Type,lcid)	\
    ( (This)->lpVtbl -> Paste(This,Type,lcid) ) 

#define _Chart_get_Perspective(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_Perspective(This,lcid,RHS) ) 

#define _Chart_put_Perspective(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_Perspective(This,lcid,RHS) ) 

#define _Chart_Pictures(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> Pictures(This,Index,lcid,RHS) ) 

#define _Chart_get_Pie3DGroup(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_Pie3DGroup(This,lcid,RHS) ) 

#define _Chart_PieGroups(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> PieGroups(This,Index,lcid,RHS) ) 

#define _Chart_get_PlotArea(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_PlotArea(This,lcid,RHS) ) 

#define _Chart_get_PlotVisibleOnly(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_PlotVisibleOnly(This,lcid,RHS) ) 

#define _Chart_put_PlotVisibleOnly(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_PlotVisibleOnly(This,lcid,RHS) ) 

#define _Chart_RadarGroups(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> RadarGroups(This,Index,lcid,RHS) ) 

#define _Chart_Rectangles(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> Rectangles(This,Index,lcid,RHS) ) 

#define _Chart_get_RightAngleAxes(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_RightAngleAxes(This,lcid,RHS) ) 

#define _Chart_put_RightAngleAxes(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_RightAngleAxes(This,lcid,RHS) ) 

#define _Chart_get_Rotation(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_Rotation(This,lcid,RHS) ) 

#define _Chart_put_Rotation(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_Rotation(This,lcid,RHS) ) 

#define _Chart_ScrollBars(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> ScrollBars(This,Index,lcid,RHS) ) 

#define _Chart_SeriesCollection(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> SeriesCollection(This,Index,lcid,RHS) ) 

#define _Chart_get_SizeWithWindow(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_SizeWithWindow(This,lcid,RHS) ) 

#define _Chart_put_SizeWithWindow(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_SizeWithWindow(This,lcid,RHS) ) 

#define _Chart_get_ShowWindow(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowWindow(This,RHS) ) 

#define _Chart_put_ShowWindow(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowWindow(This,RHS) ) 

#define _Chart_Spinners(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> Spinners(This,Index,lcid,RHS) ) 

#define _Chart_get_SubType(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_SubType(This,lcid,RHS) ) 

#define _Chart_put_SubType(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_SubType(This,lcid,RHS) ) 

#define _Chart_get_SurfaceGroup(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_SurfaceGroup(This,lcid,RHS) ) 

#define _Chart_TextBoxes(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> TextBoxes(This,Index,lcid,RHS) ) 

#define _Chart_get_Type(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_Type(This,lcid,RHS) ) 

#define _Chart_put_Type(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_Type(This,lcid,RHS) ) 

#define _Chart_get_ChartType(This,RHS)	\
    ( (This)->lpVtbl -> get_ChartType(This,RHS) ) 

#define _Chart_put_ChartType(This,RHS)	\
    ( (This)->lpVtbl -> put_ChartType(This,RHS) ) 

#define _Chart_ApplyCustomType(This,ChartType,TypeName)	\
    ( (This)->lpVtbl -> ApplyCustomType(This,ChartType,TypeName) ) 

#define _Chart_get_Walls(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_Walls(This,lcid,RHS) ) 

#define _Chart_get_WallsAndGridlines2D(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_WallsAndGridlines2D(This,lcid,RHS) ) 

#define _Chart_put_WallsAndGridlines2D(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_WallsAndGridlines2D(This,lcid,RHS) ) 

#define _Chart_XYGroups(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> XYGroups(This,Index,lcid,RHS) ) 

#define _Chart_get_BarShape(This,RHS)	\
    ( (This)->lpVtbl -> get_BarShape(This,RHS) ) 

#define _Chart_put_BarShape(This,RHS)	\
    ( (This)->lpVtbl -> put_BarShape(This,RHS) ) 

#define _Chart_get_PlotBy(This,RHS)	\
    ( (This)->lpVtbl -> get_PlotBy(This,RHS) ) 

#define _Chart_put_PlotBy(This,RHS)	\
    ( (This)->lpVtbl -> put_PlotBy(This,RHS) ) 

#define _Chart_CopyChartBuild(This)	\
    ( (This)->lpVtbl -> CopyChartBuild(This) ) 

#define _Chart_get_ProtectFormatting(This,RHS)	\
    ( (This)->lpVtbl -> get_ProtectFormatting(This,RHS) ) 

#define _Chart_put_ProtectFormatting(This,RHS)	\
    ( (This)->lpVtbl -> put_ProtectFormatting(This,RHS) ) 

#define _Chart_get_ProtectData(This,RHS)	\
    ( (This)->lpVtbl -> get_ProtectData(This,RHS) ) 

#define _Chart_put_ProtectData(This,RHS)	\
    ( (This)->lpVtbl -> put_ProtectData(This,RHS) ) 

#define _Chart_get_ProtectGoalSeek(This,RHS)	\
    ( (This)->lpVtbl -> get_ProtectGoalSeek(This,RHS) ) 

#define _Chart_put_ProtectGoalSeek(This,RHS)	\
    ( (This)->lpVtbl -> put_ProtectGoalSeek(This,RHS) ) 

#define _Chart_get_ProtectSelection(This,RHS)	\
    ( (This)->lpVtbl -> get_ProtectSelection(This,RHS) ) 

#define _Chart_put_ProtectSelection(This,RHS)	\
    ( (This)->lpVtbl -> put_ProtectSelection(This,RHS) ) 

#define _Chart_GetChartElement(This,x,y,ElementID,Arg1,Arg2)	\
    ( (This)->lpVtbl -> GetChartElement(This,x,y,ElementID,Arg1,Arg2) ) 

#define _Chart_SetSourceData(This,Source,PlotBy)	\
    ( (This)->lpVtbl -> SetSourceData(This,Source,PlotBy) ) 

#define _Chart_Export(This,Filename,FilterName,Interactive,RHS)	\
    ( (This)->lpVtbl -> Export(This,Filename,FilterName,Interactive,RHS) ) 

#define _Chart_Refresh(This)	\
    ( (This)->lpVtbl -> Refresh(This) ) 

#define _Chart_get_PivotLayout(This,RHS)	\
    ( (This)->lpVtbl -> get_PivotLayout(This,RHS) ) 

#define _Chart_get_HasPivotFields(This,RHS)	\
    ( (This)->lpVtbl -> get_HasPivotFields(This,RHS) ) 

#define _Chart_put_HasPivotFields(This,RHS)	\
    ( (This)->lpVtbl -> put_HasPivotFields(This,RHS) ) 

#define _Chart_get_Scripts(This,RHS)	\
    ( (This)->lpVtbl -> get_Scripts(This,RHS) ) 

#define _Chart__PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate,PrToFileName,lcid)	\
    ( (This)->lpVtbl -> _PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate,PrToFileName,lcid) ) 

#define _Chart_get_Tab(This,RHS)	\
    ( (This)->lpVtbl -> get_Tab(This,RHS) ) 

#define _Chart_get_MailEnvelope(This,RHS)	\
    ( (This)->lpVtbl -> get_MailEnvelope(This,RHS) ) 

#define _Chart_ApplyDataLabels(This,Type,LegendKey,AutoText,HasLeaderLines,ShowSeriesName,ShowCategoryName,ShowValue,ShowPercentage,ShowBubbleSize,Separator,lcid)	\
    ( (This)->lpVtbl -> ApplyDataLabels(This,Type,LegendKey,AutoText,HasLeaderLines,ShowSeriesName,ShowCategoryName,ShowValue,ShowPercentage,ShowBubbleSize,Separator,lcid) ) 

#define _Chart_SaveAs(This,Filename,FileFormat,Password,WriteResPassword,ReadOnlyRecommended,CreateBackup,AddToMru,TextCodepage,TextVisualLayout,Local)	\
    ( (This)->lpVtbl -> SaveAs(This,Filename,FileFormat,Password,WriteResPassword,ReadOnlyRecommended,CreateBackup,AddToMru,TextCodepage,TextVisualLayout,Local) ) 

#define _Chart_Protect(This,Password,DrawingObjects,Contents,Scenarios,UserInterfaceOnly)	\
    ( (This)->lpVtbl -> Protect(This,Password,DrawingObjects,Contents,Scenarios,UserInterfaceOnly) ) 

#define _Chart_ApplyLayout(This,Layout,ChartType)	\
    ( (This)->lpVtbl -> ApplyLayout(This,Layout,ChartType) ) 

#define _Chart_SetElement(This,Element)	\
    ( (This)->lpVtbl -> SetElement(This,Element) ) 

#define _Chart_get_ShowDataLabelsOverMaximum(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowDataLabelsOverMaximum(This,RHS) ) 

#define _Chart_put_ShowDataLabelsOverMaximum(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowDataLabelsOverMaximum(This,RHS) ) 

#define _Chart_get_SideWall(This,RHS)	\
    ( (This)->lpVtbl -> get_SideWall(This,RHS) ) 

#define _Chart_get_BackWall(This,RHS)	\
    ( (This)->lpVtbl -> get_BackWall(This,RHS) ) 

#define _Chart_PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate,PrToFileName,lcid)	\
    ( (This)->lpVtbl -> PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate,PrToFileName,lcid) ) 

#define _Chart_ApplyChartTemplate(This,Filename)	\
    ( (This)->lpVtbl -> ApplyChartTemplate(This,Filename) ) 

#define _Chart_SaveChartTemplate(This,Filename)	\
    ( (This)->lpVtbl -> SaveChartTemplate(This,Filename) ) 

#define _Chart_SetDefaultChart(This,Name)	\
    ( (This)->lpVtbl -> SetDefaultChart(This,Name) ) 

#define _Chart_ExportAsFixedFormat(This,Type,Filename,Quality,IncludeDocProperties,IgnorePrintAreas,From,To,OpenAfterPublish,FixedFormatExtClassPtr)	\
    ( (This)->lpVtbl -> ExportAsFixedFormat(This,Type,Filename,Quality,IncludeDocProperties,IgnorePrintAreas,From,To,OpenAfterPublish,FixedFormatExtClassPtr) ) 

#define _Chart_get_ChartStyle(This,RHS)	\
    ( (This)->lpVtbl -> get_ChartStyle(This,RHS) ) 

#define _Chart_put_ChartStyle(This,RHS)	\
    ( (This)->lpVtbl -> put_ChartStyle(This,RHS) ) 

#define _Chart_ClearToMatchStyle(This)	\
    ( (This)->lpVtbl -> ClearToMatchStyle(This) ) 

#define _Chart_get_PrintedCommentPages(This,RHS)	\
    ( (This)->lpVtbl -> get_PrintedCommentPages(This,RHS) ) 

#define _Chart_get_Dummy24(This,RHS)	\
    ( (This)->lpVtbl -> get_Dummy24(This,RHS) ) 

#define _Chart_put_Dummy24(This,RHS)	\
    ( (This)->lpVtbl -> put_Dummy24(This,RHS) ) 

#define _Chart_get_Dummy25(This,RHS)	\
    ( (This)->lpVtbl -> get_Dummy25(This,RHS) ) 

#define _Chart_put_Dummy25(This,RHS)	\
    ( (This)->lpVtbl -> put_Dummy25(This,RHS) ) 

#define _Chart_get_ShowReportFilterFieldButtons(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowReportFilterFieldButtons(This,RHS) ) 

#define _Chart_put_ShowReportFilterFieldButtons(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowReportFilterFieldButtons(This,RHS) ) 

#define _Chart_get_ShowLegendFieldButtons(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowLegendFieldButtons(This,RHS) ) 

#define _Chart_put_ShowLegendFieldButtons(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowLegendFieldButtons(This,RHS) ) 

#define _Chart_get_ShowAxisFieldButtons(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowAxisFieldButtons(This,RHS) ) 

#define _Chart_put_ShowAxisFieldButtons(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowAxisFieldButtons(This,RHS) ) 

#define _Chart_get_ShowValueFieldButtons(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowValueFieldButtons(This,RHS) ) 

#define _Chart_put_ShowValueFieldButtons(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowValueFieldButtons(This,RHS) ) 

#define _Chart_get_ShowAllFieldButtons(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowAllFieldButtons(This,RHS) ) 

#define _Chart_put_ShowAllFieldButtons(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowAllFieldButtons(This,RHS) ) 

#define _Chart_FullSeriesCollection(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> FullSeriesCollection(This,Index,lcid,RHS) ) 

#define _Chart_get_CategoryLabelLevel(This,RHS)	\
    ( (This)->lpVtbl -> get_CategoryLabelLevel(This,RHS) ) 

#define _Chart_put_CategoryLabelLevel(This,RHS)	\
    ( (This)->lpVtbl -> put_CategoryLabelLevel(This,RHS) ) 

#define _Chart_get_SeriesNameLevel(This,RHS)	\
    ( (This)->lpVtbl -> get_SeriesNameLevel(This,RHS) ) 

#define _Chart_put_SeriesNameLevel(This,RHS)	\
    ( (This)->lpVtbl -> put_SeriesNameLevel(This,RHS) ) 

#define _Chart_get_HasHiddenContent(This,RHS)	\
    ( (This)->lpVtbl -> get_HasHiddenContent(This,RHS) ) 

#define _Chart_DeleteHiddenContent(This)	\
    ( (This)->lpVtbl -> DeleteHiddenContent(This) ) 

#define _Chart_get_ChartColor(This,RHS)	\
    ( (This)->lpVtbl -> get_ChartColor(This,RHS) ) 

#define _Chart_put_ChartColor(This,RHS)	\
    ( (This)->lpVtbl -> put_ChartColor(This,RHS) ) 

#define _Chart_ClearToMatchColorStyle(This)	\
    ( (This)->lpVtbl -> ClearToMatchColorStyle(This) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */



/* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE _Chart_get_SubType_Proxy( 
    _Chart * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ long *RHS);


void __RPC_STUB _Chart_get_SubType_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE _Chart_put_SubType_Proxy( 
    _Chart * This,
    /* [lcid][in] */ long lcid,
    /* [in] */ long RHS);


void __RPC_STUB _Chart_put_SubType_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE _Chart_get_SurfaceGroup_Proxy( 
    _Chart * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ ChartGroup	**RHS);


void __RPC_STUB _Chart_get_SurfaceGroup_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE _Chart_TextBoxes_Proxy( 
    _Chart * This,
    /* [optional][in] */ VARIANT Index,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ IDispatch **RHS);


void __RPC_STUB _Chart_TextBoxes_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE _Chart_get_Type_Proxy( 
    _Chart * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ long *RHS);


void __RPC_STUB _Chart_get_Type_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE _Chart_put_Type_Proxy( 
    _Chart * This,
    /* [lcid][in] */ long lcid,
    /* [in] */ long RHS);


void __RPC_STUB _Chart_put_Type_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Chart_get_ChartType_Proxy( 
    _Chart * This,
    /* [retval][out] */ XlChartType *RHS);


void __RPC_STUB _Chart_get_ChartType_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Chart_put_ChartType_Proxy( 
    _Chart * This,
    /* [in] */ XlChartType RHS);


void __RPC_STUB _Chart_put_ChartType_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE _Chart_ApplyCustomType_Proxy( 
    _Chart * This,
    /* [in] */ XlChartType ChartType,
    /* [optional][in] */ VARIANT TypeName);


void __RPC_STUB _Chart_ApplyCustomType_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Chart_get_Walls_Proxy( 
    _Chart * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ Walls	**RHS);


void __RPC_STUB _Chart_get_Walls_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE _Chart_get_WallsAndGridlines2D_Proxy( 
    _Chart * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Chart_get_WallsAndGridlines2D_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE _Chart_put_WallsAndGridlines2D_Proxy( 
    _Chart * This,
    /* [lcid][in] */ long lcid,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Chart_put_WallsAndGridlines2D_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE _Chart_XYGroups_Proxy( 
    _Chart * This,
    /* [optional][in] */ VARIANT Index,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ IDispatch **RHS);


void __RPC_STUB _Chart_XYGroups_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Chart_get_BarShape_Proxy( 
    _Chart * This,
    /* [retval][out] */ XlBarShape *RHS);


void __RPC_STUB _Chart_get_BarShape_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Chart_put_BarShape_Proxy( 
    _Chart * This,
    /* [in] */ XlBarShape RHS);


void __RPC_STUB _Chart_put_BarShape_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Chart_get_PlotBy_Proxy( 
    _Chart * This,
    /* [retval][out] */ XlRowCol *RHS);


void __RPC_STUB _Chart_get_PlotBy_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Chart_put_PlotBy_Proxy( 
    _Chart * This,
    /* [in] */ XlRowCol RHS);


void __RPC_STUB _Chart_put_PlotBy_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE _Chart_CopyChartBuild_Proxy( 
    _Chart * This);


void __RPC_STUB _Chart_CopyChartBuild_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Chart_get_ProtectFormatting_Proxy( 
    _Chart * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Chart_get_ProtectFormatting_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Chart_put_ProtectFormatting_Proxy( 
    _Chart * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Chart_put_ProtectFormatting_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Chart_get_ProtectData_Proxy( 
    _Chart * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Chart_get_ProtectData_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Chart_put_ProtectData_Proxy( 
    _Chart * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Chart_put_ProtectData_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE _Chart_get_ProtectGoalSeek_Proxy( 
    _Chart * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Chart_get_ProtectGoalSeek_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE _Chart_put_ProtectGoalSeek_Proxy( 
    _Chart * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Chart_put_ProtectGoalSeek_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Chart_get_ProtectSelection_Proxy( 
    _Chart * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Chart_get_ProtectSelection_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Chart_put_ProtectSelection_Proxy( 
    _Chart * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Chart_put_ProtectSelection_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Chart_GetChartElement_Proxy( 
    _Chart * This,
    /* [in] */ long x,
    /* [in] */ long y,
    /* [in] */ long *ElementID,
    /* [in] */ long *Arg1,
    /* [in] */ long *Arg2);


void __RPC_STUB _Chart_GetChartElement_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Chart_SetSourceData_Proxy( 
    _Chart * This,
    /* [in] */ Range	*Source,
    /* [optional][in] */ VARIANT PlotBy);


void __RPC_STUB _Chart_SetSourceData_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Chart_Export_Proxy( 
    _Chart * This,
    /* [in] */ BSTR Filename,
    /* [optional][in] */ VARIANT FilterName,
    /* [optional][in] */ VARIANT Interactive,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Chart_Export_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Chart_Refresh_Proxy( 
    _Chart * This);


void __RPC_STUB _Chart_Refresh_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Chart_get_PivotLayout_Proxy( 
    _Chart * This,
    /* [retval][out] */ PivotLayout	**RHS);


void __RPC_STUB _Chart_get_PivotLayout_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE _Chart_get_HasPivotFields_Proxy( 
    _Chart * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Chart_get_HasPivotFields_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE _Chart_put_HasPivotFields_Proxy( 
    _Chart * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Chart_put_HasPivotFields_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE _Chart_get_Scripts_Proxy( 
    _Chart * This,
    /* [retval][out] */ /* external definition not present */ Scripts **RHS);


void __RPC_STUB _Chart_get_Scripts_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [custom][helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE _Chart__PrintOut_Proxy( 
    _Chart * This,
    /* [optional][in] */ VARIANT From,
    /* [optional][in] */ VARIANT To,
    /* [optional][in] */ VARIANT Copies,
    /* [optional][in] */ VARIANT Preview,
    /* [optional][in] */ VARIANT ActivePrinter,
    /* [optional][in] */ VARIANT PrintToFile,
    /* [optional][in] */ VARIANT Collate,
    /* [optional][in] */ VARIANT PrToFileName,
    /* [lcid][in] */ long lcid);


void __RPC_STUB _Chart__PrintOut_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Chart_get_Tab_Proxy( 
    _Chart * This,
    /* [retval][out] */ Tab	**RHS);


void __RPC_STUB _Chart_get_Tab_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Chart_get_MailEnvelope_Proxy( 
    _Chart * This,
    /* [retval][out] */ /* external definition not present */ MsoEnvelope **RHS);


void __RPC_STUB _Chart_get_MailEnvelope_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Chart_ApplyDataLabels_Proxy( 
    _Chart * This,
    /* [defaultvalue][optional][in] */ XlDataLabelsType Type,
    /* [optional][in] */ VARIANT LegendKey,
    /* [optional][in] */ VARIANT AutoText,
    /* [optional][in] */ VARIANT HasLeaderLines,
    /* [optional][in] */ VARIANT ShowSeriesName,
    /* [optional][in] */ VARIANT ShowCategoryName,
    /* [optional][in] */ VARIANT ShowValue,
    /* [optional][in] */ VARIANT ShowPercentage,
    /* [optional][in] */ VARIANT ShowBubbleSize,
    /* [optional][in] */ VARIANT Separator,
    /* [lcid][in] */ long lcid);


void __RPC_STUB _Chart_ApplyDataLabels_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Chart_SaveAs_Proxy( 
    _Chart * This,
    /* [in] */ BSTR Filename,
    /* [optional][in] */ VARIANT FileFormat,
    /* [optional][in] */ VARIANT Password,
    /* [optional][in] */ VARIANT WriteResPassword,
    /* [optional][in] */ VARIANT ReadOnlyRecommended,
    /* [optional][in] */ VARIANT CreateBackup,
    /* [optional][in] */ VARIANT AddToMru,
    /* [optional][in] */ VARIANT TextCodepage,
    /* [optional][in] */ VARIANT TextVisualLayout,
    /* [optional][in] */ VARIANT Local);


void __RPC_STUB _Chart_SaveAs_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Chart_Protect_Proxy( 
    _Chart * This,
    /* [optional][in] */ VARIANT Password,
    /* [optional][in] */ VARIANT DrawingObjects,
    /* [optional][in] */ VARIANT Contents,
    /* [optional][in] */ VARIANT Scenarios,
    /* [optional][in] */ VARIANT UserInterfaceOnly);


void __RPC_STUB _Chart_Protect_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Chart_ApplyLayout_Proxy( 
    _Chart * This,
    /* [in] */ long Layout,
    /* [optional][in] */ VARIANT ChartType);


void __RPC_STUB _Chart_ApplyLayout_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Chart_SetElement_Proxy( 
    _Chart * This,
    /* [in] */ MsoChartElementType Element);


void __RPC_STUB _Chart_SetElement_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Chart_get_ShowDataLabelsOverMaximum_Proxy( 
    _Chart * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Chart_get_ShowDataLabelsOverMaximum_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Chart_put_ShowDataLabelsOverMaximum_Proxy( 
    _Chart * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Chart_put_ShowDataLabelsOverMaximum_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Chart_get_SideWall_Proxy( 
    _Chart * This,
    /* [retval][out] */ Walls	**RHS);


void __RPC_STUB _Chart_get_SideWall_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Chart_get_BackWall_Proxy( 
    _Chart * This,
    /* [retval][out] */ Walls	**RHS);


void __RPC_STUB _Chart_get_BackWall_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [custom][helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Chart_PrintOut_Proxy( 
    _Chart * This,
    /* [optional][in] */ VARIANT From,
    /* [optional][in] */ VARIANT To,
    /* [optional][in] */ VARIANT Copies,
    /* [optional][in] */ VARIANT Preview,
    /* [optional][in] */ VARIANT ActivePrinter,
    /* [optional][in] */ VARIANT PrintToFile,
    /* [optional][in] */ VARIANT Collate,
    /* [optional][in] */ VARIANT PrToFileName,
    /* [lcid][in] */ long lcid);


void __RPC_STUB _Chart_PrintOut_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Chart_ApplyChartTemplate_Proxy( 
    _Chart * This,
    /* [in] */ BSTR Filename);


void __RPC_STUB _Chart_ApplyChartTemplate_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Chart_SaveChartTemplate_Proxy( 
    _Chart * This,
    /* [in] */ BSTR Filename);


void __RPC_STUB _Chart_SaveChartTemplate_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Chart_SetDefaultChart_Proxy( 
    _Chart * This,
    /* [in] */ VARIANT Name);


void __RPC_STUB _Chart_SetDefaultChart_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Chart_ExportAsFixedFormat_Proxy( 
    _Chart * This,
    /* [in] */ XlFixedFormatType Type,
    /* [optional][in] */ VARIANT Filename,
    /* [optional][in] */ VARIANT Quality,
    /* [optional][in] */ VARIANT IncludeDocProperties,
    /* [optional][in] */ VARIANT IgnorePrintAreas,
    /* [optional][in] */ VARIANT From,
    /* [optional][in] */ VARIANT To,
    /* [optional][in] */ VARIANT OpenAfterPublish,
    /* [optional][in] */ VARIANT FixedFormatExtClassPtr);


void __RPC_STUB _Chart_ExportAsFixedFormat_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Chart_get_ChartStyle_Proxy( 
    _Chart * This,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB _Chart_get_ChartStyle_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Chart_put_ChartStyle_Proxy( 
    _Chart * This,
    /* [in] */ VARIANT RHS);


void __RPC_STUB _Chart_put_ChartStyle_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Chart_ClearToMatchStyle_Proxy( 
    _Chart * This);


void __RPC_STUB _Chart_ClearToMatchStyle_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Chart_get_PrintedCommentPages_Proxy( 
    _Chart * This,
    /* [retval][out] */ long *RHS);


void __RPC_STUB _Chart_get_PrintedCommentPages_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE _Chart_get_Dummy24_Proxy( 
    _Chart * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Chart_get_Dummy24_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE _Chart_put_Dummy24_Proxy( 
    _Chart * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Chart_put_Dummy24_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE _Chart_get_Dummy25_Proxy( 
    _Chart * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Chart_get_Dummy25_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE _Chart_put_Dummy25_Proxy( 
    _Chart * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Chart_put_Dummy25_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Chart_get_ShowReportFilterFieldButtons_Proxy( 
    _Chart * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Chart_get_ShowReportFilterFieldButtons_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Chart_put_ShowReportFilterFieldButtons_Proxy( 
    _Chart * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Chart_put_ShowReportFilterFieldButtons_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Chart_get_ShowLegendFieldButtons_Proxy( 
    _Chart * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Chart_get_ShowLegendFieldButtons_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Chart_put_ShowLegendFieldButtons_Proxy( 
    _Chart * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Chart_put_ShowLegendFieldButtons_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Chart_get_ShowAxisFieldButtons_Proxy( 
    _Chart * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Chart_get_ShowAxisFieldButtons_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Chart_put_ShowAxisFieldButtons_Proxy( 
    _Chart * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Chart_put_ShowAxisFieldButtons_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Chart_get_ShowValueFieldButtons_Proxy( 
    _Chart * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Chart_get_ShowValueFieldButtons_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Chart_put_ShowValueFieldButtons_Proxy( 
    _Chart * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Chart_put_ShowValueFieldButtons_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Chart_get_ShowAllFieldButtons_Proxy( 
    _Chart * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Chart_get_ShowAllFieldButtons_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Chart_put_ShowAllFieldButtons_Proxy( 
    _Chart * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Chart_put_ShowAllFieldButtons_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Chart_FullSeriesCollection_Proxy( 
    _Chart * This,
    /* [optional][in] */ VARIANT Index,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ IDispatch **RHS);


void __RPC_STUB _Chart_FullSeriesCollection_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Chart_get_CategoryLabelLevel_Proxy( 
    _Chart * This,
    /* [retval][out] */ XlCategoryLabelLevel *RHS);


void __RPC_STUB _Chart_get_CategoryLabelLevel_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Chart_put_CategoryLabelLevel_Proxy( 
    _Chart * This,
    /* [in] */ XlCategoryLabelLevel RHS);


void __RPC_STUB _Chart_put_CategoryLabelLevel_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Chart_get_SeriesNameLevel_Proxy( 
    _Chart * This,
    /* [retval][out] */ XlSeriesNameLevel *RHS);


void __RPC_STUB _Chart_get_SeriesNameLevel_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Chart_put_SeriesNameLevel_Proxy( 
    _Chart * This,
    /* [in] */ XlSeriesNameLevel RHS);


void __RPC_STUB _Chart_put_SeriesNameLevel_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE _Chart_get_HasHiddenContent_Proxy( 
    _Chart * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Chart_get_HasHiddenContent_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE _Chart_DeleteHiddenContent_Proxy( 
    _Chart * This);


void __RPC_STUB _Chart_DeleteHiddenContent_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Chart_get_ChartColor_Proxy( 
    _Chart * This,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB _Chart_get_ChartColor_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Chart_put_ChartColor_Proxy( 
    _Chart * This,
    /* [in] */ VARIANT RHS);


void __RPC_STUB _Chart_put_ChartColor_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Chart_ClearToMatchColorStyle_Proxy( 
    _Chart * This);


void __RPC_STUB _Chart_ClearToMatchColorStyle_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);



#endif 	/* ___Chart_INTERFACE_DEFINED__ */


#ifndef __Sheets_INTERFACE_DEFINED__
#define __Sheets_INTERFACE_DEFINED__

/* interface Sheets */
/* [object][oleautomation][nonextensible][dual][helpcontext][uuid] */ 


EXTERN_C const IID IID_Sheets;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000208D7-0000-0000-C000-000000000046")
    Sheets : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Add( 
            /* [optional][in] */ VARIANT Before,
            /* [optional][in] */ VARIANT After,
            /* [optional][in] */ VARIANT Count,
            /* [optional][in] */ VARIANT Type,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Copy( 
            /* [optional][in] */ VARIANT Before,
            /* [optional][in] */ VARIANT After,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Delete( 
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE FillAcrossSheets( 
            /* [in] */ Range	*Range,
            /* [defaultvalue][optional][in] */ XlFillWith Type,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Move( 
            /* [optional][in] */ VARIANT Before,
            /* [optional][in] */ VARIANT After,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
        virtual /* [custom][helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE __PrintOut( 
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE PrintPreview( 
            /* [optional][in] */ VARIANT EnableChanges,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Select( 
            /* [optional][in] */ VARIANT Replace,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_HPageBreaks( 
            /* [retval][out] */ HPageBreaks	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_VPageBreaks( 
            /* [retval][out] */ VPageBreaks	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Visible( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_Visible( 
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [custom][helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE _PrintOut( 
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate,
            /* [optional][in] */ VARIANT PrToFileName,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [custom][helpcontext][id] */ HRESULT STDMETHODCALLTYPE PrintOut( 
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate,
            /* [optional][in] */ VARIANT PrToFileName,
            /* [optional][in] */ VARIANT IgnorePrintAreas,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Add2( 
            /* [optional][in] */ VARIANT Before,
            /* [optional][in] */ VARIANT After,
            /* [optional][in] */ VARIANT Count,
            /* [optional][in] */ VARIANT NewLayout,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct SheetsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Sheets * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Sheets * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Sheets * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Sheets * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Sheets * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Sheets * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Sheets * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Application )( 
            Sheets * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Creator )( 
            Sheets * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Parent )( 
            Sheets * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Add )( 
            Sheets * This,
            /* [optional][in] */ VARIANT Before,
            /* [optional][in] */ VARIANT After,
            /* [optional][in] */ VARIANT Count,
            /* [optional][in] */ VARIANT Type,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Copy )( 
            Sheets * This,
            /* [optional][in] */ VARIANT Before,
            /* [optional][in] */ VARIANT After,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Count )( 
            Sheets * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Delete )( 
            Sheets * This,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *FillAcrossSheets )( 
            Sheets * This,
            /* [in] */ Range	*Range,
            /* [defaultvalue][optional][in] */ XlFillWith Type,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Item )( 
            Sheets * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Move )( 
            Sheets * This,
            /* [optional][in] */ VARIANT Before,
            /* [optional][in] */ VARIANT After,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get__NewEnum )( 
            Sheets * This,
            /* [retval][out] */ IUnknown **RHS);
        
        /* [custom][helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *__PrintOut )( 
            Sheets * This,
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *PrintPreview )( 
            Sheets * This,
            /* [optional][in] */ VARIANT EnableChanges,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Select )( 
            Sheets * This,
            /* [optional][in] */ VARIANT Replace,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_HPageBreaks )( 
            Sheets * This,
            /* [retval][out] */ HPageBreaks	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_VPageBreaks )( 
            Sheets * This,
            /* [retval][out] */ VPageBreaks	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Visible )( 
            Sheets * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Visible )( 
            Sheets * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get__Default )( 
            Sheets * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [custom][helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *_PrintOut )( 
            Sheets * This,
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate,
            /* [optional][in] */ VARIANT PrToFileName,
            /* [lcid][in] */ long lcid);
        
        /* [custom][helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *PrintOut )( 
            Sheets * This,
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate,
            /* [optional][in] */ VARIANT PrToFileName,
            /* [optional][in] */ VARIANT IgnorePrintAreas,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Add2 )( 
            Sheets * This,
            /* [optional][in] */ VARIANT Before,
            /* [optional][in] */ VARIANT After,
            /* [optional][in] */ VARIANT Count,
            /* [optional][in] */ VARIANT NewLayout,
            /* [retval][out] */ IDispatch **RHS);
        
        END_INTERFACE
    } SheetsVtbl;

    interface Sheets
    {
        CONST_VTBL struct SheetsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Sheets_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Sheets_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Sheets_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Sheets_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Sheets_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Sheets_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Sheets_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define Sheets_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define Sheets_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define Sheets_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define Sheets_Add(This,Before,After,Count,Type,lcid,RHS)	\
    ( (This)->lpVtbl -> Add(This,Before,After,Count,Type,lcid,RHS) ) 

#define Sheets_Copy(This,Before,After,lcid)	\
    ( (This)->lpVtbl -> Copy(This,Before,After,lcid) ) 

#define Sheets_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define Sheets_Delete(This,lcid)	\
    ( (This)->lpVtbl -> Delete(This,lcid) ) 

#define Sheets_FillAcrossSheets(This,Range,Type,lcid)	\
    ( (This)->lpVtbl -> FillAcrossSheets(This,Range,Type,lcid) ) 

#define Sheets_get_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Item(This,Index,RHS) ) 

#define Sheets_Move(This,Before,After,lcid)	\
    ( (This)->lpVtbl -> Move(This,Before,After,lcid) ) 

#define Sheets_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#define Sheets___PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate,lcid)	\
    ( (This)->lpVtbl -> __PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate,lcid) ) 

#define Sheets_PrintPreview(This,EnableChanges,lcid)	\
    ( (This)->lpVtbl -> PrintPreview(This,EnableChanges,lcid) ) 

#define Sheets_Select(This,Replace,lcid)	\
    ( (This)->lpVtbl -> Select(This,Replace,lcid) ) 

#define Sheets_get_HPageBreaks(This,RHS)	\
    ( (This)->lpVtbl -> get_HPageBreaks(This,RHS) ) 

#define Sheets_get_VPageBreaks(This,RHS)	\
    ( (This)->lpVtbl -> get_VPageBreaks(This,RHS) ) 

#define Sheets_get_Visible(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_Visible(This,lcid,RHS) ) 

#define Sheets_put_Visible(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_Visible(This,lcid,RHS) ) 

#define Sheets_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define Sheets__PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate,PrToFileName,lcid)	\
    ( (This)->lpVtbl -> _PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate,PrToFileName,lcid) ) 

#define Sheets_PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate,PrToFileName,IgnorePrintAreas,lcid)	\
    ( (This)->lpVtbl -> PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate,PrToFileName,IgnorePrintAreas,lcid) ) 

#define Sheets_Add2(This,Before,After,Count,NewLayout,RHS)	\
    ( (This)->lpVtbl -> Add2(This,Before,After,Count,NewLayout,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __Sheets_INTERFACE_DEFINED__ */


#ifndef __IVPageBreak_INTERFACE_DEFINED__
#define __IVPageBreak_INTERFACE_DEFINED__

/* interface IVPageBreak */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IVPageBreak;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024402-0001-0000-C000-000000000046")
    IVPageBreak : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ Worksheet	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall DragOff( 
            /* [in] */ XlDirection Direction,
            /* [in] */ long RegionIndex) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Type( 
            /* [retval][out] */ XlPageBreak *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Type( 
            /* [in] */ XlPageBreak RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Extent( 
            /* [retval][out] */ XlPageBreakExtent *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Location( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propputref][id] */ HRESULT __stdcall putref_Location( 
            /* [in] */ Range	*RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IVPageBreakVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IVPageBreak * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IVPageBreak * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IVPageBreak * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IVPageBreak * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IVPageBreak * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IVPageBreak * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IVPageBreak * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IVPageBreak * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IVPageBreak * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IVPageBreak * This,
            /* [retval][out] */ Worksheet	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IVPageBreak * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *DragOff )( 
            IVPageBreak * This,
            /* [in] */ XlDirection Direction,
            /* [in] */ long RegionIndex);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Type )( 
            IVPageBreak * This,
            /* [retval][out] */ XlPageBreak *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Type )( 
            IVPageBreak * This,
            /* [in] */ XlPageBreak RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Extent )( 
            IVPageBreak * This,
            /* [retval][out] */ XlPageBreakExtent *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Location )( 
            IVPageBreak * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propputref][id] */ HRESULT ( __stdcall *putref_Location )( 
            IVPageBreak * This,
            /* [in] */ Range	*RHS);
        
        END_INTERFACE
    } IVPageBreakVtbl;

    interface IVPageBreak
    {
        CONST_VTBL struct IVPageBreakVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IVPageBreak_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IVPageBreak_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IVPageBreak_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IVPageBreak_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IVPageBreak_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IVPageBreak_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IVPageBreak_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IVPageBreak_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IVPageBreak_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IVPageBreak_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IVPageBreak_Delete(This)	\
    ( (This)->lpVtbl -> Delete(This) ) 

#define IVPageBreak_DragOff(This,Direction,RegionIndex)	\
    ( (This)->lpVtbl -> DragOff(This,Direction,RegionIndex) ) 

#define IVPageBreak_get_Type(This,RHS)	\
    ( (This)->lpVtbl -> get_Type(This,RHS) ) 

#define IVPageBreak_put_Type(This,RHS)	\
    ( (This)->lpVtbl -> put_Type(This,RHS) ) 

#define IVPageBreak_get_Extent(This,RHS)	\
    ( (This)->lpVtbl -> get_Extent(This,RHS) ) 

#define IVPageBreak_get_Location(This,RHS)	\
    ( (This)->lpVtbl -> get_Location(This,RHS) ) 

#define IVPageBreak_putref_Location(This,RHS)	\
    ( (This)->lpVtbl -> putref_Location(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IVPageBreak_INTERFACE_DEFINED__ */


#ifndef __IHPageBreak_INTERFACE_DEFINED__
#define __IHPageBreak_INTERFACE_DEFINED__

/* interface IHPageBreak */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IHPageBreak;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024401-0001-0000-C000-000000000046")
    IHPageBreak : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ Worksheet	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall DragOff( 
            /* [in] */ XlDirection Direction,
            /* [in] */ long RegionIndex) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Type( 
            /* [retval][out] */ XlPageBreak *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Type( 
            /* [in] */ XlPageBreak RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Extent( 
            /* [retval][out] */ XlPageBreakExtent *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Location( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propputref][id] */ HRESULT __stdcall putref_Location( 
            /* [in] */ Range	*RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IHPageBreakVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IHPageBreak * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IHPageBreak * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IHPageBreak * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IHPageBreak * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IHPageBreak * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IHPageBreak * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IHPageBreak * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IHPageBreak * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IHPageBreak * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IHPageBreak * This,
            /* [retval][out] */ Worksheet	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IHPageBreak * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *DragOff )( 
            IHPageBreak * This,
            /* [in] */ XlDirection Direction,
            /* [in] */ long RegionIndex);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Type )( 
            IHPageBreak * This,
            /* [retval][out] */ XlPageBreak *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Type )( 
            IHPageBreak * This,
            /* [in] */ XlPageBreak RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Extent )( 
            IHPageBreak * This,
            /* [retval][out] */ XlPageBreakExtent *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Location )( 
            IHPageBreak * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propputref][id] */ HRESULT ( __stdcall *putref_Location )( 
            IHPageBreak * This,
            /* [in] */ Range	*RHS);
        
        END_INTERFACE
    } IHPageBreakVtbl;

    interface IHPageBreak
    {
        CONST_VTBL struct IHPageBreakVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IHPageBreak_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IHPageBreak_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IHPageBreak_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IHPageBreak_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IHPageBreak_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IHPageBreak_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IHPageBreak_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IHPageBreak_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IHPageBreak_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IHPageBreak_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IHPageBreak_Delete(This)	\
    ( (This)->lpVtbl -> Delete(This) ) 

#define IHPageBreak_DragOff(This,Direction,RegionIndex)	\
    ( (This)->lpVtbl -> DragOff(This,Direction,RegionIndex) ) 

#define IHPageBreak_get_Type(This,RHS)	\
    ( (This)->lpVtbl -> get_Type(This,RHS) ) 

#define IHPageBreak_put_Type(This,RHS)	\
    ( (This)->lpVtbl -> put_Type(This,RHS) ) 

#define IHPageBreak_get_Extent(This,RHS)	\
    ( (This)->lpVtbl -> get_Extent(This,RHS) ) 

#define IHPageBreak_get_Location(This,RHS)	\
    ( (This)->lpVtbl -> get_Location(This,RHS) ) 

#define IHPageBreak_putref_Location(This,RHS)	\
    ( (This)->lpVtbl -> putref_Location(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IHPageBreak_INTERFACE_DEFINED__ */


#ifndef __IHPageBreaks_INTERFACE_DEFINED__
#define __IHPageBreaks_INTERFACE_DEFINED__

/* interface IHPageBreaks */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IHPageBreaks;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024404-0001-0000-C000-000000000046")
    IHPageBreaks : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Item( 
            /* [in] */ long Index,
            /* [retval][out] */ HPageBreak	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ long Index,
            /* [retval][out] */ HPageBreak	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add( 
            /* [in] */ IDispatch *Before,
            /* [retval][out] */ HPageBreak	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IHPageBreaksVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IHPageBreaks * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IHPageBreaks * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IHPageBreaks * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IHPageBreaks * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IHPageBreaks * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IHPageBreaks * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IHPageBreaks * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IHPageBreaks * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IHPageBreaks * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IHPageBreaks * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IHPageBreaks * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Item )( 
            IHPageBreaks * This,
            /* [in] */ long Index,
            /* [retval][out] */ HPageBreak	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IHPageBreaks * This,
            /* [in] */ long Index,
            /* [retval][out] */ HPageBreak	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            IHPageBreaks * This,
            /* [retval][out] */ IUnknown **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add )( 
            IHPageBreaks * This,
            /* [in] */ IDispatch *Before,
            /* [retval][out] */ HPageBreak	**RHS);
        
        END_INTERFACE
    } IHPageBreaksVtbl;

    interface IHPageBreaks
    {
        CONST_VTBL struct IHPageBreaksVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IHPageBreaks_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IHPageBreaks_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IHPageBreaks_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IHPageBreaks_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IHPageBreaks_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IHPageBreaks_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IHPageBreaks_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IHPageBreaks_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IHPageBreaks_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IHPageBreaks_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IHPageBreaks_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IHPageBreaks_get_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Item(This,Index,RHS) ) 

#define IHPageBreaks_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define IHPageBreaks_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#define IHPageBreaks_Add(This,Before,RHS)	\
    ( (This)->lpVtbl -> Add(This,Before,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IHPageBreaks_INTERFACE_DEFINED__ */


#ifndef __IVPageBreaks_INTERFACE_DEFINED__
#define __IVPageBreaks_INTERFACE_DEFINED__

/* interface IVPageBreaks */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IVPageBreaks;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024405-0001-0000-C000-000000000046")
    IVPageBreaks : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Item( 
            /* [in] */ long Index,
            /* [retval][out] */ VPageBreak	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ long Index,
            /* [retval][out] */ VPageBreak	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add( 
            /* [in] */ IDispatch *Before,
            /* [retval][out] */ VPageBreak	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IVPageBreaksVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IVPageBreaks * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IVPageBreaks * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IVPageBreaks * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IVPageBreaks * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IVPageBreaks * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IVPageBreaks * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IVPageBreaks * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IVPageBreaks * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IVPageBreaks * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IVPageBreaks * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IVPageBreaks * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Item )( 
            IVPageBreaks * This,
            /* [in] */ long Index,
            /* [retval][out] */ VPageBreak	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IVPageBreaks * This,
            /* [in] */ long Index,
            /* [retval][out] */ VPageBreak	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            IVPageBreaks * This,
            /* [retval][out] */ IUnknown **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add )( 
            IVPageBreaks * This,
            /* [in] */ IDispatch *Before,
            /* [retval][out] */ VPageBreak	**RHS);
        
        END_INTERFACE
    } IVPageBreaksVtbl;

    interface IVPageBreaks
    {
        CONST_VTBL struct IVPageBreaksVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IVPageBreaks_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IVPageBreaks_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IVPageBreaks_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IVPageBreaks_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IVPageBreaks_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IVPageBreaks_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IVPageBreaks_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IVPageBreaks_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IVPageBreaks_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IVPageBreaks_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IVPageBreaks_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IVPageBreaks_get_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Item(This,Index,RHS) ) 

#define IVPageBreaks_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define IVPageBreaks_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#define IVPageBreaks_Add(This,Before,RHS)	\
    ( (This)->lpVtbl -> Add(This,Before,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IVPageBreaks_INTERFACE_DEFINED__ */


#ifndef __IRecentFile_INTERFACE_DEFINED__
#define __IRecentFile_INTERFACE_DEFINED__

/* interface IRecentFile */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IRecentFile;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024407-0001-0000-C000-000000000046")
    IRecentFile : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Path( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Index( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Open( 
            /* [retval][out] */ Workbook	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( void) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IRecentFileVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IRecentFile * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IRecentFile * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IRecentFile * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IRecentFile * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IRecentFile * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IRecentFile * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IRecentFile * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IRecentFile * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IRecentFile * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IRecentFile * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            IRecentFile * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Path )( 
            IRecentFile * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Index )( 
            IRecentFile * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Open )( 
            IRecentFile * This,
            /* [retval][out] */ Workbook	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IRecentFile * This);
        
        END_INTERFACE
    } IRecentFileVtbl;

    interface IRecentFile
    {
        CONST_VTBL struct IRecentFileVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IRecentFile_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IRecentFile_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IRecentFile_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IRecentFile_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IRecentFile_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IRecentFile_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IRecentFile_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IRecentFile_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IRecentFile_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IRecentFile_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IRecentFile_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define IRecentFile_get_Path(This,RHS)	\
    ( (This)->lpVtbl -> get_Path(This,RHS) ) 

#define IRecentFile_get_Index(This,RHS)	\
    ( (This)->lpVtbl -> get_Index(This,RHS) ) 

#define IRecentFile_Open(This,RHS)	\
    ( (This)->lpVtbl -> Open(This,RHS) ) 

#define IRecentFile_Delete(This)	\
    ( (This)->lpVtbl -> Delete(This) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IRecentFile_INTERFACE_DEFINED__ */


#ifndef __IRecentFiles_INTERFACE_DEFINED__
#define __IRecentFiles_INTERFACE_DEFINED__

/* interface IRecentFiles */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IRecentFiles;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024406-0001-0000-C000-000000000046")
    IRecentFiles : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Maximum( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Maximum( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Item( 
            /* [in] */ long Index,
            /* [retval][out] */ RecentFile	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ long Index,
            /* [retval][out] */ RecentFile	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add( 
            /* [in] */ BSTR Name,
            /* [retval][out] */ RecentFile	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IRecentFilesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IRecentFiles * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IRecentFiles * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IRecentFiles * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IRecentFiles * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IRecentFiles * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IRecentFiles * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IRecentFiles * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IRecentFiles * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IRecentFiles * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IRecentFiles * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Maximum )( 
            IRecentFiles * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Maximum )( 
            IRecentFiles * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IRecentFiles * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Item )( 
            IRecentFiles * This,
            /* [in] */ long Index,
            /* [retval][out] */ RecentFile	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IRecentFiles * This,
            /* [in] */ long Index,
            /* [retval][out] */ RecentFile	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add )( 
            IRecentFiles * This,
            /* [in] */ BSTR Name,
            /* [retval][out] */ RecentFile	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            IRecentFiles * This,
            /* [retval][out] */ IUnknown **RHS);
        
        END_INTERFACE
    } IRecentFilesVtbl;

    interface IRecentFiles
    {
        CONST_VTBL struct IRecentFilesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IRecentFiles_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IRecentFiles_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IRecentFiles_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IRecentFiles_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IRecentFiles_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IRecentFiles_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IRecentFiles_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IRecentFiles_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IRecentFiles_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IRecentFiles_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IRecentFiles_get_Maximum(This,RHS)	\
    ( (This)->lpVtbl -> get_Maximum(This,RHS) ) 

#define IRecentFiles_put_Maximum(This,RHS)	\
    ( (This)->lpVtbl -> put_Maximum(This,RHS) ) 

#define IRecentFiles_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IRecentFiles_get_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Item(This,Index,RHS) ) 

#define IRecentFiles_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define IRecentFiles_Add(This,Name,RHS)	\
    ( (This)->lpVtbl -> Add(This,Name,RHS) ) 

#define IRecentFiles_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IRecentFiles_INTERFACE_DEFINED__ */


#ifndef __IDocEvents_INTERFACE_DEFINED__
#define __IDocEvents_INTERFACE_DEFINED__

/* interface IDocEvents */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IDocEvents;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024411-0001-0000-C000-000000000046")
    IDocEvents : public IDispatch
    {
    public:
        virtual /* [helpcontext][id] */ HRESULT __stdcall SelectionChange( 
            /* [in] */ Range	*Target) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall BeforeDoubleClick( 
            /* [in] */ Range	*Target,
            /* [out][in] */ VARIANT_BOOL *Cancel) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall BeforeRightClick( 
            /* [in] */ Range	*Target,
            /* [out][in] */ VARIANT_BOOL *Cancel) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Activate( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Deactivate( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Calculate( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Change( 
            /* [in] */ Range	*Target) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall FollowHyperlink( 
            /* [in] */ Hyperlink	*Target) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall PivotTableUpdate( 
            /* [in] */ PivotTable	*Target) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall PivotTableAfterValueChange( 
            /* [in] */ PivotTable	*TargetPivotTable,
            /* [in] */ Range	*TargetRange) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall PivotTableBeforeAllocateChanges( 
            /* [in] */ PivotTable	*TargetPivotTable,
            /* [in] */ long ValueChangeStart,
            /* [in] */ long ValueChangeEnd,
            /* [out][in] */ VARIANT_BOOL *Cancel) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall PivotTableBeforeCommitChanges( 
            /* [in] */ PivotTable	*TargetPivotTable,
            /* [in] */ long ValueChangeStart,
            /* [in] */ long ValueChangeEnd,
            /* [out][in] */ VARIANT_BOOL *Cancel) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall PivotTableBeforeDiscardChanges( 
            /* [in] */ PivotTable	*TargetPivotTable,
            /* [in] */ long ValueChangeStart,
            /* [in] */ long ValueChangeEnd) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall PivotTableChangeSync( 
            /* [in] */ PivotTable	*Target) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall LensGalleryRenderComplete( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall TableUpdate( 
            /* [in] */ TableObject	*Target) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall BeforeDelete( void) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IDocEventsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IDocEvents * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IDocEvents * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IDocEvents * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IDocEvents * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IDocEvents * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IDocEvents * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IDocEvents * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SelectionChange )( 
            IDocEvents * This,
            /* [in] */ Range	*Target);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *BeforeDoubleClick )( 
            IDocEvents * This,
            /* [in] */ Range	*Target,
            /* [out][in] */ VARIANT_BOOL *Cancel);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *BeforeRightClick )( 
            IDocEvents * This,
            /* [in] */ Range	*Target,
            /* [out][in] */ VARIANT_BOOL *Cancel);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Activate )( 
            IDocEvents * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Deactivate )( 
            IDocEvents * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Calculate )( 
            IDocEvents * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Change )( 
            IDocEvents * This,
            /* [in] */ Range	*Target);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *FollowHyperlink )( 
            IDocEvents * This,
            /* [in] */ Hyperlink	*Target);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *PivotTableUpdate )( 
            IDocEvents * This,
            /* [in] */ PivotTable	*Target);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *PivotTableAfterValueChange )( 
            IDocEvents * This,
            /* [in] */ PivotTable	*TargetPivotTable,
            /* [in] */ Range	*TargetRange);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *PivotTableBeforeAllocateChanges )( 
            IDocEvents * This,
            /* [in] */ PivotTable	*TargetPivotTable,
            /* [in] */ long ValueChangeStart,
            /* [in] */ long ValueChangeEnd,
            /* [out][in] */ VARIANT_BOOL *Cancel);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *PivotTableBeforeCommitChanges )( 
            IDocEvents * This,
            /* [in] */ PivotTable	*TargetPivotTable,
            /* [in] */ long ValueChangeStart,
            /* [in] */ long ValueChangeEnd,
            /* [out][in] */ VARIANT_BOOL *Cancel);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *PivotTableBeforeDiscardChanges )( 
            IDocEvents * This,
            /* [in] */ PivotTable	*TargetPivotTable,
            /* [in] */ long ValueChangeStart,
            /* [in] */ long ValueChangeEnd);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *PivotTableChangeSync )( 
            IDocEvents * This,
            /* [in] */ PivotTable	*Target);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *LensGalleryRenderComplete )( 
            IDocEvents * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *TableUpdate )( 
            IDocEvents * This,
            /* [in] */ TableObject	*Target);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *BeforeDelete )( 
            IDocEvents * This);
        
        END_INTERFACE
    } IDocEventsVtbl;

    interface IDocEvents
    {
        CONST_VTBL struct IDocEventsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IDocEvents_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IDocEvents_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IDocEvents_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IDocEvents_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IDocEvents_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IDocEvents_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IDocEvents_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IDocEvents_SelectionChange(This,Target)	\
    ( (This)->lpVtbl -> SelectionChange(This,Target) ) 

#define IDocEvents_BeforeDoubleClick(This,Target,Cancel)	\
    ( (This)->lpVtbl -> BeforeDoubleClick(This,Target,Cancel) ) 

#define IDocEvents_BeforeRightClick(This,Target,Cancel)	\
    ( (This)->lpVtbl -> BeforeRightClick(This,Target,Cancel) ) 

#define IDocEvents_Activate(This)	\
    ( (This)->lpVtbl -> Activate(This) ) 

#define IDocEvents_Deactivate(This)	\
    ( (This)->lpVtbl -> Deactivate(This) ) 

#define IDocEvents_Calculate(This)	\
    ( (This)->lpVtbl -> Calculate(This) ) 

#define IDocEvents_Change(This,Target)	\
    ( (This)->lpVtbl -> Change(This,Target) ) 

#define IDocEvents_FollowHyperlink(This,Target)	\
    ( (This)->lpVtbl -> FollowHyperlink(This,Target) ) 

#define IDocEvents_PivotTableUpdate(This,Target)	\
    ( (This)->lpVtbl -> PivotTableUpdate(This,Target) ) 

#define IDocEvents_PivotTableAfterValueChange(This,TargetPivotTable,TargetRange)	\
    ( (This)->lpVtbl -> PivotTableAfterValueChange(This,TargetPivotTable,TargetRange) ) 

#define IDocEvents_PivotTableBeforeAllocateChanges(This,TargetPivotTable,ValueChangeStart,ValueChangeEnd,Cancel)	\
    ( (This)->lpVtbl -> PivotTableBeforeAllocateChanges(This,TargetPivotTable,ValueChangeStart,ValueChangeEnd,Cancel) ) 

#define IDocEvents_PivotTableBeforeCommitChanges(This,TargetPivotTable,ValueChangeStart,ValueChangeEnd,Cancel)	\
    ( (This)->lpVtbl -> PivotTableBeforeCommitChanges(This,TargetPivotTable,ValueChangeStart,ValueChangeEnd,Cancel) ) 

#define IDocEvents_PivotTableBeforeDiscardChanges(This,TargetPivotTable,ValueChangeStart,ValueChangeEnd)	\
    ( (This)->lpVtbl -> PivotTableBeforeDiscardChanges(This,TargetPivotTable,ValueChangeStart,ValueChangeEnd) ) 

#define IDocEvents_PivotTableChangeSync(This,Target)	\
    ( (This)->lpVtbl -> PivotTableChangeSync(This,Target) ) 

#define IDocEvents_LensGalleryRenderComplete(This)	\
    ( (This)->lpVtbl -> LensGalleryRenderComplete(This) ) 

#define IDocEvents_TableUpdate(This,Target)	\
    ( (This)->lpVtbl -> TableUpdate(This,Target) ) 

#define IDocEvents_BeforeDelete(This)	\
    ( (This)->lpVtbl -> BeforeDelete(This) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IDocEvents_INTERFACE_DEFINED__ */


#ifndef ___Worksheet_INTERFACE_DEFINED__
#define ___Worksheet_INTERFACE_DEFINED__

/* interface _Worksheet */
/* [object][oleautomation][nonextensible][dual][helpcontext][uuid] */ 


EXTERN_C const IID IID__Worksheet;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000208D8-0000-0000-C000-000000000046")
    _Worksheet : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Activate( 
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Copy( 
            /* [optional][in] */ VARIANT Before,
            /* [optional][in] */ VARIANT After,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Delete( 
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_CodeName( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get__CodeName( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put__CodeName( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Index( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Move( 
            /* [optional][in] */ VARIANT Before,
            /* [optional][in] */ VARIANT After,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_Name( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Next( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_OnDoubleClick( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE put_OnDoubleClick( 
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_OnSheetActivate( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE put_OnSheetActivate( 
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_OnSheetDeactivate( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE put_OnSheetDeactivate( 
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_PageSetup( 
            /* [retval][out] */ PageSetup	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Previous( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [custom][helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE __PrintOut( 
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE PrintPreview( 
            /* [optional][in] */ VARIANT EnableChanges,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE _Protect( 
            /* [optional][in] */ VARIANT Password,
            /* [optional][in] */ VARIANT DrawingObjects,
            /* [optional][in] */ VARIANT Contents,
            /* [optional][in] */ VARIANT Scenarios,
            /* [optional][in] */ VARIANT UserInterfaceOnly,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ProtectContents( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ProtectDrawingObjects( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ProtectionMode( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ProtectScenarios( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE _SaveAs( 
            /* [in] */ BSTR Filename,
            /* [optional][in] */ VARIANT FileFormat,
            /* [optional][in] */ VARIANT Password,
            /* [optional][in] */ VARIANT WriteResPassword,
            /* [optional][in] */ VARIANT ReadOnlyRecommended,
            /* [optional][in] */ VARIANT CreateBackup,
            /* [optional][in] */ VARIANT AddToMru,
            /* [optional][in] */ VARIANT TextCodepage,
            /* [optional][in] */ VARIANT TextVisualLayout,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Select( 
            /* [optional][in] */ VARIANT Replace,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Unprotect( 
            /* [optional][in] */ VARIANT Password,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Visible( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ XlSheetVisibility *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_Visible( 
            /* [lcid][in] */ long lcid,
            /* [in] */ XlSheetVisibility RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Shapes( 
            /* [retval][out] */ Shapes	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_TransitionExpEval( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_TransitionExpEval( 
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE Arcs( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_AutoFilterMode( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_AutoFilterMode( 
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE SetBackgroundPicture( 
            /* [in] */ BSTR Filename) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE Buttons( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Calculate( 
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_EnableCalculation( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_EnableCalculation( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Cells( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE ChartObjects( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE CheckBoxes( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE CheckSpelling( 
            /* [optional][in] */ VARIANT CustomDictionary,
            /* [optional][in] */ VARIANT IgnoreUppercase,
            /* [optional][in] */ VARIANT AlwaysSuggest,
            /* [optional][in] */ VARIANT SpellLang,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_CircularReference( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE ClearArrows( 
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Columns( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ConsolidationFunction( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ XlConsolidationFunction *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ConsolidationOptions( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ConsolidationSources( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_DisplayAutomaticPageBreaks( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE put_DisplayAutomaticPageBreaks( 
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE Drawings( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE DrawingObjects( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE DropDowns( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_EnableAutoFilter( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_EnableAutoFilter( 
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_EnableSelection( 
            /* [retval][out] */ XlEnableSelection *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_EnableSelection( 
            /* [in] */ XlEnableSelection RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_EnableOutlining( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_EnableOutlining( 
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_EnablePivotTable( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_EnablePivotTable( 
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Evaluate( 
            /* [in] */ VARIANT Name,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Evaluate( 
            /* [in] */ VARIANT Name,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_FilterMode( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE ResetAllPageBreaks( void) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE GroupBoxes( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE GroupObjects( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE Labels( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE Lines( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE ListBoxes( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Names( 
            /* [retval][out] */ Names	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE OLEObjects( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_OnCalculate( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE put_OnCalculate( 
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_OnData( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE put_OnData( 
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_OnEntry( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE put_OnEntry( 
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE OptionButtons( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Outline( 
            /* [retval][out] */ Outline	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE Ovals( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Paste( 
            /* [optional][in] */ VARIANT Destination,
            /* [optional][in] */ VARIANT Link,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE _PasteSpecial( 
            /* [optional][in] */ VARIANT Format,
            /* [optional][in] */ VARIANT Link,
            /* [optional][in] */ VARIANT DisplayAsIcon,
            /* [optional][in] */ VARIANT IconFileName,
            /* [optional][in] */ VARIANT IconIndex,
            /* [optional][in] */ VARIANT IconLabel,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE Pictures( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE PivotTables( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE PivotTableWizard( 
            /* [optional][in] */ VARIANT SourceType,
            /* [optional][in] */ VARIANT SourceData,
            /* [optional][in] */ VARIANT TableDestination,
            /* [optional][in] */ VARIANT TableName,
            /* [optional][in] */ VARIANT RowGrand,
            /* [optional][in] */ VARIANT ColumnGrand,
            /* [optional][in] */ VARIANT SaveData,
            /* [optional][in] */ VARIANT HasAutoFormat,
            /* [optional][in] */ VARIANT AutoPage,
            /* [optional][in] */ VARIANT Reserved,
            /* [optional][in] */ VARIANT BackgroundQuery,
            /* [optional][in] */ VARIANT OptimizeCache,
            /* [optional][in] */ VARIANT PageFieldOrder,
            /* [optional][in] */ VARIANT PageFieldWrapCount,
            /* [optional][in] */ VARIANT ReadData,
            /* [optional][in] */ VARIANT Connection,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ PivotTable	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Range( 
            /* [in] */ VARIANT Cell1,
            /* [optional][in] */ VARIANT Cell2,
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE Rectangles( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Rows( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Scenarios( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ScrollArea( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_ScrollArea( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE ScrollBars( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE ShowAllData( 
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE ShowDataForm( 
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE Spinners( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_StandardHeight( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_StandardWidth( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_StandardWidth( 
            /* [lcid][in] */ long lcid,
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE TextBoxes( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_TransitionFormEntry( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_TransitionFormEntry( 
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Type( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ XlSheetType *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_UsedRange( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_HPageBreaks( 
            /* [retval][out] */ HPageBreaks	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_VPageBreaks( 
            /* [retval][out] */ VPageBreaks	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_QueryTables( 
            /* [retval][out] */ QueryTables	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_DisplayPageBreaks( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_DisplayPageBreaks( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Comments( 
            /* [retval][out] */ Comments	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Hyperlinks( 
            /* [retval][out] */ Hyperlinks	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE ClearCircles( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE CircleInvalid( void) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get__DisplayRightToLeft( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE put__DisplayRightToLeft( 
            /* [lcid][in] */ long lcid,
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_AutoFilter( 
            /* [retval][out] */ AutoFilter	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_DisplayRightToLeft( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_DisplayRightToLeft( 
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_Scripts( 
            /* [retval][out] */ /* external definition not present */ Scripts **RHS) = 0;
        
        virtual /* [custom][helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE _PrintOut( 
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate,
            /* [optional][in] */ VARIANT PrToFileName,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE _CheckSpelling( 
            /* [optional][in] */ VARIANT CustomDictionary,
            /* [optional][in] */ VARIANT IgnoreUppercase,
            /* [optional][in] */ VARIANT AlwaysSuggest,
            /* [optional][in] */ VARIANT SpellLang,
            /* [optional][in] */ VARIANT IgnoreFinalYaa,
            /* [optional][in] */ VARIANT SpellScript,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Tab( 
            /* [retval][out] */ Tab	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_MailEnvelope( 
            /* [retval][out] */ /* external definition not present */ MsoEnvelope **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE SaveAs( 
            /* [in] */ BSTR Filename,
            /* [optional][in] */ VARIANT FileFormat,
            /* [optional][in] */ VARIANT Password,
            /* [optional][in] */ VARIANT WriteResPassword,
            /* [optional][in] */ VARIANT ReadOnlyRecommended,
            /* [optional][in] */ VARIANT CreateBackup,
            /* [optional][in] */ VARIANT AddToMru,
            /* [optional][in] */ VARIANT TextCodepage,
            /* [optional][in] */ VARIANT TextVisualLayout,
            /* [optional][in] */ VARIANT Local) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_CustomProperties( 
            /* [retval][out] */ CustomProperties	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_SmartTags( 
            /* [retval][out] */ SmartTags	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Protection( 
            /* [retval][out] */ Protection	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE PasteSpecial( 
            /* [optional][in] */ VARIANT Format,
            /* [optional][in] */ VARIANT Link,
            /* [optional][in] */ VARIANT DisplayAsIcon,
            /* [optional][in] */ VARIANT IconFileName,
            /* [optional][in] */ VARIANT IconIndex,
            /* [optional][in] */ VARIANT IconLabel,
            /* [optional][in] */ VARIANT NoHTMLFormatting,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Protect( 
            /* [optional][in] */ VARIANT Password,
            /* [optional][in] */ VARIANT DrawingObjects,
            /* [optional][in] */ VARIANT Contents,
            /* [optional][in] */ VARIANT Scenarios,
            /* [optional][in] */ VARIANT UserInterfaceOnly,
            /* [optional][in] */ VARIANT AllowFormattingCells,
            /* [optional][in] */ VARIANT AllowFormattingColumns,
            /* [optional][in] */ VARIANT AllowFormattingRows,
            /* [optional][in] */ VARIANT AllowInsertingColumns,
            /* [optional][in] */ VARIANT AllowInsertingRows,
            /* [optional][in] */ VARIANT AllowInsertingHyperlinks,
            /* [optional][in] */ VARIANT AllowDeletingColumns,
            /* [optional][in] */ VARIANT AllowDeletingRows,
            /* [optional][in] */ VARIANT AllowSorting,
            /* [optional][in] */ VARIANT AllowFiltering,
            /* [optional][in] */ VARIANT AllowUsingPivotTables) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ListObjects( 
            /* [retval][out] */ ListObjects	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE XmlDataQuery( 
            /* [in] */ BSTR XPath,
            /* [optional][in] */ VARIANT SelectionNamespaces,
            /* [optional][in] */ VARIANT Map,
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE XmlMapQuery( 
            /* [in] */ BSTR XPath,
            /* [optional][in] */ VARIANT SelectionNamespaces,
            /* [optional][in] */ VARIANT Map,
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [custom][helpcontext][id] */ HRESULT STDMETHODCALLTYPE PrintOut( 
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate,
            /* [optional][in] */ VARIANT PrToFileName,
            /* [optional][in] */ VARIANT IgnorePrintAreas,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_EnableFormatConditionsCalculation( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_EnableFormatConditionsCalculation( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Sort( 
            /* [retval][out] */ Sort	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE ExportAsFixedFormat( 
            /* [in] */ XlFixedFormatType Type,
            /* [optional][in] */ VARIANT Filename,
            /* [optional][in] */ VARIANT Quality,
            /* [optional][in] */ VARIANT IncludeDocProperties,
            /* [optional][in] */ VARIANT IgnorePrintAreas,
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT OpenAfterPublish,
            /* [optional][in] */ VARIANT FixedFormatExtClassPtr) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_PrintedCommentPages( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [id] */ HRESULT STDMETHODCALLTYPE ExportToPNG( 
            /* [in] */ VARIANT FilePath) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct _WorksheetVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            _Worksheet * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            _Worksheet * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            _Worksheet * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            _Worksheet * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            _Worksheet * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            _Worksheet * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            _Worksheet * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Application )( 
            _Worksheet * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Creator )( 
            _Worksheet * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Parent )( 
            _Worksheet * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Activate )( 
            _Worksheet * This,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Copy )( 
            _Worksheet * This,
            /* [optional][in] */ VARIANT Before,
            /* [optional][in] */ VARIANT After,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Delete )( 
            _Worksheet * This,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_CodeName )( 
            _Worksheet * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get__CodeName )( 
            _Worksheet * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put__CodeName )( 
            _Worksheet * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Index )( 
            _Worksheet * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Move )( 
            _Worksheet * This,
            /* [optional][in] */ VARIANT Before,
            /* [optional][in] */ VARIANT After,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Name )( 
            _Worksheet * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Name )( 
            _Worksheet * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Next )( 
            _Worksheet * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_OnDoubleClick )( 
            _Worksheet * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_OnDoubleClick )( 
            _Worksheet * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_OnSheetActivate )( 
            _Worksheet * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_OnSheetActivate )( 
            _Worksheet * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_OnSheetDeactivate )( 
            _Worksheet * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_OnSheetDeactivate )( 
            _Worksheet * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_PageSetup )( 
            _Worksheet * This,
            /* [retval][out] */ PageSetup	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Previous )( 
            _Worksheet * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [custom][helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *__PrintOut )( 
            _Worksheet * This,
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *PrintPreview )( 
            _Worksheet * This,
            /* [optional][in] */ VARIANT EnableChanges,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *_Protect )( 
            _Worksheet * This,
            /* [optional][in] */ VARIANT Password,
            /* [optional][in] */ VARIANT DrawingObjects,
            /* [optional][in] */ VARIANT Contents,
            /* [optional][in] */ VARIANT Scenarios,
            /* [optional][in] */ VARIANT UserInterfaceOnly,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ProtectContents )( 
            _Worksheet * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ProtectDrawingObjects )( 
            _Worksheet * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ProtectionMode )( 
            _Worksheet * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ProtectScenarios )( 
            _Worksheet * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *_SaveAs )( 
            _Worksheet * This,
            /* [in] */ BSTR Filename,
            /* [optional][in] */ VARIANT FileFormat,
            /* [optional][in] */ VARIANT Password,
            /* [optional][in] */ VARIANT WriteResPassword,
            /* [optional][in] */ VARIANT ReadOnlyRecommended,
            /* [optional][in] */ VARIANT CreateBackup,
            /* [optional][in] */ VARIANT AddToMru,
            /* [optional][in] */ VARIANT TextCodepage,
            /* [optional][in] */ VARIANT TextVisualLayout,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Select )( 
            _Worksheet * This,
            /* [optional][in] */ VARIANT Replace,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Unprotect )( 
            _Worksheet * This,
            /* [optional][in] */ VARIANT Password,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Visible )( 
            _Worksheet * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ XlSheetVisibility *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Visible )( 
            _Worksheet * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ XlSheetVisibility RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Shapes )( 
            _Worksheet * This,
            /* [retval][out] */ Shapes	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_TransitionExpEval )( 
            _Worksheet * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_TransitionExpEval )( 
            _Worksheet * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *Arcs )( 
            _Worksheet * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_AutoFilterMode )( 
            _Worksheet * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_AutoFilterMode )( 
            _Worksheet * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *SetBackgroundPicture )( 
            _Worksheet * This,
            /* [in] */ BSTR Filename);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *Buttons )( 
            _Worksheet * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Calculate )( 
            _Worksheet * This,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_EnableCalculation )( 
            _Worksheet * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_EnableCalculation )( 
            _Worksheet * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Cells )( 
            _Worksheet * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *ChartObjects )( 
            _Worksheet * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *CheckBoxes )( 
            _Worksheet * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *CheckSpelling )( 
            _Worksheet * This,
            /* [optional][in] */ VARIANT CustomDictionary,
            /* [optional][in] */ VARIANT IgnoreUppercase,
            /* [optional][in] */ VARIANT AlwaysSuggest,
            /* [optional][in] */ VARIANT SpellLang,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_CircularReference )( 
            _Worksheet * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *ClearArrows )( 
            _Worksheet * This,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Columns )( 
            _Worksheet * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ConsolidationFunction )( 
            _Worksheet * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ XlConsolidationFunction *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ConsolidationOptions )( 
            _Worksheet * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ConsolidationSources )( 
            _Worksheet * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_DisplayAutomaticPageBreaks )( 
            _Worksheet * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_DisplayAutomaticPageBreaks )( 
            _Worksheet * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *Drawings )( 
            _Worksheet * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *DrawingObjects )( 
            _Worksheet * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *DropDowns )( 
            _Worksheet * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_EnableAutoFilter )( 
            _Worksheet * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_EnableAutoFilter )( 
            _Worksheet * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_EnableSelection )( 
            _Worksheet * This,
            /* [retval][out] */ XlEnableSelection *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_EnableSelection )( 
            _Worksheet * This,
            /* [in] */ XlEnableSelection RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_EnableOutlining )( 
            _Worksheet * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_EnableOutlining )( 
            _Worksheet * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_EnablePivotTable )( 
            _Worksheet * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_EnablePivotTable )( 
            _Worksheet * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Evaluate )( 
            _Worksheet * This,
            /* [in] */ VARIANT Name,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *_Evaluate )( 
            _Worksheet * This,
            /* [in] */ VARIANT Name,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_FilterMode )( 
            _Worksheet * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *ResetAllPageBreaks )( 
            _Worksheet * This);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *GroupBoxes )( 
            _Worksheet * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *GroupObjects )( 
            _Worksheet * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *Labels )( 
            _Worksheet * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *Lines )( 
            _Worksheet * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *ListBoxes )( 
            _Worksheet * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Names )( 
            _Worksheet * This,
            /* [retval][out] */ Names	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *OLEObjects )( 
            _Worksheet * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_OnCalculate )( 
            _Worksheet * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_OnCalculate )( 
            _Worksheet * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_OnData )( 
            _Worksheet * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_OnData )( 
            _Worksheet * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_OnEntry )( 
            _Worksheet * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_OnEntry )( 
            _Worksheet * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *OptionButtons )( 
            _Worksheet * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Outline )( 
            _Worksheet * This,
            /* [retval][out] */ Outline	**RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *Ovals )( 
            _Worksheet * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Paste )( 
            _Worksheet * This,
            /* [optional][in] */ VARIANT Destination,
            /* [optional][in] */ VARIANT Link,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *_PasteSpecial )( 
            _Worksheet * This,
            /* [optional][in] */ VARIANT Format,
            /* [optional][in] */ VARIANT Link,
            /* [optional][in] */ VARIANT DisplayAsIcon,
            /* [optional][in] */ VARIANT IconFileName,
            /* [optional][in] */ VARIANT IconIndex,
            /* [optional][in] */ VARIANT IconLabel,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *Pictures )( 
            _Worksheet * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *PivotTables )( 
            _Worksheet * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *PivotTableWizard )( 
            _Worksheet * This,
            /* [optional][in] */ VARIANT SourceType,
            /* [optional][in] */ VARIANT SourceData,
            /* [optional][in] */ VARIANT TableDestination,
            /* [optional][in] */ VARIANT TableName,
            /* [optional][in] */ VARIANT RowGrand,
            /* [optional][in] */ VARIANT ColumnGrand,
            /* [optional][in] */ VARIANT SaveData,
            /* [optional][in] */ VARIANT HasAutoFormat,
            /* [optional][in] */ VARIANT AutoPage,
            /* [optional][in] */ VARIANT Reserved,
            /* [optional][in] */ VARIANT BackgroundQuery,
            /* [optional][in] */ VARIANT OptimizeCache,
            /* [optional][in] */ VARIANT PageFieldOrder,
            /* [optional][in] */ VARIANT PageFieldWrapCount,
            /* [optional][in] */ VARIANT ReadData,
            /* [optional][in] */ VARIANT Connection,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ PivotTable	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Range )( 
            _Worksheet * This,
            /* [in] */ VARIANT Cell1,
            /* [optional][in] */ VARIANT Cell2,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *Rectangles )( 
            _Worksheet * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Rows )( 
            _Worksheet * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Scenarios )( 
            _Worksheet * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ScrollArea )( 
            _Worksheet * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_ScrollArea )( 
            _Worksheet * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *ScrollBars )( 
            _Worksheet * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *ShowAllData )( 
            _Worksheet * This,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *ShowDataForm )( 
            _Worksheet * This,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *Spinners )( 
            _Worksheet * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_StandardHeight )( 
            _Worksheet * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_StandardWidth )( 
            _Worksheet * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_StandardWidth )( 
            _Worksheet * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ double RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *TextBoxes )( 
            _Worksheet * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_TransitionFormEntry )( 
            _Worksheet * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_TransitionFormEntry )( 
            _Worksheet * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Type )( 
            _Worksheet * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ XlSheetType *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_UsedRange )( 
            _Worksheet * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_HPageBreaks )( 
            _Worksheet * This,
            /* [retval][out] */ HPageBreaks	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_VPageBreaks )( 
            _Worksheet * This,
            /* [retval][out] */ VPageBreaks	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_QueryTables )( 
            _Worksheet * This,
            /* [retval][out] */ QueryTables	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_DisplayPageBreaks )( 
            _Worksheet * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_DisplayPageBreaks )( 
            _Worksheet * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Comments )( 
            _Worksheet * This,
            /* [retval][out] */ Comments	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Hyperlinks )( 
            _Worksheet * This,
            /* [retval][out] */ Hyperlinks	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *ClearCircles )( 
            _Worksheet * This);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *CircleInvalid )( 
            _Worksheet * This);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get__DisplayRightToLeft )( 
            _Worksheet * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put__DisplayRightToLeft )( 
            _Worksheet * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_AutoFilter )( 
            _Worksheet * This,
            /* [retval][out] */ AutoFilter	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_DisplayRightToLeft )( 
            _Worksheet * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_DisplayRightToLeft )( 
            _Worksheet * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Scripts )( 
            _Worksheet * This,
            /* [retval][out] */ /* external definition not present */ Scripts **RHS);
        
        /* [custom][helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *_PrintOut )( 
            _Worksheet * This,
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate,
            /* [optional][in] */ VARIANT PrToFileName,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *_CheckSpelling )( 
            _Worksheet * This,
            /* [optional][in] */ VARIANT CustomDictionary,
            /* [optional][in] */ VARIANT IgnoreUppercase,
            /* [optional][in] */ VARIANT AlwaysSuggest,
            /* [optional][in] */ VARIANT SpellLang,
            /* [optional][in] */ VARIANT IgnoreFinalYaa,
            /* [optional][in] */ VARIANT SpellScript,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Tab )( 
            _Worksheet * This,
            /* [retval][out] */ Tab	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_MailEnvelope )( 
            _Worksheet * This,
            /* [retval][out] */ /* external definition not present */ MsoEnvelope **RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *SaveAs )( 
            _Worksheet * This,
            /* [in] */ BSTR Filename,
            /* [optional][in] */ VARIANT FileFormat,
            /* [optional][in] */ VARIANT Password,
            /* [optional][in] */ VARIANT WriteResPassword,
            /* [optional][in] */ VARIANT ReadOnlyRecommended,
            /* [optional][in] */ VARIANT CreateBackup,
            /* [optional][in] */ VARIANT AddToMru,
            /* [optional][in] */ VARIANT TextCodepage,
            /* [optional][in] */ VARIANT TextVisualLayout,
            /* [optional][in] */ VARIANT Local);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_CustomProperties )( 
            _Worksheet * This,
            /* [retval][out] */ CustomProperties	**RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_SmartTags )( 
            _Worksheet * This,
            /* [retval][out] */ SmartTags	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Protection )( 
            _Worksheet * This,
            /* [retval][out] */ Protection	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *PasteSpecial )( 
            _Worksheet * This,
            /* [optional][in] */ VARIANT Format,
            /* [optional][in] */ VARIANT Link,
            /* [optional][in] */ VARIANT DisplayAsIcon,
            /* [optional][in] */ VARIANT IconFileName,
            /* [optional][in] */ VARIANT IconIndex,
            /* [optional][in] */ VARIANT IconLabel,
            /* [optional][in] */ VARIANT NoHTMLFormatting,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Protect )( 
            _Worksheet * This,
            /* [optional][in] */ VARIANT Password,
            /* [optional][in] */ VARIANT DrawingObjects,
            /* [optional][in] */ VARIANT Contents,
            /* [optional][in] */ VARIANT Scenarios,
            /* [optional][in] */ VARIANT UserInterfaceOnly,
            /* [optional][in] */ VARIANT AllowFormattingCells,
            /* [optional][in] */ VARIANT AllowFormattingColumns,
            /* [optional][in] */ VARIANT AllowFormattingRows,
            /* [optional][in] */ VARIANT AllowInsertingColumns,
            /* [optional][in] */ VARIANT AllowInsertingRows,
            /* [optional][in] */ VARIANT AllowInsertingHyperlinks,
            /* [optional][in] */ VARIANT AllowDeletingColumns,
            /* [optional][in] */ VARIANT AllowDeletingRows,
            /* [optional][in] */ VARIANT AllowSorting,
            /* [optional][in] */ VARIANT AllowFiltering,
            /* [optional][in] */ VARIANT AllowUsingPivotTables);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ListObjects )( 
            _Worksheet * This,
            /* [retval][out] */ ListObjects	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *XmlDataQuery )( 
            _Worksheet * This,
            /* [in] */ BSTR XPath,
            /* [optional][in] */ VARIANT SelectionNamespaces,
            /* [optional][in] */ VARIANT Map,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *XmlMapQuery )( 
            _Worksheet * This,
            /* [in] */ BSTR XPath,
            /* [optional][in] */ VARIANT SelectionNamespaces,
            /* [optional][in] */ VARIANT Map,
            /* [retval][out] */ Range	**RHS);
        
        /* [custom][helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *PrintOut )( 
            _Worksheet * This,
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate,
            /* [optional][in] */ VARIANT PrToFileName,
            /* [optional][in] */ VARIANT IgnorePrintAreas,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_EnableFormatConditionsCalculation )( 
            _Worksheet * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_EnableFormatConditionsCalculation )( 
            _Worksheet * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Sort )( 
            _Worksheet * This,
            /* [retval][out] */ Sort	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *ExportAsFixedFormat )( 
            _Worksheet * This,
            /* [in] */ XlFixedFormatType Type,
            /* [optional][in] */ VARIANT Filename,
            /* [optional][in] */ VARIANT Quality,
            /* [optional][in] */ VARIANT IncludeDocProperties,
            /* [optional][in] */ VARIANT IgnorePrintAreas,
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT OpenAfterPublish,
            /* [optional][in] */ VARIANT FixedFormatExtClassPtr);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_PrintedCommentPages )( 
            _Worksheet * This,
            /* [retval][out] */ long *RHS);
        
        /* [id] */ HRESULT ( STDMETHODCALLTYPE *ExportToPNG )( 
            _Worksheet * This,
            /* [in] */ VARIANT FilePath);
        
        END_INTERFACE
    } _WorksheetVtbl;

    interface _Worksheet
    {
        CONST_VTBL struct _WorksheetVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define _Worksheet_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define _Worksheet_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define _Worksheet_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define _Worksheet_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define _Worksheet_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define _Worksheet_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define _Worksheet_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define _Worksheet_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define _Worksheet_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define _Worksheet_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define _Worksheet_Activate(This,lcid)	\
    ( (This)->lpVtbl -> Activate(This,lcid) ) 

#define _Worksheet_Copy(This,Before,After,lcid)	\
    ( (This)->lpVtbl -> Copy(This,Before,After,lcid) ) 

#define _Worksheet_Delete(This,lcid)	\
    ( (This)->lpVtbl -> Delete(This,lcid) ) 

#define _Worksheet_get_CodeName(This,RHS)	\
    ( (This)->lpVtbl -> get_CodeName(This,RHS) ) 

#define _Worksheet_get__CodeName(This,RHS)	\
    ( (This)->lpVtbl -> get__CodeName(This,RHS) ) 

#define _Worksheet_put__CodeName(This,RHS)	\
    ( (This)->lpVtbl -> put__CodeName(This,RHS) ) 

#define _Worksheet_get_Index(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_Index(This,lcid,RHS) ) 

#define _Worksheet_Move(This,Before,After,lcid)	\
    ( (This)->lpVtbl -> Move(This,Before,After,lcid) ) 

#define _Worksheet_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define _Worksheet_put_Name(This,RHS)	\
    ( (This)->lpVtbl -> put_Name(This,RHS) ) 

#define _Worksheet_get_Next(This,RHS)	\
    ( (This)->lpVtbl -> get_Next(This,RHS) ) 

#define _Worksheet_get_OnDoubleClick(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_OnDoubleClick(This,lcid,RHS) ) 

#define _Worksheet_put_OnDoubleClick(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_OnDoubleClick(This,lcid,RHS) ) 

#define _Worksheet_get_OnSheetActivate(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_OnSheetActivate(This,lcid,RHS) ) 

#define _Worksheet_put_OnSheetActivate(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_OnSheetActivate(This,lcid,RHS) ) 

#define _Worksheet_get_OnSheetDeactivate(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_OnSheetDeactivate(This,lcid,RHS) ) 

#define _Worksheet_put_OnSheetDeactivate(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_OnSheetDeactivate(This,lcid,RHS) ) 

#define _Worksheet_get_PageSetup(This,RHS)	\
    ( (This)->lpVtbl -> get_PageSetup(This,RHS) ) 

#define _Worksheet_get_Previous(This,RHS)	\
    ( (This)->lpVtbl -> get_Previous(This,RHS) ) 

#define _Worksheet___PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate,lcid)	\
    ( (This)->lpVtbl -> __PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate,lcid) ) 

#define _Worksheet_PrintPreview(This,EnableChanges,lcid)	\
    ( (This)->lpVtbl -> PrintPreview(This,EnableChanges,lcid) ) 

#define _Worksheet__Protect(This,Password,DrawingObjects,Contents,Scenarios,UserInterfaceOnly,lcid)	\
    ( (This)->lpVtbl -> _Protect(This,Password,DrawingObjects,Contents,Scenarios,UserInterfaceOnly,lcid) ) 

#define _Worksheet_get_ProtectContents(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_ProtectContents(This,lcid,RHS) ) 

#define _Worksheet_get_ProtectDrawingObjects(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_ProtectDrawingObjects(This,lcid,RHS) ) 

#define _Worksheet_get_ProtectionMode(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_ProtectionMode(This,lcid,RHS) ) 

#define _Worksheet_get_ProtectScenarios(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_ProtectScenarios(This,lcid,RHS) ) 

#define _Worksheet__SaveAs(This,Filename,FileFormat,Password,WriteResPassword,ReadOnlyRecommended,CreateBackup,AddToMru,TextCodepage,TextVisualLayout,lcid)	\
    ( (This)->lpVtbl -> _SaveAs(This,Filename,FileFormat,Password,WriteResPassword,ReadOnlyRecommended,CreateBackup,AddToMru,TextCodepage,TextVisualLayout,lcid) ) 

#define _Worksheet_Select(This,Replace,lcid)	\
    ( (This)->lpVtbl -> Select(This,Replace,lcid) ) 

#define _Worksheet_Unprotect(This,Password,lcid)	\
    ( (This)->lpVtbl -> Unprotect(This,Password,lcid) ) 

#define _Worksheet_get_Visible(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_Visible(This,lcid,RHS) ) 

#define _Worksheet_put_Visible(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_Visible(This,lcid,RHS) ) 

#define _Worksheet_get_Shapes(This,RHS)	\
    ( (This)->lpVtbl -> get_Shapes(This,RHS) ) 

#define _Worksheet_get_TransitionExpEval(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_TransitionExpEval(This,lcid,RHS) ) 

#define _Worksheet_put_TransitionExpEval(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_TransitionExpEval(This,lcid,RHS) ) 

#define _Worksheet_Arcs(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> Arcs(This,Index,lcid,RHS) ) 

#define _Worksheet_get_AutoFilterMode(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_AutoFilterMode(This,lcid,RHS) ) 

#define _Worksheet_put_AutoFilterMode(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_AutoFilterMode(This,lcid,RHS) ) 

#define _Worksheet_SetBackgroundPicture(This,Filename)	\
    ( (This)->lpVtbl -> SetBackgroundPicture(This,Filename) ) 

#define _Worksheet_Buttons(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> Buttons(This,Index,lcid,RHS) ) 

#define _Worksheet_Calculate(This,lcid)	\
    ( (This)->lpVtbl -> Calculate(This,lcid) ) 

#define _Worksheet_get_EnableCalculation(This,RHS)	\
    ( (This)->lpVtbl -> get_EnableCalculation(This,RHS) ) 

#define _Worksheet_put_EnableCalculation(This,RHS)	\
    ( (This)->lpVtbl -> put_EnableCalculation(This,RHS) ) 

#define _Worksheet_get_Cells(This,RHS)	\
    ( (This)->lpVtbl -> get_Cells(This,RHS) ) 

#define _Worksheet_ChartObjects(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> ChartObjects(This,Index,lcid,RHS) ) 

#define _Worksheet_CheckBoxes(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> CheckBoxes(This,Index,lcid,RHS) ) 

#define _Worksheet_CheckSpelling(This,CustomDictionary,IgnoreUppercase,AlwaysSuggest,SpellLang,lcid)	\
    ( (This)->lpVtbl -> CheckSpelling(This,CustomDictionary,IgnoreUppercase,AlwaysSuggest,SpellLang,lcid) ) 

#define _Worksheet_get_CircularReference(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_CircularReference(This,lcid,RHS) ) 

#define _Worksheet_ClearArrows(This,lcid)	\
    ( (This)->lpVtbl -> ClearArrows(This,lcid) ) 

#define _Worksheet_get_Columns(This,RHS)	\
    ( (This)->lpVtbl -> get_Columns(This,RHS) ) 

#define _Worksheet_get_ConsolidationFunction(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_ConsolidationFunction(This,lcid,RHS) ) 

#define _Worksheet_get_ConsolidationOptions(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_ConsolidationOptions(This,lcid,RHS) ) 

#define _Worksheet_get_ConsolidationSources(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_ConsolidationSources(This,lcid,RHS) ) 

#define _Worksheet_get_DisplayAutomaticPageBreaks(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_DisplayAutomaticPageBreaks(This,lcid,RHS) ) 

#define _Worksheet_put_DisplayAutomaticPageBreaks(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_DisplayAutomaticPageBreaks(This,lcid,RHS) ) 

#define _Worksheet_Drawings(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> Drawings(This,Index,lcid,RHS) ) 

#define _Worksheet_DrawingObjects(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> DrawingObjects(This,Index,lcid,RHS) ) 

#define _Worksheet_DropDowns(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> DropDowns(This,Index,lcid,RHS) ) 

#define _Worksheet_get_EnableAutoFilter(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_EnableAutoFilter(This,lcid,RHS) ) 

#define _Worksheet_put_EnableAutoFilter(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_EnableAutoFilter(This,lcid,RHS) ) 

#define _Worksheet_get_EnableSelection(This,RHS)	\
    ( (This)->lpVtbl -> get_EnableSelection(This,RHS) ) 

#define _Worksheet_put_EnableSelection(This,RHS)	\
    ( (This)->lpVtbl -> put_EnableSelection(This,RHS) ) 

#define _Worksheet_get_EnableOutlining(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_EnableOutlining(This,lcid,RHS) ) 

#define _Worksheet_put_EnableOutlining(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_EnableOutlining(This,lcid,RHS) ) 

#define _Worksheet_get_EnablePivotTable(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_EnablePivotTable(This,lcid,RHS) ) 

#define _Worksheet_put_EnablePivotTable(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_EnablePivotTable(This,lcid,RHS) ) 

#define _Worksheet_Evaluate(This,Name,lcid,RHS)	\
    ( (This)->lpVtbl -> Evaluate(This,Name,lcid,RHS) ) 

#define _Worksheet__Evaluate(This,Name,lcid,RHS)	\
    ( (This)->lpVtbl -> _Evaluate(This,Name,lcid,RHS) ) 

#define _Worksheet_get_FilterMode(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_FilterMode(This,lcid,RHS) ) 

#define _Worksheet_ResetAllPageBreaks(This)	\
    ( (This)->lpVtbl -> ResetAllPageBreaks(This) ) 

#define _Worksheet_GroupBoxes(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> GroupBoxes(This,Index,lcid,RHS) ) 

#define _Worksheet_GroupObjects(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> GroupObjects(This,Index,lcid,RHS) ) 

#define _Worksheet_Labels(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> Labels(This,Index,lcid,RHS) ) 

#define _Worksheet_Lines(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> Lines(This,Index,lcid,RHS) ) 

#define _Worksheet_ListBoxes(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> ListBoxes(This,Index,lcid,RHS) ) 

#define _Worksheet_get_Names(This,RHS)	\
    ( (This)->lpVtbl -> get_Names(This,RHS) ) 

#define _Worksheet_OLEObjects(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> OLEObjects(This,Index,lcid,RHS) ) 

#define _Worksheet_get_OnCalculate(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_OnCalculate(This,lcid,RHS) ) 

#define _Worksheet_put_OnCalculate(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_OnCalculate(This,lcid,RHS) ) 

#define _Worksheet_get_OnData(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_OnData(This,lcid,RHS) ) 

#define _Worksheet_put_OnData(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_OnData(This,lcid,RHS) ) 

#define _Worksheet_get_OnEntry(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_OnEntry(This,lcid,RHS) ) 

#define _Worksheet_put_OnEntry(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_OnEntry(This,lcid,RHS) ) 

#define _Worksheet_OptionButtons(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> OptionButtons(This,Index,lcid,RHS) ) 

#define _Worksheet_get_Outline(This,RHS)	\
    ( (This)->lpVtbl -> get_Outline(This,RHS) ) 

#define _Worksheet_Ovals(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> Ovals(This,Index,lcid,RHS) ) 

#define _Worksheet_Paste(This,Destination,Link,lcid)	\
    ( (This)->lpVtbl -> Paste(This,Destination,Link,lcid) ) 

#define _Worksheet__PasteSpecial(This,Format,Link,DisplayAsIcon,IconFileName,IconIndex,IconLabel,lcid)	\
    ( (This)->lpVtbl -> _PasteSpecial(This,Format,Link,DisplayAsIcon,IconFileName,IconIndex,IconLabel,lcid) ) 

#define _Worksheet_Pictures(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> Pictures(This,Index,lcid,RHS) ) 

#define _Worksheet_PivotTables(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> PivotTables(This,Index,lcid,RHS) ) 

#define _Worksheet_PivotTableWizard(This,SourceType,SourceData,TableDestination,TableName,RowGrand,ColumnGrand,SaveData,HasAutoFormat,AutoPage,Reserved,BackgroundQuery,OptimizeCache,PageFieldOrder,PageFieldWrapCount,ReadData,Connection,lcid,RHS)	\
    ( (This)->lpVtbl -> PivotTableWizard(This,SourceType,SourceData,TableDestination,TableName,RowGrand,ColumnGrand,SaveData,HasAutoFormat,AutoPage,Reserved,BackgroundQuery,OptimizeCache,PageFieldOrder,PageFieldWrapCount,ReadData,Connection,lcid,RHS) ) 

#define _Worksheet_get_Range(This,Cell1,Cell2,RHS)	\
    ( (This)->lpVtbl -> get_Range(This,Cell1,Cell2,RHS) ) 

#define _Worksheet_Rectangles(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> Rectangles(This,Index,lcid,RHS) ) 

#define _Worksheet_get_Rows(This,RHS)	\
    ( (This)->lpVtbl -> get_Rows(This,RHS) ) 

#define _Worksheet_Scenarios(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> Scenarios(This,Index,lcid,RHS) ) 

#define _Worksheet_get_ScrollArea(This,RHS)	\
    ( (This)->lpVtbl -> get_ScrollArea(This,RHS) ) 

#define _Worksheet_put_ScrollArea(This,RHS)	\
    ( (This)->lpVtbl -> put_ScrollArea(This,RHS) ) 

#define _Worksheet_ScrollBars(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> ScrollBars(This,Index,lcid,RHS) ) 

#define _Worksheet_ShowAllData(This,lcid)	\
    ( (This)->lpVtbl -> ShowAllData(This,lcid) ) 

#define _Worksheet_ShowDataForm(This,lcid)	\
    ( (This)->lpVtbl -> ShowDataForm(This,lcid) ) 

#define _Worksheet_Spinners(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> Spinners(This,Index,lcid,RHS) ) 

#define _Worksheet_get_StandardHeight(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_StandardHeight(This,lcid,RHS) ) 

#define _Worksheet_get_StandardWidth(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_StandardWidth(This,lcid,RHS) ) 

#define _Worksheet_put_StandardWidth(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_StandardWidth(This,lcid,RHS) ) 

#define _Worksheet_TextBoxes(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> TextBoxes(This,Index,lcid,RHS) ) 

#define _Worksheet_get_TransitionFormEntry(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_TransitionFormEntry(This,lcid,RHS) ) 

#define _Worksheet_put_TransitionFormEntry(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_TransitionFormEntry(This,lcid,RHS) ) 

#define _Worksheet_get_Type(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_Type(This,lcid,RHS) ) 

#define _Worksheet_get_UsedRange(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_UsedRange(This,lcid,RHS) ) 

#define _Worksheet_get_HPageBreaks(This,RHS)	\
    ( (This)->lpVtbl -> get_HPageBreaks(This,RHS) ) 

#define _Worksheet_get_VPageBreaks(This,RHS)	\
    ( (This)->lpVtbl -> get_VPageBreaks(This,RHS) ) 

#define _Worksheet_get_QueryTables(This,RHS)	\
    ( (This)->lpVtbl -> get_QueryTables(This,RHS) ) 

#define _Worksheet_get_DisplayPageBreaks(This,RHS)	\
    ( (This)->lpVtbl -> get_DisplayPageBreaks(This,RHS) ) 

#define _Worksheet_put_DisplayPageBreaks(This,RHS)	\
    ( (This)->lpVtbl -> put_DisplayPageBreaks(This,RHS) ) 

#define _Worksheet_get_Comments(This,RHS)	\
    ( (This)->lpVtbl -> get_Comments(This,RHS) ) 

#define _Worksheet_get_Hyperlinks(This,RHS)	\
    ( (This)->lpVtbl -> get_Hyperlinks(This,RHS) ) 

#define _Worksheet_ClearCircles(This)	\
    ( (This)->lpVtbl -> ClearCircles(This) ) 

#define _Worksheet_CircleInvalid(This)	\
    ( (This)->lpVtbl -> CircleInvalid(This) ) 

#define _Worksheet_get__DisplayRightToLeft(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get__DisplayRightToLeft(This,lcid,RHS) ) 

#define _Worksheet_put__DisplayRightToLeft(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put__DisplayRightToLeft(This,lcid,RHS) ) 

#define _Worksheet_get_AutoFilter(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoFilter(This,RHS) ) 

#define _Worksheet_get_DisplayRightToLeft(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_DisplayRightToLeft(This,lcid,RHS) ) 

#define _Worksheet_put_DisplayRightToLeft(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_DisplayRightToLeft(This,lcid,RHS) ) 

#define _Worksheet_get_Scripts(This,RHS)	\
    ( (This)->lpVtbl -> get_Scripts(This,RHS) ) 

#define _Worksheet__PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate,PrToFileName,lcid)	\
    ( (This)->lpVtbl -> _PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate,PrToFileName,lcid) ) 

#define _Worksheet__CheckSpelling(This,CustomDictionary,IgnoreUppercase,AlwaysSuggest,SpellLang,IgnoreFinalYaa,SpellScript,lcid)	\
    ( (This)->lpVtbl -> _CheckSpelling(This,CustomDictionary,IgnoreUppercase,AlwaysSuggest,SpellLang,IgnoreFinalYaa,SpellScript,lcid) ) 

#define _Worksheet_get_Tab(This,RHS)	\
    ( (This)->lpVtbl -> get_Tab(This,RHS) ) 

#define _Worksheet_get_MailEnvelope(This,RHS)	\
    ( (This)->lpVtbl -> get_MailEnvelope(This,RHS) ) 

#define _Worksheet_SaveAs(This,Filename,FileFormat,Password,WriteResPassword,ReadOnlyRecommended,CreateBackup,AddToMru,TextCodepage,TextVisualLayout,Local)	\
    ( (This)->lpVtbl -> SaveAs(This,Filename,FileFormat,Password,WriteResPassword,ReadOnlyRecommended,CreateBackup,AddToMru,TextCodepage,TextVisualLayout,Local) ) 

#define _Worksheet_get_CustomProperties(This,RHS)	\
    ( (This)->lpVtbl -> get_CustomProperties(This,RHS) ) 

#define _Worksheet_get_SmartTags(This,RHS)	\
    ( (This)->lpVtbl -> get_SmartTags(This,RHS) ) 

#define _Worksheet_get_Protection(This,RHS)	\
    ( (This)->lpVtbl -> get_Protection(This,RHS) ) 

#define _Worksheet_PasteSpecial(This,Format,Link,DisplayAsIcon,IconFileName,IconIndex,IconLabel,NoHTMLFormatting,lcid)	\
    ( (This)->lpVtbl -> PasteSpecial(This,Format,Link,DisplayAsIcon,IconFileName,IconIndex,IconLabel,NoHTMLFormatting,lcid) ) 

#define _Worksheet_Protect(This,Password,DrawingObjects,Contents,Scenarios,UserInterfaceOnly,AllowFormattingCells,AllowFormattingColumns,AllowFormattingRows,AllowInsertingColumns,AllowInsertingRows,AllowInsertingHyperlinks,AllowDeletingColumns,AllowDeletingRows,AllowSorting,AllowFiltering,AllowUsingPivotTables)	\
    ( (This)->lpVtbl -> Protect(This,Password,DrawingObjects,Contents,Scenarios,UserInterfaceOnly,AllowFormattingCells,AllowFormattingColumns,AllowFormattingRows,AllowInsertingColumns,AllowInsertingRows,AllowInsertingHyperlinks,AllowDeletingColumns,AllowDeletingRows,AllowSorting,AllowFiltering,AllowUsingPivotTables) ) 

#define _Worksheet_get_ListObjects(This,RHS)	\
    ( (This)->lpVtbl -> get_ListObjects(This,RHS) ) 

#define _Worksheet_XmlDataQuery(This,XPath,SelectionNamespaces,Map,RHS)	\
    ( (This)->lpVtbl -> XmlDataQuery(This,XPath,SelectionNamespaces,Map,RHS) ) 

#define _Worksheet_XmlMapQuery(This,XPath,SelectionNamespaces,Map,RHS)	\
    ( (This)->lpVtbl -> XmlMapQuery(This,XPath,SelectionNamespaces,Map,RHS) ) 

#define _Worksheet_PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate,PrToFileName,IgnorePrintAreas,lcid)	\
    ( (This)->lpVtbl -> PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate,PrToFileName,IgnorePrintAreas,lcid) ) 

#define _Worksheet_get_EnableFormatConditionsCalculation(This,RHS)	\
    ( (This)->lpVtbl -> get_EnableFormatConditionsCalculation(This,RHS) ) 

#define _Worksheet_put_EnableFormatConditionsCalculation(This,RHS)	\
    ( (This)->lpVtbl -> put_EnableFormatConditionsCalculation(This,RHS) ) 

#define _Worksheet_get_Sort(This,RHS)	\
    ( (This)->lpVtbl -> get_Sort(This,RHS) ) 

#define _Worksheet_ExportAsFixedFormat(This,Type,Filename,Quality,IncludeDocProperties,IgnorePrintAreas,From,To,OpenAfterPublish,FixedFormatExtClassPtr)	\
    ( (This)->lpVtbl -> ExportAsFixedFormat(This,Type,Filename,Quality,IncludeDocProperties,IgnorePrintAreas,From,To,OpenAfterPublish,FixedFormatExtClassPtr) ) 

#define _Worksheet_get_PrintedCommentPages(This,RHS)	\
    ( (This)->lpVtbl -> get_PrintedCommentPages(This,RHS) ) 

#define _Worksheet_ExportToPNG(This,FilePath)	\
    ( (This)->lpVtbl -> ExportToPNG(This,FilePath) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */



/* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE _Worksheet_put__DisplayRightToLeft_Proxy( 
    _Worksheet * This,
    /* [lcid][in] */ long lcid,
    /* [in] */ long RHS);


void __RPC_STUB _Worksheet_put__DisplayRightToLeft_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Worksheet_get_AutoFilter_Proxy( 
    _Worksheet * This,
    /* [retval][out] */ AutoFilter	**RHS);


void __RPC_STUB _Worksheet_get_AutoFilter_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Worksheet_get_DisplayRightToLeft_Proxy( 
    _Worksheet * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Worksheet_get_DisplayRightToLeft_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Worksheet_put_DisplayRightToLeft_Proxy( 
    _Worksheet * This,
    /* [lcid][in] */ long lcid,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Worksheet_put_DisplayRightToLeft_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE _Worksheet_get_Scripts_Proxy( 
    _Worksheet * This,
    /* [retval][out] */ /* external definition not present */ Scripts **RHS);


void __RPC_STUB _Worksheet_get_Scripts_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [custom][helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE _Worksheet__PrintOut_Proxy( 
    _Worksheet * This,
    /* [optional][in] */ VARIANT From,
    /* [optional][in] */ VARIANT To,
    /* [optional][in] */ VARIANT Copies,
    /* [optional][in] */ VARIANT Preview,
    /* [optional][in] */ VARIANT ActivePrinter,
    /* [optional][in] */ VARIANT PrintToFile,
    /* [optional][in] */ VARIANT Collate,
    /* [optional][in] */ VARIANT PrToFileName,
    /* [lcid][in] */ long lcid);


void __RPC_STUB _Worksheet__PrintOut_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE _Worksheet__CheckSpelling_Proxy( 
    _Worksheet * This,
    /* [optional][in] */ VARIANT CustomDictionary,
    /* [optional][in] */ VARIANT IgnoreUppercase,
    /* [optional][in] */ VARIANT AlwaysSuggest,
    /* [optional][in] */ VARIANT SpellLang,
    /* [optional][in] */ VARIANT IgnoreFinalYaa,
    /* [optional][in] */ VARIANT SpellScript,
    /* [lcid][in] */ long lcid);


void __RPC_STUB _Worksheet__CheckSpelling_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Worksheet_get_Tab_Proxy( 
    _Worksheet * This,
    /* [retval][out] */ Tab	**RHS);


void __RPC_STUB _Worksheet_get_Tab_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Worksheet_get_MailEnvelope_Proxy( 
    _Worksheet * This,
    /* [retval][out] */ /* external definition not present */ MsoEnvelope **RHS);


void __RPC_STUB _Worksheet_get_MailEnvelope_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Worksheet_SaveAs_Proxy( 
    _Worksheet * This,
    /* [in] */ BSTR Filename,
    /* [optional][in] */ VARIANT FileFormat,
    /* [optional][in] */ VARIANT Password,
    /* [optional][in] */ VARIANT WriteResPassword,
    /* [optional][in] */ VARIANT ReadOnlyRecommended,
    /* [optional][in] */ VARIANT CreateBackup,
    /* [optional][in] */ VARIANT AddToMru,
    /* [optional][in] */ VARIANT TextCodepage,
    /* [optional][in] */ VARIANT TextVisualLayout,
    /* [optional][in] */ VARIANT Local);


void __RPC_STUB _Worksheet_SaveAs_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Worksheet_get_CustomProperties_Proxy( 
    _Worksheet * This,
    /* [retval][out] */ CustomProperties	**RHS);


void __RPC_STUB _Worksheet_get_CustomProperties_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE _Worksheet_get_SmartTags_Proxy( 
    _Worksheet * This,
    /* [retval][out] */ SmartTags	**RHS);


void __RPC_STUB _Worksheet_get_SmartTags_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Worksheet_get_Protection_Proxy( 
    _Worksheet * This,
    /* [retval][out] */ Protection	**RHS);


void __RPC_STUB _Worksheet_get_Protection_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Worksheet_PasteSpecial_Proxy( 
    _Worksheet * This,
    /* [optional][in] */ VARIANT Format,
    /* [optional][in] */ VARIANT Link,
    /* [optional][in] */ VARIANT DisplayAsIcon,
    /* [optional][in] */ VARIANT IconFileName,
    /* [optional][in] */ VARIANT IconIndex,
    /* [optional][in] */ VARIANT IconLabel,
    /* [optional][in] */ VARIANT NoHTMLFormatting,
    /* [lcid][in] */ long lcid);


void __RPC_STUB _Worksheet_PasteSpecial_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Worksheet_Protect_Proxy( 
    _Worksheet * This,
    /* [optional][in] */ VARIANT Password,
    /* [optional][in] */ VARIANT DrawingObjects,
    /* [optional][in] */ VARIANT Contents,
    /* [optional][in] */ VARIANT Scenarios,
    /* [optional][in] */ VARIANT UserInterfaceOnly,
    /* [optional][in] */ VARIANT AllowFormattingCells,
    /* [optional][in] */ VARIANT AllowFormattingColumns,
    /* [optional][in] */ VARIANT AllowFormattingRows,
    /* [optional][in] */ VARIANT AllowInsertingColumns,
    /* [optional][in] */ VARIANT AllowInsertingRows,
    /* [optional][in] */ VARIANT AllowInsertingHyperlinks,
    /* [optional][in] */ VARIANT AllowDeletingColumns,
    /* [optional][in] */ VARIANT AllowDeletingRows,
    /* [optional][in] */ VARIANT AllowSorting,
    /* [optional][in] */ VARIANT AllowFiltering,
    /* [optional][in] */ VARIANT AllowUsingPivotTables);


void __RPC_STUB _Worksheet_Protect_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Worksheet_get_ListObjects_Proxy( 
    _Worksheet * This,
    /* [retval][out] */ ListObjects	**RHS);


void __RPC_STUB _Worksheet_get_ListObjects_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Worksheet_XmlDataQuery_Proxy( 
    _Worksheet * This,
    /* [in] */ BSTR XPath,
    /* [optional][in] */ VARIANT SelectionNamespaces,
    /* [optional][in] */ VARIANT Map,
    /* [retval][out] */ Range	**RHS);


void __RPC_STUB _Worksheet_XmlDataQuery_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Worksheet_XmlMapQuery_Proxy( 
    _Worksheet * This,
    /* [in] */ BSTR XPath,
    /* [optional][in] */ VARIANT SelectionNamespaces,
    /* [optional][in] */ VARIANT Map,
    /* [retval][out] */ Range	**RHS);


void __RPC_STUB _Worksheet_XmlMapQuery_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [custom][helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Worksheet_PrintOut_Proxy( 
    _Worksheet * This,
    /* [optional][in] */ VARIANT From,
    /* [optional][in] */ VARIANT To,
    /* [optional][in] */ VARIANT Copies,
    /* [optional][in] */ VARIANT Preview,
    /* [optional][in] */ VARIANT ActivePrinter,
    /* [optional][in] */ VARIANT PrintToFile,
    /* [optional][in] */ VARIANT Collate,
    /* [optional][in] */ VARIANT PrToFileName,
    /* [optional][in] */ VARIANT IgnorePrintAreas,
    /* [lcid][in] */ long lcid);


void __RPC_STUB _Worksheet_PrintOut_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Worksheet_get_EnableFormatConditionsCalculation_Proxy( 
    _Worksheet * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Worksheet_get_EnableFormatConditionsCalculation_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Worksheet_put_EnableFormatConditionsCalculation_Proxy( 
    _Worksheet * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Worksheet_put_EnableFormatConditionsCalculation_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Worksheet_get_Sort_Proxy( 
    _Worksheet * This,
    /* [retval][out] */ Sort	**RHS);


void __RPC_STUB _Worksheet_get_Sort_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Worksheet_ExportAsFixedFormat_Proxy( 
    _Worksheet * This,
    /* [in] */ XlFixedFormatType Type,
    /* [optional][in] */ VARIANT Filename,
    /* [optional][in] */ VARIANT Quality,
    /* [optional][in] */ VARIANT IncludeDocProperties,
    /* [optional][in] */ VARIANT IgnorePrintAreas,
    /* [optional][in] */ VARIANT From,
    /* [optional][in] */ VARIANT To,
    /* [optional][in] */ VARIANT OpenAfterPublish,
    /* [optional][in] */ VARIANT FixedFormatExtClassPtr);


void __RPC_STUB _Worksheet_ExportAsFixedFormat_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Worksheet_get_PrintedCommentPages_Proxy( 
    _Worksheet * This,
    /* [retval][out] */ long *RHS);


void __RPC_STUB _Worksheet_get_PrintedCommentPages_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [id] */ HRESULT STDMETHODCALLTYPE _Worksheet_ExportToPNG_Proxy( 
    _Worksheet * This,
    /* [in] */ VARIANT FilePath);


void __RPC_STUB _Worksheet_ExportToPNG_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);



#endif 	/* ___Worksheet_INTERFACE_DEFINED__ */


#ifndef __IStyle_INTERFACE_DEFINED__
#define __IStyle_INTERFACE_DEFINED__

/* interface IStyle */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IStyle;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00020852-0001-0000-C000-000000000046")
    IStyle : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AddIndent( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AddIndent( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_BuiltIn( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Borders( 
            /* [retval][out] */ Borders	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Font( 
            /* [retval][out] */ Font	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_FormulaHidden( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_FormulaHidden( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HorizontalAlignment( 
            /* [retval][out] */ XlHAlign *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_HorizontalAlignment( 
            /* [in] */ XlHAlign RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_IncludeAlignment( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_IncludeAlignment( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_IncludeBorder( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_IncludeBorder( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_IncludeFont( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_IncludeFont( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_IncludeNumber( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_IncludeNumber( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_IncludePatterns( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_IncludePatterns( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_IncludeProtection( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_IncludeProtection( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_IndentLevel( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_IndentLevel( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Interior( 
            /* [retval][out] */ Interior	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Locked( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Locked( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MergeCells( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_MergeCells( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_NameLocal( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_NumberFormat( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_NumberFormat( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_NumberFormatLocal( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_NumberFormatLocal( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Orientation( 
            /* [retval][out] */ XlOrientation *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Orientation( 
            /* [in] */ XlOrientation RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShrinkToFit( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ShrinkToFit( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Value( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_VerticalAlignment( 
            /* [retval][out] */ XlVAlign *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_VerticalAlignment( 
            /* [in] */ XlVAlign RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_WrapText( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_WrapText( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ReadingOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ReadingOrder( 
            /* [in] */ long RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IStyleVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IStyle * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IStyle * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IStyle * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IStyle * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IStyle * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IStyle * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IStyle * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IStyle * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IStyle * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IStyle * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AddIndent )( 
            IStyle * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AddIndent )( 
            IStyle * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_BuiltIn )( 
            IStyle * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Borders )( 
            IStyle * This,
            /* [retval][out] */ Borders	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IStyle * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Font )( 
            IStyle * This,
            /* [retval][out] */ Font	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_FormulaHidden )( 
            IStyle * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_FormulaHidden )( 
            IStyle * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HorizontalAlignment )( 
            IStyle * This,
            /* [retval][out] */ XlHAlign *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_HorizontalAlignment )( 
            IStyle * This,
            /* [in] */ XlHAlign RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_IncludeAlignment )( 
            IStyle * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_IncludeAlignment )( 
            IStyle * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_IncludeBorder )( 
            IStyle * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_IncludeBorder )( 
            IStyle * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_IncludeFont )( 
            IStyle * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_IncludeFont )( 
            IStyle * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_IncludeNumber )( 
            IStyle * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_IncludeNumber )( 
            IStyle * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_IncludePatterns )( 
            IStyle * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_IncludePatterns )( 
            IStyle * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_IncludeProtection )( 
            IStyle * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_IncludeProtection )( 
            IStyle * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_IndentLevel )( 
            IStyle * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_IndentLevel )( 
            IStyle * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Interior )( 
            IStyle * This,
            /* [retval][out] */ Interior	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Locked )( 
            IStyle * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Locked )( 
            IStyle * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MergeCells )( 
            IStyle * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_MergeCells )( 
            IStyle * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            IStyle * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_NameLocal )( 
            IStyle * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_NumberFormat )( 
            IStyle * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_NumberFormat )( 
            IStyle * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_NumberFormatLocal )( 
            IStyle * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_NumberFormatLocal )( 
            IStyle * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Orientation )( 
            IStyle * This,
            /* [retval][out] */ XlOrientation *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Orientation )( 
            IStyle * This,
            /* [in] */ XlOrientation RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShrinkToFit )( 
            IStyle * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ShrinkToFit )( 
            IStyle * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Value )( 
            IStyle * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_VerticalAlignment )( 
            IStyle * This,
            /* [retval][out] */ XlVAlign *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_VerticalAlignment )( 
            IStyle * This,
            /* [in] */ XlVAlign RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_WrapText )( 
            IStyle * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_WrapText )( 
            IStyle * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IStyle * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ReadingOrder )( 
            IStyle * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ReadingOrder )( 
            IStyle * This,
            /* [in] */ long RHS);
        
        END_INTERFACE
    } IStyleVtbl;

    interface IStyle
    {
        CONST_VTBL struct IStyleVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IStyle_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IStyle_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IStyle_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IStyle_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IStyle_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IStyle_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IStyle_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IStyle_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IStyle_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IStyle_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IStyle_get_AddIndent(This,RHS)	\
    ( (This)->lpVtbl -> get_AddIndent(This,RHS) ) 

#define IStyle_put_AddIndent(This,RHS)	\
    ( (This)->lpVtbl -> put_AddIndent(This,RHS) ) 

#define IStyle_get_BuiltIn(This,RHS)	\
    ( (This)->lpVtbl -> get_BuiltIn(This,RHS) ) 

#define IStyle_get_Borders(This,RHS)	\
    ( (This)->lpVtbl -> get_Borders(This,RHS) ) 

#define IStyle_Delete(This,RHS)	\
    ( (This)->lpVtbl -> Delete(This,RHS) ) 

#define IStyle_get_Font(This,RHS)	\
    ( (This)->lpVtbl -> get_Font(This,RHS) ) 

#define IStyle_get_FormulaHidden(This,RHS)	\
    ( (This)->lpVtbl -> get_FormulaHidden(This,RHS) ) 

#define IStyle_put_FormulaHidden(This,RHS)	\
    ( (This)->lpVtbl -> put_FormulaHidden(This,RHS) ) 

#define IStyle_get_HorizontalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> get_HorizontalAlignment(This,RHS) ) 

#define IStyle_put_HorizontalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> put_HorizontalAlignment(This,RHS) ) 

#define IStyle_get_IncludeAlignment(This,RHS)	\
    ( (This)->lpVtbl -> get_IncludeAlignment(This,RHS) ) 

#define IStyle_put_IncludeAlignment(This,RHS)	\
    ( (This)->lpVtbl -> put_IncludeAlignment(This,RHS) ) 

#define IStyle_get_IncludeBorder(This,RHS)	\
    ( (This)->lpVtbl -> get_IncludeBorder(This,RHS) ) 

#define IStyle_put_IncludeBorder(This,RHS)	\
    ( (This)->lpVtbl -> put_IncludeBorder(This,RHS) ) 

#define IStyle_get_IncludeFont(This,RHS)	\
    ( (This)->lpVtbl -> get_IncludeFont(This,RHS) ) 

#define IStyle_put_IncludeFont(This,RHS)	\
    ( (This)->lpVtbl -> put_IncludeFont(This,RHS) ) 

#define IStyle_get_IncludeNumber(This,RHS)	\
    ( (This)->lpVtbl -> get_IncludeNumber(This,RHS) ) 

#define IStyle_put_IncludeNumber(This,RHS)	\
    ( (This)->lpVtbl -> put_IncludeNumber(This,RHS) ) 

#define IStyle_get_IncludePatterns(This,RHS)	\
    ( (This)->lpVtbl -> get_IncludePatterns(This,RHS) ) 

#define IStyle_put_IncludePatterns(This,RHS)	\
    ( (This)->lpVtbl -> put_IncludePatterns(This,RHS) ) 

#define IStyle_get_IncludeProtection(This,RHS)	\
    ( (This)->lpVtbl -> get_IncludeProtection(This,RHS) ) 

#define IStyle_put_IncludeProtection(This,RHS)	\
    ( (This)->lpVtbl -> put_IncludeProtection(This,RHS) ) 

#define IStyle_get_IndentLevel(This,RHS)	\
    ( (This)->lpVtbl -> get_IndentLevel(This,RHS) ) 

#define IStyle_put_IndentLevel(This,RHS)	\
    ( (This)->lpVtbl -> put_IndentLevel(This,RHS) ) 

#define IStyle_get_Interior(This,RHS)	\
    ( (This)->lpVtbl -> get_Interior(This,RHS) ) 

#define IStyle_get_Locked(This,RHS)	\
    ( (This)->lpVtbl -> get_Locked(This,RHS) ) 

#define IStyle_put_Locked(This,RHS)	\
    ( (This)->lpVtbl -> put_Locked(This,RHS) ) 

#define IStyle_get_MergeCells(This,RHS)	\
    ( (This)->lpVtbl -> get_MergeCells(This,RHS) ) 

#define IStyle_put_MergeCells(This,RHS)	\
    ( (This)->lpVtbl -> put_MergeCells(This,RHS) ) 

#define IStyle_get_Name(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,lcid,RHS) ) 

#define IStyle_get_NameLocal(This,RHS)	\
    ( (This)->lpVtbl -> get_NameLocal(This,RHS) ) 

#define IStyle_get_NumberFormat(This,RHS)	\
    ( (This)->lpVtbl -> get_NumberFormat(This,RHS) ) 

#define IStyle_put_NumberFormat(This,RHS)	\
    ( (This)->lpVtbl -> put_NumberFormat(This,RHS) ) 

#define IStyle_get_NumberFormatLocal(This,RHS)	\
    ( (This)->lpVtbl -> get_NumberFormatLocal(This,RHS) ) 

#define IStyle_put_NumberFormatLocal(This,RHS)	\
    ( (This)->lpVtbl -> put_NumberFormatLocal(This,RHS) ) 

#define IStyle_get_Orientation(This,RHS)	\
    ( (This)->lpVtbl -> get_Orientation(This,RHS) ) 

#define IStyle_put_Orientation(This,RHS)	\
    ( (This)->lpVtbl -> put_Orientation(This,RHS) ) 

#define IStyle_get_ShrinkToFit(This,RHS)	\
    ( (This)->lpVtbl -> get_ShrinkToFit(This,RHS) ) 

#define IStyle_put_ShrinkToFit(This,RHS)	\
    ( (This)->lpVtbl -> put_ShrinkToFit(This,RHS) ) 

#define IStyle_get_Value(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_Value(This,lcid,RHS) ) 

#define IStyle_get_VerticalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> get_VerticalAlignment(This,RHS) ) 

#define IStyle_put_VerticalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> put_VerticalAlignment(This,RHS) ) 

#define IStyle_get_WrapText(This,RHS)	\
    ( (This)->lpVtbl -> get_WrapText(This,RHS) ) 

#define IStyle_put_WrapText(This,RHS)	\
    ( (This)->lpVtbl -> put_WrapText(This,RHS) ) 

#define IStyle_get__Default(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,lcid,RHS) ) 

#define IStyle_get_ReadingOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_ReadingOrder(This,RHS) ) 

#define IStyle_put_ReadingOrder(This,RHS)	\
    ( (This)->lpVtbl -> put_ReadingOrder(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IStyle_INTERFACE_DEFINED__ */


#ifndef __IStyles_INTERFACE_DEFINED__
#define __IStyles_INTERFACE_DEFINED__

/* interface IStyles */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IStyles;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00020853-0001-0000-C000-000000000046")
    IStyles : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add( 
            /* [in] */ BSTR Name,
            /* [optional][in] */ VARIANT BasedOn,
            /* [retval][out] */ Style	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Item( 
            /* [in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ Style	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Merge( 
            /* [in] */ VARIANT Workbook,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ Style	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IStylesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IStyles * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IStyles * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IStyles * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IStyles * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IStyles * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IStyles * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IStyles * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IStyles * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IStyles * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IStyles * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add )( 
            IStyles * This,
            /* [in] */ BSTR Name,
            /* [optional][in] */ VARIANT BasedOn,
            /* [retval][out] */ Style	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IStyles * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Item )( 
            IStyles * This,
            /* [in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ Style	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Merge )( 
            IStyles * This,
            /* [in] */ VARIANT Workbook,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            IStyles * This,
            /* [retval][out] */ IUnknown **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IStyles * This,
            /* [in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ Style	**RHS);
        
        END_INTERFACE
    } IStylesVtbl;

    interface IStyles
    {
        CONST_VTBL struct IStylesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IStyles_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IStyles_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IStyles_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IStyles_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IStyles_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IStyles_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IStyles_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IStyles_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IStyles_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IStyles_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IStyles_Add(This,Name,BasedOn,RHS)	\
    ( (This)->lpVtbl -> Add(This,Name,BasedOn,RHS) ) 

#define IStyles_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IStyles_get_Item(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> get_Item(This,Index,lcid,RHS) ) 

#define IStyles_Merge(This,Workbook,RHS)	\
    ( (This)->lpVtbl -> Merge(This,Workbook,RHS) ) 

#define IStyles_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#define IStyles_get__Default(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,lcid,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IStyles_INTERFACE_DEFINED__ */


#ifndef __IBorders_INTERFACE_DEFINED__
#define __IBorders_INTERFACE_DEFINED__

/* interface IBorders */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IBorders;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00020855-0001-0000-C000-000000000046")
    IBorders : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Color( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Color( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ColorIndex( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ColorIndex( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Item( 
            /* [in] */ XlBordersIndex Index,
            /* [retval][out] */ Border	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LineStyle( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_LineStyle( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Value( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Value( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Weight( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Weight( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ XlBordersIndex Index,
            /* [retval][out] */ Border	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ThemeColor( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ThemeColor( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TintAndShade( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_TintAndShade( 
            /* [in] */ VARIANT RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IBordersVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IBorders * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IBorders * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IBorders * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IBorders * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IBorders * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IBorders * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IBorders * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IBorders * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IBorders * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IBorders * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Color )( 
            IBorders * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Color )( 
            IBorders * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ColorIndex )( 
            IBorders * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ColorIndex )( 
            IBorders * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IBorders * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Item )( 
            IBorders * This,
            /* [in] */ XlBordersIndex Index,
            /* [retval][out] */ Border	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LineStyle )( 
            IBorders * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_LineStyle )( 
            IBorders * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            IBorders * This,
            /* [retval][out] */ IUnknown **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Value )( 
            IBorders * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Value )( 
            IBorders * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Weight )( 
            IBorders * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Weight )( 
            IBorders * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IBorders * This,
            /* [in] */ XlBordersIndex Index,
            /* [retval][out] */ Border	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ThemeColor )( 
            IBorders * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ThemeColor )( 
            IBorders * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TintAndShade )( 
            IBorders * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_TintAndShade )( 
            IBorders * This,
            /* [in] */ VARIANT RHS);
        
        END_INTERFACE
    } IBordersVtbl;

    interface IBorders
    {
        CONST_VTBL struct IBordersVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IBorders_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IBorders_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IBorders_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IBorders_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IBorders_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IBorders_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IBorders_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IBorders_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IBorders_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IBorders_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IBorders_get_Color(This,RHS)	\
    ( (This)->lpVtbl -> get_Color(This,RHS) ) 

#define IBorders_put_Color(This,RHS)	\
    ( (This)->lpVtbl -> put_Color(This,RHS) ) 

#define IBorders_get_ColorIndex(This,RHS)	\
    ( (This)->lpVtbl -> get_ColorIndex(This,RHS) ) 

#define IBorders_put_ColorIndex(This,RHS)	\
    ( (This)->lpVtbl -> put_ColorIndex(This,RHS) ) 

#define IBorders_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IBorders_get_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Item(This,Index,RHS) ) 

#define IBorders_get_LineStyle(This,RHS)	\
    ( (This)->lpVtbl -> get_LineStyle(This,RHS) ) 

#define IBorders_put_LineStyle(This,RHS)	\
    ( (This)->lpVtbl -> put_LineStyle(This,RHS) ) 

#define IBorders_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#define IBorders_get_Value(This,RHS)	\
    ( (This)->lpVtbl -> get_Value(This,RHS) ) 

#define IBorders_put_Value(This,RHS)	\
    ( (This)->lpVtbl -> put_Value(This,RHS) ) 

#define IBorders_get_Weight(This,RHS)	\
    ( (This)->lpVtbl -> get_Weight(This,RHS) ) 

#define IBorders_put_Weight(This,RHS)	\
    ( (This)->lpVtbl -> put_Weight(This,RHS) ) 

#define IBorders_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define IBorders_get_ThemeColor(This,RHS)	\
    ( (This)->lpVtbl -> get_ThemeColor(This,RHS) ) 

#define IBorders_put_ThemeColor(This,RHS)	\
    ( (This)->lpVtbl -> put_ThemeColor(This,RHS) ) 

#define IBorders_get_TintAndShade(This,RHS)	\
    ( (This)->lpVtbl -> get_TintAndShade(This,RHS) ) 

#define IBorders_put_TintAndShade(This,RHS)	\
    ( (This)->lpVtbl -> put_TintAndShade(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IBorders_INTERFACE_DEFINED__ */


#ifndef ___Global_INTERFACE_DEFINED__
#define ___Global_INTERFACE_DEFINED__

/* interface _Global */
/* [object][oleautomation][nonextensible][dual][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID__Global;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000208D9-0000-0000-C000-000000000046")
    _Global : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Parent( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ActiveCell( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ActiveChart( 
            /* [retval][out] */ Chart	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_ActiveDialog( 
            /* [retval][out] */ DialogSheet	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_ActiveMenuBar( 
            /* [retval][out] */ MenuBar	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ActivePrinter( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_ActivePrinter( 
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ActiveSheet( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ActiveWindow( 
            /* [retval][out] */ Window	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ActiveWorkbook( 
            /* [retval][out] */ Workbook	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_AddIns( 
            /* [retval][out] */ AddIns	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_Assistant( 
            /* [retval][out] */ /* external definition not present */ Assistant **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Calculate( 
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Cells( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Charts( 
            /* [retval][out] */ Sheets **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Columns( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_CommandBars( 
            /* [retval][out] */ /* external definition not present */ CommandBars **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_DDEAppReturnCode( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE DDEExecute( 
            /* [in] */ long Channel,
            /* [in] */ BSTR String,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE DDEInitiate( 
            /* [in] */ BSTR App,
            /* [in] */ BSTR Topic,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE DDEPoke( 
            /* [in] */ long Channel,
            /* [in] */ VARIANT Item,
            /* [in] */ VARIANT Data,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE DDERequest( 
            /* [in] */ long Channel,
            /* [in] */ BSTR Item,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE DDETerminate( 
            /* [in] */ long Channel,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_DialogSheets( 
            /* [retval][out] */ Sheets **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Evaluate( 
            /* [in] */ VARIANT Name,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Evaluate( 
            /* [in] */ VARIANT Name,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE ExecuteExcel4Macro( 
            /* [in] */ BSTR String,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Intersect( 
            /* [in] */ Range	*Arg1,
            /* [in] */ Range	*Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_MenuBars( 
            /* [retval][out] */ MenuBars	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_Modules( 
            /* [retval][out] */ Modules	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Names( 
            /* [retval][out] */ Names	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Range( 
            /* [in] */ VARIANT Cell1,
            /* [optional][in] */ VARIANT Cell2,
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Rows( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Run( 
            /* [optional][in] */ VARIANT Macro,
            /* [optional][in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Run2( 
            /* [optional][in] */ VARIANT Macro,
            /* [optional][in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Selection( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE SendKeys( 
            /* [in] */ VARIANT Keys,
            /* [optional][in] */ VARIANT Wait,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Sheets( 
            /* [retval][out] */ Sheets **RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_ShortcutMenus( 
            /* [in] */ long Index,
            /* [retval][out] */ Menu	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ThisWorkbook( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ Workbook	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_Toolbars( 
            /* [retval][out] */ Toolbars	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Union( 
            /* [in] */ Range	*Arg1,
            /* [in] */ Range	*Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Windows( 
            /* [retval][out] */ Windows	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Workbooks( 
            /* [retval][out] */ Workbooks **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_WorksheetFunction( 
            /* [retval][out] */ WorksheetFunction	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Worksheets( 
            /* [retval][out] */ Sheets **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Excel4IntlMacroSheets( 
            /* [retval][out] */ Sheets **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Excel4MacroSheets( 
            /* [retval][out] */ Sheets **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct _GlobalVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            _Global * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            _Global * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            _Global * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            _Global * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            _Global * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            _Global * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            _Global * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Application )( 
            _Global * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Creator )( 
            _Global * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Parent )( 
            _Global * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ActiveCell )( 
            _Global * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ActiveChart )( 
            _Global * This,
            /* [retval][out] */ Chart	**RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ActiveDialog )( 
            _Global * This,
            /* [retval][out] */ DialogSheet	**RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ActiveMenuBar )( 
            _Global * This,
            /* [retval][out] */ MenuBar	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ActivePrinter )( 
            _Global * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_ActivePrinter )( 
            _Global * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ActiveSheet )( 
            _Global * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ActiveWindow )( 
            _Global * This,
            /* [retval][out] */ Window	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ActiveWorkbook )( 
            _Global * This,
            /* [retval][out] */ Workbook	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_AddIns )( 
            _Global * This,
            /* [retval][out] */ AddIns	**RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Assistant )( 
            _Global * This,
            /* [retval][out] */ /* external definition not present */ Assistant **RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Calculate )( 
            _Global * This,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Cells )( 
            _Global * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Charts )( 
            _Global * This,
            /* [retval][out] */ Sheets **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Columns )( 
            _Global * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_CommandBars )( 
            _Global * This,
            /* [retval][out] */ /* external definition not present */ CommandBars **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_DDEAppReturnCode )( 
            _Global * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *DDEExecute )( 
            _Global * This,
            /* [in] */ long Channel,
            /* [in] */ BSTR String,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *DDEInitiate )( 
            _Global * This,
            /* [in] */ BSTR App,
            /* [in] */ BSTR Topic,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *DDEPoke )( 
            _Global * This,
            /* [in] */ long Channel,
            /* [in] */ VARIANT Item,
            /* [in] */ VARIANT Data,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *DDERequest )( 
            _Global * This,
            /* [in] */ long Channel,
            /* [in] */ BSTR Item,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *DDETerminate )( 
            _Global * This,
            /* [in] */ long Channel,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_DialogSheets )( 
            _Global * This,
            /* [retval][out] */ Sheets **RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Evaluate )( 
            _Global * This,
            /* [in] */ VARIANT Name,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *_Evaluate )( 
            _Global * This,
            /* [in] */ VARIANT Name,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *ExecuteExcel4Macro )( 
            _Global * This,
            /* [in] */ BSTR String,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Intersect )( 
            _Global * This,
            /* [in] */ Range	*Arg1,
            /* [in] */ Range	*Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_MenuBars )( 
            _Global * This,
            /* [retval][out] */ MenuBars	**RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Modules )( 
            _Global * This,
            /* [retval][out] */ Modules	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Names )( 
            _Global * This,
            /* [retval][out] */ Names	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Range )( 
            _Global * This,
            /* [in] */ VARIANT Cell1,
            /* [optional][in] */ VARIANT Cell2,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Rows )( 
            _Global * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Run )( 
            _Global * This,
            /* [optional][in] */ VARIANT Macro,
            /* [optional][in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *_Run2 )( 
            _Global * This,
            /* [optional][in] */ VARIANT Macro,
            /* [optional][in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Selection )( 
            _Global * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *SendKeys )( 
            _Global * This,
            /* [in] */ VARIANT Keys,
            /* [optional][in] */ VARIANT Wait,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Sheets )( 
            _Global * This,
            /* [retval][out] */ Sheets **RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ShortcutMenus )( 
            _Global * This,
            /* [in] */ long Index,
            /* [retval][out] */ Menu	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ThisWorkbook )( 
            _Global * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ Workbook	**RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Toolbars )( 
            _Global * This,
            /* [retval][out] */ Toolbars	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Union )( 
            _Global * This,
            /* [in] */ Range	*Arg1,
            /* [in] */ Range	*Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Windows )( 
            _Global * This,
            /* [retval][out] */ Windows	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Workbooks )( 
            _Global * This,
            /* [retval][out] */ Workbooks **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_WorksheetFunction )( 
            _Global * This,
            /* [retval][out] */ WorksheetFunction	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Worksheets )( 
            _Global * This,
            /* [retval][out] */ Sheets **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Excel4IntlMacroSheets )( 
            _Global * This,
            /* [retval][out] */ Sheets **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Excel4MacroSheets )( 
            _Global * This,
            /* [retval][out] */ Sheets **RHS);
        
        END_INTERFACE
    } _GlobalVtbl;

    interface _Global
    {
        CONST_VTBL struct _GlobalVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define _Global_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define _Global_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define _Global_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define _Global_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define _Global_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define _Global_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define _Global_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define _Global_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define _Global_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define _Global_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define _Global_get_ActiveCell(This,RHS)	\
    ( (This)->lpVtbl -> get_ActiveCell(This,RHS) ) 

#define _Global_get_ActiveChart(This,RHS)	\
    ( (This)->lpVtbl -> get_ActiveChart(This,RHS) ) 

#define _Global_get_ActiveDialog(This,RHS)	\
    ( (This)->lpVtbl -> get_ActiveDialog(This,RHS) ) 

#define _Global_get_ActiveMenuBar(This,RHS)	\
    ( (This)->lpVtbl -> get_ActiveMenuBar(This,RHS) ) 

#define _Global_get_ActivePrinter(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_ActivePrinter(This,lcid,RHS) ) 

#define _Global_put_ActivePrinter(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_ActivePrinter(This,lcid,RHS) ) 

#define _Global_get_ActiveSheet(This,RHS)	\
    ( (This)->lpVtbl -> get_ActiveSheet(This,RHS) ) 

#define _Global_get_ActiveWindow(This,RHS)	\
    ( (This)->lpVtbl -> get_ActiveWindow(This,RHS) ) 

#define _Global_get_ActiveWorkbook(This,RHS)	\
    ( (This)->lpVtbl -> get_ActiveWorkbook(This,RHS) ) 

#define _Global_get_AddIns(This,RHS)	\
    ( (This)->lpVtbl -> get_AddIns(This,RHS) ) 

#define _Global_get_Assistant(This,RHS)	\
    ( (This)->lpVtbl -> get_Assistant(This,RHS) ) 

#define _Global_Calculate(This,lcid)	\
    ( (This)->lpVtbl -> Calculate(This,lcid) ) 

#define _Global_get_Cells(This,RHS)	\
    ( (This)->lpVtbl -> get_Cells(This,RHS) ) 

#define _Global_get_Charts(This,RHS)	\
    ( (This)->lpVtbl -> get_Charts(This,RHS) ) 

#define _Global_get_Columns(This,RHS)	\
    ( (This)->lpVtbl -> get_Columns(This,RHS) ) 

#define _Global_get_CommandBars(This,RHS)	\
    ( (This)->lpVtbl -> get_CommandBars(This,RHS) ) 

#define _Global_get_DDEAppReturnCode(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_DDEAppReturnCode(This,lcid,RHS) ) 

#define _Global_DDEExecute(This,Channel,String,lcid)	\
    ( (This)->lpVtbl -> DDEExecute(This,Channel,String,lcid) ) 

#define _Global_DDEInitiate(This,App,Topic,lcid,RHS)	\
    ( (This)->lpVtbl -> DDEInitiate(This,App,Topic,lcid,RHS) ) 

#define _Global_DDEPoke(This,Channel,Item,Data,lcid)	\
    ( (This)->lpVtbl -> DDEPoke(This,Channel,Item,Data,lcid) ) 

#define _Global_DDERequest(This,Channel,Item,lcid,RHS)	\
    ( (This)->lpVtbl -> DDERequest(This,Channel,Item,lcid,RHS) ) 

#define _Global_DDETerminate(This,Channel,lcid)	\
    ( (This)->lpVtbl -> DDETerminate(This,Channel,lcid) ) 

#define _Global_get_DialogSheets(This,RHS)	\
    ( (This)->lpVtbl -> get_DialogSheets(This,RHS) ) 

#define _Global_Evaluate(This,Name,lcid,RHS)	\
    ( (This)->lpVtbl -> Evaluate(This,Name,lcid,RHS) ) 

#define _Global__Evaluate(This,Name,lcid,RHS)	\
    ( (This)->lpVtbl -> _Evaluate(This,Name,lcid,RHS) ) 

#define _Global_ExecuteExcel4Macro(This,String,lcid,RHS)	\
    ( (This)->lpVtbl -> ExecuteExcel4Macro(This,String,lcid,RHS) ) 

#define _Global_Intersect(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,lcid,RHS)	\
    ( (This)->lpVtbl -> Intersect(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,lcid,RHS) ) 

#define _Global_get_MenuBars(This,RHS)	\
    ( (This)->lpVtbl -> get_MenuBars(This,RHS) ) 

#define _Global_get_Modules(This,RHS)	\
    ( (This)->lpVtbl -> get_Modules(This,RHS) ) 

#define _Global_get_Names(This,RHS)	\
    ( (This)->lpVtbl -> get_Names(This,RHS) ) 

#define _Global_get_Range(This,Cell1,Cell2,RHS)	\
    ( (This)->lpVtbl -> get_Range(This,Cell1,Cell2,RHS) ) 

#define _Global_get_Rows(This,RHS)	\
    ( (This)->lpVtbl -> get_Rows(This,RHS) ) 

#define _Global_Run(This,Macro,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS)	\
    ( (This)->lpVtbl -> Run(This,Macro,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS) ) 

#define _Global__Run2(This,Macro,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,lcid,RHS)	\
    ( (This)->lpVtbl -> _Run2(This,Macro,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,lcid,RHS) ) 

#define _Global_get_Selection(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_Selection(This,lcid,RHS) ) 

#define _Global_SendKeys(This,Keys,Wait,lcid)	\
    ( (This)->lpVtbl -> SendKeys(This,Keys,Wait,lcid) ) 

#define _Global_get_Sheets(This,RHS)	\
    ( (This)->lpVtbl -> get_Sheets(This,RHS) ) 

#define _Global_get_ShortcutMenus(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_ShortcutMenus(This,Index,RHS) ) 

#define _Global_get_ThisWorkbook(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_ThisWorkbook(This,lcid,RHS) ) 

#define _Global_get_Toolbars(This,RHS)	\
    ( (This)->lpVtbl -> get_Toolbars(This,RHS) ) 

#define _Global_Union(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,lcid,RHS)	\
    ( (This)->lpVtbl -> Union(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,lcid,RHS) ) 

#define _Global_get_Windows(This,RHS)	\
    ( (This)->lpVtbl -> get_Windows(This,RHS) ) 

#define _Global_get_Workbooks(This,RHS)	\
    ( (This)->lpVtbl -> get_Workbooks(This,RHS) ) 

#define _Global_get_WorksheetFunction(This,RHS)	\
    ( (This)->lpVtbl -> get_WorksheetFunction(This,RHS) ) 

#define _Global_get_Worksheets(This,RHS)	\
    ( (This)->lpVtbl -> get_Worksheets(This,RHS) ) 

#define _Global_get_Excel4IntlMacroSheets(This,RHS)	\
    ( (This)->lpVtbl -> get_Excel4IntlMacroSheets(This,RHS) ) 

#define _Global_get_Excel4MacroSheets(This,RHS)	\
    ( (This)->lpVtbl -> get_Excel4MacroSheets(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* ___Global_INTERFACE_DEFINED__ */


#ifndef __IAddIn_INTERFACE_DEFINED__
#define __IAddIn_INTERFACE_DEFINED__

/* interface IAddIn */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IAddIn;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00020857-0001-0000-C000-000000000046")
    IAddIn : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Author( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Comments( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_FullName( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Installed( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Installed( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Keywords( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Path( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Subject( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Title( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_progID( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CLSID( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_IsOpen( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IAddInVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IAddIn * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IAddIn * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IAddIn * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IAddIn * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IAddIn * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IAddIn * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IAddIn * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IAddIn * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IAddIn * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IAddIn * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Author )( 
            IAddIn * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Comments )( 
            IAddIn * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_FullName )( 
            IAddIn * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Installed )( 
            IAddIn * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Installed )( 
            IAddIn * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Keywords )( 
            IAddIn * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            IAddIn * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Path )( 
            IAddIn * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Subject )( 
            IAddIn * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Title )( 
            IAddIn * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_progID )( 
            IAddIn * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CLSID )( 
            IAddIn * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_IsOpen )( 
            IAddIn * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        END_INTERFACE
    } IAddInVtbl;

    interface IAddIn
    {
        CONST_VTBL struct IAddInVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IAddIn_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IAddIn_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IAddIn_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IAddIn_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IAddIn_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IAddIn_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IAddIn_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IAddIn_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IAddIn_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IAddIn_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IAddIn_get_Author(This,RHS)	\
    ( (This)->lpVtbl -> get_Author(This,RHS) ) 

#define IAddIn_get_Comments(This,RHS)	\
    ( (This)->lpVtbl -> get_Comments(This,RHS) ) 

#define IAddIn_get_FullName(This,RHS)	\
    ( (This)->lpVtbl -> get_FullName(This,RHS) ) 

#define IAddIn_get_Installed(This,RHS)	\
    ( (This)->lpVtbl -> get_Installed(This,RHS) ) 

#define IAddIn_put_Installed(This,RHS)	\
    ( (This)->lpVtbl -> put_Installed(This,RHS) ) 

#define IAddIn_get_Keywords(This,RHS)	\
    ( (This)->lpVtbl -> get_Keywords(This,RHS) ) 

#define IAddIn_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define IAddIn_get_Path(This,RHS)	\
    ( (This)->lpVtbl -> get_Path(This,RHS) ) 

#define IAddIn_get_Subject(This,RHS)	\
    ( (This)->lpVtbl -> get_Subject(This,RHS) ) 

#define IAddIn_get_Title(This,RHS)	\
    ( (This)->lpVtbl -> get_Title(This,RHS) ) 

#define IAddIn_get_progID(This,RHS)	\
    ( (This)->lpVtbl -> get_progID(This,RHS) ) 

#define IAddIn_get_CLSID(This,RHS)	\
    ( (This)->lpVtbl -> get_CLSID(This,RHS) ) 

#define IAddIn_get_IsOpen(This,RHS)	\
    ( (This)->lpVtbl -> get_IsOpen(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IAddIn_INTERFACE_DEFINED__ */


#ifndef __IAddIns_INTERFACE_DEFINED__
#define __IAddIns_INTERFACE_DEFINED__

/* interface IAddIns */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IAddIns;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00020858-0001-0000-C000-000000000046")
    IAddIns : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add( 
            /* [in] */ BSTR Filename,
            /* [optional][in] */ VARIANT CopyFile,
            /* [retval][out] */ AddIn	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ AddIn	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ AddIn	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IAddInsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IAddIns * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IAddIns * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IAddIns * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IAddIns * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IAddIns * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IAddIns * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IAddIns * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IAddIns * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IAddIns * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IAddIns * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add )( 
            IAddIns * This,
            /* [in] */ BSTR Filename,
            /* [optional][in] */ VARIANT CopyFile,
            /* [retval][out] */ AddIn	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IAddIns * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Item )( 
            IAddIns * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ AddIn	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            IAddIns * This,
            /* [retval][out] */ IUnknown **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IAddIns * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ AddIn	**RHS);
        
        END_INTERFACE
    } IAddInsVtbl;

    interface IAddIns
    {
        CONST_VTBL struct IAddInsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IAddIns_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IAddIns_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IAddIns_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IAddIns_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IAddIns_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IAddIns_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IAddIns_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IAddIns_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IAddIns_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IAddIns_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IAddIns_Add(This,Filename,CopyFile,RHS)	\
    ( (This)->lpVtbl -> Add(This,Filename,CopyFile,RHS) ) 

#define IAddIns_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IAddIns_get_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Item(This,Index,RHS) ) 

#define IAddIns_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#define IAddIns_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IAddIns_INTERFACE_DEFINED__ */


#ifndef __IToolbar_INTERFACE_DEFINED__
#define __IToolbar_INTERFACE_DEFINED__

/* interface IToolbar */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IToolbar;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002085C-0001-0000-C000-000000000046")
    IToolbar : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_BuiltIn( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Height( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Height( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Left( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Left( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Position( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Position( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Protection( 
            /* [retval][out] */ XlToolbarProtection *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Protection( 
            /* [in] */ XlToolbarProtection RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Reset( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ToolbarButtons( 
            /* [retval][out] */ ToolbarButtons	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Top( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Top( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Visible( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Visible( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Width( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Width( 
            /* [in] */ long RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IToolbarVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IToolbar * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IToolbar * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IToolbar * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IToolbar * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IToolbar * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IToolbar * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IToolbar * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IToolbar * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IToolbar * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IToolbar * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_BuiltIn )( 
            IToolbar * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IToolbar * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Height )( 
            IToolbar * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Height )( 
            IToolbar * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Left )( 
            IToolbar * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Left )( 
            IToolbar * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            IToolbar * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Position )( 
            IToolbar * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Position )( 
            IToolbar * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Protection )( 
            IToolbar * This,
            /* [retval][out] */ XlToolbarProtection *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Protection )( 
            IToolbar * This,
            /* [in] */ XlToolbarProtection RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Reset )( 
            IToolbar * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ToolbarButtons )( 
            IToolbar * This,
            /* [retval][out] */ ToolbarButtons	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Top )( 
            IToolbar * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Top )( 
            IToolbar * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Visible )( 
            IToolbar * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Visible )( 
            IToolbar * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Width )( 
            IToolbar * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Width )( 
            IToolbar * This,
            /* [in] */ long RHS);
        
        END_INTERFACE
    } IToolbarVtbl;

    interface IToolbar
    {
        CONST_VTBL struct IToolbarVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IToolbar_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IToolbar_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IToolbar_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IToolbar_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IToolbar_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IToolbar_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IToolbar_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IToolbar_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IToolbar_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IToolbar_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IToolbar_get_BuiltIn(This,RHS)	\
    ( (This)->lpVtbl -> get_BuiltIn(This,RHS) ) 

#define IToolbar_Delete(This)	\
    ( (This)->lpVtbl -> Delete(This) ) 

#define IToolbar_get_Height(This,RHS)	\
    ( (This)->lpVtbl -> get_Height(This,RHS) ) 

#define IToolbar_put_Height(This,RHS)	\
    ( (This)->lpVtbl -> put_Height(This,RHS) ) 

#define IToolbar_get_Left(This,RHS)	\
    ( (This)->lpVtbl -> get_Left(This,RHS) ) 

#define IToolbar_put_Left(This,RHS)	\
    ( (This)->lpVtbl -> put_Left(This,RHS) ) 

#define IToolbar_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define IToolbar_get_Position(This,RHS)	\
    ( (This)->lpVtbl -> get_Position(This,RHS) ) 

#define IToolbar_put_Position(This,RHS)	\
    ( (This)->lpVtbl -> put_Position(This,RHS) ) 

#define IToolbar_get_Protection(This,RHS)	\
    ( (This)->lpVtbl -> get_Protection(This,RHS) ) 

#define IToolbar_put_Protection(This,RHS)	\
    ( (This)->lpVtbl -> put_Protection(This,RHS) ) 

#define IToolbar_Reset(This)	\
    ( (This)->lpVtbl -> Reset(This) ) 

#define IToolbar_get_ToolbarButtons(This,RHS)	\
    ( (This)->lpVtbl -> get_ToolbarButtons(This,RHS) ) 

#define IToolbar_get_Top(This,RHS)	\
    ( (This)->lpVtbl -> get_Top(This,RHS) ) 

#define IToolbar_put_Top(This,RHS)	\
    ( (This)->lpVtbl -> put_Top(This,RHS) ) 

#define IToolbar_get_Visible(This,RHS)	\
    ( (This)->lpVtbl -> get_Visible(This,RHS) ) 

#define IToolbar_put_Visible(This,RHS)	\
    ( (This)->lpVtbl -> put_Visible(This,RHS) ) 

#define IToolbar_get_Width(This,RHS)	\
    ( (This)->lpVtbl -> get_Width(This,RHS) ) 

#define IToolbar_put_Width(This,RHS)	\
    ( (This)->lpVtbl -> put_Width(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IToolbar_INTERFACE_DEFINED__ */


#ifndef __IToolbars_INTERFACE_DEFINED__
#define __IToolbars_INTERFACE_DEFINED__

/* interface IToolbars */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IToolbars;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002085D-0001-0000-C000-000000000046")
    IToolbars : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add( 
            /* [optional][in] */ VARIANT Name,
            /* [retval][out] */ Toolbar	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Toolbar	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Toolbar	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IToolbarsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IToolbars * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IToolbars * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IToolbars * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IToolbars * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IToolbars * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IToolbars * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IToolbars * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IToolbars * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IToolbars * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IToolbars * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add )( 
            IToolbars * This,
            /* [optional][in] */ VARIANT Name,
            /* [retval][out] */ Toolbar	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IToolbars * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IToolbars * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Toolbar	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Item )( 
            IToolbars * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Toolbar	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            IToolbars * This,
            /* [retval][out] */ IUnknown **RHS);
        
        END_INTERFACE
    } IToolbarsVtbl;

    interface IToolbars
    {
        CONST_VTBL struct IToolbarsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IToolbars_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IToolbars_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IToolbars_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IToolbars_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IToolbars_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IToolbars_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IToolbars_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IToolbars_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IToolbars_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IToolbars_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IToolbars_Add(This,Name,RHS)	\
    ( (This)->lpVtbl -> Add(This,Name,RHS) ) 

#define IToolbars_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IToolbars_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define IToolbars_get_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Item(This,Index,RHS) ) 

#define IToolbars_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IToolbars_INTERFACE_DEFINED__ */


#ifndef __IToolbarButton_INTERFACE_DEFINED__
#define __IToolbarButton_INTERFACE_DEFINED__

/* interface IToolbarButton */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IToolbarButton;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002085E-0001-0000-C000-000000000046")
    IToolbarButton : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_BuiltIn( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_BuiltInFace( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_BuiltInFace( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Copy( 
            /* [in] */ Toolbar	*Toolbar,
            /* [in] */ long Before) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CopyFace( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Edit( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Enabled( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Enabled( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HelpContextID( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_HelpContextID( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HelpFile( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_HelpFile( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ID( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_IsGap( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Move( 
            /* [in] */ Toolbar	*Toolbar,
            /* [in] */ long Before) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Name( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_OnAction( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_OnAction( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall PasteFace( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Pushed( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Pushed( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Reset( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_StatusBar( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_StatusBar( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Width( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Width( 
            /* [in] */ long RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IToolbarButtonVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IToolbarButton * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IToolbarButton * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IToolbarButton * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IToolbarButton * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IToolbarButton * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IToolbarButton * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IToolbarButton * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IToolbarButton * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IToolbarButton * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IToolbarButton * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_BuiltIn )( 
            IToolbarButton * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_BuiltInFace )( 
            IToolbarButton * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_BuiltInFace )( 
            IToolbarButton * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Copy )( 
            IToolbarButton * This,
            /* [in] */ Toolbar	*Toolbar,
            /* [in] */ long Before);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CopyFace )( 
            IToolbarButton * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IToolbarButton * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Edit )( 
            IToolbarButton * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Enabled )( 
            IToolbarButton * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Enabled )( 
            IToolbarButton * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HelpContextID )( 
            IToolbarButton * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_HelpContextID )( 
            IToolbarButton * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HelpFile )( 
            IToolbarButton * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_HelpFile )( 
            IToolbarButton * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ID )( 
            IToolbarButton * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_IsGap )( 
            IToolbarButton * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Move )( 
            IToolbarButton * This,
            /* [in] */ Toolbar	*Toolbar,
            /* [in] */ long Before);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            IToolbarButton * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Name )( 
            IToolbarButton * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_OnAction )( 
            IToolbarButton * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_OnAction )( 
            IToolbarButton * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *PasteFace )( 
            IToolbarButton * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Pushed )( 
            IToolbarButton * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Pushed )( 
            IToolbarButton * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Reset )( 
            IToolbarButton * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_StatusBar )( 
            IToolbarButton * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_StatusBar )( 
            IToolbarButton * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Width )( 
            IToolbarButton * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Width )( 
            IToolbarButton * This,
            /* [in] */ long RHS);
        
        END_INTERFACE
    } IToolbarButtonVtbl;

    interface IToolbarButton
    {
        CONST_VTBL struct IToolbarButtonVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IToolbarButton_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IToolbarButton_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IToolbarButton_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IToolbarButton_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IToolbarButton_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IToolbarButton_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IToolbarButton_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IToolbarButton_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IToolbarButton_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IToolbarButton_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IToolbarButton_get_BuiltIn(This,RHS)	\
    ( (This)->lpVtbl -> get_BuiltIn(This,RHS) ) 

#define IToolbarButton_get_BuiltInFace(This,RHS)	\
    ( (This)->lpVtbl -> get_BuiltInFace(This,RHS) ) 

#define IToolbarButton_put_BuiltInFace(This,RHS)	\
    ( (This)->lpVtbl -> put_BuiltInFace(This,RHS) ) 

#define IToolbarButton_Copy(This,Toolbar,Before)	\
    ( (This)->lpVtbl -> Copy(This,Toolbar,Before) ) 

#define IToolbarButton_CopyFace(This)	\
    ( (This)->lpVtbl -> CopyFace(This) ) 

#define IToolbarButton_Delete(This)	\
    ( (This)->lpVtbl -> Delete(This) ) 

#define IToolbarButton_Edit(This)	\
    ( (This)->lpVtbl -> Edit(This) ) 

#define IToolbarButton_get_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> get_Enabled(This,RHS) ) 

#define IToolbarButton_put_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> put_Enabled(This,RHS) ) 

#define IToolbarButton_get_HelpContextID(This,RHS)	\
    ( (This)->lpVtbl -> get_HelpContextID(This,RHS) ) 

#define IToolbarButton_put_HelpContextID(This,RHS)	\
    ( (This)->lpVtbl -> put_HelpContextID(This,RHS) ) 

#define IToolbarButton_get_HelpFile(This,RHS)	\
    ( (This)->lpVtbl -> get_HelpFile(This,RHS) ) 

#define IToolbarButton_put_HelpFile(This,RHS)	\
    ( (This)->lpVtbl -> put_HelpFile(This,RHS) ) 

#define IToolbarButton_get_ID(This,RHS)	\
    ( (This)->lpVtbl -> get_ID(This,RHS) ) 

#define IToolbarButton_get_IsGap(This,RHS)	\
    ( (This)->lpVtbl -> get_IsGap(This,RHS) ) 

#define IToolbarButton_Move(This,Toolbar,Before)	\
    ( (This)->lpVtbl -> Move(This,Toolbar,Before) ) 

#define IToolbarButton_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define IToolbarButton_put_Name(This,RHS)	\
    ( (This)->lpVtbl -> put_Name(This,RHS) ) 

#define IToolbarButton_get_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> get_OnAction(This,RHS) ) 

#define IToolbarButton_put_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> put_OnAction(This,RHS) ) 

#define IToolbarButton_PasteFace(This)	\
    ( (This)->lpVtbl -> PasteFace(This) ) 

#define IToolbarButton_get_Pushed(This,RHS)	\
    ( (This)->lpVtbl -> get_Pushed(This,RHS) ) 

#define IToolbarButton_put_Pushed(This,RHS)	\
    ( (This)->lpVtbl -> put_Pushed(This,RHS) ) 

#define IToolbarButton_Reset(This)	\
    ( (This)->lpVtbl -> Reset(This) ) 

#define IToolbarButton_get_StatusBar(This,RHS)	\
    ( (This)->lpVtbl -> get_StatusBar(This,RHS) ) 

#define IToolbarButton_put_StatusBar(This,RHS)	\
    ( (This)->lpVtbl -> put_StatusBar(This,RHS) ) 

#define IToolbarButton_get_Width(This,RHS)	\
    ( (This)->lpVtbl -> get_Width(This,RHS) ) 

#define IToolbarButton_put_Width(This,RHS)	\
    ( (This)->lpVtbl -> put_Width(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IToolbarButton_INTERFACE_DEFINED__ */


#ifndef __IToolbarButtons_INTERFACE_DEFINED__
#define __IToolbarButtons_INTERFACE_DEFINED__

/* interface IToolbarButtons */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IToolbarButtons;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002085F-0001-0000-C000-000000000046")
    IToolbarButtons : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add( 
            /* [optional][in] */ VARIANT Button,
            /* [optional][in] */ VARIANT Before,
            /* [optional][in] */ VARIANT OnAction,
            /* [optional][in] */ VARIANT Pushed,
            /* [optional][in] */ VARIANT Enabled,
            /* [optional][in] */ VARIANT StatusBar,
            /* [optional][in] */ VARIANT HelpFile,
            /* [optional][in] */ VARIANT HelpContextID,
            /* [retval][out] */ ToolbarButton	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Item( 
            /* [in] */ long Index,
            /* [retval][out] */ ToolbarButton	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ long Index,
            /* [retval][out] */ ToolbarButton	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IToolbarButtonsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IToolbarButtons * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IToolbarButtons * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IToolbarButtons * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IToolbarButtons * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IToolbarButtons * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IToolbarButtons * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IToolbarButtons * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IToolbarButtons * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IToolbarButtons * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IToolbarButtons * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add )( 
            IToolbarButtons * This,
            /* [optional][in] */ VARIANT Button,
            /* [optional][in] */ VARIANT Before,
            /* [optional][in] */ VARIANT OnAction,
            /* [optional][in] */ VARIANT Pushed,
            /* [optional][in] */ VARIANT Enabled,
            /* [optional][in] */ VARIANT StatusBar,
            /* [optional][in] */ VARIANT HelpFile,
            /* [optional][in] */ VARIANT HelpContextID,
            /* [retval][out] */ ToolbarButton	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IToolbarButtons * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Item )( 
            IToolbarButtons * This,
            /* [in] */ long Index,
            /* [retval][out] */ ToolbarButton	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            IToolbarButtons * This,
            /* [retval][out] */ IUnknown **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IToolbarButtons * This,
            /* [in] */ long Index,
            /* [retval][out] */ ToolbarButton	**RHS);
        
        END_INTERFACE
    } IToolbarButtonsVtbl;

    interface IToolbarButtons
    {
        CONST_VTBL struct IToolbarButtonsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IToolbarButtons_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IToolbarButtons_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IToolbarButtons_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IToolbarButtons_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IToolbarButtons_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IToolbarButtons_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IToolbarButtons_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IToolbarButtons_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IToolbarButtons_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IToolbarButtons_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IToolbarButtons_Add(This,Button,Before,OnAction,Pushed,Enabled,StatusBar,HelpFile,HelpContextID,RHS)	\
    ( (This)->lpVtbl -> Add(This,Button,Before,OnAction,Pushed,Enabled,StatusBar,HelpFile,HelpContextID,RHS) ) 

#define IToolbarButtons_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IToolbarButtons_get_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Item(This,Index,RHS) ) 

#define IToolbarButtons_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#define IToolbarButtons_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IToolbarButtons_INTERFACE_DEFINED__ */


#ifndef __IAreas_INTERFACE_DEFINED__
#define __IAreas_INTERFACE_DEFINED__

/* interface IAreas */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IAreas;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00020860-0001-0000-C000-000000000046")
    IAreas : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Item( 
            /* [in] */ long Index,
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ long Index,
            /* [retval][out] */ Range	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IAreasVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IAreas * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IAreas * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IAreas * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IAreas * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IAreas * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IAreas * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IAreas * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IAreas * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IAreas * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IAreas * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IAreas * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Item )( 
            IAreas * This,
            /* [in] */ long Index,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            IAreas * This,
            /* [retval][out] */ IUnknown **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IAreas * This,
            /* [in] */ long Index,
            /* [retval][out] */ Range	**RHS);
        
        END_INTERFACE
    } IAreasVtbl;

    interface IAreas
    {
        CONST_VTBL struct IAreasVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IAreas_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IAreas_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IAreas_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IAreas_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IAreas_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IAreas_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IAreas_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IAreas_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IAreas_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IAreas_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IAreas_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IAreas_get_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Item(This,Index,RHS) ) 

#define IAreas_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#define IAreas_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IAreas_INTERFACE_DEFINED__ */


#ifndef __IWorkbookEvents_INTERFACE_DEFINED__
#define __IWorkbookEvents_INTERFACE_DEFINED__

/* interface IWorkbookEvents */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IWorkbookEvents;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024412-0001-0000-C000-000000000046")
    IWorkbookEvents : public IDispatch
    {
    public:
        virtual /* [helpcontext][id] */ HRESULT __stdcall Open( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Activate( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Deactivate( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall BeforeClose( 
            /* [out][in] */ VARIANT_BOOL *Cancel) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall BeforeSave( 
            /* [in] */ VARIANT_BOOL SaveAsUI,
            /* [out][in] */ VARIANT_BOOL *Cancel) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall BeforePrint( 
            /* [out][in] */ VARIANT_BOOL *Cancel) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall NewSheet( 
            /* [in] */ IDispatch *Sh) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall AddinInstall( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall AddinUninstall( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall WindowResize( 
            /* [in] */ Window	*Wn) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall WindowActivate( 
            /* [in] */ Window	*Wn) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall WindowDeactivate( 
            /* [in] */ Window	*Wn) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SheetSelectionChange( 
            /* [in] */ IDispatch *Sh,
            /* [in] */ Range	*Target) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SheetBeforeDoubleClick( 
            /* [in] */ IDispatch *Sh,
            /* [in] */ Range	*Target,
            /* [out][in] */ VARIANT_BOOL *Cancel) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SheetBeforeRightClick( 
            /* [in] */ IDispatch *Sh,
            /* [in] */ Range	*Target,
            /* [out][in] */ VARIANT_BOOL *Cancel) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SheetActivate( 
            /* [in] */ IDispatch *Sh) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SheetDeactivate( 
            /* [in] */ IDispatch *Sh) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SheetCalculate( 
            /* [in] */ IDispatch *Sh) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SheetChange( 
            /* [in] */ IDispatch *Sh,
            /* [in] */ Range	*Target) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SheetFollowHyperlink( 
            /* [in] */ IDispatch *Sh,
            /* [in] */ Hyperlink	*Target) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SheetPivotTableUpdate( 
            /* [in] */ IDispatch *Sh,
            /* [in] */ PivotTable	*Target) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall PivotTableCloseConnection( 
            /* [in] */ PivotTable	*Target) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall PivotTableOpenConnection( 
            /* [in] */ PivotTable	*Target) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Sync( 
            /* [in] */ MsoSyncEventType SyncEventType) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall BeforeXmlImport( 
            /* [in] */ XmlMap	*Map,
            /* [in] */ BSTR Url,
            /* [in] */ VARIANT_BOOL IsRefresh,
            /* [out][in] */ VARIANT_BOOL *Cancel) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall AfterXmlImport( 
            /* [in] */ XmlMap	*Map,
            /* [in] */ VARIANT_BOOL IsRefresh,
            /* [in] */ XlXmlImportResult Result) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall BeforeXmlExport( 
            /* [in] */ XmlMap	*Map,
            /* [in] */ BSTR Url,
            /* [out][in] */ VARIANT_BOOL *Cancel) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall AfterXmlExport( 
            /* [in] */ XmlMap	*Map,
            /* [in] */ BSTR Url,
            /* [in] */ XlXmlExportResult Result) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall RowsetComplete( 
            /* [in] */ BSTR Description,
            /* [in] */ BSTR Sheet,
            /* [in] */ VARIANT_BOOL Success) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SheetPivotTableAfterValueChange( 
            /* [in] */ IDispatch *Sh,
            /* [in] */ PivotTable	*TargetPivotTable,
            /* [in] */ Range	*TargetRange) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SheetPivotTableBeforeAllocateChanges( 
            /* [in] */ IDispatch *Sh,
            /* [in] */ PivotTable	*TargetPivotTable,
            /* [in] */ long ValueChangeStart,
            /* [in] */ long ValueChangeEnd,
            /* [out][in] */ VARIANT_BOOL *Cancel) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SheetPivotTableBeforeCommitChanges( 
            /* [in] */ IDispatch *Sh,
            /* [in] */ PivotTable	*TargetPivotTable,
            /* [in] */ long ValueChangeStart,
            /* [in] */ long ValueChangeEnd,
            /* [out][in] */ VARIANT_BOOL *Cancel) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SheetPivotTableBeforeDiscardChanges( 
            /* [in] */ IDispatch *Sh,
            /* [in] */ PivotTable	*TargetPivotTable,
            /* [in] */ long ValueChangeStart,
            /* [in] */ long ValueChangeEnd) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SheetPivotTableChangeSync( 
            /* [in] */ IDispatch *Sh,
            /* [in] */ PivotTable	*Target) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall AfterSave( 
            /* [in] */ VARIANT_BOOL Success) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall NewChart( 
            /* [in] */ Chart	*Ch) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SheetLensGalleryRenderComplete( 
            /* [in] */ IDispatch *Sh) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SheetTableUpdate( 
            /* [in] */ IDispatch *Sh,
            /* [in] */ TableObject	*Target) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ModelChange( 
            /* [in] */ ModelChanges	*Changes) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SheetBeforeDelete( 
            /* [in] */ IDispatch *Sh) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IWorkbookEventsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IWorkbookEvents * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IWorkbookEvents * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IWorkbookEvents * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IWorkbookEvents * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IWorkbookEvents * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IWorkbookEvents * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IWorkbookEvents * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Open )( 
            IWorkbookEvents * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Activate )( 
            IWorkbookEvents * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Deactivate )( 
            IWorkbookEvents * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *BeforeClose )( 
            IWorkbookEvents * This,
            /* [out][in] */ VARIANT_BOOL *Cancel);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *BeforeSave )( 
            IWorkbookEvents * This,
            /* [in] */ VARIANT_BOOL SaveAsUI,
            /* [out][in] */ VARIANT_BOOL *Cancel);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *BeforePrint )( 
            IWorkbookEvents * This,
            /* [out][in] */ VARIANT_BOOL *Cancel);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *NewSheet )( 
            IWorkbookEvents * This,
            /* [in] */ IDispatch *Sh);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *AddinInstall )( 
            IWorkbookEvents * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *AddinUninstall )( 
            IWorkbookEvents * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *WindowResize )( 
            IWorkbookEvents * This,
            /* [in] */ Window	*Wn);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *WindowActivate )( 
            IWorkbookEvents * This,
            /* [in] */ Window	*Wn);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *WindowDeactivate )( 
            IWorkbookEvents * This,
            /* [in] */ Window	*Wn);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SheetSelectionChange )( 
            IWorkbookEvents * This,
            /* [in] */ IDispatch *Sh,
            /* [in] */ Range	*Target);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SheetBeforeDoubleClick )( 
            IWorkbookEvents * This,
            /* [in] */ IDispatch *Sh,
            /* [in] */ Range	*Target,
            /* [out][in] */ VARIANT_BOOL *Cancel);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SheetBeforeRightClick )( 
            IWorkbookEvents * This,
            /* [in] */ IDispatch *Sh,
            /* [in] */ Range	*Target,
            /* [out][in] */ VARIANT_BOOL *Cancel);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SheetActivate )( 
            IWorkbookEvents * This,
            /* [in] */ IDispatch *Sh);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SheetDeactivate )( 
            IWorkbookEvents * This,
            /* [in] */ IDispatch *Sh);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SheetCalculate )( 
            IWorkbookEvents * This,
            /* [in] */ IDispatch *Sh);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SheetChange )( 
            IWorkbookEvents * This,
            /* [in] */ IDispatch *Sh,
            /* [in] */ Range	*Target);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SheetFollowHyperlink )( 
            IWorkbookEvents * This,
            /* [in] */ IDispatch *Sh,
            /* [in] */ Hyperlink	*Target);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SheetPivotTableUpdate )( 
            IWorkbookEvents * This,
            /* [in] */ IDispatch *Sh,
            /* [in] */ PivotTable	*Target);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *PivotTableCloseConnection )( 
            IWorkbookEvents * This,
            /* [in] */ PivotTable	*Target);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *PivotTableOpenConnection )( 
            IWorkbookEvents * This,
            /* [in] */ PivotTable	*Target);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Sync )( 
            IWorkbookEvents * This,
            /* [in] */ MsoSyncEventType SyncEventType);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *BeforeXmlImport )( 
            IWorkbookEvents * This,
            /* [in] */ XmlMap	*Map,
            /* [in] */ BSTR Url,
            /* [in] */ VARIANT_BOOL IsRefresh,
            /* [out][in] */ VARIANT_BOOL *Cancel);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *AfterXmlImport )( 
            IWorkbookEvents * This,
            /* [in] */ XmlMap	*Map,
            /* [in] */ VARIANT_BOOL IsRefresh,
            /* [in] */ XlXmlImportResult Result);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *BeforeXmlExport )( 
            IWorkbookEvents * This,
            /* [in] */ XmlMap	*Map,
            /* [in] */ BSTR Url,
            /* [out][in] */ VARIANT_BOOL *Cancel);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *AfterXmlExport )( 
            IWorkbookEvents * This,
            /* [in] */ XmlMap	*Map,
            /* [in] */ BSTR Url,
            /* [in] */ XlXmlExportResult Result);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *RowsetComplete )( 
            IWorkbookEvents * This,
            /* [in] */ BSTR Description,
            /* [in] */ BSTR Sheet,
            /* [in] */ VARIANT_BOOL Success);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SheetPivotTableAfterValueChange )( 
            IWorkbookEvents * This,
            /* [in] */ IDispatch *Sh,
            /* [in] */ PivotTable	*TargetPivotTable,
            /* [in] */ Range	*TargetRange);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SheetPivotTableBeforeAllocateChanges )( 
            IWorkbookEvents * This,
            /* [in] */ IDispatch *Sh,
            /* [in] */ PivotTable	*TargetPivotTable,
            /* [in] */ long ValueChangeStart,
            /* [in] */ long ValueChangeEnd,
            /* [out][in] */ VARIANT_BOOL *Cancel);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SheetPivotTableBeforeCommitChanges )( 
            IWorkbookEvents * This,
            /* [in] */ IDispatch *Sh,
            /* [in] */ PivotTable	*TargetPivotTable,
            /* [in] */ long ValueChangeStart,
            /* [in] */ long ValueChangeEnd,
            /* [out][in] */ VARIANT_BOOL *Cancel);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SheetPivotTableBeforeDiscardChanges )( 
            IWorkbookEvents * This,
            /* [in] */ IDispatch *Sh,
            /* [in] */ PivotTable	*TargetPivotTable,
            /* [in] */ long ValueChangeStart,
            /* [in] */ long ValueChangeEnd);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SheetPivotTableChangeSync )( 
            IWorkbookEvents * This,
            /* [in] */ IDispatch *Sh,
            /* [in] */ PivotTable	*Target);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *AfterSave )( 
            IWorkbookEvents * This,
            /* [in] */ VARIANT_BOOL Success);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *NewChart )( 
            IWorkbookEvents * This,
            /* [in] */ Chart	*Ch);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SheetLensGalleryRenderComplete )( 
            IWorkbookEvents * This,
            /* [in] */ IDispatch *Sh);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SheetTableUpdate )( 
            IWorkbookEvents * This,
            /* [in] */ IDispatch *Sh,
            /* [in] */ TableObject	*Target);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ModelChange )( 
            IWorkbookEvents * This,
            /* [in] */ ModelChanges	*Changes);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SheetBeforeDelete )( 
            IWorkbookEvents * This,
            /* [in] */ IDispatch *Sh);
        
        END_INTERFACE
    } IWorkbookEventsVtbl;

    interface IWorkbookEvents
    {
        CONST_VTBL struct IWorkbookEventsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IWorkbookEvents_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IWorkbookEvents_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IWorkbookEvents_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IWorkbookEvents_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IWorkbookEvents_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IWorkbookEvents_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IWorkbookEvents_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IWorkbookEvents_Open(This)	\
    ( (This)->lpVtbl -> Open(This) ) 

#define IWorkbookEvents_Activate(This)	\
    ( (This)->lpVtbl -> Activate(This) ) 

#define IWorkbookEvents_Deactivate(This)	\
    ( (This)->lpVtbl -> Deactivate(This) ) 

#define IWorkbookEvents_BeforeClose(This,Cancel)	\
    ( (This)->lpVtbl -> BeforeClose(This,Cancel) ) 

#define IWorkbookEvents_BeforeSave(This,SaveAsUI,Cancel)	\
    ( (This)->lpVtbl -> BeforeSave(This,SaveAsUI,Cancel) ) 

#define IWorkbookEvents_BeforePrint(This,Cancel)	\
    ( (This)->lpVtbl -> BeforePrint(This,Cancel) ) 

#define IWorkbookEvents_NewSheet(This,Sh)	\
    ( (This)->lpVtbl -> NewSheet(This,Sh) ) 

#define IWorkbookEvents_AddinInstall(This)	\
    ( (This)->lpVtbl -> AddinInstall(This) ) 

#define IWorkbookEvents_AddinUninstall(This)	\
    ( (This)->lpVtbl -> AddinUninstall(This) ) 

#define IWorkbookEvents_WindowResize(This,Wn)	\
    ( (This)->lpVtbl -> WindowResize(This,Wn) ) 

#define IWorkbookEvents_WindowActivate(This,Wn)	\
    ( (This)->lpVtbl -> WindowActivate(This,Wn) ) 

#define IWorkbookEvents_WindowDeactivate(This,Wn)	\
    ( (This)->lpVtbl -> WindowDeactivate(This,Wn) ) 

#define IWorkbookEvents_SheetSelectionChange(This,Sh,Target)	\
    ( (This)->lpVtbl -> SheetSelectionChange(This,Sh,Target) ) 

#define IWorkbookEvents_SheetBeforeDoubleClick(This,Sh,Target,Cancel)	\
    ( (This)->lpVtbl -> SheetBeforeDoubleClick(This,Sh,Target,Cancel) ) 

#define IWorkbookEvents_SheetBeforeRightClick(This,Sh,Target,Cancel)	\
    ( (This)->lpVtbl -> SheetBeforeRightClick(This,Sh,Target,Cancel) ) 

#define IWorkbookEvents_SheetActivate(This,Sh)	\
    ( (This)->lpVtbl -> SheetActivate(This,Sh) ) 

#define IWorkbookEvents_SheetDeactivate(This,Sh)	\
    ( (This)->lpVtbl -> SheetDeactivate(This,Sh) ) 

#define IWorkbookEvents_SheetCalculate(This,Sh)	\
    ( (This)->lpVtbl -> SheetCalculate(This,Sh) ) 

#define IWorkbookEvents_SheetChange(This,Sh,Target)	\
    ( (This)->lpVtbl -> SheetChange(This,Sh,Target) ) 

#define IWorkbookEvents_SheetFollowHyperlink(This,Sh,Target)	\
    ( (This)->lpVtbl -> SheetFollowHyperlink(This,Sh,Target) ) 

#define IWorkbookEvents_SheetPivotTableUpdate(This,Sh,Target)	\
    ( (This)->lpVtbl -> SheetPivotTableUpdate(This,Sh,Target) ) 

#define IWorkbookEvents_PivotTableCloseConnection(This,Target)	\
    ( (This)->lpVtbl -> PivotTableCloseConnection(This,Target) ) 

#define IWorkbookEvents_PivotTableOpenConnection(This,Target)	\
    ( (This)->lpVtbl -> PivotTableOpenConnection(This,Target) ) 

#define IWorkbookEvents_Sync(This,SyncEventType)	\
    ( (This)->lpVtbl -> Sync(This,SyncEventType) ) 

#define IWorkbookEvents_BeforeXmlImport(This,Map,Url,IsRefresh,Cancel)	\
    ( (This)->lpVtbl -> BeforeXmlImport(This,Map,Url,IsRefresh,Cancel) ) 

#define IWorkbookEvents_AfterXmlImport(This,Map,IsRefresh,Result)	\
    ( (This)->lpVtbl -> AfterXmlImport(This,Map,IsRefresh,Result) ) 

#define IWorkbookEvents_BeforeXmlExport(This,Map,Url,Cancel)	\
    ( (This)->lpVtbl -> BeforeXmlExport(This,Map,Url,Cancel) ) 

#define IWorkbookEvents_AfterXmlExport(This,Map,Url,Result)	\
    ( (This)->lpVtbl -> AfterXmlExport(This,Map,Url,Result) ) 

#define IWorkbookEvents_RowsetComplete(This,Description,Sheet,Success)	\
    ( (This)->lpVtbl -> RowsetComplete(This,Description,Sheet,Success) ) 

#define IWorkbookEvents_SheetPivotTableAfterValueChange(This,Sh,TargetPivotTable,TargetRange)	\
    ( (This)->lpVtbl -> SheetPivotTableAfterValueChange(This,Sh,TargetPivotTable,TargetRange) ) 

#define IWorkbookEvents_SheetPivotTableBeforeAllocateChanges(This,Sh,TargetPivotTable,ValueChangeStart,ValueChangeEnd,Cancel)	\
    ( (This)->lpVtbl -> SheetPivotTableBeforeAllocateChanges(This,Sh,TargetPivotTable,ValueChangeStart,ValueChangeEnd,Cancel) ) 

#define IWorkbookEvents_SheetPivotTableBeforeCommitChanges(This,Sh,TargetPivotTable,ValueChangeStart,ValueChangeEnd,Cancel)	\
    ( (This)->lpVtbl -> SheetPivotTableBeforeCommitChanges(This,Sh,TargetPivotTable,ValueChangeStart,ValueChangeEnd,Cancel) ) 

#define IWorkbookEvents_SheetPivotTableBeforeDiscardChanges(This,Sh,TargetPivotTable,ValueChangeStart,ValueChangeEnd)	\
    ( (This)->lpVtbl -> SheetPivotTableBeforeDiscardChanges(This,Sh,TargetPivotTable,ValueChangeStart,ValueChangeEnd) ) 

#define IWorkbookEvents_SheetPivotTableChangeSync(This,Sh,Target)	\
    ( (This)->lpVtbl -> SheetPivotTableChangeSync(This,Sh,Target) ) 

#define IWorkbookEvents_AfterSave(This,Success)	\
    ( (This)->lpVtbl -> AfterSave(This,Success) ) 

#define IWorkbookEvents_NewChart(This,Ch)	\
    ( (This)->lpVtbl -> NewChart(This,Ch) ) 

#define IWorkbookEvents_SheetLensGalleryRenderComplete(This,Sh)	\
    ( (This)->lpVtbl -> SheetLensGalleryRenderComplete(This,Sh) ) 

#define IWorkbookEvents_SheetTableUpdate(This,Sh,Target)	\
    ( (This)->lpVtbl -> SheetTableUpdate(This,Sh,Target) ) 

#define IWorkbookEvents_ModelChange(This,Changes)	\
    ( (This)->lpVtbl -> ModelChange(This,Changes) ) 

#define IWorkbookEvents_SheetBeforeDelete(This,Sh)	\
    ( (This)->lpVtbl -> SheetBeforeDelete(This,Sh) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IWorkbookEvents_INTERFACE_DEFINED__ */


#ifndef ___Workbook_INTERFACE_DEFINED__
#define ___Workbook_INTERFACE_DEFINED__

/* interface _Workbook */
/* [object][oleautomation][dual][helpcontext][uuid] */ 


EXTERN_C const IID IID__Workbook;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000208DA-0000-0000-C000-000000000046")
    _Workbook : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_AcceptLabelsInFormulas( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE put_AcceptLabelsInFormulas( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Activate( 
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ActiveChart( 
            /* [retval][out] */ Chart	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ActiveSheet( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_Author( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE put_Author( 
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_AutoUpdateFrequency( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_AutoUpdateFrequency( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_AutoUpdateSaveChanges( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_AutoUpdateSaveChanges( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ChangeHistoryDuration( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_ChangeHistoryDuration( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_BuiltinDocumentProperties( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE ChangeFileAccess( 
            /* [in] */ XlFileAccess Mode,
            /* [optional][in] */ VARIANT WritePassword,
            /* [optional][in] */ VARIANT Notify,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE ChangeLink( 
            /* [in] */ BSTR Name,
            /* [in] */ BSTR NewName,
            /* [defaultvalue][optional][in] */ XlLinkType Type,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Charts( 
            /* [retval][out] */ Sheets **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Close( 
            /* [optional][in] */ VARIANT SaveChanges,
            /* [optional][in] */ VARIANT Filename,
            /* [optional][in] */ VARIANT RouteWorkbook,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_CodeName( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get__CodeName( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put__CodeName( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Colors( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_Colors( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_CommandBars( 
            /* [retval][out] */ /* external definition not present */ CommandBars **RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_Comments( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE put_Comments( 
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ConflictResolution( 
            /* [retval][out] */ XlSaveConflictResolution *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_ConflictResolution( 
            /* [in] */ XlSaveConflictResolution RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Container( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_CreateBackup( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_CustomDocumentProperties( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Date1904( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_Date1904( 
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE DeleteNumberFormat( 
            /* [in] */ BSTR NumberFormat,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_DialogSheets( 
            /* [retval][out] */ Sheets **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_DisplayDrawingObjects( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ XlDisplayDrawingObjects *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_DisplayDrawingObjects( 
            /* [lcid][in] */ long lcid,
            /* [in] */ XlDisplayDrawingObjects RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE ExclusiveAccess( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_FileFormat( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ XlFileFormat *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE ForwardMailer( 
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_FullName( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_HasMailer( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE put_HasMailer( 
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_HasPassword( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_HasRoutingSlip( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE put_HasRoutingSlip( 
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_IsAddin( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_IsAddin( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_Keywords( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE put_Keywords( 
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE LinkInfo( 
            /* [in] */ BSTR Name,
            /* [in] */ XlLinkInfo LinkInfo,
            /* [optional][in] */ VARIANT Type,
            /* [optional][in] */ VARIANT EditionRef,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE LinkSources( 
            /* [optional][in] */ VARIANT Type,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Mailer( 
            /* [retval][out] */ Mailer	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE MergeWorkbook( 
            /* [in] */ VARIANT Filename) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_Modules( 
            /* [retval][out] */ Sheets **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_MultiUserEditing( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Names( 
            /* [retval][out] */ Names	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE NewWindow( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ Window	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_OnSave( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE put_OnSave( 
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_OnSheetActivate( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE put_OnSheetActivate( 
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_OnSheetDeactivate( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE put_OnSheetDeactivate( 
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE OpenLinks( 
            /* [in] */ BSTR Name,
            /* [optional][in] */ VARIANT ReadOnly,
            /* [optional][in] */ VARIANT Type,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Path( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_PersonalViewListSettings( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_PersonalViewListSettings( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_PersonalViewPrintSettings( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_PersonalViewPrintSettings( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE PivotCaches( 
            /* [retval][out] */ PivotCaches	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Post( 
            /* [optional][in] */ VARIANT DestName,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_PrecisionAsDisplayed( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_PrecisionAsDisplayed( 
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [custom][helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE __PrintOut( 
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE PrintPreview( 
            /* [optional][in] */ VARIANT EnableChanges,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE _Protect( 
            /* [optional][in] */ VARIANT Password,
            /* [optional][in] */ VARIANT Structure,
            /* [optional][in] */ VARIANT Windows) = 0;
        
        virtual /* [custom][helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE _ProtectSharing( 
            /* [optional][in] */ VARIANT Filename,
            /* [optional][in] */ VARIANT Password,
            /* [optional][in] */ VARIANT WriteResPassword,
            /* [optional][in] */ VARIANT ReadOnlyRecommended,
            /* [optional][in] */ VARIANT CreateBackup,
            /* [optional][in] */ VARIANT SharingPassword) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ProtectStructure( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ProtectWindows( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ReadOnly( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get__ReadOnlyRecommended( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE RefreshAll( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Reply( 
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE ReplyAll( 
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE RemoveUser( 
            /* [in] */ long Index) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_RevisionNumber( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE Route( 
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_Routed( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_RoutingSlip( 
            /* [retval][out] */ RoutingSlip	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE RunAutoMacros( 
            /* [in] */ XlRunAutoMacro Which,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Save( 
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE _SaveAs( 
            /* [optional][in] */ VARIANT Filename,
            /* [optional][in] */ VARIANT FileFormat,
            /* [optional][in] */ VARIANT Password,
            /* [optional][in] */ VARIANT WriteResPassword,
            /* [optional][in] */ VARIANT ReadOnlyRecommended,
            /* [optional][in] */ VARIANT CreateBackup,
            /* [defaultvalue][optional][in] */ XlSaveAsAccessMode AccessMode,
            /* [optional][in] */ VARIANT ConflictResolution,
            /* [optional][in] */ VARIANT AddToMru,
            /* [optional][in] */ VARIANT TextCodepage,
            /* [optional][in] */ VARIANT TextVisualLayout,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE SaveCopyAs( 
            /* [optional][in] */ VARIANT Filename,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Saved( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_Saved( 
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_SaveLinkValues( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_SaveLinkValues( 
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE SendMail( 
            /* [in] */ VARIANT Recipients,
            /* [optional][in] */ VARIANT Subject,
            /* [optional][in] */ VARIANT ReturnReceipt,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE SendMailer( 
            /* [optional][in] */ VARIANT FileFormat,
            /* [defaultvalue][optional][in] */ XlPriority Priority,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE SetLinkOnData( 
            /* [in] */ BSTR Name,
            /* [optional][in] */ VARIANT Procedure,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Sheets( 
            /* [retval][out] */ Sheets **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ShowConflictHistory( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_ShowConflictHistory( 
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Styles( 
            /* [retval][out] */ Styles	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_Subject( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE put_Subject( 
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_Title( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE put_Title( 
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Unprotect( 
            /* [optional][in] */ VARIANT Password,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE UnprotectSharing( 
            /* [optional][in] */ VARIANT SharingPassword) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE UpdateFromFile( 
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE UpdateLink( 
            /* [optional][in] */ VARIANT Name,
            /* [optional][in] */ VARIANT Type,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_UpdateRemoteReferences( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_UpdateRemoteReferences( 
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_UserControl( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE put_UserControl( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_UserStatus( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_CustomViews( 
            /* [retval][out] */ CustomViews	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Windows( 
            /* [retval][out] */ Windows	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Worksheets( 
            /* [retval][out] */ Sheets **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_WriteReserved( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_WriteReservedBy( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Excel4IntlMacroSheets( 
            /* [retval][out] */ Sheets **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Excel4MacroSheets( 
            /* [retval][out] */ Sheets **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_TemplateRemoveExtData( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_TemplateRemoveExtData( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE HighlightChangesOptions( 
            /* [optional][in] */ VARIANT When,
            /* [optional][in] */ VARIANT Who,
            /* [optional][in] */ VARIANT Where) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_HighlightChangesOnScreen( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_HighlightChangesOnScreen( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_KeepChangeHistory( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_KeepChangeHistory( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ListChangesOnNewSheet( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_ListChangesOnNewSheet( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE PurgeChangeHistoryNow( 
            /* [in] */ long Days,
            /* [optional][in] */ VARIANT SharingPassword) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE AcceptAllChanges( 
            /* [optional][in] */ VARIANT When,
            /* [optional][in] */ VARIANT Who,
            /* [optional][in] */ VARIANT Where) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE RejectAllChanges( 
            /* [optional][in] */ VARIANT When,
            /* [optional][in] */ VARIANT Who,
            /* [optional][in] */ VARIANT Where) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE PivotTableWizard( 
            /* [optional][in] */ VARIANT SourceType,
            /* [optional][in] */ VARIANT SourceData,
            /* [optional][in] */ VARIANT TableDestination,
            /* [optional][in] */ VARIANT TableName,
            /* [optional][in] */ VARIANT RowGrand,
            /* [optional][in] */ VARIANT ColumnGrand,
            /* [optional][in] */ VARIANT SaveData,
            /* [optional][in] */ VARIANT HasAutoFormat,
            /* [optional][in] */ VARIANT AutoPage,
            /* [optional][in] */ VARIANT Reserved,
            /* [optional][in] */ VARIANT BackgroundQuery,
            /* [optional][in] */ VARIANT OptimizeCache,
            /* [optional][in] */ VARIANT PageFieldOrder,
            /* [optional][in] */ VARIANT PageFieldWrapCount,
            /* [optional][in] */ VARIANT ReadData,
            /* [optional][in] */ VARIANT Connection,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE ResetColors( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_VBProject( 
            /* [retval][out] */ /* external definition not present */ VBProject **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE FollowHyperlink( 
            /* [in] */ BSTR Address,
            /* [optional][in] */ VARIANT SubAddress,
            /* [optional][in] */ VARIANT NewWindow,
            /* [optional][in] */ VARIANT AddHistory,
            /* [optional][in] */ VARIANT ExtraInfo,
            /* [optional][in] */ VARIANT Method,
            /* [optional][in] */ VARIANT HeaderInfo) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE AddToFavorites( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_IsInplace( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [custom][helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE _PrintOut( 
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate,
            /* [optional][in] */ VARIANT PrToFileName,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE WebPagePreview( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_PublishObjects( 
            /* [retval][out] */ PublishObjects	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_WebOptions( 
            /* [retval][out] */ WebOptions **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE ReloadAs( 
            /* [in] */ MsoEncoding Encoding) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_HTMLProject( 
            /* [retval][out] */ /* external definition not present */ HTMLProject **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_EnvelopeVisible( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_EnvelopeVisible( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_CalculationVersion( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE Dummy17( 
            /* [in] */ long calcid) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE sblt( 
            /* [in] */ BSTR s) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_VBASigned( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ShowPivotTableFieldList( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_ShowPivotTableFieldList( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_UpdateLinks( 
            /* [retval][out] */ XlUpdateLinks *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_UpdateLinks( 
            /* [in] */ XlUpdateLinks RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE BreakLink( 
            /* [in] */ BSTR Name,
            /* [in] */ XlLinkType Type) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE Dummy16( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE SaveAs( 
            /* [optional][in] */ VARIANT Filename,
            /* [optional][in] */ VARIANT FileFormat,
            /* [optional][in] */ VARIANT Password,
            /* [optional][in] */ VARIANT WriteResPassword,
            /* [optional][in] */ VARIANT ReadOnlyRecommended,
            /* [optional][in] */ VARIANT CreateBackup,
            /* [defaultvalue][optional][in] */ XlSaveAsAccessMode AccessMode,
            /* [optional][in] */ VARIANT ConflictResolution,
            /* [optional][in] */ VARIANT AddToMru,
            /* [optional][in] */ VARIANT TextCodepage,
            /* [optional][in] */ VARIANT TextVisualLayout,
            /* [optional][in] */ VARIANT Local,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_EnableAutoRecover( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_EnableAutoRecover( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_RemovePersonalInformation( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_RemovePersonalInformation( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_FullNameURLEncoded( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE CheckIn( 
            /* [optional][in] */ VARIANT SaveChanges,
            /* [optional][in] */ VARIANT Comments,
            /* [optional][in] */ VARIANT MakePublic) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE CanCheckIn( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE SendForReview( 
            /* [optional][in] */ VARIANT Recipients,
            /* [optional][in] */ VARIANT Subject,
            /* [optional][in] */ VARIANT ShowMessage,
            /* [optional][in] */ VARIANT IncludeAttachment) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE ReplyWithChanges( 
            /* [optional][in] */ VARIANT ShowMessage) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE EndReview( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Password( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_Password( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_WritePassword( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_WritePassword( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_PasswordEncryptionProvider( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_PasswordEncryptionAlgorithm( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_PasswordEncryptionKeyLength( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE SetPasswordEncryptionOptions( 
            /* [optional][in] */ VARIANT PasswordEncryptionProvider,
            /* [optional][in] */ VARIANT PasswordEncryptionAlgorithm,
            /* [optional][in] */ VARIANT PasswordEncryptionKeyLength,
            /* [optional][in] */ VARIANT PasswordEncryptionFileProperties) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_PasswordEncryptionFileProperties( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ReadOnlyRecommended( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_ReadOnlyRecommended( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Protect( 
            /* [optional][in] */ VARIANT Password,
            /* [optional][in] */ VARIANT Structure,
            /* [optional][in] */ VARIANT Windows) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_SmartTagOptions( 
            /* [retval][out] */ SmartTagOptions	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE RecheckSmartTags( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Permission( 
            /* [retval][out] */ /* external definition not present */ Permission **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_SharedWorkspace( 
            /* [retval][out] */ /* external definition not present */ SharedWorkspace **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Sync( 
            /* [retval][out] */ /* external definition not present */ Sync **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE SendFaxOverInternet( 
            /* [optional][in] */ VARIANT Recipients,
            /* [optional][in] */ VARIANT Subject,
            /* [optional][in] */ VARIANT ShowMessage) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_XmlNamespaces( 
            /* [retval][out] */ XmlNamespaces	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_XmlMaps( 
            /* [retval][out] */ XmlMaps	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE XmlImport( 
            /* [in] */ BSTR Url,
            /* [out] */ XmlMap	**ImportMap,
            /* [optional][in] */ VARIANT Overwrite,
            /* [optional][in] */ VARIANT Destination,
            /* [retval][out] */ XlXmlImportResult *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_SmartDocument( 
            /* [retval][out] */ /* external definition not present */ SmartDocument **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_DocumentLibraryVersions( 
            /* [retval][out] */ /* external definition not present */ DocumentLibraryVersions **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_InactiveListBorderVisible( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_InactiveListBorderVisible( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_DisplayInkComments( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_DisplayInkComments( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE XmlImportXml( 
            /* [in] */ BSTR Data,
            /* [out] */ XmlMap	**ImportMap,
            /* [optional][in] */ VARIANT Overwrite,
            /* [optional][in] */ VARIANT Destination,
            /* [retval][out] */ XlXmlImportResult *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE SaveAsXMLData( 
            /* [in] */ BSTR Filename,
            /* [in] */ XmlMap	*Map) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE ToggleFormsDesign( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ContentTypeProperties( 
            /* [retval][out] */ /* external definition not present */ MetaProperties **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Connections( 
            /* [retval][out] */ Connections	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE RemoveDocumentInformation( 
            /* [in] */ XlRemoveDocInfoType RemoveDocInfoType) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Signatures( 
            /* [retval][out] */ /* external definition not present */ SignatureSet **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE CheckInWithVersion( 
            /* [optional][in] */ VARIANT SaveChanges,
            /* [optional][in] */ VARIANT Comments,
            /* [optional][in] */ VARIANT MakePublic,
            /* [optional][in] */ VARIANT VersionType) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ServerPolicy( 
            /* [retval][out] */ /* external definition not present */ ServerPolicy **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE LockServerFile( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_DocumentInspectors( 
            /* [retval][out] */ /* external definition not present */ DocumentInspectors **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE GetWorkflowTasks( 
            /* [retval][out] */ /* external definition not present */ WorkflowTasks **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE GetWorkflowTemplates( 
            /* [retval][out] */ /* external definition not present */ WorkflowTemplates **RHS) = 0;
        
        virtual /* [custom][helpcontext][id] */ HRESULT STDMETHODCALLTYPE PrintOut( 
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate,
            /* [optional][in] */ VARIANT PrToFileName,
            /* [optional][in] */ VARIANT IgnorePrintAreas,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ServerViewableItems( 
            /* [retval][out] */ ServerViewableItems	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_TableStyles( 
            /* [retval][out] */ TableStyles	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_DefaultTableStyle( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_DefaultTableStyle( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_DefaultPivotTableStyle( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_DefaultPivotTableStyle( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_CheckCompatibility( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_CheckCompatibility( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_HasVBProject( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_CustomXMLParts( 
            /* [retval][out] */ /* external definition not present */ CustomXMLParts **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Final( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_Final( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Research( 
            /* [retval][out] */ Research	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Theme( 
            /* [retval][out] */ /* external definition not present */ OfficeTheme **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE ApplyTheme( 
            /* [in] */ BSTR Filename) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Excel8CompatibilityMode( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ConnectionsDisabled( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE EnableConnections( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ShowPivotChartActiveFields( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_ShowPivotChartActiveFields( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE ExportAsFixedFormat( 
            /* [in] */ XlFixedFormatType Type,
            /* [optional][in] */ VARIANT Filename,
            /* [optional][in] */ VARIANT Quality,
            /* [optional][in] */ VARIANT IncludeDocProperties,
            /* [optional][in] */ VARIANT IgnorePrintAreas,
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT OpenAfterPublish,
            /* [optional][in] */ VARIANT FixedFormatExtClassPtr) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_IconSets( 
            /* [retval][out] */ IconSets	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_EncryptionProvider( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_EncryptionProvider( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_DoNotPromptForConvert( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_DoNotPromptForConvert( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ForceFullCalculation( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_ForceFullCalculation( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [custom][helpcontext][id] */ HRESULT STDMETHODCALLTYPE ProtectSharing( 
            /* [optional][in] */ VARIANT Filename,
            /* [optional][in] */ VARIANT Password,
            /* [optional][in] */ VARIANT WriteResPassword,
            /* [optional][in] */ VARIANT ReadOnlyRecommended,
            /* [optional][in] */ VARIANT CreateBackup,
            /* [optional][in] */ VARIANT SharingPassword,
            /* [optional][in] */ VARIANT FileFormat) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_SlicerCaches( 
            /* [retval][out] */ SlicerCaches	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ActiveSlicer( 
            /* [retval][out] */ Slicer	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_DefaultSlicerStyle( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_DefaultSlicerStyle( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE Dummy26( void) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE Dummy27( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_AccuracyVersion( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_AccuracyVersion( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_CaseSensitive( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_UseWholeCellCriteria( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_UseWildcards( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_PivotTables( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Model( 
            /* [retval][out] */ Model	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ChartDataPointTrack( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_ChartDataPointTrack( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_DefaultTimelineStyle( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_DefaultTimelineStyle( 
            /* [in] */ VARIANT RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct _WorkbookVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            _Workbook * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            _Workbook * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            _Workbook * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            _Workbook * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            _Workbook * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            _Workbook * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            _Workbook * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Application )( 
            _Workbook * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Creator )( 
            _Workbook * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Parent )( 
            _Workbook * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_AcceptLabelsInFormulas )( 
            _Workbook * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_AcceptLabelsInFormulas )( 
            _Workbook * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Activate )( 
            _Workbook * This,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ActiveChart )( 
            _Workbook * This,
            /* [retval][out] */ Chart	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ActiveSheet )( 
            _Workbook * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Author )( 
            _Workbook * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Author )( 
            _Workbook * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_AutoUpdateFrequency )( 
            _Workbook * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_AutoUpdateFrequency )( 
            _Workbook * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_AutoUpdateSaveChanges )( 
            _Workbook * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_AutoUpdateSaveChanges )( 
            _Workbook * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ChangeHistoryDuration )( 
            _Workbook * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_ChangeHistoryDuration )( 
            _Workbook * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_BuiltinDocumentProperties )( 
            _Workbook * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *ChangeFileAccess )( 
            _Workbook * This,
            /* [in] */ XlFileAccess Mode,
            /* [optional][in] */ VARIANT WritePassword,
            /* [optional][in] */ VARIANT Notify,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *ChangeLink )( 
            _Workbook * This,
            /* [in] */ BSTR Name,
            /* [in] */ BSTR NewName,
            /* [defaultvalue][optional][in] */ XlLinkType Type,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Charts )( 
            _Workbook * This,
            /* [retval][out] */ Sheets **RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Close )( 
            _Workbook * This,
            /* [optional][in] */ VARIANT SaveChanges,
            /* [optional][in] */ VARIANT Filename,
            /* [optional][in] */ VARIANT RouteWorkbook,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_CodeName )( 
            _Workbook * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get__CodeName )( 
            _Workbook * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put__CodeName )( 
            _Workbook * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Colors )( 
            _Workbook * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Colors )( 
            _Workbook * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_CommandBars )( 
            _Workbook * This,
            /* [retval][out] */ /* external definition not present */ CommandBars **RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Comments )( 
            _Workbook * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Comments )( 
            _Workbook * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ConflictResolution )( 
            _Workbook * This,
            /* [retval][out] */ XlSaveConflictResolution *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_ConflictResolution )( 
            _Workbook * This,
            /* [in] */ XlSaveConflictResolution RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Container )( 
            _Workbook * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_CreateBackup )( 
            _Workbook * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_CustomDocumentProperties )( 
            _Workbook * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Date1904 )( 
            _Workbook * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Date1904 )( 
            _Workbook * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *DeleteNumberFormat )( 
            _Workbook * This,
            /* [in] */ BSTR NumberFormat,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_DialogSheets )( 
            _Workbook * This,
            /* [retval][out] */ Sheets **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_DisplayDrawingObjects )( 
            _Workbook * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ XlDisplayDrawingObjects *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_DisplayDrawingObjects )( 
            _Workbook * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ XlDisplayDrawingObjects RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *ExclusiveAccess )( 
            _Workbook * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_FileFormat )( 
            _Workbook * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ XlFileFormat *RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *ForwardMailer )( 
            _Workbook * This,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_FullName )( 
            _Workbook * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_HasMailer )( 
            _Workbook * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_HasMailer )( 
            _Workbook * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_HasPassword )( 
            _Workbook * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_HasRoutingSlip )( 
            _Workbook * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_HasRoutingSlip )( 
            _Workbook * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_IsAddin )( 
            _Workbook * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_IsAddin )( 
            _Workbook * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Keywords )( 
            _Workbook * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Keywords )( 
            _Workbook * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *LinkInfo )( 
            _Workbook * This,
            /* [in] */ BSTR Name,
            /* [in] */ XlLinkInfo LinkInfo,
            /* [optional][in] */ VARIANT Type,
            /* [optional][in] */ VARIANT EditionRef,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *LinkSources )( 
            _Workbook * This,
            /* [optional][in] */ VARIANT Type,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Mailer )( 
            _Workbook * This,
            /* [retval][out] */ Mailer	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *MergeWorkbook )( 
            _Workbook * This,
            /* [in] */ VARIANT Filename);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Modules )( 
            _Workbook * This,
            /* [retval][out] */ Sheets **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_MultiUserEditing )( 
            _Workbook * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Name )( 
            _Workbook * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Names )( 
            _Workbook * This,
            /* [retval][out] */ Names	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *NewWindow )( 
            _Workbook * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ Window	**RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_OnSave )( 
            _Workbook * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_OnSave )( 
            _Workbook * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_OnSheetActivate )( 
            _Workbook * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_OnSheetActivate )( 
            _Workbook * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_OnSheetDeactivate )( 
            _Workbook * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_OnSheetDeactivate )( 
            _Workbook * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *OpenLinks )( 
            _Workbook * This,
            /* [in] */ BSTR Name,
            /* [optional][in] */ VARIANT ReadOnly,
            /* [optional][in] */ VARIANT Type,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Path )( 
            _Workbook * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_PersonalViewListSettings )( 
            _Workbook * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_PersonalViewListSettings )( 
            _Workbook * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_PersonalViewPrintSettings )( 
            _Workbook * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_PersonalViewPrintSettings )( 
            _Workbook * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *PivotCaches )( 
            _Workbook * This,
            /* [retval][out] */ PivotCaches	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Post )( 
            _Workbook * This,
            /* [optional][in] */ VARIANT DestName,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_PrecisionAsDisplayed )( 
            _Workbook * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_PrecisionAsDisplayed )( 
            _Workbook * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [custom][helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *__PrintOut )( 
            _Workbook * This,
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *PrintPreview )( 
            _Workbook * This,
            /* [optional][in] */ VARIANT EnableChanges,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *_Protect )( 
            _Workbook * This,
            /* [optional][in] */ VARIANT Password,
            /* [optional][in] */ VARIANT Structure,
            /* [optional][in] */ VARIANT Windows);
        
        /* [custom][helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *_ProtectSharing )( 
            _Workbook * This,
            /* [optional][in] */ VARIANT Filename,
            /* [optional][in] */ VARIANT Password,
            /* [optional][in] */ VARIANT WriteResPassword,
            /* [optional][in] */ VARIANT ReadOnlyRecommended,
            /* [optional][in] */ VARIANT CreateBackup,
            /* [optional][in] */ VARIANT SharingPassword);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ProtectStructure )( 
            _Workbook * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ProtectWindows )( 
            _Workbook * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ReadOnly )( 
            _Workbook * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get__ReadOnlyRecommended )( 
            _Workbook * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *RefreshAll )( 
            _Workbook * This);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Reply )( 
            _Workbook * This,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *ReplyAll )( 
            _Workbook * This,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *RemoveUser )( 
            _Workbook * This,
            /* [in] */ long Index);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_RevisionNumber )( 
            _Workbook * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *Route )( 
            _Workbook * This,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Routed )( 
            _Workbook * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_RoutingSlip )( 
            _Workbook * This,
            /* [retval][out] */ RoutingSlip	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *RunAutoMacros )( 
            _Workbook * This,
            /* [in] */ XlRunAutoMacro Which,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Save )( 
            _Workbook * This,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *_SaveAs )( 
            _Workbook * This,
            /* [optional][in] */ VARIANT Filename,
            /* [optional][in] */ VARIANT FileFormat,
            /* [optional][in] */ VARIANT Password,
            /* [optional][in] */ VARIANT WriteResPassword,
            /* [optional][in] */ VARIANT ReadOnlyRecommended,
            /* [optional][in] */ VARIANT CreateBackup,
            /* [defaultvalue][optional][in] */ XlSaveAsAccessMode AccessMode,
            /* [optional][in] */ VARIANT ConflictResolution,
            /* [optional][in] */ VARIANT AddToMru,
            /* [optional][in] */ VARIANT TextCodepage,
            /* [optional][in] */ VARIANT TextVisualLayout,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *SaveCopyAs )( 
            _Workbook * This,
            /* [optional][in] */ VARIANT Filename,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Saved )( 
            _Workbook * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Saved )( 
            _Workbook * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_SaveLinkValues )( 
            _Workbook * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_SaveLinkValues )( 
            _Workbook * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *SendMail )( 
            _Workbook * This,
            /* [in] */ VARIANT Recipients,
            /* [optional][in] */ VARIANT Subject,
            /* [optional][in] */ VARIANT ReturnReceipt,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *SendMailer )( 
            _Workbook * This,
            /* [optional][in] */ VARIANT FileFormat,
            /* [defaultvalue][optional][in] */ XlPriority Priority,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *SetLinkOnData )( 
            _Workbook * This,
            /* [in] */ BSTR Name,
            /* [optional][in] */ VARIANT Procedure,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Sheets )( 
            _Workbook * This,
            /* [retval][out] */ Sheets **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ShowConflictHistory )( 
            _Workbook * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_ShowConflictHistory )( 
            _Workbook * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Styles )( 
            _Workbook * This,
            /* [retval][out] */ Styles	**RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Subject )( 
            _Workbook * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Subject )( 
            _Workbook * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Title )( 
            _Workbook * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Title )( 
            _Workbook * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Unprotect )( 
            _Workbook * This,
            /* [optional][in] */ VARIANT Password,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *UnprotectSharing )( 
            _Workbook * This,
            /* [optional][in] */ VARIANT SharingPassword);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *UpdateFromFile )( 
            _Workbook * This,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *UpdateLink )( 
            _Workbook * This,
            /* [optional][in] */ VARIANT Name,
            /* [optional][in] */ VARIANT Type,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_UpdateRemoteReferences )( 
            _Workbook * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_UpdateRemoteReferences )( 
            _Workbook * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_UserControl )( 
            _Workbook * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_UserControl )( 
            _Workbook * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_UserStatus )( 
            _Workbook * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_CustomViews )( 
            _Workbook * This,
            /* [retval][out] */ CustomViews	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Windows )( 
            _Workbook * This,
            /* [retval][out] */ Windows	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Worksheets )( 
            _Workbook * This,
            /* [retval][out] */ Sheets **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_WriteReserved )( 
            _Workbook * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_WriteReservedBy )( 
            _Workbook * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Excel4IntlMacroSheets )( 
            _Workbook * This,
            /* [retval][out] */ Sheets **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Excel4MacroSheets )( 
            _Workbook * This,
            /* [retval][out] */ Sheets **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_TemplateRemoveExtData )( 
            _Workbook * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_TemplateRemoveExtData )( 
            _Workbook * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *HighlightChangesOptions )( 
            _Workbook * This,
            /* [optional][in] */ VARIANT When,
            /* [optional][in] */ VARIANT Who,
            /* [optional][in] */ VARIANT Where);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_HighlightChangesOnScreen )( 
            _Workbook * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_HighlightChangesOnScreen )( 
            _Workbook * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_KeepChangeHistory )( 
            _Workbook * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_KeepChangeHistory )( 
            _Workbook * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ListChangesOnNewSheet )( 
            _Workbook * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_ListChangesOnNewSheet )( 
            _Workbook * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *PurgeChangeHistoryNow )( 
            _Workbook * This,
            /* [in] */ long Days,
            /* [optional][in] */ VARIANT SharingPassword);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *AcceptAllChanges )( 
            _Workbook * This,
            /* [optional][in] */ VARIANT When,
            /* [optional][in] */ VARIANT Who,
            /* [optional][in] */ VARIANT Where);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *RejectAllChanges )( 
            _Workbook * This,
            /* [optional][in] */ VARIANT When,
            /* [optional][in] */ VARIANT Who,
            /* [optional][in] */ VARIANT Where);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *PivotTableWizard )( 
            _Workbook * This,
            /* [optional][in] */ VARIANT SourceType,
            /* [optional][in] */ VARIANT SourceData,
            /* [optional][in] */ VARIANT TableDestination,
            /* [optional][in] */ VARIANT TableName,
            /* [optional][in] */ VARIANT RowGrand,
            /* [optional][in] */ VARIANT ColumnGrand,
            /* [optional][in] */ VARIANT SaveData,
            /* [optional][in] */ VARIANT HasAutoFormat,
            /* [optional][in] */ VARIANT AutoPage,
            /* [optional][in] */ VARIANT Reserved,
            /* [optional][in] */ VARIANT BackgroundQuery,
            /* [optional][in] */ VARIANT OptimizeCache,
            /* [optional][in] */ VARIANT PageFieldOrder,
            /* [optional][in] */ VARIANT PageFieldWrapCount,
            /* [optional][in] */ VARIANT ReadData,
            /* [optional][in] */ VARIANT Connection,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *ResetColors )( 
            _Workbook * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_VBProject )( 
            _Workbook * This,
            /* [retval][out] */ /* external definition not present */ VBProject **RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *FollowHyperlink )( 
            _Workbook * This,
            /* [in] */ BSTR Address,
            /* [optional][in] */ VARIANT SubAddress,
            /* [optional][in] */ VARIANT NewWindow,
            /* [optional][in] */ VARIANT AddHistory,
            /* [optional][in] */ VARIANT ExtraInfo,
            /* [optional][in] */ VARIANT Method,
            /* [optional][in] */ VARIANT HeaderInfo);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *AddToFavorites )( 
            _Workbook * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_IsInplace )( 
            _Workbook * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [custom][helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *_PrintOut )( 
            _Workbook * This,
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate,
            /* [optional][in] */ VARIANT PrToFileName,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *WebPagePreview )( 
            _Workbook * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_PublishObjects )( 
            _Workbook * This,
            /* [retval][out] */ PublishObjects	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_WebOptions )( 
            _Workbook * This,
            /* [retval][out] */ WebOptions **RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *ReloadAs )( 
            _Workbook * This,
            /* [in] */ MsoEncoding Encoding);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_HTMLProject )( 
            _Workbook * This,
            /* [retval][out] */ /* external definition not present */ HTMLProject **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_EnvelopeVisible )( 
            _Workbook * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_EnvelopeVisible )( 
            _Workbook * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_CalculationVersion )( 
            _Workbook * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *Dummy17 )( 
            _Workbook * This,
            /* [in] */ long calcid);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *sblt )( 
            _Workbook * This,
            /* [in] */ BSTR s);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_VBASigned )( 
            _Workbook * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ShowPivotTableFieldList )( 
            _Workbook * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_ShowPivotTableFieldList )( 
            _Workbook * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_UpdateLinks )( 
            _Workbook * This,
            /* [retval][out] */ XlUpdateLinks *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_UpdateLinks )( 
            _Workbook * This,
            /* [in] */ XlUpdateLinks RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *BreakLink )( 
            _Workbook * This,
            /* [in] */ BSTR Name,
            /* [in] */ XlLinkType Type);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *Dummy16 )( 
            _Workbook * This);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *SaveAs )( 
            _Workbook * This,
            /* [optional][in] */ VARIANT Filename,
            /* [optional][in] */ VARIANT FileFormat,
            /* [optional][in] */ VARIANT Password,
            /* [optional][in] */ VARIANT WriteResPassword,
            /* [optional][in] */ VARIANT ReadOnlyRecommended,
            /* [optional][in] */ VARIANT CreateBackup,
            /* [defaultvalue][optional][in] */ XlSaveAsAccessMode AccessMode,
            /* [optional][in] */ VARIANT ConflictResolution,
            /* [optional][in] */ VARIANT AddToMru,
            /* [optional][in] */ VARIANT TextCodepage,
            /* [optional][in] */ VARIANT TextVisualLayout,
            /* [optional][in] */ VARIANT Local,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_EnableAutoRecover )( 
            _Workbook * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_EnableAutoRecover )( 
            _Workbook * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_RemovePersonalInformation )( 
            _Workbook * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_RemovePersonalInformation )( 
            _Workbook * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_FullNameURLEncoded )( 
            _Workbook * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *CheckIn )( 
            _Workbook * This,
            /* [optional][in] */ VARIANT SaveChanges,
            /* [optional][in] */ VARIANT Comments,
            /* [optional][in] */ VARIANT MakePublic);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *CanCheckIn )( 
            _Workbook * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *SendForReview )( 
            _Workbook * This,
            /* [optional][in] */ VARIANT Recipients,
            /* [optional][in] */ VARIANT Subject,
            /* [optional][in] */ VARIANT ShowMessage,
            /* [optional][in] */ VARIANT IncludeAttachment);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *ReplyWithChanges )( 
            _Workbook * This,
            /* [optional][in] */ VARIANT ShowMessage);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *EndReview )( 
            _Workbook * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Password )( 
            _Workbook * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Password )( 
            _Workbook * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_WritePassword )( 
            _Workbook * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_WritePassword )( 
            _Workbook * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_PasswordEncryptionProvider )( 
            _Workbook * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_PasswordEncryptionAlgorithm )( 
            _Workbook * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_PasswordEncryptionKeyLength )( 
            _Workbook * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *SetPasswordEncryptionOptions )( 
            _Workbook * This,
            /* [optional][in] */ VARIANT PasswordEncryptionProvider,
            /* [optional][in] */ VARIANT PasswordEncryptionAlgorithm,
            /* [optional][in] */ VARIANT PasswordEncryptionKeyLength,
            /* [optional][in] */ VARIANT PasswordEncryptionFileProperties);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_PasswordEncryptionFileProperties )( 
            _Workbook * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ReadOnlyRecommended )( 
            _Workbook * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_ReadOnlyRecommended )( 
            _Workbook * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Protect )( 
            _Workbook * This,
            /* [optional][in] */ VARIANT Password,
            /* [optional][in] */ VARIANT Structure,
            /* [optional][in] */ VARIANT Windows);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_SmartTagOptions )( 
            _Workbook * This,
            /* [retval][out] */ SmartTagOptions	**RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *RecheckSmartTags )( 
            _Workbook * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Permission )( 
            _Workbook * This,
            /* [retval][out] */ /* external definition not present */ Permission **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_SharedWorkspace )( 
            _Workbook * This,
            /* [retval][out] */ /* external definition not present */ SharedWorkspace **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Sync )( 
            _Workbook * This,
            /* [retval][out] */ /* external definition not present */ Sync **RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *SendFaxOverInternet )( 
            _Workbook * This,
            /* [optional][in] */ VARIANT Recipients,
            /* [optional][in] */ VARIANT Subject,
            /* [optional][in] */ VARIANT ShowMessage);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_XmlNamespaces )( 
            _Workbook * This,
            /* [retval][out] */ XmlNamespaces	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_XmlMaps )( 
            _Workbook * This,
            /* [retval][out] */ XmlMaps	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *XmlImport )( 
            _Workbook * This,
            /* [in] */ BSTR Url,
            /* [out] */ XmlMap	**ImportMap,
            /* [optional][in] */ VARIANT Overwrite,
            /* [optional][in] */ VARIANT Destination,
            /* [retval][out] */ XlXmlImportResult *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_SmartDocument )( 
            _Workbook * This,
            /* [retval][out] */ /* external definition not present */ SmartDocument **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_DocumentLibraryVersions )( 
            _Workbook * This,
            /* [retval][out] */ /* external definition not present */ DocumentLibraryVersions **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_InactiveListBorderVisible )( 
            _Workbook * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_InactiveListBorderVisible )( 
            _Workbook * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_DisplayInkComments )( 
            _Workbook * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_DisplayInkComments )( 
            _Workbook * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *XmlImportXml )( 
            _Workbook * This,
            /* [in] */ BSTR Data,
            /* [out] */ XmlMap	**ImportMap,
            /* [optional][in] */ VARIANT Overwrite,
            /* [optional][in] */ VARIANT Destination,
            /* [retval][out] */ XlXmlImportResult *RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *SaveAsXMLData )( 
            _Workbook * This,
            /* [in] */ BSTR Filename,
            /* [in] */ XmlMap	*Map);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *ToggleFormsDesign )( 
            _Workbook * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ContentTypeProperties )( 
            _Workbook * This,
            /* [retval][out] */ /* external definition not present */ MetaProperties **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Connections )( 
            _Workbook * This,
            /* [retval][out] */ Connections	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *RemoveDocumentInformation )( 
            _Workbook * This,
            /* [in] */ XlRemoveDocInfoType RemoveDocInfoType);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Signatures )( 
            _Workbook * This,
            /* [retval][out] */ /* external definition not present */ SignatureSet **RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *CheckInWithVersion )( 
            _Workbook * This,
            /* [optional][in] */ VARIANT SaveChanges,
            /* [optional][in] */ VARIANT Comments,
            /* [optional][in] */ VARIANT MakePublic,
            /* [optional][in] */ VARIANT VersionType);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ServerPolicy )( 
            _Workbook * This,
            /* [retval][out] */ /* external definition not present */ ServerPolicy **RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *LockServerFile )( 
            _Workbook * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_DocumentInspectors )( 
            _Workbook * This,
            /* [retval][out] */ /* external definition not present */ DocumentInspectors **RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *GetWorkflowTasks )( 
            _Workbook * This,
            /* [retval][out] */ /* external definition not present */ WorkflowTasks **RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *GetWorkflowTemplates )( 
            _Workbook * This,
            /* [retval][out] */ /* external definition not present */ WorkflowTemplates **RHS);
        
        /* [custom][helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *PrintOut )( 
            _Workbook * This,
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate,
            /* [optional][in] */ VARIANT PrToFileName,
            /* [optional][in] */ VARIANT IgnorePrintAreas,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ServerViewableItems )( 
            _Workbook * This,
            /* [retval][out] */ ServerViewableItems	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_TableStyles )( 
            _Workbook * This,
            /* [retval][out] */ TableStyles	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_DefaultTableStyle )( 
            _Workbook * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_DefaultTableStyle )( 
            _Workbook * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_DefaultPivotTableStyle )( 
            _Workbook * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_DefaultPivotTableStyle )( 
            _Workbook * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_CheckCompatibility )( 
            _Workbook * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_CheckCompatibility )( 
            _Workbook * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_HasVBProject )( 
            _Workbook * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_CustomXMLParts )( 
            _Workbook * This,
            /* [retval][out] */ /* external definition not present */ CustomXMLParts **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Final )( 
            _Workbook * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Final )( 
            _Workbook * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Research )( 
            _Workbook * This,
            /* [retval][out] */ Research	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Theme )( 
            _Workbook * This,
            /* [retval][out] */ /* external definition not present */ OfficeTheme **RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *ApplyTheme )( 
            _Workbook * This,
            /* [in] */ BSTR Filename);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Excel8CompatibilityMode )( 
            _Workbook * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ConnectionsDisabled )( 
            _Workbook * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *EnableConnections )( 
            _Workbook * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ShowPivotChartActiveFields )( 
            _Workbook * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_ShowPivotChartActiveFields )( 
            _Workbook * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *ExportAsFixedFormat )( 
            _Workbook * This,
            /* [in] */ XlFixedFormatType Type,
            /* [optional][in] */ VARIANT Filename,
            /* [optional][in] */ VARIANT Quality,
            /* [optional][in] */ VARIANT IncludeDocProperties,
            /* [optional][in] */ VARIANT IgnorePrintAreas,
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT OpenAfterPublish,
            /* [optional][in] */ VARIANT FixedFormatExtClassPtr);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_IconSets )( 
            _Workbook * This,
            /* [retval][out] */ IconSets	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_EncryptionProvider )( 
            _Workbook * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_EncryptionProvider )( 
            _Workbook * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_DoNotPromptForConvert )( 
            _Workbook * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_DoNotPromptForConvert )( 
            _Workbook * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ForceFullCalculation )( 
            _Workbook * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_ForceFullCalculation )( 
            _Workbook * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [custom][helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *ProtectSharing )( 
            _Workbook * This,
            /* [optional][in] */ VARIANT Filename,
            /* [optional][in] */ VARIANT Password,
            /* [optional][in] */ VARIANT WriteResPassword,
            /* [optional][in] */ VARIANT ReadOnlyRecommended,
            /* [optional][in] */ VARIANT CreateBackup,
            /* [optional][in] */ VARIANT SharingPassword,
            /* [optional][in] */ VARIANT FileFormat);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_SlicerCaches )( 
            _Workbook * This,
            /* [retval][out] */ SlicerCaches	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ActiveSlicer )( 
            _Workbook * This,
            /* [retval][out] */ Slicer	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_DefaultSlicerStyle )( 
            _Workbook * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_DefaultSlicerStyle )( 
            _Workbook * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *Dummy26 )( 
            _Workbook * This);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *Dummy27 )( 
            _Workbook * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_AccuracyVersion )( 
            _Workbook * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_AccuracyVersion )( 
            _Workbook * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_CaseSensitive )( 
            _Workbook * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_UseWholeCellCriteria )( 
            _Workbook * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_UseWildcards )( 
            _Workbook * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_PivotTables )( 
            _Workbook * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Model )( 
            _Workbook * This,
            /* [retval][out] */ Model	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ChartDataPointTrack )( 
            _Workbook * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_ChartDataPointTrack )( 
            _Workbook * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_DefaultTimelineStyle )( 
            _Workbook * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_DefaultTimelineStyle )( 
            _Workbook * This,
            /* [in] */ VARIANT RHS);
        
        END_INTERFACE
    } _WorkbookVtbl;

    interface _Workbook
    {
        CONST_VTBL struct _WorkbookVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define _Workbook_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define _Workbook_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define _Workbook_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define _Workbook_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define _Workbook_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define _Workbook_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define _Workbook_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define _Workbook_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define _Workbook_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define _Workbook_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define _Workbook_get_AcceptLabelsInFormulas(This,RHS)	\
    ( (This)->lpVtbl -> get_AcceptLabelsInFormulas(This,RHS) ) 

#define _Workbook_put_AcceptLabelsInFormulas(This,RHS)	\
    ( (This)->lpVtbl -> put_AcceptLabelsInFormulas(This,RHS) ) 

#define _Workbook_Activate(This,lcid)	\
    ( (This)->lpVtbl -> Activate(This,lcid) ) 

#define _Workbook_get_ActiveChart(This,RHS)	\
    ( (This)->lpVtbl -> get_ActiveChart(This,RHS) ) 

#define _Workbook_get_ActiveSheet(This,RHS)	\
    ( (This)->lpVtbl -> get_ActiveSheet(This,RHS) ) 

#define _Workbook_get_Author(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_Author(This,lcid,RHS) ) 

#define _Workbook_put_Author(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_Author(This,lcid,RHS) ) 

#define _Workbook_get_AutoUpdateFrequency(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoUpdateFrequency(This,RHS) ) 

#define _Workbook_put_AutoUpdateFrequency(This,RHS)	\
    ( (This)->lpVtbl -> put_AutoUpdateFrequency(This,RHS) ) 

#define _Workbook_get_AutoUpdateSaveChanges(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoUpdateSaveChanges(This,RHS) ) 

#define _Workbook_put_AutoUpdateSaveChanges(This,RHS)	\
    ( (This)->lpVtbl -> put_AutoUpdateSaveChanges(This,RHS) ) 

#define _Workbook_get_ChangeHistoryDuration(This,RHS)	\
    ( (This)->lpVtbl -> get_ChangeHistoryDuration(This,RHS) ) 

#define _Workbook_put_ChangeHistoryDuration(This,RHS)	\
    ( (This)->lpVtbl -> put_ChangeHistoryDuration(This,RHS) ) 

#define _Workbook_get_BuiltinDocumentProperties(This,RHS)	\
    ( (This)->lpVtbl -> get_BuiltinDocumentProperties(This,RHS) ) 

#define _Workbook_ChangeFileAccess(This,Mode,WritePassword,Notify,lcid)	\
    ( (This)->lpVtbl -> ChangeFileAccess(This,Mode,WritePassword,Notify,lcid) ) 

#define _Workbook_ChangeLink(This,Name,NewName,Type,lcid)	\
    ( (This)->lpVtbl -> ChangeLink(This,Name,NewName,Type,lcid) ) 

#define _Workbook_get_Charts(This,RHS)	\
    ( (This)->lpVtbl -> get_Charts(This,RHS) ) 

#define _Workbook_Close(This,SaveChanges,Filename,RouteWorkbook,lcid)	\
    ( (This)->lpVtbl -> Close(This,SaveChanges,Filename,RouteWorkbook,lcid) ) 

#define _Workbook_get_CodeName(This,RHS)	\
    ( (This)->lpVtbl -> get_CodeName(This,RHS) ) 

#define _Workbook_get__CodeName(This,RHS)	\
    ( (This)->lpVtbl -> get__CodeName(This,RHS) ) 

#define _Workbook_put__CodeName(This,RHS)	\
    ( (This)->lpVtbl -> put__CodeName(This,RHS) ) 

#define _Workbook_get_Colors(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> get_Colors(This,Index,lcid,RHS) ) 

#define _Workbook_put_Colors(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> put_Colors(This,Index,lcid,RHS) ) 

#define _Workbook_get_CommandBars(This,RHS)	\
    ( (This)->lpVtbl -> get_CommandBars(This,RHS) ) 

#define _Workbook_get_Comments(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_Comments(This,lcid,RHS) ) 

#define _Workbook_put_Comments(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_Comments(This,lcid,RHS) ) 

#define _Workbook_get_ConflictResolution(This,RHS)	\
    ( (This)->lpVtbl -> get_ConflictResolution(This,RHS) ) 

#define _Workbook_put_ConflictResolution(This,RHS)	\
    ( (This)->lpVtbl -> put_ConflictResolution(This,RHS) ) 

#define _Workbook_get_Container(This,RHS)	\
    ( (This)->lpVtbl -> get_Container(This,RHS) ) 

#define _Workbook_get_CreateBackup(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_CreateBackup(This,lcid,RHS) ) 

#define _Workbook_get_CustomDocumentProperties(This,RHS)	\
    ( (This)->lpVtbl -> get_CustomDocumentProperties(This,RHS) ) 

#define _Workbook_get_Date1904(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_Date1904(This,lcid,RHS) ) 

#define _Workbook_put_Date1904(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_Date1904(This,lcid,RHS) ) 

#define _Workbook_DeleteNumberFormat(This,NumberFormat,lcid)	\
    ( (This)->lpVtbl -> DeleteNumberFormat(This,NumberFormat,lcid) ) 

#define _Workbook_get_DialogSheets(This,RHS)	\
    ( (This)->lpVtbl -> get_DialogSheets(This,RHS) ) 

#define _Workbook_get_DisplayDrawingObjects(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_DisplayDrawingObjects(This,lcid,RHS) ) 

#define _Workbook_put_DisplayDrawingObjects(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_DisplayDrawingObjects(This,lcid,RHS) ) 

#define _Workbook_ExclusiveAccess(This,lcid,RHS)	\
    ( (This)->lpVtbl -> ExclusiveAccess(This,lcid,RHS) ) 

#define _Workbook_get_FileFormat(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_FileFormat(This,lcid,RHS) ) 

#define _Workbook_ForwardMailer(This,lcid)	\
    ( (This)->lpVtbl -> ForwardMailer(This,lcid) ) 

#define _Workbook_get_FullName(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_FullName(This,lcid,RHS) ) 

#define _Workbook_get_HasMailer(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_HasMailer(This,lcid,RHS) ) 

#define _Workbook_put_HasMailer(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_HasMailer(This,lcid,RHS) ) 

#define _Workbook_get_HasPassword(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_HasPassword(This,lcid,RHS) ) 

#define _Workbook_get_HasRoutingSlip(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_HasRoutingSlip(This,lcid,RHS) ) 

#define _Workbook_put_HasRoutingSlip(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_HasRoutingSlip(This,lcid,RHS) ) 

#define _Workbook_get_IsAddin(This,RHS)	\
    ( (This)->lpVtbl -> get_IsAddin(This,RHS) ) 

#define _Workbook_put_IsAddin(This,RHS)	\
    ( (This)->lpVtbl -> put_IsAddin(This,RHS) ) 

#define _Workbook_get_Keywords(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_Keywords(This,lcid,RHS) ) 

#define _Workbook_put_Keywords(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_Keywords(This,lcid,RHS) ) 

#define _Workbook_LinkInfo(This,Name,LinkInfo,Type,EditionRef,lcid,RHS)	\
    ( (This)->lpVtbl -> LinkInfo(This,Name,LinkInfo,Type,EditionRef,lcid,RHS) ) 

#define _Workbook_LinkSources(This,Type,lcid,RHS)	\
    ( (This)->lpVtbl -> LinkSources(This,Type,lcid,RHS) ) 

#define _Workbook_get_Mailer(This,RHS)	\
    ( (This)->lpVtbl -> get_Mailer(This,RHS) ) 

#define _Workbook_MergeWorkbook(This,Filename)	\
    ( (This)->lpVtbl -> MergeWorkbook(This,Filename) ) 

#define _Workbook_get_Modules(This,RHS)	\
    ( (This)->lpVtbl -> get_Modules(This,RHS) ) 

#define _Workbook_get_MultiUserEditing(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_MultiUserEditing(This,lcid,RHS) ) 

#define _Workbook_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define _Workbook_get_Names(This,RHS)	\
    ( (This)->lpVtbl -> get_Names(This,RHS) ) 

#define _Workbook_NewWindow(This,lcid,RHS)	\
    ( (This)->lpVtbl -> NewWindow(This,lcid,RHS) ) 

#define _Workbook_get_OnSave(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_OnSave(This,lcid,RHS) ) 

#define _Workbook_put_OnSave(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_OnSave(This,lcid,RHS) ) 

#define _Workbook_get_OnSheetActivate(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_OnSheetActivate(This,lcid,RHS) ) 

#define _Workbook_put_OnSheetActivate(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_OnSheetActivate(This,lcid,RHS) ) 

#define _Workbook_get_OnSheetDeactivate(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_OnSheetDeactivate(This,lcid,RHS) ) 

#define _Workbook_put_OnSheetDeactivate(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_OnSheetDeactivate(This,lcid,RHS) ) 

#define _Workbook_OpenLinks(This,Name,ReadOnly,Type,lcid)	\
    ( (This)->lpVtbl -> OpenLinks(This,Name,ReadOnly,Type,lcid) ) 

#define _Workbook_get_Path(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_Path(This,lcid,RHS) ) 

#define _Workbook_get_PersonalViewListSettings(This,RHS)	\
    ( (This)->lpVtbl -> get_PersonalViewListSettings(This,RHS) ) 

#define _Workbook_put_PersonalViewListSettings(This,RHS)	\
    ( (This)->lpVtbl -> put_PersonalViewListSettings(This,RHS) ) 

#define _Workbook_get_PersonalViewPrintSettings(This,RHS)	\
    ( (This)->lpVtbl -> get_PersonalViewPrintSettings(This,RHS) ) 

#define _Workbook_put_PersonalViewPrintSettings(This,RHS)	\
    ( (This)->lpVtbl -> put_PersonalViewPrintSettings(This,RHS) ) 

#define _Workbook_PivotCaches(This,RHS)	\
    ( (This)->lpVtbl -> PivotCaches(This,RHS) ) 

#define _Workbook_Post(This,DestName,lcid)	\
    ( (This)->lpVtbl -> Post(This,DestName,lcid) ) 

#define _Workbook_get_PrecisionAsDisplayed(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_PrecisionAsDisplayed(This,lcid,RHS) ) 

#define _Workbook_put_PrecisionAsDisplayed(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_PrecisionAsDisplayed(This,lcid,RHS) ) 

#define _Workbook___PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate,lcid)	\
    ( (This)->lpVtbl -> __PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate,lcid) ) 

#define _Workbook_PrintPreview(This,EnableChanges,lcid)	\
    ( (This)->lpVtbl -> PrintPreview(This,EnableChanges,lcid) ) 

#define _Workbook__Protect(This,Password,Structure,Windows)	\
    ( (This)->lpVtbl -> _Protect(This,Password,Structure,Windows) ) 

#define _Workbook__ProtectSharing(This,Filename,Password,WriteResPassword,ReadOnlyRecommended,CreateBackup,SharingPassword)	\
    ( (This)->lpVtbl -> _ProtectSharing(This,Filename,Password,WriteResPassword,ReadOnlyRecommended,CreateBackup,SharingPassword) ) 

#define _Workbook_get_ProtectStructure(This,RHS)	\
    ( (This)->lpVtbl -> get_ProtectStructure(This,RHS) ) 

#define _Workbook_get_ProtectWindows(This,RHS)	\
    ( (This)->lpVtbl -> get_ProtectWindows(This,RHS) ) 

#define _Workbook_get_ReadOnly(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_ReadOnly(This,lcid,RHS) ) 

#define _Workbook_get__ReadOnlyRecommended(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get__ReadOnlyRecommended(This,lcid,RHS) ) 

#define _Workbook_RefreshAll(This)	\
    ( (This)->lpVtbl -> RefreshAll(This) ) 

#define _Workbook_Reply(This,lcid)	\
    ( (This)->lpVtbl -> Reply(This,lcid) ) 

#define _Workbook_ReplyAll(This,lcid)	\
    ( (This)->lpVtbl -> ReplyAll(This,lcid) ) 

#define _Workbook_RemoveUser(This,Index)	\
    ( (This)->lpVtbl -> RemoveUser(This,Index) ) 

#define _Workbook_get_RevisionNumber(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_RevisionNumber(This,lcid,RHS) ) 

#define _Workbook_Route(This,lcid)	\
    ( (This)->lpVtbl -> Route(This,lcid) ) 

#define _Workbook_get_Routed(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_Routed(This,lcid,RHS) ) 

#define _Workbook_get_RoutingSlip(This,RHS)	\
    ( (This)->lpVtbl -> get_RoutingSlip(This,RHS) ) 

#define _Workbook_RunAutoMacros(This,Which,lcid)	\
    ( (This)->lpVtbl -> RunAutoMacros(This,Which,lcid) ) 

#define _Workbook_Save(This,lcid)	\
    ( (This)->lpVtbl -> Save(This,lcid) ) 

#define _Workbook__SaveAs(This,Filename,FileFormat,Password,WriteResPassword,ReadOnlyRecommended,CreateBackup,AccessMode,ConflictResolution,AddToMru,TextCodepage,TextVisualLayout,lcid)	\
    ( (This)->lpVtbl -> _SaveAs(This,Filename,FileFormat,Password,WriteResPassword,ReadOnlyRecommended,CreateBackup,AccessMode,ConflictResolution,AddToMru,TextCodepage,TextVisualLayout,lcid) ) 

#define _Workbook_SaveCopyAs(This,Filename,lcid)	\
    ( (This)->lpVtbl -> SaveCopyAs(This,Filename,lcid) ) 

#define _Workbook_get_Saved(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_Saved(This,lcid,RHS) ) 

#define _Workbook_put_Saved(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_Saved(This,lcid,RHS) ) 

#define _Workbook_get_SaveLinkValues(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_SaveLinkValues(This,lcid,RHS) ) 

#define _Workbook_put_SaveLinkValues(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_SaveLinkValues(This,lcid,RHS) ) 

#define _Workbook_SendMail(This,Recipients,Subject,ReturnReceipt,lcid)	\
    ( (This)->lpVtbl -> SendMail(This,Recipients,Subject,ReturnReceipt,lcid) ) 

#define _Workbook_SendMailer(This,FileFormat,Priority,lcid)	\
    ( (This)->lpVtbl -> SendMailer(This,FileFormat,Priority,lcid) ) 

#define _Workbook_SetLinkOnData(This,Name,Procedure,lcid)	\
    ( (This)->lpVtbl -> SetLinkOnData(This,Name,Procedure,lcid) ) 

#define _Workbook_get_Sheets(This,RHS)	\
    ( (This)->lpVtbl -> get_Sheets(This,RHS) ) 

#define _Workbook_get_ShowConflictHistory(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_ShowConflictHistory(This,lcid,RHS) ) 

#define _Workbook_put_ShowConflictHistory(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_ShowConflictHistory(This,lcid,RHS) ) 

#define _Workbook_get_Styles(This,RHS)	\
    ( (This)->lpVtbl -> get_Styles(This,RHS) ) 

#define _Workbook_get_Subject(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_Subject(This,lcid,RHS) ) 

#define _Workbook_put_Subject(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_Subject(This,lcid,RHS) ) 

#define _Workbook_get_Title(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_Title(This,lcid,RHS) ) 

#define _Workbook_put_Title(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_Title(This,lcid,RHS) ) 

#define _Workbook_Unprotect(This,Password,lcid)	\
    ( (This)->lpVtbl -> Unprotect(This,Password,lcid) ) 

#define _Workbook_UnprotectSharing(This,SharingPassword)	\
    ( (This)->lpVtbl -> UnprotectSharing(This,SharingPassword) ) 

#define _Workbook_UpdateFromFile(This,lcid)	\
    ( (This)->lpVtbl -> UpdateFromFile(This,lcid) ) 

#define _Workbook_UpdateLink(This,Name,Type,lcid)	\
    ( (This)->lpVtbl -> UpdateLink(This,Name,Type,lcid) ) 

#define _Workbook_get_UpdateRemoteReferences(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_UpdateRemoteReferences(This,lcid,RHS) ) 

#define _Workbook_put_UpdateRemoteReferences(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_UpdateRemoteReferences(This,lcid,RHS) ) 

#define _Workbook_get_UserControl(This,RHS)	\
    ( (This)->lpVtbl -> get_UserControl(This,RHS) ) 

#define _Workbook_put_UserControl(This,RHS)	\
    ( (This)->lpVtbl -> put_UserControl(This,RHS) ) 

#define _Workbook_get_UserStatus(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_UserStatus(This,lcid,RHS) ) 

#define _Workbook_get_CustomViews(This,RHS)	\
    ( (This)->lpVtbl -> get_CustomViews(This,RHS) ) 

#define _Workbook_get_Windows(This,RHS)	\
    ( (This)->lpVtbl -> get_Windows(This,RHS) ) 

#define _Workbook_get_Worksheets(This,RHS)	\
    ( (This)->lpVtbl -> get_Worksheets(This,RHS) ) 

#define _Workbook_get_WriteReserved(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_WriteReserved(This,lcid,RHS) ) 

#define _Workbook_get_WriteReservedBy(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_WriteReservedBy(This,lcid,RHS) ) 

#define _Workbook_get_Excel4IntlMacroSheets(This,RHS)	\
    ( (This)->lpVtbl -> get_Excel4IntlMacroSheets(This,RHS) ) 

#define _Workbook_get_Excel4MacroSheets(This,RHS)	\
    ( (This)->lpVtbl -> get_Excel4MacroSheets(This,RHS) ) 

#define _Workbook_get_TemplateRemoveExtData(This,RHS)	\
    ( (This)->lpVtbl -> get_TemplateRemoveExtData(This,RHS) ) 

#define _Workbook_put_TemplateRemoveExtData(This,RHS)	\
    ( (This)->lpVtbl -> put_TemplateRemoveExtData(This,RHS) ) 

#define _Workbook_HighlightChangesOptions(This,When,Who,Where)	\
    ( (This)->lpVtbl -> HighlightChangesOptions(This,When,Who,Where) ) 

#define _Workbook_get_HighlightChangesOnScreen(This,RHS)	\
    ( (This)->lpVtbl -> get_HighlightChangesOnScreen(This,RHS) ) 

#define _Workbook_put_HighlightChangesOnScreen(This,RHS)	\
    ( (This)->lpVtbl -> put_HighlightChangesOnScreen(This,RHS) ) 

#define _Workbook_get_KeepChangeHistory(This,RHS)	\
    ( (This)->lpVtbl -> get_KeepChangeHistory(This,RHS) ) 

#define _Workbook_put_KeepChangeHistory(This,RHS)	\
    ( (This)->lpVtbl -> put_KeepChangeHistory(This,RHS) ) 

#define _Workbook_get_ListChangesOnNewSheet(This,RHS)	\
    ( (This)->lpVtbl -> get_ListChangesOnNewSheet(This,RHS) ) 

#define _Workbook_put_ListChangesOnNewSheet(This,RHS)	\
    ( (This)->lpVtbl -> put_ListChangesOnNewSheet(This,RHS) ) 

#define _Workbook_PurgeChangeHistoryNow(This,Days,SharingPassword)	\
    ( (This)->lpVtbl -> PurgeChangeHistoryNow(This,Days,SharingPassword) ) 

#define _Workbook_AcceptAllChanges(This,When,Who,Where)	\
    ( (This)->lpVtbl -> AcceptAllChanges(This,When,Who,Where) ) 

#define _Workbook_RejectAllChanges(This,When,Who,Where)	\
    ( (This)->lpVtbl -> RejectAllChanges(This,When,Who,Where) ) 

#define _Workbook_PivotTableWizard(This,SourceType,SourceData,TableDestination,TableName,RowGrand,ColumnGrand,SaveData,HasAutoFormat,AutoPage,Reserved,BackgroundQuery,OptimizeCache,PageFieldOrder,PageFieldWrapCount,ReadData,Connection,lcid)	\
    ( (This)->lpVtbl -> PivotTableWizard(This,SourceType,SourceData,TableDestination,TableName,RowGrand,ColumnGrand,SaveData,HasAutoFormat,AutoPage,Reserved,BackgroundQuery,OptimizeCache,PageFieldOrder,PageFieldWrapCount,ReadData,Connection,lcid) ) 

#define _Workbook_ResetColors(This)	\
    ( (This)->lpVtbl -> ResetColors(This) ) 

#define _Workbook_get_VBProject(This,RHS)	\
    ( (This)->lpVtbl -> get_VBProject(This,RHS) ) 

#define _Workbook_FollowHyperlink(This,Address,SubAddress,NewWindow,AddHistory,ExtraInfo,Method,HeaderInfo)	\
    ( (This)->lpVtbl -> FollowHyperlink(This,Address,SubAddress,NewWindow,AddHistory,ExtraInfo,Method,HeaderInfo) ) 

#define _Workbook_AddToFavorites(This)	\
    ( (This)->lpVtbl -> AddToFavorites(This) ) 

#define _Workbook_get_IsInplace(This,RHS)	\
    ( (This)->lpVtbl -> get_IsInplace(This,RHS) ) 

#define _Workbook__PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate,PrToFileName,lcid)	\
    ( (This)->lpVtbl -> _PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate,PrToFileName,lcid) ) 

#define _Workbook_WebPagePreview(This)	\
    ( (This)->lpVtbl -> WebPagePreview(This) ) 

#define _Workbook_get_PublishObjects(This,RHS)	\
    ( (This)->lpVtbl -> get_PublishObjects(This,RHS) ) 

#define _Workbook_get_WebOptions(This,RHS)	\
    ( (This)->lpVtbl -> get_WebOptions(This,RHS) ) 

#define _Workbook_ReloadAs(This,Encoding)	\
    ( (This)->lpVtbl -> ReloadAs(This,Encoding) ) 

#define _Workbook_get_HTMLProject(This,RHS)	\
    ( (This)->lpVtbl -> get_HTMLProject(This,RHS) ) 

#define _Workbook_get_EnvelopeVisible(This,RHS)	\
    ( (This)->lpVtbl -> get_EnvelopeVisible(This,RHS) ) 

#define _Workbook_put_EnvelopeVisible(This,RHS)	\
    ( (This)->lpVtbl -> put_EnvelopeVisible(This,RHS) ) 

#define _Workbook_get_CalculationVersion(This,RHS)	\
    ( (This)->lpVtbl -> get_CalculationVersion(This,RHS) ) 

#define _Workbook_Dummy17(This,calcid)	\
    ( (This)->lpVtbl -> Dummy17(This,calcid) ) 

#define _Workbook_sblt(This,s)	\
    ( (This)->lpVtbl -> sblt(This,s) ) 

#define _Workbook_get_VBASigned(This,RHS)	\
    ( (This)->lpVtbl -> get_VBASigned(This,RHS) ) 

#define _Workbook_get_ShowPivotTableFieldList(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowPivotTableFieldList(This,RHS) ) 

#define _Workbook_put_ShowPivotTableFieldList(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowPivotTableFieldList(This,RHS) ) 

#define _Workbook_get_UpdateLinks(This,RHS)	\
    ( (This)->lpVtbl -> get_UpdateLinks(This,RHS) ) 

#define _Workbook_put_UpdateLinks(This,RHS)	\
    ( (This)->lpVtbl -> put_UpdateLinks(This,RHS) ) 

#define _Workbook_BreakLink(This,Name,Type)	\
    ( (This)->lpVtbl -> BreakLink(This,Name,Type) ) 

#define _Workbook_Dummy16(This)	\
    ( (This)->lpVtbl -> Dummy16(This) ) 

#define _Workbook_SaveAs(This,Filename,FileFormat,Password,WriteResPassword,ReadOnlyRecommended,CreateBackup,AccessMode,ConflictResolution,AddToMru,TextCodepage,TextVisualLayout,Local,lcid)	\
    ( (This)->lpVtbl -> SaveAs(This,Filename,FileFormat,Password,WriteResPassword,ReadOnlyRecommended,CreateBackup,AccessMode,ConflictResolution,AddToMru,TextCodepage,TextVisualLayout,Local,lcid) ) 

#define _Workbook_get_EnableAutoRecover(This,RHS)	\
    ( (This)->lpVtbl -> get_EnableAutoRecover(This,RHS) ) 

#define _Workbook_put_EnableAutoRecover(This,RHS)	\
    ( (This)->lpVtbl -> put_EnableAutoRecover(This,RHS) ) 

#define _Workbook_get_RemovePersonalInformation(This,RHS)	\
    ( (This)->lpVtbl -> get_RemovePersonalInformation(This,RHS) ) 

#define _Workbook_put_RemovePersonalInformation(This,RHS)	\
    ( (This)->lpVtbl -> put_RemovePersonalInformation(This,RHS) ) 

#define _Workbook_get_FullNameURLEncoded(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_FullNameURLEncoded(This,lcid,RHS) ) 

#define _Workbook_CheckIn(This,SaveChanges,Comments,MakePublic)	\
    ( (This)->lpVtbl -> CheckIn(This,SaveChanges,Comments,MakePublic) ) 

#define _Workbook_CanCheckIn(This,RHS)	\
    ( (This)->lpVtbl -> CanCheckIn(This,RHS) ) 

#define _Workbook_SendForReview(This,Recipients,Subject,ShowMessage,IncludeAttachment)	\
    ( (This)->lpVtbl -> SendForReview(This,Recipients,Subject,ShowMessage,IncludeAttachment) ) 

#define _Workbook_ReplyWithChanges(This,ShowMessage)	\
    ( (This)->lpVtbl -> ReplyWithChanges(This,ShowMessage) ) 

#define _Workbook_EndReview(This)	\
    ( (This)->lpVtbl -> EndReview(This) ) 

#define _Workbook_get_Password(This,RHS)	\
    ( (This)->lpVtbl -> get_Password(This,RHS) ) 

#define _Workbook_put_Password(This,RHS)	\
    ( (This)->lpVtbl -> put_Password(This,RHS) ) 

#define _Workbook_get_WritePassword(This,RHS)	\
    ( (This)->lpVtbl -> get_WritePassword(This,RHS) ) 

#define _Workbook_put_WritePassword(This,RHS)	\
    ( (This)->lpVtbl -> put_WritePassword(This,RHS) ) 

#define _Workbook_get_PasswordEncryptionProvider(This,RHS)	\
    ( (This)->lpVtbl -> get_PasswordEncryptionProvider(This,RHS) ) 

#define _Workbook_get_PasswordEncryptionAlgorithm(This,RHS)	\
    ( (This)->lpVtbl -> get_PasswordEncryptionAlgorithm(This,RHS) ) 

#define _Workbook_get_PasswordEncryptionKeyLength(This,RHS)	\
    ( (This)->lpVtbl -> get_PasswordEncryptionKeyLength(This,RHS) ) 

#define _Workbook_SetPasswordEncryptionOptions(This,PasswordEncryptionProvider,PasswordEncryptionAlgorithm,PasswordEncryptionKeyLength,PasswordEncryptionFileProperties)	\
    ( (This)->lpVtbl -> SetPasswordEncryptionOptions(This,PasswordEncryptionProvider,PasswordEncryptionAlgorithm,PasswordEncryptionKeyLength,PasswordEncryptionFileProperties) ) 

#define _Workbook_get_PasswordEncryptionFileProperties(This,RHS)	\
    ( (This)->lpVtbl -> get_PasswordEncryptionFileProperties(This,RHS) ) 

#define _Workbook_get_ReadOnlyRecommended(This,RHS)	\
    ( (This)->lpVtbl -> get_ReadOnlyRecommended(This,RHS) ) 

#define _Workbook_put_ReadOnlyRecommended(This,RHS)	\
    ( (This)->lpVtbl -> put_ReadOnlyRecommended(This,RHS) ) 

#define _Workbook_Protect(This,Password,Structure,Windows)	\
    ( (This)->lpVtbl -> Protect(This,Password,Structure,Windows) ) 

#define _Workbook_get_SmartTagOptions(This,RHS)	\
    ( (This)->lpVtbl -> get_SmartTagOptions(This,RHS) ) 

#define _Workbook_RecheckSmartTags(This)	\
    ( (This)->lpVtbl -> RecheckSmartTags(This) ) 

#define _Workbook_get_Permission(This,RHS)	\
    ( (This)->lpVtbl -> get_Permission(This,RHS) ) 

#define _Workbook_get_SharedWorkspace(This,RHS)	\
    ( (This)->lpVtbl -> get_SharedWorkspace(This,RHS) ) 

#define _Workbook_get_Sync(This,RHS)	\
    ( (This)->lpVtbl -> get_Sync(This,RHS) ) 

#define _Workbook_SendFaxOverInternet(This,Recipients,Subject,ShowMessage)	\
    ( (This)->lpVtbl -> SendFaxOverInternet(This,Recipients,Subject,ShowMessage) ) 

#define _Workbook_get_XmlNamespaces(This,RHS)	\
    ( (This)->lpVtbl -> get_XmlNamespaces(This,RHS) ) 

#define _Workbook_get_XmlMaps(This,RHS)	\
    ( (This)->lpVtbl -> get_XmlMaps(This,RHS) ) 

#define _Workbook_XmlImport(This,Url,ImportMap,Overwrite,Destination,RHS)	\
    ( (This)->lpVtbl -> XmlImport(This,Url,ImportMap,Overwrite,Destination,RHS) ) 

#define _Workbook_get_SmartDocument(This,RHS)	\
    ( (This)->lpVtbl -> get_SmartDocument(This,RHS) ) 

#define _Workbook_get_DocumentLibraryVersions(This,RHS)	\
    ( (This)->lpVtbl -> get_DocumentLibraryVersions(This,RHS) ) 

#define _Workbook_get_InactiveListBorderVisible(This,RHS)	\
    ( (This)->lpVtbl -> get_InactiveListBorderVisible(This,RHS) ) 

#define _Workbook_put_InactiveListBorderVisible(This,RHS)	\
    ( (This)->lpVtbl -> put_InactiveListBorderVisible(This,RHS) ) 

#define _Workbook_get_DisplayInkComments(This,RHS)	\
    ( (This)->lpVtbl -> get_DisplayInkComments(This,RHS) ) 

#define _Workbook_put_DisplayInkComments(This,RHS)	\
    ( (This)->lpVtbl -> put_DisplayInkComments(This,RHS) ) 

#define _Workbook_XmlImportXml(This,Data,ImportMap,Overwrite,Destination,RHS)	\
    ( (This)->lpVtbl -> XmlImportXml(This,Data,ImportMap,Overwrite,Destination,RHS) ) 

#define _Workbook_SaveAsXMLData(This,Filename,Map)	\
    ( (This)->lpVtbl -> SaveAsXMLData(This,Filename,Map) ) 

#define _Workbook_ToggleFormsDesign(This)	\
    ( (This)->lpVtbl -> ToggleFormsDesign(This) ) 

#define _Workbook_get_ContentTypeProperties(This,RHS)	\
    ( (This)->lpVtbl -> get_ContentTypeProperties(This,RHS) ) 

#define _Workbook_get_Connections(This,RHS)	\
    ( (This)->lpVtbl -> get_Connections(This,RHS) ) 

#define _Workbook_RemoveDocumentInformation(This,RemoveDocInfoType)	\
    ( (This)->lpVtbl -> RemoveDocumentInformation(This,RemoveDocInfoType) ) 

#define _Workbook_get_Signatures(This,RHS)	\
    ( (This)->lpVtbl -> get_Signatures(This,RHS) ) 

#define _Workbook_CheckInWithVersion(This,SaveChanges,Comments,MakePublic,VersionType)	\
    ( (This)->lpVtbl -> CheckInWithVersion(This,SaveChanges,Comments,MakePublic,VersionType) ) 

#define _Workbook_get_ServerPolicy(This,RHS)	\
    ( (This)->lpVtbl -> get_ServerPolicy(This,RHS) ) 

#define _Workbook_LockServerFile(This)	\
    ( (This)->lpVtbl -> LockServerFile(This) ) 

#define _Workbook_get_DocumentInspectors(This,RHS)	\
    ( (This)->lpVtbl -> get_DocumentInspectors(This,RHS) ) 

#define _Workbook_GetWorkflowTasks(This,RHS)	\
    ( (This)->lpVtbl -> GetWorkflowTasks(This,RHS) ) 

#define _Workbook_GetWorkflowTemplates(This,RHS)	\
    ( (This)->lpVtbl -> GetWorkflowTemplates(This,RHS) ) 

#define _Workbook_PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate,PrToFileName,IgnorePrintAreas,lcid)	\
    ( (This)->lpVtbl -> PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate,PrToFileName,IgnorePrintAreas,lcid) ) 

#define _Workbook_get_ServerViewableItems(This,RHS)	\
    ( (This)->lpVtbl -> get_ServerViewableItems(This,RHS) ) 

#define _Workbook_get_TableStyles(This,RHS)	\
    ( (This)->lpVtbl -> get_TableStyles(This,RHS) ) 

#define _Workbook_get_DefaultTableStyle(This,RHS)	\
    ( (This)->lpVtbl -> get_DefaultTableStyle(This,RHS) ) 

#define _Workbook_put_DefaultTableStyle(This,RHS)	\
    ( (This)->lpVtbl -> put_DefaultTableStyle(This,RHS) ) 

#define _Workbook_get_DefaultPivotTableStyle(This,RHS)	\
    ( (This)->lpVtbl -> get_DefaultPivotTableStyle(This,RHS) ) 

#define _Workbook_put_DefaultPivotTableStyle(This,RHS)	\
    ( (This)->lpVtbl -> put_DefaultPivotTableStyle(This,RHS) ) 

#define _Workbook_get_CheckCompatibility(This,RHS)	\
    ( (This)->lpVtbl -> get_CheckCompatibility(This,RHS) ) 

#define _Workbook_put_CheckCompatibility(This,RHS)	\
    ( (This)->lpVtbl -> put_CheckCompatibility(This,RHS) ) 

#define _Workbook_get_HasVBProject(This,RHS)	\
    ( (This)->lpVtbl -> get_HasVBProject(This,RHS) ) 

#define _Workbook_get_CustomXMLParts(This,RHS)	\
    ( (This)->lpVtbl -> get_CustomXMLParts(This,RHS) ) 

#define _Workbook_get_Final(This,RHS)	\
    ( (This)->lpVtbl -> get_Final(This,RHS) ) 

#define _Workbook_put_Final(This,RHS)	\
    ( (This)->lpVtbl -> put_Final(This,RHS) ) 

#define _Workbook_get_Research(This,RHS)	\
    ( (This)->lpVtbl -> get_Research(This,RHS) ) 

#define _Workbook_get_Theme(This,RHS)	\
    ( (This)->lpVtbl -> get_Theme(This,RHS) ) 

#define _Workbook_ApplyTheme(This,Filename)	\
    ( (This)->lpVtbl -> ApplyTheme(This,Filename) ) 

#define _Workbook_get_Excel8CompatibilityMode(This,RHS)	\
    ( (This)->lpVtbl -> get_Excel8CompatibilityMode(This,RHS) ) 

#define _Workbook_get_ConnectionsDisabled(This,RHS)	\
    ( (This)->lpVtbl -> get_ConnectionsDisabled(This,RHS) ) 

#define _Workbook_EnableConnections(This)	\
    ( (This)->lpVtbl -> EnableConnections(This) ) 

#define _Workbook_get_ShowPivotChartActiveFields(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowPivotChartActiveFields(This,RHS) ) 

#define _Workbook_put_ShowPivotChartActiveFields(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowPivotChartActiveFields(This,RHS) ) 

#define _Workbook_ExportAsFixedFormat(This,Type,Filename,Quality,IncludeDocProperties,IgnorePrintAreas,From,To,OpenAfterPublish,FixedFormatExtClassPtr)	\
    ( (This)->lpVtbl -> ExportAsFixedFormat(This,Type,Filename,Quality,IncludeDocProperties,IgnorePrintAreas,From,To,OpenAfterPublish,FixedFormatExtClassPtr) ) 

#define _Workbook_get_IconSets(This,RHS)	\
    ( (This)->lpVtbl -> get_IconSets(This,RHS) ) 

#define _Workbook_get_EncryptionProvider(This,RHS)	\
    ( (This)->lpVtbl -> get_EncryptionProvider(This,RHS) ) 

#define _Workbook_put_EncryptionProvider(This,RHS)	\
    ( (This)->lpVtbl -> put_EncryptionProvider(This,RHS) ) 

#define _Workbook_get_DoNotPromptForConvert(This,RHS)	\
    ( (This)->lpVtbl -> get_DoNotPromptForConvert(This,RHS) ) 

#define _Workbook_put_DoNotPromptForConvert(This,RHS)	\
    ( (This)->lpVtbl -> put_DoNotPromptForConvert(This,RHS) ) 

#define _Workbook_get_ForceFullCalculation(This,RHS)	\
    ( (This)->lpVtbl -> get_ForceFullCalculation(This,RHS) ) 

#define _Workbook_put_ForceFullCalculation(This,RHS)	\
    ( (This)->lpVtbl -> put_ForceFullCalculation(This,RHS) ) 

#define _Workbook_ProtectSharing(This,Filename,Password,WriteResPassword,ReadOnlyRecommended,CreateBackup,SharingPassword,FileFormat)	\
    ( (This)->lpVtbl -> ProtectSharing(This,Filename,Password,WriteResPassword,ReadOnlyRecommended,CreateBackup,SharingPassword,FileFormat) ) 

#define _Workbook_get_SlicerCaches(This,RHS)	\
    ( (This)->lpVtbl -> get_SlicerCaches(This,RHS) ) 

#define _Workbook_get_ActiveSlicer(This,RHS)	\
    ( (This)->lpVtbl -> get_ActiveSlicer(This,RHS) ) 

#define _Workbook_get_DefaultSlicerStyle(This,RHS)	\
    ( (This)->lpVtbl -> get_DefaultSlicerStyle(This,RHS) ) 

#define _Workbook_put_DefaultSlicerStyle(This,RHS)	\
    ( (This)->lpVtbl -> put_DefaultSlicerStyle(This,RHS) ) 

#define _Workbook_Dummy26(This)	\
    ( (This)->lpVtbl -> Dummy26(This) ) 

#define _Workbook_Dummy27(This)	\
    ( (This)->lpVtbl -> Dummy27(This) ) 

#define _Workbook_get_AccuracyVersion(This,RHS)	\
    ( (This)->lpVtbl -> get_AccuracyVersion(This,RHS) ) 

#define _Workbook_put_AccuracyVersion(This,RHS)	\
    ( (This)->lpVtbl -> put_AccuracyVersion(This,RHS) ) 

#define _Workbook_get_CaseSensitive(This,RHS)	\
    ( (This)->lpVtbl -> get_CaseSensitive(This,RHS) ) 

#define _Workbook_get_UseWholeCellCriteria(This,RHS)	\
    ( (This)->lpVtbl -> get_UseWholeCellCriteria(This,RHS) ) 

#define _Workbook_get_UseWildcards(This,RHS)	\
    ( (This)->lpVtbl -> get_UseWildcards(This,RHS) ) 

#define _Workbook_get_PivotTables(This,RHS)	\
    ( (This)->lpVtbl -> get_PivotTables(This,RHS) ) 

#define _Workbook_get_Model(This,RHS)	\
    ( (This)->lpVtbl -> get_Model(This,RHS) ) 

#define _Workbook_get_ChartDataPointTrack(This,RHS)	\
    ( (This)->lpVtbl -> get_ChartDataPointTrack(This,RHS) ) 

#define _Workbook_put_ChartDataPointTrack(This,RHS)	\
    ( (This)->lpVtbl -> put_ChartDataPointTrack(This,RHS) ) 

#define _Workbook_get_DefaultTimelineStyle(This,RHS)	\
    ( (This)->lpVtbl -> get_DefaultTimelineStyle(This,RHS) ) 

#define _Workbook_put_DefaultTimelineStyle(This,RHS)	\
    ( (This)->lpVtbl -> put_DefaultTimelineStyle(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */



/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_UserStatus_Proxy( 
    _Workbook * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB _Workbook_get_UserStatus_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_CustomViews_Proxy( 
    _Workbook * This,
    /* [retval][out] */ CustomViews	**RHS);


void __RPC_STUB _Workbook_get_CustomViews_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_Windows_Proxy( 
    _Workbook * This,
    /* [retval][out] */ Windows	**RHS);


void __RPC_STUB _Workbook_get_Windows_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_Worksheets_Proxy( 
    _Workbook * This,
    /* [retval][out] */ Sheets **RHS);


void __RPC_STUB _Workbook_get_Worksheets_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_WriteReserved_Proxy( 
    _Workbook * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Workbook_get_WriteReserved_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_WriteReservedBy_Proxy( 
    _Workbook * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB _Workbook_get_WriteReservedBy_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_Excel4IntlMacroSheets_Proxy( 
    _Workbook * This,
    /* [retval][out] */ Sheets **RHS);


void __RPC_STUB _Workbook_get_Excel4IntlMacroSheets_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_Excel4MacroSheets_Proxy( 
    _Workbook * This,
    /* [retval][out] */ Sheets **RHS);


void __RPC_STUB _Workbook_get_Excel4MacroSheets_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_TemplateRemoveExtData_Proxy( 
    _Workbook * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Workbook_get_TemplateRemoveExtData_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Workbook_put_TemplateRemoveExtData_Proxy( 
    _Workbook * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Workbook_put_TemplateRemoveExtData_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Workbook_HighlightChangesOptions_Proxy( 
    _Workbook * This,
    /* [optional][in] */ VARIANT When,
    /* [optional][in] */ VARIANT Who,
    /* [optional][in] */ VARIANT Where);


void __RPC_STUB _Workbook_HighlightChangesOptions_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_HighlightChangesOnScreen_Proxy( 
    _Workbook * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Workbook_get_HighlightChangesOnScreen_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Workbook_put_HighlightChangesOnScreen_Proxy( 
    _Workbook * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Workbook_put_HighlightChangesOnScreen_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_KeepChangeHistory_Proxy( 
    _Workbook * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Workbook_get_KeepChangeHistory_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Workbook_put_KeepChangeHistory_Proxy( 
    _Workbook * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Workbook_put_KeepChangeHistory_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_ListChangesOnNewSheet_Proxy( 
    _Workbook * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Workbook_get_ListChangesOnNewSheet_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Workbook_put_ListChangesOnNewSheet_Proxy( 
    _Workbook * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Workbook_put_ListChangesOnNewSheet_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Workbook_PurgeChangeHistoryNow_Proxy( 
    _Workbook * This,
    /* [in] */ long Days,
    /* [optional][in] */ VARIANT SharingPassword);


void __RPC_STUB _Workbook_PurgeChangeHistoryNow_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Workbook_AcceptAllChanges_Proxy( 
    _Workbook * This,
    /* [optional][in] */ VARIANT When,
    /* [optional][in] */ VARIANT Who,
    /* [optional][in] */ VARIANT Where);


void __RPC_STUB _Workbook_AcceptAllChanges_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Workbook_RejectAllChanges_Proxy( 
    _Workbook * This,
    /* [optional][in] */ VARIANT When,
    /* [optional][in] */ VARIANT Who,
    /* [optional][in] */ VARIANT Where);


void __RPC_STUB _Workbook_RejectAllChanges_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE _Workbook_PivotTableWizard_Proxy( 
    _Workbook * This,
    /* [optional][in] */ VARIANT SourceType,
    /* [optional][in] */ VARIANT SourceData,
    /* [optional][in] */ VARIANT TableDestination,
    /* [optional][in] */ VARIANT TableName,
    /* [optional][in] */ VARIANT RowGrand,
    /* [optional][in] */ VARIANT ColumnGrand,
    /* [optional][in] */ VARIANT SaveData,
    /* [optional][in] */ VARIANT HasAutoFormat,
    /* [optional][in] */ VARIANT AutoPage,
    /* [optional][in] */ VARIANT Reserved,
    /* [optional][in] */ VARIANT BackgroundQuery,
    /* [optional][in] */ VARIANT OptimizeCache,
    /* [optional][in] */ VARIANT PageFieldOrder,
    /* [optional][in] */ VARIANT PageFieldWrapCount,
    /* [optional][in] */ VARIANT ReadData,
    /* [optional][in] */ VARIANT Connection,
    /* [lcid][in] */ long lcid);


void __RPC_STUB _Workbook_PivotTableWizard_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Workbook_ResetColors_Proxy( 
    _Workbook * This);


void __RPC_STUB _Workbook_ResetColors_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_VBProject_Proxy( 
    _Workbook * This,
    /* [retval][out] */ /* external definition not present */ VBProject **RHS);


void __RPC_STUB _Workbook_get_VBProject_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Workbook_FollowHyperlink_Proxy( 
    _Workbook * This,
    /* [in] */ BSTR Address,
    /* [optional][in] */ VARIANT SubAddress,
    /* [optional][in] */ VARIANT NewWindow,
    /* [optional][in] */ VARIANT AddHistory,
    /* [optional][in] */ VARIANT ExtraInfo,
    /* [optional][in] */ VARIANT Method,
    /* [optional][in] */ VARIANT HeaderInfo);


void __RPC_STUB _Workbook_FollowHyperlink_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Workbook_AddToFavorites_Proxy( 
    _Workbook * This);


void __RPC_STUB _Workbook_AddToFavorites_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_IsInplace_Proxy( 
    _Workbook * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Workbook_get_IsInplace_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [custom][helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE _Workbook__PrintOut_Proxy( 
    _Workbook * This,
    /* [optional][in] */ VARIANT From,
    /* [optional][in] */ VARIANT To,
    /* [optional][in] */ VARIANT Copies,
    /* [optional][in] */ VARIANT Preview,
    /* [optional][in] */ VARIANT ActivePrinter,
    /* [optional][in] */ VARIANT PrintToFile,
    /* [optional][in] */ VARIANT Collate,
    /* [optional][in] */ VARIANT PrToFileName,
    /* [lcid][in] */ long lcid);


void __RPC_STUB _Workbook__PrintOut_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Workbook_WebPagePreview_Proxy( 
    _Workbook * This);


void __RPC_STUB _Workbook_WebPagePreview_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_PublishObjects_Proxy( 
    _Workbook * This,
    /* [retval][out] */ PublishObjects	**RHS);


void __RPC_STUB _Workbook_get_PublishObjects_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_WebOptions_Proxy( 
    _Workbook * This,
    /* [retval][out] */ WebOptions **RHS);


void __RPC_STUB _Workbook_get_WebOptions_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Workbook_ReloadAs_Proxy( 
    _Workbook * This,
    /* [in] */ MsoEncoding Encoding);


void __RPC_STUB _Workbook_ReloadAs_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_HTMLProject_Proxy( 
    _Workbook * This,
    /* [retval][out] */ /* external definition not present */ HTMLProject **RHS);


void __RPC_STUB _Workbook_get_HTMLProject_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_EnvelopeVisible_Proxy( 
    _Workbook * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Workbook_get_EnvelopeVisible_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Workbook_put_EnvelopeVisible_Proxy( 
    _Workbook * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Workbook_put_EnvelopeVisible_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_CalculationVersion_Proxy( 
    _Workbook * This,
    /* [retval][out] */ long *RHS);


void __RPC_STUB _Workbook_get_CalculationVersion_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE _Workbook_Dummy17_Proxy( 
    _Workbook * This,
    /* [in] */ long calcid);


void __RPC_STUB _Workbook_Dummy17_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE _Workbook_sblt_Proxy( 
    _Workbook * This,
    /* [in] */ BSTR s);


void __RPC_STUB _Workbook_sblt_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_VBASigned_Proxy( 
    _Workbook * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Workbook_get_VBASigned_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_ShowPivotTableFieldList_Proxy( 
    _Workbook * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Workbook_get_ShowPivotTableFieldList_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Workbook_put_ShowPivotTableFieldList_Proxy( 
    _Workbook * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Workbook_put_ShowPivotTableFieldList_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_UpdateLinks_Proxy( 
    _Workbook * This,
    /* [retval][out] */ XlUpdateLinks *RHS);


void __RPC_STUB _Workbook_get_UpdateLinks_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Workbook_put_UpdateLinks_Proxy( 
    _Workbook * This,
    /* [in] */ XlUpdateLinks RHS);


void __RPC_STUB _Workbook_put_UpdateLinks_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Workbook_BreakLink_Proxy( 
    _Workbook * This,
    /* [in] */ BSTR Name,
    /* [in] */ XlLinkType Type);


void __RPC_STUB _Workbook_BreakLink_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE _Workbook_Dummy16_Proxy( 
    _Workbook * This);


void __RPC_STUB _Workbook_Dummy16_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Workbook_SaveAs_Proxy( 
    _Workbook * This,
    /* [optional][in] */ VARIANT Filename,
    /* [optional][in] */ VARIANT FileFormat,
    /* [optional][in] */ VARIANT Password,
    /* [optional][in] */ VARIANT WriteResPassword,
    /* [optional][in] */ VARIANT ReadOnlyRecommended,
    /* [optional][in] */ VARIANT CreateBackup,
    /* [defaultvalue][optional][in] */ XlSaveAsAccessMode AccessMode,
    /* [optional][in] */ VARIANT ConflictResolution,
    /* [optional][in] */ VARIANT AddToMru,
    /* [optional][in] */ VARIANT TextCodepage,
    /* [optional][in] */ VARIANT TextVisualLayout,
    /* [optional][in] */ VARIANT Local,
    /* [lcid][in] */ long lcid);


void __RPC_STUB _Workbook_SaveAs_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_EnableAutoRecover_Proxy( 
    _Workbook * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Workbook_get_EnableAutoRecover_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Workbook_put_EnableAutoRecover_Proxy( 
    _Workbook * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Workbook_put_EnableAutoRecover_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_RemovePersonalInformation_Proxy( 
    _Workbook * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Workbook_get_RemovePersonalInformation_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Workbook_put_RemovePersonalInformation_Proxy( 
    _Workbook * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Workbook_put_RemovePersonalInformation_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_FullNameURLEncoded_Proxy( 
    _Workbook * This,
    /* [lcid][in] */ long lcid,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB _Workbook_get_FullNameURLEncoded_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Workbook_CheckIn_Proxy( 
    _Workbook * This,
    /* [optional][in] */ VARIANT SaveChanges,
    /* [optional][in] */ VARIANT Comments,
    /* [optional][in] */ VARIANT MakePublic);


void __RPC_STUB _Workbook_CheckIn_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Workbook_CanCheckIn_Proxy( 
    _Workbook * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Workbook_CanCheckIn_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Workbook_SendForReview_Proxy( 
    _Workbook * This,
    /* [optional][in] */ VARIANT Recipients,
    /* [optional][in] */ VARIANT Subject,
    /* [optional][in] */ VARIANT ShowMessage,
    /* [optional][in] */ VARIANT IncludeAttachment);


void __RPC_STUB _Workbook_SendForReview_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Workbook_ReplyWithChanges_Proxy( 
    _Workbook * This,
    /* [optional][in] */ VARIANT ShowMessage);


void __RPC_STUB _Workbook_ReplyWithChanges_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Workbook_EndReview_Proxy( 
    _Workbook * This);


void __RPC_STUB _Workbook_EndReview_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_Password_Proxy( 
    _Workbook * This,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB _Workbook_get_Password_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Workbook_put_Password_Proxy( 
    _Workbook * This,
    /* [in] */ BSTR RHS);


void __RPC_STUB _Workbook_put_Password_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_WritePassword_Proxy( 
    _Workbook * This,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB _Workbook_get_WritePassword_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Workbook_put_WritePassword_Proxy( 
    _Workbook * This,
    /* [in] */ BSTR RHS);


void __RPC_STUB _Workbook_put_WritePassword_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_PasswordEncryptionProvider_Proxy( 
    _Workbook * This,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB _Workbook_get_PasswordEncryptionProvider_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_PasswordEncryptionAlgorithm_Proxy( 
    _Workbook * This,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB _Workbook_get_PasswordEncryptionAlgorithm_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_PasswordEncryptionKeyLength_Proxy( 
    _Workbook * This,
    /* [retval][out] */ long *RHS);


void __RPC_STUB _Workbook_get_PasswordEncryptionKeyLength_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Workbook_SetPasswordEncryptionOptions_Proxy( 
    _Workbook * This,
    /* [optional][in] */ VARIANT PasswordEncryptionProvider,
    /* [optional][in] */ VARIANT PasswordEncryptionAlgorithm,
    /* [optional][in] */ VARIANT PasswordEncryptionKeyLength,
    /* [optional][in] */ VARIANT PasswordEncryptionFileProperties);


void __RPC_STUB _Workbook_SetPasswordEncryptionOptions_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_PasswordEncryptionFileProperties_Proxy( 
    _Workbook * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Workbook_get_PasswordEncryptionFileProperties_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_ReadOnlyRecommended_Proxy( 
    _Workbook * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Workbook_get_ReadOnlyRecommended_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Workbook_put_ReadOnlyRecommended_Proxy( 
    _Workbook * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Workbook_put_ReadOnlyRecommended_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Workbook_Protect_Proxy( 
    _Workbook * This,
    /* [optional][in] */ VARIANT Password,
    /* [optional][in] */ VARIANT Structure,
    /* [optional][in] */ VARIANT Windows);


void __RPC_STUB _Workbook_Protect_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_SmartTagOptions_Proxy( 
    _Workbook * This,
    /* [retval][out] */ SmartTagOptions	**RHS);


void __RPC_STUB _Workbook_get_SmartTagOptions_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE _Workbook_RecheckSmartTags_Proxy( 
    _Workbook * This);


void __RPC_STUB _Workbook_RecheckSmartTags_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_Permission_Proxy( 
    _Workbook * This,
    /* [retval][out] */ /* external definition not present */ Permission **RHS);


void __RPC_STUB _Workbook_get_Permission_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_SharedWorkspace_Proxy( 
    _Workbook * This,
    /* [retval][out] */ /* external definition not present */ SharedWorkspace **RHS);


void __RPC_STUB _Workbook_get_SharedWorkspace_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_Sync_Proxy( 
    _Workbook * This,
    /* [retval][out] */ /* external definition not present */ Sync **RHS);


void __RPC_STUB _Workbook_get_Sync_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Workbook_SendFaxOverInternet_Proxy( 
    _Workbook * This,
    /* [optional][in] */ VARIANT Recipients,
    /* [optional][in] */ VARIANT Subject,
    /* [optional][in] */ VARIANT ShowMessage);


void __RPC_STUB _Workbook_SendFaxOverInternet_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_XmlNamespaces_Proxy( 
    _Workbook * This,
    /* [retval][out] */ XmlNamespaces	**RHS);


void __RPC_STUB _Workbook_get_XmlNamespaces_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_XmlMaps_Proxy( 
    _Workbook * This,
    /* [retval][out] */ XmlMaps	**RHS);


void __RPC_STUB _Workbook_get_XmlMaps_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Workbook_XmlImport_Proxy( 
    _Workbook * This,
    /* [in] */ BSTR Url,
    /* [out] */ XmlMap	**ImportMap,
    /* [optional][in] */ VARIANT Overwrite,
    /* [optional][in] */ VARIANT Destination,
    /* [retval][out] */ XlXmlImportResult *RHS);


void __RPC_STUB _Workbook_XmlImport_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_SmartDocument_Proxy( 
    _Workbook * This,
    /* [retval][out] */ /* external definition not present */ SmartDocument **RHS);


void __RPC_STUB _Workbook_get_SmartDocument_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_DocumentLibraryVersions_Proxy( 
    _Workbook * This,
    /* [retval][out] */ /* external definition not present */ DocumentLibraryVersions **RHS);


void __RPC_STUB _Workbook_get_DocumentLibraryVersions_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_InactiveListBorderVisible_Proxy( 
    _Workbook * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Workbook_get_InactiveListBorderVisible_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Workbook_put_InactiveListBorderVisible_Proxy( 
    _Workbook * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Workbook_put_InactiveListBorderVisible_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_DisplayInkComments_Proxy( 
    _Workbook * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Workbook_get_DisplayInkComments_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Workbook_put_DisplayInkComments_Proxy( 
    _Workbook * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Workbook_put_DisplayInkComments_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Workbook_XmlImportXml_Proxy( 
    _Workbook * This,
    /* [in] */ BSTR Data,
    /* [out] */ XmlMap	**ImportMap,
    /* [optional][in] */ VARIANT Overwrite,
    /* [optional][in] */ VARIANT Destination,
    /* [retval][out] */ XlXmlImportResult *RHS);


void __RPC_STUB _Workbook_XmlImportXml_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Workbook_SaveAsXMLData_Proxy( 
    _Workbook * This,
    /* [in] */ BSTR Filename,
    /* [in] */ XmlMap	*Map);


void __RPC_STUB _Workbook_SaveAsXMLData_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Workbook_ToggleFormsDesign_Proxy( 
    _Workbook * This);


void __RPC_STUB _Workbook_ToggleFormsDesign_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_ContentTypeProperties_Proxy( 
    _Workbook * This,
    /* [retval][out] */ /* external definition not present */ MetaProperties **RHS);


void __RPC_STUB _Workbook_get_ContentTypeProperties_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_Connections_Proxy( 
    _Workbook * This,
    /* [retval][out] */ Connections	**RHS);


void __RPC_STUB _Workbook_get_Connections_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Workbook_RemoveDocumentInformation_Proxy( 
    _Workbook * This,
    /* [in] */ XlRemoveDocInfoType RemoveDocInfoType);


void __RPC_STUB _Workbook_RemoveDocumentInformation_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_Signatures_Proxy( 
    _Workbook * This,
    /* [retval][out] */ /* external definition not present */ SignatureSet **RHS);


void __RPC_STUB _Workbook_get_Signatures_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Workbook_CheckInWithVersion_Proxy( 
    _Workbook * This,
    /* [optional][in] */ VARIANT SaveChanges,
    /* [optional][in] */ VARIANT Comments,
    /* [optional][in] */ VARIANT MakePublic,
    /* [optional][in] */ VARIANT VersionType);


void __RPC_STUB _Workbook_CheckInWithVersion_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_ServerPolicy_Proxy( 
    _Workbook * This,
    /* [retval][out] */ /* external definition not present */ ServerPolicy **RHS);


void __RPC_STUB _Workbook_get_ServerPolicy_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Workbook_LockServerFile_Proxy( 
    _Workbook * This);


void __RPC_STUB _Workbook_LockServerFile_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_DocumentInspectors_Proxy( 
    _Workbook * This,
    /* [retval][out] */ /* external definition not present */ DocumentInspectors **RHS);


void __RPC_STUB _Workbook_get_DocumentInspectors_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Workbook_GetWorkflowTasks_Proxy( 
    _Workbook * This,
    /* [retval][out] */ /* external definition not present */ WorkflowTasks **RHS);


void __RPC_STUB _Workbook_GetWorkflowTasks_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Workbook_GetWorkflowTemplates_Proxy( 
    _Workbook * This,
    /* [retval][out] */ /* external definition not present */ WorkflowTemplates **RHS);


void __RPC_STUB _Workbook_GetWorkflowTemplates_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [custom][helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Workbook_PrintOut_Proxy( 
    _Workbook * This,
    /* [optional][in] */ VARIANT From,
    /* [optional][in] */ VARIANT To,
    /* [optional][in] */ VARIANT Copies,
    /* [optional][in] */ VARIANT Preview,
    /* [optional][in] */ VARIANT ActivePrinter,
    /* [optional][in] */ VARIANT PrintToFile,
    /* [optional][in] */ VARIANT Collate,
    /* [optional][in] */ VARIANT PrToFileName,
    /* [optional][in] */ VARIANT IgnorePrintAreas,
    /* [lcid][in] */ long lcid);


void __RPC_STUB _Workbook_PrintOut_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_ServerViewableItems_Proxy( 
    _Workbook * This,
    /* [retval][out] */ ServerViewableItems	**RHS);


void __RPC_STUB _Workbook_get_ServerViewableItems_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_TableStyles_Proxy( 
    _Workbook * This,
    /* [retval][out] */ TableStyles	**RHS);


void __RPC_STUB _Workbook_get_TableStyles_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_DefaultTableStyle_Proxy( 
    _Workbook * This,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB _Workbook_get_DefaultTableStyle_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Workbook_put_DefaultTableStyle_Proxy( 
    _Workbook * This,
    /* [in] */ VARIANT RHS);


void __RPC_STUB _Workbook_put_DefaultTableStyle_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_DefaultPivotTableStyle_Proxy( 
    _Workbook * This,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB _Workbook_get_DefaultPivotTableStyle_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Workbook_put_DefaultPivotTableStyle_Proxy( 
    _Workbook * This,
    /* [in] */ VARIANT RHS);


void __RPC_STUB _Workbook_put_DefaultPivotTableStyle_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_CheckCompatibility_Proxy( 
    _Workbook * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Workbook_get_CheckCompatibility_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Workbook_put_CheckCompatibility_Proxy( 
    _Workbook * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Workbook_put_CheckCompatibility_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_HasVBProject_Proxy( 
    _Workbook * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Workbook_get_HasVBProject_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_CustomXMLParts_Proxy( 
    _Workbook * This,
    /* [retval][out] */ /* external definition not present */ CustomXMLParts **RHS);


void __RPC_STUB _Workbook_get_CustomXMLParts_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_Final_Proxy( 
    _Workbook * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Workbook_get_Final_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Workbook_put_Final_Proxy( 
    _Workbook * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Workbook_put_Final_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_Research_Proxy( 
    _Workbook * This,
    /* [retval][out] */ Research	**RHS);


void __RPC_STUB _Workbook_get_Research_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_Theme_Proxy( 
    _Workbook * This,
    /* [retval][out] */ /* external definition not present */ OfficeTheme **RHS);


void __RPC_STUB _Workbook_get_Theme_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Workbook_ApplyTheme_Proxy( 
    _Workbook * This,
    /* [in] */ BSTR Filename);


void __RPC_STUB _Workbook_ApplyTheme_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_Excel8CompatibilityMode_Proxy( 
    _Workbook * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Workbook_get_Excel8CompatibilityMode_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_ConnectionsDisabled_Proxy( 
    _Workbook * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Workbook_get_ConnectionsDisabled_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Workbook_EnableConnections_Proxy( 
    _Workbook * This);


void __RPC_STUB _Workbook_EnableConnections_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_ShowPivotChartActiveFields_Proxy( 
    _Workbook * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Workbook_get_ShowPivotChartActiveFields_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Workbook_put_ShowPivotChartActiveFields_Proxy( 
    _Workbook * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Workbook_put_ShowPivotChartActiveFields_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Workbook_ExportAsFixedFormat_Proxy( 
    _Workbook * This,
    /* [in] */ XlFixedFormatType Type,
    /* [optional][in] */ VARIANT Filename,
    /* [optional][in] */ VARIANT Quality,
    /* [optional][in] */ VARIANT IncludeDocProperties,
    /* [optional][in] */ VARIANT IgnorePrintAreas,
    /* [optional][in] */ VARIANT From,
    /* [optional][in] */ VARIANT To,
    /* [optional][in] */ VARIANT OpenAfterPublish,
    /* [optional][in] */ VARIANT FixedFormatExtClassPtr);


void __RPC_STUB _Workbook_ExportAsFixedFormat_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_IconSets_Proxy( 
    _Workbook * This,
    /* [retval][out] */ IconSets	**RHS);


void __RPC_STUB _Workbook_get_IconSets_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_EncryptionProvider_Proxy( 
    _Workbook * This,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB _Workbook_get_EncryptionProvider_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Workbook_put_EncryptionProvider_Proxy( 
    _Workbook * This,
    /* [in] */ BSTR RHS);


void __RPC_STUB _Workbook_put_EncryptionProvider_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_DoNotPromptForConvert_Proxy( 
    _Workbook * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Workbook_get_DoNotPromptForConvert_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Workbook_put_DoNotPromptForConvert_Proxy( 
    _Workbook * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Workbook_put_DoNotPromptForConvert_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_ForceFullCalculation_Proxy( 
    _Workbook * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Workbook_get_ForceFullCalculation_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Workbook_put_ForceFullCalculation_Proxy( 
    _Workbook * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Workbook_put_ForceFullCalculation_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [custom][helpcontext][id] */ HRESULT STDMETHODCALLTYPE _Workbook_ProtectSharing_Proxy( 
    _Workbook * This,
    /* [optional][in] */ VARIANT Filename,
    /* [optional][in] */ VARIANT Password,
    /* [optional][in] */ VARIANT WriteResPassword,
    /* [optional][in] */ VARIANT ReadOnlyRecommended,
    /* [optional][in] */ VARIANT CreateBackup,
    /* [optional][in] */ VARIANT SharingPassword,
    /* [optional][in] */ VARIANT FileFormat);


void __RPC_STUB _Workbook_ProtectSharing_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_SlicerCaches_Proxy( 
    _Workbook * This,
    /* [retval][out] */ SlicerCaches	**RHS);


void __RPC_STUB _Workbook_get_SlicerCaches_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_ActiveSlicer_Proxy( 
    _Workbook * This,
    /* [retval][out] */ Slicer	**RHS);


void __RPC_STUB _Workbook_get_ActiveSlicer_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_DefaultSlicerStyle_Proxy( 
    _Workbook * This,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB _Workbook_get_DefaultSlicerStyle_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Workbook_put_DefaultSlicerStyle_Proxy( 
    _Workbook * This,
    /* [in] */ VARIANT RHS);


void __RPC_STUB _Workbook_put_DefaultSlicerStyle_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE _Workbook_Dummy26_Proxy( 
    _Workbook * This);


void __RPC_STUB _Workbook_Dummy26_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE _Workbook_Dummy27_Proxy( 
    _Workbook * This);


void __RPC_STUB _Workbook_Dummy27_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_AccuracyVersion_Proxy( 
    _Workbook * This,
    /* [retval][out] */ long *RHS);


void __RPC_STUB _Workbook_get_AccuracyVersion_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Workbook_put_AccuracyVersion_Proxy( 
    _Workbook * This,
    /* [in] */ long RHS);


void __RPC_STUB _Workbook_put_AccuracyVersion_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_CaseSensitive_Proxy( 
    _Workbook * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Workbook_get_CaseSensitive_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_UseWholeCellCriteria_Proxy( 
    _Workbook * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Workbook_get_UseWholeCellCriteria_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_UseWildcards_Proxy( 
    _Workbook * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Workbook_get_UseWildcards_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_PivotTables_Proxy( 
    _Workbook * This,
    /* [retval][out] */ IDispatch **RHS);


void __RPC_STUB _Workbook_get_PivotTables_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_Model_Proxy( 
    _Workbook * This,
    /* [retval][out] */ Model	**RHS);


void __RPC_STUB _Workbook_get_Model_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_ChartDataPointTrack_Proxy( 
    _Workbook * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB _Workbook_get_ChartDataPointTrack_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Workbook_put_ChartDataPointTrack_Proxy( 
    _Workbook * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB _Workbook_put_ChartDataPointTrack_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE _Workbook_get_DefaultTimelineStyle_Proxy( 
    _Workbook * This,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB _Workbook_get_DefaultTimelineStyle_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE _Workbook_put_DefaultTimelineStyle_Proxy( 
    _Workbook * This,
    /* [in] */ VARIANT RHS);


void __RPC_STUB _Workbook_put_DefaultTimelineStyle_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);



#endif 	/* ___Workbook_INTERFACE_DEFINED__ */


#ifndef __Workbooks_INTERFACE_DEFINED__
#define __Workbooks_INTERFACE_DEFINED__

/* interface Workbooks */
/* [object][oleautomation][nonextensible][dual][helpcontext][uuid] */ 


EXTERN_C const IID IID_Workbooks;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000208DB-0000-0000-C000-000000000046")
    Workbooks : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Add( 
            /* [optional][in] */ VARIANT Template,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ Workbook	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Close( 
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Workbook	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE _Open( 
            /* [in] */ BSTR Filename,
            /* [optional][in] */ VARIANT UpdateLinks,
            /* [optional][in] */ VARIANT ReadOnly,
            /* [optional][in] */ VARIANT Format,
            /* [optional][in] */ VARIANT Password,
            /* [optional][in] */ VARIANT WriteResPassword,
            /* [optional][in] */ VARIANT IgnoreReadOnlyRecommended,
            /* [optional][in] */ VARIANT Origin,
            /* [optional][in] */ VARIANT Delimiter,
            /* [optional][in] */ VARIANT Editable,
            /* [optional][in] */ VARIANT Notify,
            /* [optional][in] */ VARIANT Converter,
            /* [optional][in] */ VARIANT AddToMru,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ Workbook	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE __OpenText( 
            /* [in] */ BSTR Filename,
            /* [optional][in] */ VARIANT Origin,
            /* [optional][in] */ VARIANT StartRow,
            /* [optional][in] */ VARIANT DataType,
            /* [defaultvalue][optional][in] */ XlTextQualifier TextQualifier,
            /* [optional][in] */ VARIANT ConsecutiveDelimiter,
            /* [optional][in] */ VARIANT Tab,
            /* [optional][in] */ VARIANT Semicolon,
            /* [optional][in] */ VARIANT Comma,
            /* [optional][in] */ VARIANT Space,
            /* [optional][in] */ VARIANT Other,
            /* [optional][in] */ VARIANT OtherChar,
            /* [optional][in] */ VARIANT FieldInfo,
            /* [optional][in] */ VARIANT TextVisualLayout,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Workbook	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE _OpenText( 
            /* [in] */ BSTR Filename,
            /* [optional][in] */ VARIANT Origin,
            /* [optional][in] */ VARIANT StartRow,
            /* [optional][in] */ VARIANT DataType,
            /* [defaultvalue][optional][in] */ XlTextQualifier TextQualifier,
            /* [optional][in] */ VARIANT ConsecutiveDelimiter,
            /* [optional][in] */ VARIANT Tab,
            /* [optional][in] */ VARIANT Semicolon,
            /* [optional][in] */ VARIANT Comma,
            /* [optional][in] */ VARIANT Space,
            /* [optional][in] */ VARIANT Other,
            /* [optional][in] */ VARIANT OtherChar,
            /* [optional][in] */ VARIANT FieldInfo,
            /* [optional][in] */ VARIANT TextVisualLayout,
            /* [optional][in] */ VARIANT DecimalSeparator,
            /* [optional][in] */ VARIANT ThousandsSeparator,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Open( 
            /* [in] */ BSTR Filename,
            /* [optional][in] */ VARIANT UpdateLinks,
            /* [optional][in] */ VARIANT ReadOnly,
            /* [optional][in] */ VARIANT Format,
            /* [optional][in] */ VARIANT Password,
            /* [optional][in] */ VARIANT WriteResPassword,
            /* [optional][in] */ VARIANT IgnoreReadOnlyRecommended,
            /* [optional][in] */ VARIANT Origin,
            /* [optional][in] */ VARIANT Delimiter,
            /* [optional][in] */ VARIANT Editable,
            /* [optional][in] */ VARIANT Notify,
            /* [optional][in] */ VARIANT Converter,
            /* [optional][in] */ VARIANT AddToMru,
            /* [optional][in] */ VARIANT Local,
            /* [optional][in] */ VARIANT CorruptLoad,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ Workbook	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE OpenText( 
            /* [in] */ BSTR Filename,
            /* [optional][in] */ VARIANT Origin,
            /* [optional][in] */ VARIANT StartRow,
            /* [optional][in] */ VARIANT DataType,
            /* [defaultvalue][optional][in] */ XlTextQualifier TextQualifier,
            /* [optional][in] */ VARIANT ConsecutiveDelimiter,
            /* [optional][in] */ VARIANT Tab,
            /* [optional][in] */ VARIANT Semicolon,
            /* [optional][in] */ VARIANT Comma,
            /* [optional][in] */ VARIANT Space,
            /* [optional][in] */ VARIANT Other,
            /* [optional][in] */ VARIANT OtherChar,
            /* [optional][in] */ VARIANT FieldInfo,
            /* [optional][in] */ VARIANT TextVisualLayout,
            /* [optional][in] */ VARIANT DecimalSeparator,
            /* [optional][in] */ VARIANT ThousandsSeparator,
            /* [optional][in] */ VARIANT TrailingMinusNumbers,
            /* [optional][in] */ VARIANT Local,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE OpenDatabase( 
            /* [in] */ BSTR Filename,
            /* [optional][in] */ VARIANT CommandText,
            /* [optional][in] */ VARIANT CommandType,
            /* [optional][in] */ VARIANT BackgroundQuery,
            /* [optional][in] */ VARIANT ImportDataAs,
            /* [retval][out] */ Workbook	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE CheckOut( 
            /* [in] */ BSTR Filename) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE CanCheckOut( 
            /* [in] */ BSTR Filename,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE _OpenXML( 
            /* [in] */ BSTR Filename,
            /* [optional][in] */ VARIANT Stylesheets,
            /* [retval][out] */ Workbook	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE OpenXML( 
            /* [in] */ BSTR Filename,
            /* [optional][in] */ VARIANT Stylesheets,
            /* [optional][in] */ VARIANT LoadOption,
            /* [retval][out] */ Workbook	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct WorkbooksVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Workbooks * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Workbooks * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Workbooks * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Workbooks * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Workbooks * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Workbooks * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Workbooks * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Application )( 
            Workbooks * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Creator )( 
            Workbooks * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Parent )( 
            Workbooks * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Add )( 
            Workbooks * This,
            /* [optional][in] */ VARIANT Template,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ Workbook	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Close )( 
            Workbooks * This,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Count )( 
            Workbooks * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Item )( 
            Workbooks * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Workbook	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get__NewEnum )( 
            Workbooks * This,
            /* [retval][out] */ IUnknown **RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *_Open )( 
            Workbooks * This,
            /* [in] */ BSTR Filename,
            /* [optional][in] */ VARIANT UpdateLinks,
            /* [optional][in] */ VARIANT ReadOnly,
            /* [optional][in] */ VARIANT Format,
            /* [optional][in] */ VARIANT Password,
            /* [optional][in] */ VARIANT WriteResPassword,
            /* [optional][in] */ VARIANT IgnoreReadOnlyRecommended,
            /* [optional][in] */ VARIANT Origin,
            /* [optional][in] */ VARIANT Delimiter,
            /* [optional][in] */ VARIANT Editable,
            /* [optional][in] */ VARIANT Notify,
            /* [optional][in] */ VARIANT Converter,
            /* [optional][in] */ VARIANT AddToMru,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ Workbook	**RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *__OpenText )( 
            Workbooks * This,
            /* [in] */ BSTR Filename,
            /* [optional][in] */ VARIANT Origin,
            /* [optional][in] */ VARIANT StartRow,
            /* [optional][in] */ VARIANT DataType,
            /* [defaultvalue][optional][in] */ XlTextQualifier TextQualifier,
            /* [optional][in] */ VARIANT ConsecutiveDelimiter,
            /* [optional][in] */ VARIANT Tab,
            /* [optional][in] */ VARIANT Semicolon,
            /* [optional][in] */ VARIANT Comma,
            /* [optional][in] */ VARIANT Space,
            /* [optional][in] */ VARIANT Other,
            /* [optional][in] */ VARIANT OtherChar,
            /* [optional][in] */ VARIANT FieldInfo,
            /* [optional][in] */ VARIANT TextVisualLayout,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get__Default )( 
            Workbooks * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Workbook	**RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *_OpenText )( 
            Workbooks * This,
            /* [in] */ BSTR Filename,
            /* [optional][in] */ VARIANT Origin,
            /* [optional][in] */ VARIANT StartRow,
            /* [optional][in] */ VARIANT DataType,
            /* [defaultvalue][optional][in] */ XlTextQualifier TextQualifier,
            /* [optional][in] */ VARIANT ConsecutiveDelimiter,
            /* [optional][in] */ VARIANT Tab,
            /* [optional][in] */ VARIANT Semicolon,
            /* [optional][in] */ VARIANT Comma,
            /* [optional][in] */ VARIANT Space,
            /* [optional][in] */ VARIANT Other,
            /* [optional][in] */ VARIANT OtherChar,
            /* [optional][in] */ VARIANT FieldInfo,
            /* [optional][in] */ VARIANT TextVisualLayout,
            /* [optional][in] */ VARIANT DecimalSeparator,
            /* [optional][in] */ VARIANT ThousandsSeparator,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Open )( 
            Workbooks * This,
            /* [in] */ BSTR Filename,
            /* [optional][in] */ VARIANT UpdateLinks,
            /* [optional][in] */ VARIANT ReadOnly,
            /* [optional][in] */ VARIANT Format,
            /* [optional][in] */ VARIANT Password,
            /* [optional][in] */ VARIANT WriteResPassword,
            /* [optional][in] */ VARIANT IgnoreReadOnlyRecommended,
            /* [optional][in] */ VARIANT Origin,
            /* [optional][in] */ VARIANT Delimiter,
            /* [optional][in] */ VARIANT Editable,
            /* [optional][in] */ VARIANT Notify,
            /* [optional][in] */ VARIANT Converter,
            /* [optional][in] */ VARIANT AddToMru,
            /* [optional][in] */ VARIANT Local,
            /* [optional][in] */ VARIANT CorruptLoad,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ Workbook	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *OpenText )( 
            Workbooks * This,
            /* [in] */ BSTR Filename,
            /* [optional][in] */ VARIANT Origin,
            /* [optional][in] */ VARIANT StartRow,
            /* [optional][in] */ VARIANT DataType,
            /* [defaultvalue][optional][in] */ XlTextQualifier TextQualifier,
            /* [optional][in] */ VARIANT ConsecutiveDelimiter,
            /* [optional][in] */ VARIANT Tab,
            /* [optional][in] */ VARIANT Semicolon,
            /* [optional][in] */ VARIANT Comma,
            /* [optional][in] */ VARIANT Space,
            /* [optional][in] */ VARIANT Other,
            /* [optional][in] */ VARIANT OtherChar,
            /* [optional][in] */ VARIANT FieldInfo,
            /* [optional][in] */ VARIANT TextVisualLayout,
            /* [optional][in] */ VARIANT DecimalSeparator,
            /* [optional][in] */ VARIANT ThousandsSeparator,
            /* [optional][in] */ VARIANT TrailingMinusNumbers,
            /* [optional][in] */ VARIANT Local,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *OpenDatabase )( 
            Workbooks * This,
            /* [in] */ BSTR Filename,
            /* [optional][in] */ VARIANT CommandText,
            /* [optional][in] */ VARIANT CommandType,
            /* [optional][in] */ VARIANT BackgroundQuery,
            /* [optional][in] */ VARIANT ImportDataAs,
            /* [retval][out] */ Workbook	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *CheckOut )( 
            Workbooks * This,
            /* [in] */ BSTR Filename);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *CanCheckOut )( 
            Workbooks * This,
            /* [in] */ BSTR Filename,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *_OpenXML )( 
            Workbooks * This,
            /* [in] */ BSTR Filename,
            /* [optional][in] */ VARIANT Stylesheets,
            /* [retval][out] */ Workbook	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *OpenXML )( 
            Workbooks * This,
            /* [in] */ BSTR Filename,
            /* [optional][in] */ VARIANT Stylesheets,
            /* [optional][in] */ VARIANT LoadOption,
            /* [retval][out] */ Workbook	**RHS);
        
        END_INTERFACE
    } WorkbooksVtbl;

    interface Workbooks
    {
        CONST_VTBL struct WorkbooksVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Workbooks_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Workbooks_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Workbooks_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Workbooks_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Workbooks_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Workbooks_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Workbooks_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define Workbooks_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define Workbooks_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define Workbooks_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define Workbooks_Add(This,Template,lcid,RHS)	\
    ( (This)->lpVtbl -> Add(This,Template,lcid,RHS) ) 

#define Workbooks_Close(This,lcid)	\
    ( (This)->lpVtbl -> Close(This,lcid) ) 

#define Workbooks_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define Workbooks_get_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Item(This,Index,RHS) ) 

#define Workbooks_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#define Workbooks__Open(This,Filename,UpdateLinks,ReadOnly,Format,Password,WriteResPassword,IgnoreReadOnlyRecommended,Origin,Delimiter,Editable,Notify,Converter,AddToMru,lcid,RHS)	\
    ( (This)->lpVtbl -> _Open(This,Filename,UpdateLinks,ReadOnly,Format,Password,WriteResPassword,IgnoreReadOnlyRecommended,Origin,Delimiter,Editable,Notify,Converter,AddToMru,lcid,RHS) ) 

#define Workbooks___OpenText(This,Filename,Origin,StartRow,DataType,TextQualifier,ConsecutiveDelimiter,Tab,Semicolon,Comma,Space,Other,OtherChar,FieldInfo,TextVisualLayout,lcid)	\
    ( (This)->lpVtbl -> __OpenText(This,Filename,Origin,StartRow,DataType,TextQualifier,ConsecutiveDelimiter,Tab,Semicolon,Comma,Space,Other,OtherChar,FieldInfo,TextVisualLayout,lcid) ) 

#define Workbooks_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define Workbooks__OpenText(This,Filename,Origin,StartRow,DataType,TextQualifier,ConsecutiveDelimiter,Tab,Semicolon,Comma,Space,Other,OtherChar,FieldInfo,TextVisualLayout,DecimalSeparator,ThousandsSeparator,lcid)	\
    ( (This)->lpVtbl -> _OpenText(This,Filename,Origin,StartRow,DataType,TextQualifier,ConsecutiveDelimiter,Tab,Semicolon,Comma,Space,Other,OtherChar,FieldInfo,TextVisualLayout,DecimalSeparator,ThousandsSeparator,lcid) ) 

#define Workbooks_Open(This,Filename,UpdateLinks,ReadOnly,Format,Password,WriteResPassword,IgnoreReadOnlyRecommended,Origin,Delimiter,Editable,Notify,Converter,AddToMru,Local,CorruptLoad,lcid,RHS)	\
    ( (This)->lpVtbl -> Open(This,Filename,UpdateLinks,ReadOnly,Format,Password,WriteResPassword,IgnoreReadOnlyRecommended,Origin,Delimiter,Editable,Notify,Converter,AddToMru,Local,CorruptLoad,lcid,RHS) ) 

#define Workbooks_OpenText(This,Filename,Origin,StartRow,DataType,TextQualifier,ConsecutiveDelimiter,Tab,Semicolon,Comma,Space,Other,OtherChar,FieldInfo,TextVisualLayout,DecimalSeparator,ThousandsSeparator,TrailingMinusNumbers,Local,lcid)	\
    ( (This)->lpVtbl -> OpenText(This,Filename,Origin,StartRow,DataType,TextQualifier,ConsecutiveDelimiter,Tab,Semicolon,Comma,Space,Other,OtherChar,FieldInfo,TextVisualLayout,DecimalSeparator,ThousandsSeparator,TrailingMinusNumbers,Local,lcid) ) 

#define Workbooks_OpenDatabase(This,Filename,CommandText,CommandType,BackgroundQuery,ImportDataAs,RHS)	\
    ( (This)->lpVtbl -> OpenDatabase(This,Filename,CommandText,CommandType,BackgroundQuery,ImportDataAs,RHS) ) 

#define Workbooks_CheckOut(This,Filename)	\
    ( (This)->lpVtbl -> CheckOut(This,Filename) ) 

#define Workbooks_CanCheckOut(This,Filename,RHS)	\
    ( (This)->lpVtbl -> CanCheckOut(This,Filename,RHS) ) 

#define Workbooks__OpenXML(This,Filename,Stylesheets,RHS)	\
    ( (This)->lpVtbl -> _OpenXML(This,Filename,Stylesheets,RHS) ) 

#define Workbooks_OpenXML(This,Filename,Stylesheets,LoadOption,RHS)	\
    ( (This)->lpVtbl -> OpenXML(This,Filename,Stylesheets,LoadOption,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __Workbooks_INTERFACE_DEFINED__ */


#ifndef __IMenuBars_INTERFACE_DEFINED__
#define __IMenuBars_INTERFACE_DEFINED__

/* interface IMenuBars */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IMenuBars;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00020863-0001-0000-C000-000000000046")
    IMenuBars : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add( 
            /* [optional][in] */ VARIANT Name,
            /* [retval][out] */ MenuBar	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ MenuBar	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ MenuBar	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IMenuBarsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IMenuBars * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IMenuBars * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IMenuBars * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IMenuBars * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IMenuBars * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IMenuBars * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IMenuBars * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IMenuBars * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IMenuBars * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IMenuBars * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add )( 
            IMenuBars * This,
            /* [optional][in] */ VARIANT Name,
            /* [retval][out] */ MenuBar	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IMenuBars * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IMenuBars * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ MenuBar	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Item )( 
            IMenuBars * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ MenuBar	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            IMenuBars * This,
            /* [retval][out] */ IUnknown **RHS);
        
        END_INTERFACE
    } IMenuBarsVtbl;

    interface IMenuBars
    {
        CONST_VTBL struct IMenuBarsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IMenuBars_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IMenuBars_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IMenuBars_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IMenuBars_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IMenuBars_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IMenuBars_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IMenuBars_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IMenuBars_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IMenuBars_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IMenuBars_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IMenuBars_Add(This,Name,RHS)	\
    ( (This)->lpVtbl -> Add(This,Name,RHS) ) 

#define IMenuBars_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IMenuBars_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define IMenuBars_get_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Item(This,Index,RHS) ) 

#define IMenuBars_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IMenuBars_INTERFACE_DEFINED__ */


#ifndef __IMenuBar_INTERFACE_DEFINED__
#define __IMenuBar_INTERFACE_DEFINED__

/* interface IMenuBar */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IMenuBar;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00020864-0001-0000-C000-000000000046")
    IMenuBar : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Activate( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_BuiltIn( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Caption( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Caption( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Index( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Menus( 
            /* [retval][out] */ Menus	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Reset( void) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IMenuBarVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IMenuBar * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IMenuBar * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IMenuBar * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IMenuBar * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IMenuBar * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IMenuBar * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IMenuBar * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IMenuBar * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IMenuBar * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IMenuBar * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Activate )( 
            IMenuBar * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_BuiltIn )( 
            IMenuBar * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Caption )( 
            IMenuBar * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Caption )( 
            IMenuBar * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IMenuBar * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Index )( 
            IMenuBar * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Menus )( 
            IMenuBar * This,
            /* [retval][out] */ Menus	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Reset )( 
            IMenuBar * This);
        
        END_INTERFACE
    } IMenuBarVtbl;

    interface IMenuBar
    {
        CONST_VTBL struct IMenuBarVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IMenuBar_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IMenuBar_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IMenuBar_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IMenuBar_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IMenuBar_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IMenuBar_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IMenuBar_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IMenuBar_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IMenuBar_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IMenuBar_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IMenuBar_Activate(This)	\
    ( (This)->lpVtbl -> Activate(This) ) 

#define IMenuBar_get_BuiltIn(This,RHS)	\
    ( (This)->lpVtbl -> get_BuiltIn(This,RHS) ) 

#define IMenuBar_get_Caption(This,RHS)	\
    ( (This)->lpVtbl -> get_Caption(This,RHS) ) 

#define IMenuBar_put_Caption(This,RHS)	\
    ( (This)->lpVtbl -> put_Caption(This,RHS) ) 

#define IMenuBar_Delete(This)	\
    ( (This)->lpVtbl -> Delete(This) ) 

#define IMenuBar_get_Index(This,RHS)	\
    ( (This)->lpVtbl -> get_Index(This,RHS) ) 

#define IMenuBar_get_Menus(This,RHS)	\
    ( (This)->lpVtbl -> get_Menus(This,RHS) ) 

#define IMenuBar_Reset(This)	\
    ( (This)->lpVtbl -> Reset(This) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IMenuBar_INTERFACE_DEFINED__ */


#ifndef __IMenus_INTERFACE_DEFINED__
#define __IMenus_INTERFACE_DEFINED__

/* interface IMenus */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IMenus;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00020865-0001-0000-C000-000000000046")
    IMenus : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add( 
            /* [in] */ BSTR Caption,
            /* [optional][in] */ VARIANT Before,
            /* [optional][in] */ VARIANT Restore,
            /* [retval][out] */ Menu	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Menu	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Menu	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IMenusVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IMenus * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IMenus * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IMenus * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IMenus * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IMenus * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IMenus * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IMenus * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IMenus * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IMenus * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IMenus * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add )( 
            IMenus * This,
            /* [in] */ BSTR Caption,
            /* [optional][in] */ VARIANT Before,
            /* [optional][in] */ VARIANT Restore,
            /* [retval][out] */ Menu	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IMenus * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IMenus * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Menu	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Item )( 
            IMenus * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Menu	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            IMenus * This,
            /* [retval][out] */ IUnknown **RHS);
        
        END_INTERFACE
    } IMenusVtbl;

    interface IMenus
    {
        CONST_VTBL struct IMenusVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IMenus_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IMenus_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IMenus_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IMenus_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IMenus_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IMenus_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IMenus_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IMenus_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IMenus_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IMenus_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IMenus_Add(This,Caption,Before,Restore,RHS)	\
    ( (This)->lpVtbl -> Add(This,Caption,Before,Restore,RHS) ) 

#define IMenus_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IMenus_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define IMenus_get_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Item(This,Index,RHS) ) 

#define IMenus_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IMenus_INTERFACE_DEFINED__ */


#ifndef __IMenu_INTERFACE_DEFINED__
#define __IMenu_INTERFACE_DEFINED__

/* interface IMenu */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IMenu;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00020866-0001-0000-C000-000000000046")
    IMenu : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Caption( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Caption( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Enabled( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Enabled( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Index( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MenuItems( 
            /* [retval][out] */ MenuItems	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IMenuVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IMenu * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IMenu * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IMenu * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IMenu * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IMenu * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IMenu * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IMenu * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IMenu * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IMenu * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IMenu * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Caption )( 
            IMenu * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Caption )( 
            IMenu * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IMenu * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Enabled )( 
            IMenu * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Enabled )( 
            IMenu * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Index )( 
            IMenu * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MenuItems )( 
            IMenu * This,
            /* [retval][out] */ MenuItems	**RHS);
        
        END_INTERFACE
    } IMenuVtbl;

    interface IMenu
    {
        CONST_VTBL struct IMenuVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IMenu_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IMenu_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IMenu_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IMenu_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IMenu_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IMenu_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IMenu_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IMenu_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IMenu_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IMenu_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IMenu_get_Caption(This,RHS)	\
    ( (This)->lpVtbl -> get_Caption(This,RHS) ) 

#define IMenu_put_Caption(This,RHS)	\
    ( (This)->lpVtbl -> put_Caption(This,RHS) ) 

#define IMenu_Delete(This)	\
    ( (This)->lpVtbl -> Delete(This) ) 

#define IMenu_get_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> get_Enabled(This,RHS) ) 

#define IMenu_put_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> put_Enabled(This,RHS) ) 

#define IMenu_get_Index(This,RHS)	\
    ( (This)->lpVtbl -> get_Index(This,RHS) ) 

#define IMenu_get_MenuItems(This,RHS)	\
    ( (This)->lpVtbl -> get_MenuItems(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IMenu_INTERFACE_DEFINED__ */


#ifndef __IMenuItems_INTERFACE_DEFINED__
#define __IMenuItems_INTERFACE_DEFINED__

/* interface IMenuItems */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IMenuItems;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00020867-0001-0000-C000-000000000046")
    IMenuItems : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add( 
            /* [in] */ BSTR Caption,
            /* [optional][in] */ VARIANT OnAction,
            /* [optional][in] */ VARIANT ShortcutKey,
            /* [optional][in] */ VARIANT Before,
            /* [optional][in] */ VARIANT Restore,
            /* [optional][in] */ VARIANT StatusBar,
            /* [optional][in] */ VARIANT HelpFile,
            /* [optional][in] */ VARIANT HelpContextID,
            /* [retval][out] */ MenuItem	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall AddMenu( 
            /* [in] */ BSTR Caption,
            /* [optional][in] */ VARIANT Before,
            /* [optional][in] */ VARIANT Restore,
            /* [retval][out] */ Menu	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IMenuItemsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IMenuItems * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IMenuItems * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IMenuItems * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IMenuItems * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IMenuItems * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IMenuItems * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IMenuItems * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IMenuItems * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IMenuItems * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IMenuItems * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add )( 
            IMenuItems * This,
            /* [in] */ BSTR Caption,
            /* [optional][in] */ VARIANT OnAction,
            /* [optional][in] */ VARIANT ShortcutKey,
            /* [optional][in] */ VARIANT Before,
            /* [optional][in] */ VARIANT Restore,
            /* [optional][in] */ VARIANT StatusBar,
            /* [optional][in] */ VARIANT HelpFile,
            /* [optional][in] */ VARIANT HelpContextID,
            /* [retval][out] */ MenuItem	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *AddMenu )( 
            IMenuItems * This,
            /* [in] */ BSTR Caption,
            /* [optional][in] */ VARIANT Before,
            /* [optional][in] */ VARIANT Restore,
            /* [retval][out] */ Menu	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IMenuItems * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IMenuItems * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Item )( 
            IMenuItems * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            IMenuItems * This,
            /* [retval][out] */ IUnknown **RHS);
        
        END_INTERFACE
    } IMenuItemsVtbl;

    interface IMenuItems
    {
        CONST_VTBL struct IMenuItemsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IMenuItems_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IMenuItems_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IMenuItems_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IMenuItems_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IMenuItems_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IMenuItems_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IMenuItems_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IMenuItems_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IMenuItems_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IMenuItems_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IMenuItems_Add(This,Caption,OnAction,ShortcutKey,Before,Restore,StatusBar,HelpFile,HelpContextID,RHS)	\
    ( (This)->lpVtbl -> Add(This,Caption,OnAction,ShortcutKey,Before,Restore,StatusBar,HelpFile,HelpContextID,RHS) ) 

#define IMenuItems_AddMenu(This,Caption,Before,Restore,RHS)	\
    ( (This)->lpVtbl -> AddMenu(This,Caption,Before,Restore,RHS) ) 

#define IMenuItems_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IMenuItems_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define IMenuItems_get_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Item(This,Index,RHS) ) 

#define IMenuItems_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IMenuItems_INTERFACE_DEFINED__ */


#ifndef __IMenuItem_INTERFACE_DEFINED__
#define __IMenuItem_INTERFACE_DEFINED__

/* interface IMenuItem */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IMenuItem;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00020868-0001-0000-C000-000000000046")
    IMenuItem : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Caption( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Caption( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Checked( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Checked( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Enabled( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Enabled( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HelpContextID( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_HelpContextID( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HelpFile( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_HelpFile( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Index( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_OnAction( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_OnAction( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_StatusBar( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_StatusBar( 
            /* [in] */ BSTR RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IMenuItemVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IMenuItem * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IMenuItem * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IMenuItem * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IMenuItem * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IMenuItem * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IMenuItem * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IMenuItem * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IMenuItem * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IMenuItem * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IMenuItem * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Caption )( 
            IMenuItem * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Caption )( 
            IMenuItem * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Checked )( 
            IMenuItem * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Checked )( 
            IMenuItem * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IMenuItem * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Enabled )( 
            IMenuItem * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Enabled )( 
            IMenuItem * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HelpContextID )( 
            IMenuItem * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_HelpContextID )( 
            IMenuItem * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HelpFile )( 
            IMenuItem * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_HelpFile )( 
            IMenuItem * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Index )( 
            IMenuItem * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_OnAction )( 
            IMenuItem * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_OnAction )( 
            IMenuItem * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_StatusBar )( 
            IMenuItem * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_StatusBar )( 
            IMenuItem * This,
            /* [in] */ BSTR RHS);
        
        END_INTERFACE
    } IMenuItemVtbl;

    interface IMenuItem
    {
        CONST_VTBL struct IMenuItemVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IMenuItem_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IMenuItem_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IMenuItem_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IMenuItem_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IMenuItem_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IMenuItem_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IMenuItem_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IMenuItem_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IMenuItem_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IMenuItem_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IMenuItem_get_Caption(This,RHS)	\
    ( (This)->lpVtbl -> get_Caption(This,RHS) ) 

#define IMenuItem_put_Caption(This,RHS)	\
    ( (This)->lpVtbl -> put_Caption(This,RHS) ) 

#define IMenuItem_get_Checked(This,RHS)	\
    ( (This)->lpVtbl -> get_Checked(This,RHS) ) 

#define IMenuItem_put_Checked(This,RHS)	\
    ( (This)->lpVtbl -> put_Checked(This,RHS) ) 

#define IMenuItem_Delete(This)	\
    ( (This)->lpVtbl -> Delete(This) ) 

#define IMenuItem_get_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> get_Enabled(This,RHS) ) 

#define IMenuItem_put_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> put_Enabled(This,RHS) ) 

#define IMenuItem_get_HelpContextID(This,RHS)	\
    ( (This)->lpVtbl -> get_HelpContextID(This,RHS) ) 

#define IMenuItem_put_HelpContextID(This,RHS)	\
    ( (This)->lpVtbl -> put_HelpContextID(This,RHS) ) 

#define IMenuItem_get_HelpFile(This,RHS)	\
    ( (This)->lpVtbl -> get_HelpFile(This,RHS) ) 

#define IMenuItem_put_HelpFile(This,RHS)	\
    ( (This)->lpVtbl -> put_HelpFile(This,RHS) ) 

#define IMenuItem_get_Index(This,RHS)	\
    ( (This)->lpVtbl -> get_Index(This,RHS) ) 

#define IMenuItem_get_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> get_OnAction(This,RHS) ) 

#define IMenuItem_put_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> put_OnAction(This,RHS) ) 

#define IMenuItem_get_StatusBar(This,RHS)	\
    ( (This)->lpVtbl -> get_StatusBar(This,RHS) ) 

#define IMenuItem_put_StatusBar(This,RHS)	\
    ( (This)->lpVtbl -> put_StatusBar(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IMenuItem_INTERFACE_DEFINED__ */


#ifndef __ICharts_INTERFACE_DEFINED__
#define __ICharts_INTERFACE_DEFINED__

/* interface ICharts */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ICharts;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002086D-0001-0000-C000-000000000046")
    ICharts : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall Add( 
            /* [optional][in] */ VARIANT Before,
            /* [optional][in] */ VARIANT After,
            /* [optional][in] */ VARIANT Count,
            /* [retval][out] */ Chart	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Copy( 
            /* [optional][in] */ VARIANT Before,
            /* [optional][in] */ VARIANT After,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy7( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Move( 
            /* [optional][in] */ VARIANT Before,
            /* [optional][in] */ VARIANT After,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
        virtual /* [custom][helpcontext][hidden][id] */ HRESULT __stdcall __PrintOut( 
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall PrintPreview( 
            /* [optional][in] */ VARIANT EnableChanges,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [optional][in] */ VARIANT Replace,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HPageBreaks( 
            /* [retval][out] */ HPageBreaks	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_VPageBreaks( 
            /* [retval][out] */ VPageBreaks	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Visible( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Visible( 
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [custom][helpcontext][hidden][id] */ HRESULT __stdcall _PrintOut( 
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate,
            /* [optional][in] */ VARIANT PrToFileName,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall PrintOut( 
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate,
            /* [optional][in] */ VARIANT PrToFileName) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add2( 
            /* [optional][in] */ VARIANT Before,
            /* [optional][in] */ VARIANT After,
            /* [optional][in] */ VARIANT Count,
            /* [optional][in] */ VARIANT NewLayout,
            /* [retval][out] */ Chart	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IChartsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ICharts * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ICharts * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ICharts * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ICharts * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ICharts * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ICharts * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ICharts * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ICharts * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ICharts * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ICharts * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *Add )( 
            ICharts * This,
            /* [optional][in] */ VARIANT Before,
            /* [optional][in] */ VARIANT After,
            /* [optional][in] */ VARIANT Count,
            /* [retval][out] */ Chart	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Copy )( 
            ICharts * This,
            /* [optional][in] */ VARIANT Before,
            /* [optional][in] */ VARIANT After,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            ICharts * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            ICharts * This,
            /* [lcid][in] */ long lcid);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy7 )( 
            ICharts * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Item )( 
            ICharts * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Move )( 
            ICharts * This,
            /* [optional][in] */ VARIANT Before,
            /* [optional][in] */ VARIANT After,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            ICharts * This,
            /* [retval][out] */ IUnknown **RHS);
        
        /* [custom][helpcontext][hidden][id] */ HRESULT ( __stdcall *__PrintOut )( 
            ICharts * This,
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *PrintPreview )( 
            ICharts * This,
            /* [optional][in] */ VARIANT EnableChanges,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            ICharts * This,
            /* [optional][in] */ VARIANT Replace,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HPageBreaks )( 
            ICharts * This,
            /* [retval][out] */ HPageBreaks	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_VPageBreaks )( 
            ICharts * This,
            /* [retval][out] */ VPageBreaks	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Visible )( 
            ICharts * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Visible )( 
            ICharts * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            ICharts * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [custom][helpcontext][hidden][id] */ HRESULT ( __stdcall *_PrintOut )( 
            ICharts * This,
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate,
            /* [optional][in] */ VARIANT PrToFileName,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *PrintOut )( 
            ICharts * This,
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate,
            /* [optional][in] */ VARIANT PrToFileName);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add2 )( 
            ICharts * This,
            /* [optional][in] */ VARIANT Before,
            /* [optional][in] */ VARIANT After,
            /* [optional][in] */ VARIANT Count,
            /* [optional][in] */ VARIANT NewLayout,
            /* [retval][out] */ Chart	**RHS);
        
        END_INTERFACE
    } IChartsVtbl;

    interface ICharts
    {
        CONST_VTBL struct IChartsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ICharts_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ICharts_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ICharts_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ICharts_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ICharts_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ICharts_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ICharts_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ICharts_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ICharts_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ICharts_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ICharts_Add(This,Before,After,Count,RHS)	\
    ( (This)->lpVtbl -> Add(This,Before,After,Count,RHS) ) 

#define ICharts_Copy(This,Before,After,lcid)	\
    ( (This)->lpVtbl -> Copy(This,Before,After,lcid) ) 

#define ICharts_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define ICharts_Delete(This,lcid)	\
    ( (This)->lpVtbl -> Delete(This,lcid) ) 

#define ICharts__Dummy7(This)	\
    ( (This)->lpVtbl -> _Dummy7(This) ) 

#define ICharts_get_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Item(This,Index,RHS) ) 

#define ICharts_Move(This,Before,After,lcid)	\
    ( (This)->lpVtbl -> Move(This,Before,After,lcid) ) 

#define ICharts_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#define ICharts___PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate,lcid)	\
    ( (This)->lpVtbl -> __PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate,lcid) ) 

#define ICharts_PrintPreview(This,EnableChanges,lcid)	\
    ( (This)->lpVtbl -> PrintPreview(This,EnableChanges,lcid) ) 

#define ICharts_Select(This,Replace,lcid)	\
    ( (This)->lpVtbl -> Select(This,Replace,lcid) ) 

#define ICharts_get_HPageBreaks(This,RHS)	\
    ( (This)->lpVtbl -> get_HPageBreaks(This,RHS) ) 

#define ICharts_get_VPageBreaks(This,RHS)	\
    ( (This)->lpVtbl -> get_VPageBreaks(This,RHS) ) 

#define ICharts_get_Visible(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_Visible(This,lcid,RHS) ) 

#define ICharts_put_Visible(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_Visible(This,lcid,RHS) ) 

#define ICharts_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define ICharts__PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate,PrToFileName,lcid)	\
    ( (This)->lpVtbl -> _PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate,PrToFileName,lcid) ) 

#define ICharts_PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate,PrToFileName)	\
    ( (This)->lpVtbl -> PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate,PrToFileName) ) 

#define ICharts_Add2(This,Before,After,Count,NewLayout,RHS)	\
    ( (This)->lpVtbl -> Add2(This,Before,After,Count,NewLayout,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ICharts_INTERFACE_DEFINED__ */


#ifndef __IDrawingObjects_INTERFACE_DEFINED__
#define __IDrawingObjects_INTERFACE_DEFINED__

/* interface IDrawingObjects */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IDrawingObjects;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002086F-0001-0000-C000-000000000046")
    IDrawingObjects : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy3( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall BringToFront( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Copy( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CopyPicture( 
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Cut( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Duplicate( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Enabled( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Enabled( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Height( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Height( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy12( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Left( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Left( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Locked( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Locked( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy15( void) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_OnAction( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_OnAction( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Placement( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Placement( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PrintObject( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PrintObject( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SendToBack( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Top( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Top( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy22( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Visible( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Visible( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Width( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Width( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ZOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShapeRange( 
            /* [retval][out] */ ShapeRange	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Accelerator( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Accelerator( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy28( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AddIndent( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AddIndent( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall AddItem( 
            /* [in] */ VARIANT Text,
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ArrowHeadLength( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ArrowHeadLength( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ArrowHeadStyle( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ArrowHeadStyle( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ArrowHeadWidth( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ArrowHeadWidth( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AutoSize( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AutoSize( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Border( 
            /* [retval][out] */ Border	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CancelButton( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_CancelButton( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Caption( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Caption( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Characters( 
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Length,
            /* [retval][out] */ Characters	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CheckSpelling( 
            /* [optional][in] */ VARIANT CustomDictionary,
            /* [optional][in] */ VARIANT IgnoreUppercase,
            /* [optional][in] */ VARIANT AlwaysSuggest,
            /* [optional][in] */ VARIANT SpellLang,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put__Default( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DefaultButton( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DefaultButton( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DismissButton( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DismissButton( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Display3DShading( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Display3DShading( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DisplayVerticalScrollBar( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DisplayVerticalScrollBar( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DropDownLines( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DropDownLines( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Font( 
            /* [retval][out] */ Font	**RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy47( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HelpButton( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_HelpButton( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HorizontalAlignment( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_HorizontalAlignment( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_InputType( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_InputType( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Interior( 
            /* [retval][out] */ Interior	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LargeChange( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_LargeChange( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LinkedCell( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_LinkedCell( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy54( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall List( 
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy56( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ListFillRange( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ListFillRange( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ListIndex( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ListIndex( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LockedText( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_LockedText( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Max( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Max( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Min( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Min( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MultiLine( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_MultiLine( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MultiSelect( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_MultiSelect( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Orientation( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Orientation( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PhoneticAccelerator( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PhoneticAccelerator( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall RemoveAllItems( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall RemoveItem( 
            /* [in] */ long Index,
            /* [optional][in] */ VARIANT Count,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Reshape( 
            /* [in] */ long Vertex,
            /* [in] */ VARIANT Insert,
            /* [optional][in] */ VARIANT Left,
            /* [optional][in] */ VARIANT Top,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RoundedCorners( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_RoundedCorners( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Selected( 
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Shadow( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Shadow( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SmallChange( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_SmallChange( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Text( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Text( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Ungroup( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Value( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Value( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_VerticalAlignment( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_VerticalAlignment( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Vertices( 
            /* [optional][in] */ VARIANT Index1,
            /* [optional][in] */ VARIANT Index2,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ReadingOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ReadingOrder( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Group( 
            /* [retval][out] */ GroupObject	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall LinkCombo( 
            /* [optional][in] */ VARIANT Link,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall _NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IDrawingObjectsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IDrawingObjects * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IDrawingObjects * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IDrawingObjects * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IDrawingObjects * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IDrawingObjects * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IDrawingObjects * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IDrawingObjects * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IDrawingObjects * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IDrawingObjects * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IDrawingObjects * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy3 )( 
            IDrawingObjects * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *BringToFront )( 
            IDrawingObjects * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Copy )( 
            IDrawingObjects * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CopyPicture )( 
            IDrawingObjects * This,
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Cut )( 
            IDrawingObjects * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IDrawingObjects * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Duplicate )( 
            IDrawingObjects * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Enabled )( 
            IDrawingObjects * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Enabled )( 
            IDrawingObjects * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Height )( 
            IDrawingObjects * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Height )( 
            IDrawingObjects * This,
            /* [in] */ double RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy12 )( 
            IDrawingObjects * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Left )( 
            IDrawingObjects * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Left )( 
            IDrawingObjects * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Locked )( 
            IDrawingObjects * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Locked )( 
            IDrawingObjects * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy15 )( 
            IDrawingObjects * This);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_OnAction )( 
            IDrawingObjects * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_OnAction )( 
            IDrawingObjects * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Placement )( 
            IDrawingObjects * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Placement )( 
            IDrawingObjects * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PrintObject )( 
            IDrawingObjects * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PrintObject )( 
            IDrawingObjects * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            IDrawingObjects * This,
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SendToBack )( 
            IDrawingObjects * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Top )( 
            IDrawingObjects * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Top )( 
            IDrawingObjects * This,
            /* [in] */ double RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy22 )( 
            IDrawingObjects * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Visible )( 
            IDrawingObjects * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Visible )( 
            IDrawingObjects * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Width )( 
            IDrawingObjects * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Width )( 
            IDrawingObjects * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ZOrder )( 
            IDrawingObjects * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShapeRange )( 
            IDrawingObjects * This,
            /* [retval][out] */ ShapeRange	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Accelerator )( 
            IDrawingObjects * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Accelerator )( 
            IDrawingObjects * This,
            /* [in] */ VARIANT RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy28 )( 
            IDrawingObjects * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AddIndent )( 
            IDrawingObjects * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AddIndent )( 
            IDrawingObjects * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *AddItem )( 
            IDrawingObjects * This,
            /* [in] */ VARIANT Text,
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ArrowHeadLength )( 
            IDrawingObjects * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ArrowHeadLength )( 
            IDrawingObjects * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ArrowHeadStyle )( 
            IDrawingObjects * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ArrowHeadStyle )( 
            IDrawingObjects * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ArrowHeadWidth )( 
            IDrawingObjects * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ArrowHeadWidth )( 
            IDrawingObjects * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AutoSize )( 
            IDrawingObjects * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AutoSize )( 
            IDrawingObjects * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Border )( 
            IDrawingObjects * This,
            /* [retval][out] */ Border	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CancelButton )( 
            IDrawingObjects * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_CancelButton )( 
            IDrawingObjects * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Caption )( 
            IDrawingObjects * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Caption )( 
            IDrawingObjects * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Characters )( 
            IDrawingObjects * This,
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Length,
            /* [retval][out] */ Characters	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CheckSpelling )( 
            IDrawingObjects * This,
            /* [optional][in] */ VARIANT CustomDictionary,
            /* [optional][in] */ VARIANT IgnoreUppercase,
            /* [optional][in] */ VARIANT AlwaysSuggest,
            /* [optional][in] */ VARIANT SpellLang,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IDrawingObjects * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put__Default )( 
            IDrawingObjects * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DefaultButton )( 
            IDrawingObjects * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DefaultButton )( 
            IDrawingObjects * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DismissButton )( 
            IDrawingObjects * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DismissButton )( 
            IDrawingObjects * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Display3DShading )( 
            IDrawingObjects * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Display3DShading )( 
            IDrawingObjects * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DisplayVerticalScrollBar )( 
            IDrawingObjects * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DisplayVerticalScrollBar )( 
            IDrawingObjects * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DropDownLines )( 
            IDrawingObjects * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DropDownLines )( 
            IDrawingObjects * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Font )( 
            IDrawingObjects * This,
            /* [retval][out] */ Font	**RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy47 )( 
            IDrawingObjects * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HelpButton )( 
            IDrawingObjects * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_HelpButton )( 
            IDrawingObjects * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HorizontalAlignment )( 
            IDrawingObjects * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_HorizontalAlignment )( 
            IDrawingObjects * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_InputType )( 
            IDrawingObjects * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_InputType )( 
            IDrawingObjects * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Interior )( 
            IDrawingObjects * This,
            /* [retval][out] */ Interior	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LargeChange )( 
            IDrawingObjects * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_LargeChange )( 
            IDrawingObjects * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LinkedCell )( 
            IDrawingObjects * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_LinkedCell )( 
            IDrawingObjects * This,
            /* [in] */ BSTR RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy54 )( 
            IDrawingObjects * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *List )( 
            IDrawingObjects * This,
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy56 )( 
            IDrawingObjects * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ListFillRange )( 
            IDrawingObjects * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ListFillRange )( 
            IDrawingObjects * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ListIndex )( 
            IDrawingObjects * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ListIndex )( 
            IDrawingObjects * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LockedText )( 
            IDrawingObjects * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_LockedText )( 
            IDrawingObjects * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Max )( 
            IDrawingObjects * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Max )( 
            IDrawingObjects * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Min )( 
            IDrawingObjects * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Min )( 
            IDrawingObjects * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MultiLine )( 
            IDrawingObjects * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_MultiLine )( 
            IDrawingObjects * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MultiSelect )( 
            IDrawingObjects * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_MultiSelect )( 
            IDrawingObjects * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Orientation )( 
            IDrawingObjects * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Orientation )( 
            IDrawingObjects * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PhoneticAccelerator )( 
            IDrawingObjects * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PhoneticAccelerator )( 
            IDrawingObjects * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *RemoveAllItems )( 
            IDrawingObjects * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *RemoveItem )( 
            IDrawingObjects * This,
            /* [in] */ long Index,
            /* [optional][in] */ VARIANT Count,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Reshape )( 
            IDrawingObjects * This,
            /* [in] */ long Vertex,
            /* [in] */ VARIANT Insert,
            /* [optional][in] */ VARIANT Left,
            /* [optional][in] */ VARIANT Top,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RoundedCorners )( 
            IDrawingObjects * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_RoundedCorners )( 
            IDrawingObjects * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Selected )( 
            IDrawingObjects * This,
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Shadow )( 
            IDrawingObjects * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Shadow )( 
            IDrawingObjects * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SmallChange )( 
            IDrawingObjects * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_SmallChange )( 
            IDrawingObjects * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Text )( 
            IDrawingObjects * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Text )( 
            IDrawingObjects * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Ungroup )( 
            IDrawingObjects * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Value )( 
            IDrawingObjects * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Value )( 
            IDrawingObjects * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_VerticalAlignment )( 
            IDrawingObjects * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_VerticalAlignment )( 
            IDrawingObjects * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Vertices )( 
            IDrawingObjects * This,
            /* [optional][in] */ VARIANT Index1,
            /* [optional][in] */ VARIANT Index2,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ReadingOrder )( 
            IDrawingObjects * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ReadingOrder )( 
            IDrawingObjects * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IDrawingObjects * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Item )( 
            IDrawingObjects * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Group )( 
            IDrawingObjects * This,
            /* [retval][out] */ GroupObject	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *LinkCombo )( 
            IDrawingObjects * This,
            /* [optional][in] */ VARIANT Link,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *_NewEnum )( 
            IDrawingObjects * This,
            /* [retval][out] */ IUnknown **RHS);
        
        END_INTERFACE
    } IDrawingObjectsVtbl;

    interface IDrawingObjects
    {
        CONST_VTBL struct IDrawingObjectsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IDrawingObjects_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IDrawingObjects_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IDrawingObjects_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IDrawingObjects_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IDrawingObjects_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IDrawingObjects_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IDrawingObjects_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IDrawingObjects_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IDrawingObjects_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IDrawingObjects_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IDrawingObjects__Dummy3(This)	\
    ( (This)->lpVtbl -> _Dummy3(This) ) 

#define IDrawingObjects_BringToFront(This,RHS)	\
    ( (This)->lpVtbl -> BringToFront(This,RHS) ) 

#define IDrawingObjects_Copy(This,RHS)	\
    ( (This)->lpVtbl -> Copy(This,RHS) ) 

#define IDrawingObjects_CopyPicture(This,Appearance,Format,RHS)	\
    ( (This)->lpVtbl -> CopyPicture(This,Appearance,Format,RHS) ) 

#define IDrawingObjects_Cut(This,RHS)	\
    ( (This)->lpVtbl -> Cut(This,RHS) ) 

#define IDrawingObjects_Delete(This,RHS)	\
    ( (This)->lpVtbl -> Delete(This,RHS) ) 

#define IDrawingObjects_Duplicate(This,RHS)	\
    ( (This)->lpVtbl -> Duplicate(This,RHS) ) 

#define IDrawingObjects_get_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> get_Enabled(This,RHS) ) 

#define IDrawingObjects_put_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> put_Enabled(This,RHS) ) 

#define IDrawingObjects_get_Height(This,RHS)	\
    ( (This)->lpVtbl -> get_Height(This,RHS) ) 

#define IDrawingObjects_put_Height(This,RHS)	\
    ( (This)->lpVtbl -> put_Height(This,RHS) ) 

#define IDrawingObjects__Dummy12(This)	\
    ( (This)->lpVtbl -> _Dummy12(This) ) 

#define IDrawingObjects_get_Left(This,RHS)	\
    ( (This)->lpVtbl -> get_Left(This,RHS) ) 

#define IDrawingObjects_put_Left(This,RHS)	\
    ( (This)->lpVtbl -> put_Left(This,RHS) ) 

#define IDrawingObjects_get_Locked(This,RHS)	\
    ( (This)->lpVtbl -> get_Locked(This,RHS) ) 

#define IDrawingObjects_put_Locked(This,RHS)	\
    ( (This)->lpVtbl -> put_Locked(This,RHS) ) 

#define IDrawingObjects__Dummy15(This)	\
    ( (This)->lpVtbl -> _Dummy15(This) ) 

#define IDrawingObjects_get_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> get_OnAction(This,RHS) ) 

#define IDrawingObjects_put_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> put_OnAction(This,RHS) ) 

#define IDrawingObjects_get_Placement(This,RHS)	\
    ( (This)->lpVtbl -> get_Placement(This,RHS) ) 

#define IDrawingObjects_put_Placement(This,RHS)	\
    ( (This)->lpVtbl -> put_Placement(This,RHS) ) 

#define IDrawingObjects_get_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> get_PrintObject(This,RHS) ) 

#define IDrawingObjects_put_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> put_PrintObject(This,RHS) ) 

#define IDrawingObjects_Select(This,Replace,RHS)	\
    ( (This)->lpVtbl -> Select(This,Replace,RHS) ) 

#define IDrawingObjects_SendToBack(This,RHS)	\
    ( (This)->lpVtbl -> SendToBack(This,RHS) ) 

#define IDrawingObjects_get_Top(This,RHS)	\
    ( (This)->lpVtbl -> get_Top(This,RHS) ) 

#define IDrawingObjects_put_Top(This,RHS)	\
    ( (This)->lpVtbl -> put_Top(This,RHS) ) 

#define IDrawingObjects__Dummy22(This)	\
    ( (This)->lpVtbl -> _Dummy22(This) ) 

#define IDrawingObjects_get_Visible(This,RHS)	\
    ( (This)->lpVtbl -> get_Visible(This,RHS) ) 

#define IDrawingObjects_put_Visible(This,RHS)	\
    ( (This)->lpVtbl -> put_Visible(This,RHS) ) 

#define IDrawingObjects_get_Width(This,RHS)	\
    ( (This)->lpVtbl -> get_Width(This,RHS) ) 

#define IDrawingObjects_put_Width(This,RHS)	\
    ( (This)->lpVtbl -> put_Width(This,RHS) ) 

#define IDrawingObjects_get_ZOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_ZOrder(This,RHS) ) 

#define IDrawingObjects_get_ShapeRange(This,RHS)	\
    ( (This)->lpVtbl -> get_ShapeRange(This,RHS) ) 

#define IDrawingObjects_get_Accelerator(This,RHS)	\
    ( (This)->lpVtbl -> get_Accelerator(This,RHS) ) 

#define IDrawingObjects_put_Accelerator(This,RHS)	\
    ( (This)->lpVtbl -> put_Accelerator(This,RHS) ) 

#define IDrawingObjects__Dummy28(This)	\
    ( (This)->lpVtbl -> _Dummy28(This) ) 

#define IDrawingObjects_get_AddIndent(This,RHS)	\
    ( (This)->lpVtbl -> get_AddIndent(This,RHS) ) 

#define IDrawingObjects_put_AddIndent(This,RHS)	\
    ( (This)->lpVtbl -> put_AddIndent(This,RHS) ) 

#define IDrawingObjects_AddItem(This,Text,Index,RHS)	\
    ( (This)->lpVtbl -> AddItem(This,Text,Index,RHS) ) 

#define IDrawingObjects_get_ArrowHeadLength(This,RHS)	\
    ( (This)->lpVtbl -> get_ArrowHeadLength(This,RHS) ) 

#define IDrawingObjects_put_ArrowHeadLength(This,RHS)	\
    ( (This)->lpVtbl -> put_ArrowHeadLength(This,RHS) ) 

#define IDrawingObjects_get_ArrowHeadStyle(This,RHS)	\
    ( (This)->lpVtbl -> get_ArrowHeadStyle(This,RHS) ) 

#define IDrawingObjects_put_ArrowHeadStyle(This,RHS)	\
    ( (This)->lpVtbl -> put_ArrowHeadStyle(This,RHS) ) 

#define IDrawingObjects_get_ArrowHeadWidth(This,RHS)	\
    ( (This)->lpVtbl -> get_ArrowHeadWidth(This,RHS) ) 

#define IDrawingObjects_put_ArrowHeadWidth(This,RHS)	\
    ( (This)->lpVtbl -> put_ArrowHeadWidth(This,RHS) ) 

#define IDrawingObjects_get_AutoSize(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoSize(This,RHS) ) 

#define IDrawingObjects_put_AutoSize(This,RHS)	\
    ( (This)->lpVtbl -> put_AutoSize(This,RHS) ) 

#define IDrawingObjects_get_Border(This,RHS)	\
    ( (This)->lpVtbl -> get_Border(This,RHS) ) 

#define IDrawingObjects_get_CancelButton(This,RHS)	\
    ( (This)->lpVtbl -> get_CancelButton(This,RHS) ) 

#define IDrawingObjects_put_CancelButton(This,RHS)	\
    ( (This)->lpVtbl -> put_CancelButton(This,RHS) ) 

#define IDrawingObjects_get_Caption(This,RHS)	\
    ( (This)->lpVtbl -> get_Caption(This,RHS) ) 

#define IDrawingObjects_put_Caption(This,RHS)	\
    ( (This)->lpVtbl -> put_Caption(This,RHS) ) 

#define IDrawingObjects_get_Characters(This,Start,Length,RHS)	\
    ( (This)->lpVtbl -> get_Characters(This,Start,Length,RHS) ) 

#define IDrawingObjects_CheckSpelling(This,CustomDictionary,IgnoreUppercase,AlwaysSuggest,SpellLang,RHS)	\
    ( (This)->lpVtbl -> CheckSpelling(This,CustomDictionary,IgnoreUppercase,AlwaysSuggest,SpellLang,RHS) ) 

#define IDrawingObjects_get__Default(This,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,RHS) ) 

#define IDrawingObjects_put__Default(This,RHS)	\
    ( (This)->lpVtbl -> put__Default(This,RHS) ) 

#define IDrawingObjects_get_DefaultButton(This,RHS)	\
    ( (This)->lpVtbl -> get_DefaultButton(This,RHS) ) 

#define IDrawingObjects_put_DefaultButton(This,RHS)	\
    ( (This)->lpVtbl -> put_DefaultButton(This,RHS) ) 

#define IDrawingObjects_get_DismissButton(This,RHS)	\
    ( (This)->lpVtbl -> get_DismissButton(This,RHS) ) 

#define IDrawingObjects_put_DismissButton(This,RHS)	\
    ( (This)->lpVtbl -> put_DismissButton(This,RHS) ) 

#define IDrawingObjects_get_Display3DShading(This,RHS)	\
    ( (This)->lpVtbl -> get_Display3DShading(This,RHS) ) 

#define IDrawingObjects_put_Display3DShading(This,RHS)	\
    ( (This)->lpVtbl -> put_Display3DShading(This,RHS) ) 

#define IDrawingObjects_get_DisplayVerticalScrollBar(This,RHS)	\
    ( (This)->lpVtbl -> get_DisplayVerticalScrollBar(This,RHS) ) 

#define IDrawingObjects_put_DisplayVerticalScrollBar(This,RHS)	\
    ( (This)->lpVtbl -> put_DisplayVerticalScrollBar(This,RHS) ) 

#define IDrawingObjects_get_DropDownLines(This,RHS)	\
    ( (This)->lpVtbl -> get_DropDownLines(This,RHS) ) 

#define IDrawingObjects_put_DropDownLines(This,RHS)	\
    ( (This)->lpVtbl -> put_DropDownLines(This,RHS) ) 

#define IDrawingObjects_get_Font(This,RHS)	\
    ( (This)->lpVtbl -> get_Font(This,RHS) ) 

#define IDrawingObjects__Dummy47(This)	\
    ( (This)->lpVtbl -> _Dummy47(This) ) 

#define IDrawingObjects_get_HelpButton(This,RHS)	\
    ( (This)->lpVtbl -> get_HelpButton(This,RHS) ) 

#define IDrawingObjects_put_HelpButton(This,RHS)	\
    ( (This)->lpVtbl -> put_HelpButton(This,RHS) ) 

#define IDrawingObjects_get_HorizontalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> get_HorizontalAlignment(This,RHS) ) 

#define IDrawingObjects_put_HorizontalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> put_HorizontalAlignment(This,RHS) ) 

#define IDrawingObjects_get_InputType(This,RHS)	\
    ( (This)->lpVtbl -> get_InputType(This,RHS) ) 

#define IDrawingObjects_put_InputType(This,RHS)	\
    ( (This)->lpVtbl -> put_InputType(This,RHS) ) 

#define IDrawingObjects_get_Interior(This,RHS)	\
    ( (This)->lpVtbl -> get_Interior(This,RHS) ) 

#define IDrawingObjects_get_LargeChange(This,RHS)	\
    ( (This)->lpVtbl -> get_LargeChange(This,RHS) ) 

#define IDrawingObjects_put_LargeChange(This,RHS)	\
    ( (This)->lpVtbl -> put_LargeChange(This,RHS) ) 

#define IDrawingObjects_get_LinkedCell(This,RHS)	\
    ( (This)->lpVtbl -> get_LinkedCell(This,RHS) ) 

#define IDrawingObjects_put_LinkedCell(This,RHS)	\
    ( (This)->lpVtbl -> put_LinkedCell(This,RHS) ) 

#define IDrawingObjects__Dummy54(This)	\
    ( (This)->lpVtbl -> _Dummy54(This) ) 

#define IDrawingObjects_List(This,Index,RHS)	\
    ( (This)->lpVtbl -> List(This,Index,RHS) ) 

#define IDrawingObjects__Dummy56(This)	\
    ( (This)->lpVtbl -> _Dummy56(This) ) 

#define IDrawingObjects_get_ListFillRange(This,RHS)	\
    ( (This)->lpVtbl -> get_ListFillRange(This,RHS) ) 

#define IDrawingObjects_put_ListFillRange(This,RHS)	\
    ( (This)->lpVtbl -> put_ListFillRange(This,RHS) ) 

#define IDrawingObjects_get_ListIndex(This,RHS)	\
    ( (This)->lpVtbl -> get_ListIndex(This,RHS) ) 

#define IDrawingObjects_put_ListIndex(This,RHS)	\
    ( (This)->lpVtbl -> put_ListIndex(This,RHS) ) 

#define IDrawingObjects_get_LockedText(This,RHS)	\
    ( (This)->lpVtbl -> get_LockedText(This,RHS) ) 

#define IDrawingObjects_put_LockedText(This,RHS)	\
    ( (This)->lpVtbl -> put_LockedText(This,RHS) ) 

#define IDrawingObjects_get_Max(This,RHS)	\
    ( (This)->lpVtbl -> get_Max(This,RHS) ) 

#define IDrawingObjects_put_Max(This,RHS)	\
    ( (This)->lpVtbl -> put_Max(This,RHS) ) 

#define IDrawingObjects_get_Min(This,RHS)	\
    ( (This)->lpVtbl -> get_Min(This,RHS) ) 

#define IDrawingObjects_put_Min(This,RHS)	\
    ( (This)->lpVtbl -> put_Min(This,RHS) ) 

#define IDrawingObjects_get_MultiLine(This,RHS)	\
    ( (This)->lpVtbl -> get_MultiLine(This,RHS) ) 

#define IDrawingObjects_put_MultiLine(This,RHS)	\
    ( (This)->lpVtbl -> put_MultiLine(This,RHS) ) 

#define IDrawingObjects_get_MultiSelect(This,RHS)	\
    ( (This)->lpVtbl -> get_MultiSelect(This,RHS) ) 

#define IDrawingObjects_put_MultiSelect(This,RHS)	\
    ( (This)->lpVtbl -> put_MultiSelect(This,RHS) ) 

#define IDrawingObjects_get_Orientation(This,RHS)	\
    ( (This)->lpVtbl -> get_Orientation(This,RHS) ) 

#define IDrawingObjects_put_Orientation(This,RHS)	\
    ( (This)->lpVtbl -> put_Orientation(This,RHS) ) 

#define IDrawingObjects_get_PhoneticAccelerator(This,RHS)	\
    ( (This)->lpVtbl -> get_PhoneticAccelerator(This,RHS) ) 

#define IDrawingObjects_put_PhoneticAccelerator(This,RHS)	\
    ( (This)->lpVtbl -> put_PhoneticAccelerator(This,RHS) ) 

#define IDrawingObjects_RemoveAllItems(This,RHS)	\
    ( (This)->lpVtbl -> RemoveAllItems(This,RHS) ) 

#define IDrawingObjects_RemoveItem(This,Index,Count,RHS)	\
    ( (This)->lpVtbl -> RemoveItem(This,Index,Count,RHS) ) 

#define IDrawingObjects_Reshape(This,Vertex,Insert,Left,Top,RHS)	\
    ( (This)->lpVtbl -> Reshape(This,Vertex,Insert,Left,Top,RHS) ) 

#define IDrawingObjects_get_RoundedCorners(This,RHS)	\
    ( (This)->lpVtbl -> get_RoundedCorners(This,RHS) ) 

#define IDrawingObjects_put_RoundedCorners(This,RHS)	\
    ( (This)->lpVtbl -> put_RoundedCorners(This,RHS) ) 

#define IDrawingObjects_Selected(This,Index,RHS)	\
    ( (This)->lpVtbl -> Selected(This,Index,RHS) ) 

#define IDrawingObjects_get_Shadow(This,RHS)	\
    ( (This)->lpVtbl -> get_Shadow(This,RHS) ) 

#define IDrawingObjects_put_Shadow(This,RHS)	\
    ( (This)->lpVtbl -> put_Shadow(This,RHS) ) 

#define IDrawingObjects_get_SmallChange(This,RHS)	\
    ( (This)->lpVtbl -> get_SmallChange(This,RHS) ) 

#define IDrawingObjects_put_SmallChange(This,RHS)	\
    ( (This)->lpVtbl -> put_SmallChange(This,RHS) ) 

#define IDrawingObjects_get_Text(This,RHS)	\
    ( (This)->lpVtbl -> get_Text(This,RHS) ) 

#define IDrawingObjects_put_Text(This,RHS)	\
    ( (This)->lpVtbl -> put_Text(This,RHS) ) 

#define IDrawingObjects_Ungroup(This,RHS)	\
    ( (This)->lpVtbl -> Ungroup(This,RHS) ) 

#define IDrawingObjects_get_Value(This,RHS)	\
    ( (This)->lpVtbl -> get_Value(This,RHS) ) 

#define IDrawingObjects_put_Value(This,RHS)	\
    ( (This)->lpVtbl -> put_Value(This,RHS) ) 

#define IDrawingObjects_get_VerticalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> get_VerticalAlignment(This,RHS) ) 

#define IDrawingObjects_put_VerticalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> put_VerticalAlignment(This,RHS) ) 

#define IDrawingObjects_Vertices(This,Index1,Index2,RHS)	\
    ( (This)->lpVtbl -> Vertices(This,Index1,Index2,RHS) ) 

#define IDrawingObjects_get_ReadingOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_ReadingOrder(This,RHS) ) 

#define IDrawingObjects_put_ReadingOrder(This,RHS)	\
    ( (This)->lpVtbl -> put_ReadingOrder(This,RHS) ) 

#define IDrawingObjects_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IDrawingObjects_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> Item(This,Index,RHS) ) 

#define IDrawingObjects_Group(This,RHS)	\
    ( (This)->lpVtbl -> Group(This,RHS) ) 

#define IDrawingObjects_LinkCombo(This,Link,RHS)	\
    ( (This)->lpVtbl -> LinkCombo(This,Link,RHS) ) 

#define IDrawingObjects__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> _NewEnum(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */



/* [helpcontext][id] */ HRESULT __stdcall IDrawingObjects_Vertices_Proxy( 
    IDrawingObjects * This,
    /* [optional][in] */ VARIANT Index1,
    /* [optional][in] */ VARIANT Index2,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB IDrawingObjects_Vertices_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IDrawingObjects_get_ReadingOrder_Proxy( 
    IDrawingObjects * This,
    /* [retval][out] */ long *RHS);


void __RPC_STUB IDrawingObjects_get_ReadingOrder_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT __stdcall IDrawingObjects_put_ReadingOrder_Proxy( 
    IDrawingObjects * This,
    /* [in] */ long RHS);


void __RPC_STUB IDrawingObjects_put_ReadingOrder_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IDrawingObjects_get_Count_Proxy( 
    IDrawingObjects * This,
    /* [retval][out] */ long *RHS);


void __RPC_STUB IDrawingObjects_get_Count_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IDrawingObjects_Item_Proxy( 
    IDrawingObjects * This,
    /* [in] */ VARIANT Index,
    /* [retval][out] */ IDispatch **RHS);


void __RPC_STUB IDrawingObjects_Item_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IDrawingObjects_Group_Proxy( 
    IDrawingObjects * This,
    /* [retval][out] */ GroupObject	**RHS);


void __RPC_STUB IDrawingObjects_Group_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IDrawingObjects_LinkCombo_Proxy( 
    IDrawingObjects * This,
    /* [optional][in] */ VARIANT Link,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB IDrawingObjects_LinkCombo_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IDrawingObjects__NewEnum_Proxy( 
    IDrawingObjects * This,
    /* [retval][out] */ IUnknown **RHS);


void __RPC_STUB IDrawingObjects__NewEnum_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);



#endif 	/* __IDrawingObjects_INTERFACE_DEFINED__ */


#ifndef __IPivotCache_INTERFACE_DEFINED__
#define __IPivotCache_INTERFACE_DEFINED__

/* interface IPivotCache */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IPivotCache;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002441C-0001-0000-C000-000000000046")
    IPivotCache : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_BackgroundQuery( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_BackgroundQuery( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Connection( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Connection( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_EnableRefresh( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_EnableRefresh( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Index( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MemoryUsed( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_OptimizeCache( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_OptimizeCache( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RecordCount( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Refresh( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RefreshDate( 
            /* [retval][out] */ DATE *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RefreshName( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RefreshOnFileOpen( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_RefreshOnFileOpen( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Sql( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_Sql( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SavePassword( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_SavePassword( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SourceData( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_SourceData( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CommandText( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_CommandText( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CommandType( 
            /* [retval][out] */ XlCmdType *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_CommandType( 
            /* [in] */ XlCmdType RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_QueryType( 
            /* [retval][out] */ XlQueryType *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MaintainConnection( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_MaintainConnection( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RefreshPeriod( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_RefreshPeriod( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Recordset( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propputref][id] */ HRESULT __stdcall putref_Recordset( 
            /* [in] */ IDispatch *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ResetTimer( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LocalConnection( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_LocalConnection( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CreatePivotTable( 
            /* [in] */ VARIANT TableDestination,
            /* [optional][in] */ VARIANT TableName,
            /* [optional][in] */ VARIANT ReadData,
            /* [optional][in] */ VARIANT DefaultVersion,
            /* [retval][out] */ PivotTable	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_UseLocalConnection( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_UseLocalConnection( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ADOConnection( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_IsConnected( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall MakeConnection( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_OLAP( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SourceType( 
            /* [retval][out] */ XlPivotTableSourceType *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MissingItemsLimit( 
            /* [retval][out] */ XlPivotTableMissingItems *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_MissingItemsLimit( 
            /* [in] */ XlPivotTableMissingItems RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SourceConnectionFile( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_SourceConnectionFile( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SourceDataFile( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RobustConnect( 
            /* [retval][out] */ XlRobustConnect *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_RobustConnect( 
            /* [in] */ XlRobustConnect RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SaveAsODC( 
            /* [in] */ BSTR ODCFileName,
            /* [optional][in] */ VARIANT Description,
            /* [optional][in] */ VARIANT Keywords) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_WorkbookConnection( 
            /* [retval][out] */ WorkbookConnection	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Version( 
            /* [retval][out] */ XlPivotTableVersionList *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_UpgradeOnRefresh( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_UpgradeOnRefresh( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CreatePivotChart( 
            /* [in] */ VARIANT ChartDestination,
            /* [optional][in] */ VARIANT XlChartType,
            /* [optional][in] */ VARIANT Left,
            /* [optional][in] */ VARIANT Top,
            /* [optional][in] */ VARIANT Width,
            /* [optional][in] */ VARIANT Height,
            /* [retval][out] */ Shape	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IPivotCacheVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IPivotCache * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IPivotCache * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IPivotCache * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IPivotCache * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IPivotCache * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IPivotCache * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IPivotCache * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IPivotCache * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IPivotCache * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IPivotCache * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_BackgroundQuery )( 
            IPivotCache * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_BackgroundQuery )( 
            IPivotCache * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Connection )( 
            IPivotCache * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Connection )( 
            IPivotCache * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_EnableRefresh )( 
            IPivotCache * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_EnableRefresh )( 
            IPivotCache * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Index )( 
            IPivotCache * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MemoryUsed )( 
            IPivotCache * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_OptimizeCache )( 
            IPivotCache * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_OptimizeCache )( 
            IPivotCache * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RecordCount )( 
            IPivotCache * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Refresh )( 
            IPivotCache * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RefreshDate )( 
            IPivotCache * This,
            /* [retval][out] */ DATE *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RefreshName )( 
            IPivotCache * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RefreshOnFileOpen )( 
            IPivotCache * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_RefreshOnFileOpen )( 
            IPivotCache * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Sql )( 
            IPivotCache * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_Sql )( 
            IPivotCache * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SavePassword )( 
            IPivotCache * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_SavePassword )( 
            IPivotCache * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SourceData )( 
            IPivotCache * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_SourceData )( 
            IPivotCache * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CommandText )( 
            IPivotCache * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_CommandText )( 
            IPivotCache * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CommandType )( 
            IPivotCache * This,
            /* [retval][out] */ XlCmdType *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_CommandType )( 
            IPivotCache * This,
            /* [in] */ XlCmdType RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_QueryType )( 
            IPivotCache * This,
            /* [retval][out] */ XlQueryType *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MaintainConnection )( 
            IPivotCache * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_MaintainConnection )( 
            IPivotCache * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RefreshPeriod )( 
            IPivotCache * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_RefreshPeriod )( 
            IPivotCache * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Recordset )( 
            IPivotCache * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propputref][id] */ HRESULT ( __stdcall *putref_Recordset )( 
            IPivotCache * This,
            /* [in] */ IDispatch *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ResetTimer )( 
            IPivotCache * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LocalConnection )( 
            IPivotCache * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_LocalConnection )( 
            IPivotCache * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CreatePivotTable )( 
            IPivotCache * This,
            /* [in] */ VARIANT TableDestination,
            /* [optional][in] */ VARIANT TableName,
            /* [optional][in] */ VARIANT ReadData,
            /* [optional][in] */ VARIANT DefaultVersion,
            /* [retval][out] */ PivotTable	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_UseLocalConnection )( 
            IPivotCache * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_UseLocalConnection )( 
            IPivotCache * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ADOConnection )( 
            IPivotCache * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_IsConnected )( 
            IPivotCache * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *MakeConnection )( 
            IPivotCache * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_OLAP )( 
            IPivotCache * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SourceType )( 
            IPivotCache * This,
            /* [retval][out] */ XlPivotTableSourceType *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MissingItemsLimit )( 
            IPivotCache * This,
            /* [retval][out] */ XlPivotTableMissingItems *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_MissingItemsLimit )( 
            IPivotCache * This,
            /* [in] */ XlPivotTableMissingItems RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SourceConnectionFile )( 
            IPivotCache * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_SourceConnectionFile )( 
            IPivotCache * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SourceDataFile )( 
            IPivotCache * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RobustConnect )( 
            IPivotCache * This,
            /* [retval][out] */ XlRobustConnect *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_RobustConnect )( 
            IPivotCache * This,
            /* [in] */ XlRobustConnect RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SaveAsODC )( 
            IPivotCache * This,
            /* [in] */ BSTR ODCFileName,
            /* [optional][in] */ VARIANT Description,
            /* [optional][in] */ VARIANT Keywords);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_WorkbookConnection )( 
            IPivotCache * This,
            /* [retval][out] */ WorkbookConnection	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Version )( 
            IPivotCache * This,
            /* [retval][out] */ XlPivotTableVersionList *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_UpgradeOnRefresh )( 
            IPivotCache * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_UpgradeOnRefresh )( 
            IPivotCache * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CreatePivotChart )( 
            IPivotCache * This,
            /* [in] */ VARIANT ChartDestination,
            /* [optional][in] */ VARIANT XlChartType,
            /* [optional][in] */ VARIANT Left,
            /* [optional][in] */ VARIANT Top,
            /* [optional][in] */ VARIANT Width,
            /* [optional][in] */ VARIANT Height,
            /* [retval][out] */ Shape	**RHS);
        
        END_INTERFACE
    } IPivotCacheVtbl;

    interface IPivotCache
    {
        CONST_VTBL struct IPivotCacheVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IPivotCache_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IPivotCache_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IPivotCache_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IPivotCache_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IPivotCache_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IPivotCache_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IPivotCache_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IPivotCache_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IPivotCache_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IPivotCache_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IPivotCache_get_BackgroundQuery(This,RHS)	\
    ( (This)->lpVtbl -> get_BackgroundQuery(This,RHS) ) 

#define IPivotCache_put_BackgroundQuery(This,RHS)	\
    ( (This)->lpVtbl -> put_BackgroundQuery(This,RHS) ) 

#define IPivotCache_get_Connection(This,RHS)	\
    ( (This)->lpVtbl -> get_Connection(This,RHS) ) 

#define IPivotCache_put_Connection(This,RHS)	\
    ( (This)->lpVtbl -> put_Connection(This,RHS) ) 

#define IPivotCache_get_EnableRefresh(This,RHS)	\
    ( (This)->lpVtbl -> get_EnableRefresh(This,RHS) ) 

#define IPivotCache_put_EnableRefresh(This,RHS)	\
    ( (This)->lpVtbl -> put_EnableRefresh(This,RHS) ) 

#define IPivotCache_get_Index(This,RHS)	\
    ( (This)->lpVtbl -> get_Index(This,RHS) ) 

#define IPivotCache_get_MemoryUsed(This,RHS)	\
    ( (This)->lpVtbl -> get_MemoryUsed(This,RHS) ) 

#define IPivotCache_get_OptimizeCache(This,RHS)	\
    ( (This)->lpVtbl -> get_OptimizeCache(This,RHS) ) 

#define IPivotCache_put_OptimizeCache(This,RHS)	\
    ( (This)->lpVtbl -> put_OptimizeCache(This,RHS) ) 

#define IPivotCache_get_RecordCount(This,RHS)	\
    ( (This)->lpVtbl -> get_RecordCount(This,RHS) ) 

#define IPivotCache_Refresh(This)	\
    ( (This)->lpVtbl -> Refresh(This) ) 

#define IPivotCache_get_RefreshDate(This,RHS)	\
    ( (This)->lpVtbl -> get_RefreshDate(This,RHS) ) 

#define IPivotCache_get_RefreshName(This,RHS)	\
    ( (This)->lpVtbl -> get_RefreshName(This,RHS) ) 

#define IPivotCache_get_RefreshOnFileOpen(This,RHS)	\
    ( (This)->lpVtbl -> get_RefreshOnFileOpen(This,RHS) ) 

#define IPivotCache_put_RefreshOnFileOpen(This,RHS)	\
    ( (This)->lpVtbl -> put_RefreshOnFileOpen(This,RHS) ) 

#define IPivotCache_get_Sql(This,RHS)	\
    ( (This)->lpVtbl -> get_Sql(This,RHS) ) 

#define IPivotCache_put_Sql(This,RHS)	\
    ( (This)->lpVtbl -> put_Sql(This,RHS) ) 

#define IPivotCache_get_SavePassword(This,RHS)	\
    ( (This)->lpVtbl -> get_SavePassword(This,RHS) ) 

#define IPivotCache_put_SavePassword(This,RHS)	\
    ( (This)->lpVtbl -> put_SavePassword(This,RHS) ) 

#define IPivotCache_get_SourceData(This,RHS)	\
    ( (This)->lpVtbl -> get_SourceData(This,RHS) ) 

#define IPivotCache_put_SourceData(This,RHS)	\
    ( (This)->lpVtbl -> put_SourceData(This,RHS) ) 

#define IPivotCache_get_CommandText(This,RHS)	\
    ( (This)->lpVtbl -> get_CommandText(This,RHS) ) 

#define IPivotCache_put_CommandText(This,RHS)	\
    ( (This)->lpVtbl -> put_CommandText(This,RHS) ) 

#define IPivotCache_get_CommandType(This,RHS)	\
    ( (This)->lpVtbl -> get_CommandType(This,RHS) ) 

#define IPivotCache_put_CommandType(This,RHS)	\
    ( (This)->lpVtbl -> put_CommandType(This,RHS) ) 

#define IPivotCache_get_QueryType(This,RHS)	\
    ( (This)->lpVtbl -> get_QueryType(This,RHS) ) 

#define IPivotCache_get_MaintainConnection(This,RHS)	\
    ( (This)->lpVtbl -> get_MaintainConnection(This,RHS) ) 

#define IPivotCache_put_MaintainConnection(This,RHS)	\
    ( (This)->lpVtbl -> put_MaintainConnection(This,RHS) ) 

#define IPivotCache_get_RefreshPeriod(This,RHS)	\
    ( (This)->lpVtbl -> get_RefreshPeriod(This,RHS) ) 

#define IPivotCache_put_RefreshPeriod(This,RHS)	\
    ( (This)->lpVtbl -> put_RefreshPeriod(This,RHS) ) 

#define IPivotCache_get_Recordset(This,RHS)	\
    ( (This)->lpVtbl -> get_Recordset(This,RHS) ) 

#define IPivotCache_putref_Recordset(This,RHS)	\
    ( (This)->lpVtbl -> putref_Recordset(This,RHS) ) 

#define IPivotCache_ResetTimer(This)	\
    ( (This)->lpVtbl -> ResetTimer(This) ) 

#define IPivotCache_get_LocalConnection(This,RHS)	\
    ( (This)->lpVtbl -> get_LocalConnection(This,RHS) ) 

#define IPivotCache_put_LocalConnection(This,RHS)	\
    ( (This)->lpVtbl -> put_LocalConnection(This,RHS) ) 

#define IPivotCache_CreatePivotTable(This,TableDestination,TableName,ReadData,DefaultVersion,RHS)	\
    ( (This)->lpVtbl -> CreatePivotTable(This,TableDestination,TableName,ReadData,DefaultVersion,RHS) ) 

#define IPivotCache_get_UseLocalConnection(This,RHS)	\
    ( (This)->lpVtbl -> get_UseLocalConnection(This,RHS) ) 

#define IPivotCache_put_UseLocalConnection(This,RHS)	\
    ( (This)->lpVtbl -> put_UseLocalConnection(This,RHS) ) 

#define IPivotCache_get_ADOConnection(This,RHS)	\
    ( (This)->lpVtbl -> get_ADOConnection(This,RHS) ) 

#define IPivotCache_get_IsConnected(This,RHS)	\
    ( (This)->lpVtbl -> get_IsConnected(This,RHS) ) 

#define IPivotCache_MakeConnection(This)	\
    ( (This)->lpVtbl -> MakeConnection(This) ) 

#define IPivotCache_get_OLAP(This,RHS)	\
    ( (This)->lpVtbl -> get_OLAP(This,RHS) ) 

#define IPivotCache_get_SourceType(This,RHS)	\
    ( (This)->lpVtbl -> get_SourceType(This,RHS) ) 

#define IPivotCache_get_MissingItemsLimit(This,RHS)	\
    ( (This)->lpVtbl -> get_MissingItemsLimit(This,RHS) ) 

#define IPivotCache_put_MissingItemsLimit(This,RHS)	\
    ( (This)->lpVtbl -> put_MissingItemsLimit(This,RHS) ) 

#define IPivotCache_get_SourceConnectionFile(This,RHS)	\
    ( (This)->lpVtbl -> get_SourceConnectionFile(This,RHS) ) 

#define IPivotCache_put_SourceConnectionFile(This,RHS)	\
    ( (This)->lpVtbl -> put_SourceConnectionFile(This,RHS) ) 

#define IPivotCache_get_SourceDataFile(This,RHS)	\
    ( (This)->lpVtbl -> get_SourceDataFile(This,RHS) ) 

#define IPivotCache_get_RobustConnect(This,RHS)	\
    ( (This)->lpVtbl -> get_RobustConnect(This,RHS) ) 

#define IPivotCache_put_RobustConnect(This,RHS)	\
    ( (This)->lpVtbl -> put_RobustConnect(This,RHS) ) 

#define IPivotCache_SaveAsODC(This,ODCFileName,Description,Keywords)	\
    ( (This)->lpVtbl -> SaveAsODC(This,ODCFileName,Description,Keywords) ) 

#define IPivotCache_get_WorkbookConnection(This,RHS)	\
    ( (This)->lpVtbl -> get_WorkbookConnection(This,RHS) ) 

#define IPivotCache_get_Version(This,RHS)	\
    ( (This)->lpVtbl -> get_Version(This,RHS) ) 

#define IPivotCache_get_UpgradeOnRefresh(This,RHS)	\
    ( (This)->lpVtbl -> get_UpgradeOnRefresh(This,RHS) ) 

#define IPivotCache_put_UpgradeOnRefresh(This,RHS)	\
    ( (This)->lpVtbl -> put_UpgradeOnRefresh(This,RHS) ) 

#define IPivotCache_CreatePivotChart(This,ChartDestination,XlChartType,Left,Top,Width,Height,RHS)	\
    ( (This)->lpVtbl -> CreatePivotChart(This,ChartDestination,XlChartType,Left,Top,Width,Height,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IPivotCache_INTERFACE_DEFINED__ */


#ifndef __IPivotCaches_INTERFACE_DEFINED__
#define __IPivotCaches_INTERFACE_DEFINED__

/* interface IPivotCaches */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IPivotCaches;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002441D-0001-0000-C000-000000000046")
    IPivotCaches : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ PivotCache	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ PivotCache	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall _NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall Add( 
            /* [in] */ XlPivotTableSourceType SourceType,
            /* [optional][in] */ VARIANT SourceData,
            /* [retval][out] */ PivotCache	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Create( 
            /* [in] */ XlPivotTableSourceType SourceType,
            /* [optional][in] */ VARIANT SourceData,
            /* [optional][in] */ VARIANT Version,
            /* [retval][out] */ PivotCache	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IPivotCachesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IPivotCaches * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IPivotCaches * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IPivotCaches * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IPivotCaches * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IPivotCaches * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IPivotCaches * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IPivotCaches * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IPivotCaches * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IPivotCaches * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IPivotCaches * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IPivotCaches * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Item )( 
            IPivotCaches * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ PivotCache	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IPivotCaches * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ PivotCache	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *_NewEnum )( 
            IPivotCaches * This,
            /* [retval][out] */ IUnknown **RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *Add )( 
            IPivotCaches * This,
            /* [in] */ XlPivotTableSourceType SourceType,
            /* [optional][in] */ VARIANT SourceData,
            /* [retval][out] */ PivotCache	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Create )( 
            IPivotCaches * This,
            /* [in] */ XlPivotTableSourceType SourceType,
            /* [optional][in] */ VARIANT SourceData,
            /* [optional][in] */ VARIANT Version,
            /* [retval][out] */ PivotCache	**RHS);
        
        END_INTERFACE
    } IPivotCachesVtbl;

    interface IPivotCaches
    {
        CONST_VTBL struct IPivotCachesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IPivotCaches_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IPivotCaches_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IPivotCaches_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IPivotCaches_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IPivotCaches_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IPivotCaches_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IPivotCaches_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IPivotCaches_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IPivotCaches_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IPivotCaches_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IPivotCaches_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IPivotCaches_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> Item(This,Index,RHS) ) 

#define IPivotCaches_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define IPivotCaches__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> _NewEnum(This,RHS) ) 

#define IPivotCaches_Add(This,SourceType,SourceData,RHS)	\
    ( (This)->lpVtbl -> Add(This,SourceType,SourceData,RHS) ) 

#define IPivotCaches_Create(This,SourceType,SourceData,Version,RHS)	\
    ( (This)->lpVtbl -> Create(This,SourceType,SourceData,Version,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IPivotCaches_INTERFACE_DEFINED__ */


#ifndef __IPivotFormula_INTERFACE_DEFINED__
#define __IPivotFormula_INTERFACE_DEFINED__

/* interface IPivotFormula */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IPivotFormula;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002441E-0001-0000-C000-000000000046")
    IPivotFormula : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put__Default( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Formula( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Formula( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Value( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Value( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Index( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Index( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_StandardFormula( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_StandardFormula( 
            /* [in] */ BSTR RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IPivotFormulaVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IPivotFormula * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IPivotFormula * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IPivotFormula * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IPivotFormula * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IPivotFormula * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IPivotFormula * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IPivotFormula * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IPivotFormula * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IPivotFormula * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IPivotFormula * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IPivotFormula * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IPivotFormula * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put__Default )( 
            IPivotFormula * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Formula )( 
            IPivotFormula * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Formula )( 
            IPivotFormula * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Value )( 
            IPivotFormula * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Value )( 
            IPivotFormula * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Index )( 
            IPivotFormula * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Index )( 
            IPivotFormula * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_StandardFormula )( 
            IPivotFormula * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_StandardFormula )( 
            IPivotFormula * This,
            /* [in] */ BSTR RHS);
        
        END_INTERFACE
    } IPivotFormulaVtbl;

    interface IPivotFormula
    {
        CONST_VTBL struct IPivotFormulaVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IPivotFormula_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IPivotFormula_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IPivotFormula_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IPivotFormula_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IPivotFormula_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IPivotFormula_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IPivotFormula_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IPivotFormula_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IPivotFormula_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IPivotFormula_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IPivotFormula_Delete(This)	\
    ( (This)->lpVtbl -> Delete(This) ) 

#define IPivotFormula_get__Default(This,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,RHS) ) 

#define IPivotFormula_put__Default(This,RHS)	\
    ( (This)->lpVtbl -> put__Default(This,RHS) ) 

#define IPivotFormula_get_Formula(This,RHS)	\
    ( (This)->lpVtbl -> get_Formula(This,RHS) ) 

#define IPivotFormula_put_Formula(This,RHS)	\
    ( (This)->lpVtbl -> put_Formula(This,RHS) ) 

#define IPivotFormula_get_Value(This,RHS)	\
    ( (This)->lpVtbl -> get_Value(This,RHS) ) 

#define IPivotFormula_put_Value(This,RHS)	\
    ( (This)->lpVtbl -> put_Value(This,RHS) ) 

#define IPivotFormula_get_Index(This,RHS)	\
    ( (This)->lpVtbl -> get_Index(This,RHS) ) 

#define IPivotFormula_put_Index(This,RHS)	\
    ( (This)->lpVtbl -> put_Index(This,RHS) ) 

#define IPivotFormula_get_StandardFormula(This,RHS)	\
    ( (This)->lpVtbl -> get_StandardFormula(This,RHS) ) 

#define IPivotFormula_put_StandardFormula(This,RHS)	\
    ( (This)->lpVtbl -> put_StandardFormula(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IPivotFormula_INTERFACE_DEFINED__ */


#ifndef __IPivotFormulas_INTERFACE_DEFINED__
#define __IPivotFormulas_INTERFACE_DEFINED__

/* interface IPivotFormulas */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IPivotFormulas;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002441F-0001-0000-C000-000000000046")
    IPivotFormulas : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall _Add( 
            /* [in] */ BSTR Formula,
            /* [retval][out] */ PivotFormula	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ PivotFormula	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ PivotFormula	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall _NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add( 
            /* [in] */ BSTR Formula,
            /* [optional][in] */ VARIANT UseStandardFormula,
            /* [retval][out] */ PivotFormula	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IPivotFormulasVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IPivotFormulas * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IPivotFormulas * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IPivotFormulas * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IPivotFormulas * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IPivotFormulas * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IPivotFormulas * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IPivotFormulas * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IPivotFormulas * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IPivotFormulas * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IPivotFormulas * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IPivotFormulas * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *_Add )( 
            IPivotFormulas * This,
            /* [in] */ BSTR Formula,
            /* [retval][out] */ PivotFormula	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Item )( 
            IPivotFormulas * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ PivotFormula	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IPivotFormulas * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ PivotFormula	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *_NewEnum )( 
            IPivotFormulas * This,
            /* [retval][out] */ IUnknown **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add )( 
            IPivotFormulas * This,
            /* [in] */ BSTR Formula,
            /* [optional][in] */ VARIANT UseStandardFormula,
            /* [retval][out] */ PivotFormula	**RHS);
        
        END_INTERFACE
    } IPivotFormulasVtbl;

    interface IPivotFormulas
    {
        CONST_VTBL struct IPivotFormulasVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IPivotFormulas_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IPivotFormulas_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IPivotFormulas_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IPivotFormulas_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IPivotFormulas_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IPivotFormulas_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IPivotFormulas_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IPivotFormulas_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IPivotFormulas_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IPivotFormulas_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IPivotFormulas_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IPivotFormulas__Add(This,Formula,RHS)	\
    ( (This)->lpVtbl -> _Add(This,Formula,RHS) ) 

#define IPivotFormulas_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> Item(This,Index,RHS) ) 

#define IPivotFormulas_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define IPivotFormulas__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> _NewEnum(This,RHS) ) 

#define IPivotFormulas_Add(This,Formula,UseStandardFormula,RHS)	\
    ( (This)->lpVtbl -> Add(This,Formula,UseStandardFormula,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IPivotFormulas_INTERFACE_DEFINED__ */


#ifndef __IPivotTable_INTERFACE_DEFINED__
#define __IPivotTable_INTERFACE_DEFINED__

/* interface IPivotTable */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IPivotTable;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00020872-0001-0000-C000-000000000046")
    IPivotTable : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall AddFields( 
            /* [optional][in] */ VARIANT RowFields,
            /* [optional][in] */ VARIANT ColumnFields,
            /* [optional][in] */ VARIANT PageFields,
            /* [optional][in] */ VARIANT AddToTable,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ColumnFields( 
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ColumnGrand( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ColumnGrand( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ColumnRange( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ShowPages( 
            /* [optional][in] */ VARIANT PageField,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DataBodyRange( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DataFields( 
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DataLabelRange( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put__Default( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HasAutoFormat( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_HasAutoFormat( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HiddenFields( 
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_InnerDetail( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_InnerDetail( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Name( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PageFields( 
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PageRange( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PageRangeCells( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall PivotFields( 
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RefreshDate( 
            /* [retval][out] */ DATE *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RefreshName( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall RefreshTable( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RowFields( 
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RowGrand( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_RowGrand( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RowRange( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SaveData( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_SaveData( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SourceData( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_SourceData( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TableRange1( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TableRange2( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Value( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Value( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_VisibleFields( 
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CacheIndex( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_CacheIndex( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CalculatedFields( 
            /* [retval][out] */ CalculatedFields	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DisplayErrorString( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DisplayErrorString( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DisplayNullString( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DisplayNullString( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_EnableDrilldown( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_EnableDrilldown( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_EnableFieldDialog( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_EnableFieldDialog( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_EnableWizard( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_EnableWizard( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ErrorString( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ErrorString( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall GetData( 
            /* [in] */ BSTR Name,
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ListFormulas( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ManualUpdate( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ManualUpdate( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MergeLabels( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_MergeLabels( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_NullString( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_NullString( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall PivotCache( 
            /* [retval][out] */ PivotCache	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PivotFormulas( 
            /* [retval][out] */ PivotFormulas	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall PivotTableWizard( 
            /* [optional][in] */ VARIANT SourceType,
            /* [optional][in] */ VARIANT SourceData,
            /* [optional][in] */ VARIANT TableDestination,
            /* [optional][in] */ VARIANT TableName,
            /* [optional][in] */ VARIANT RowGrand,
            /* [optional][in] */ VARIANT ColumnGrand,
            /* [optional][in] */ VARIANT SaveData,
            /* [optional][in] */ VARIANT HasAutoFormat,
            /* [optional][in] */ VARIANT AutoPage,
            /* [optional][in] */ VARIANT Reserved,
            /* [optional][in] */ VARIANT BackgroundQuery,
            /* [optional][in] */ VARIANT OptimizeCache,
            /* [optional][in] */ VARIANT PageFieldOrder,
            /* [optional][in] */ VARIANT PageFieldWrapCount,
            /* [optional][in] */ VARIANT ReadData,
            /* [optional][in] */ VARIANT Connection) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SubtotalHiddenPageItems( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_SubtotalHiddenPageItems( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PageFieldOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PageFieldOrder( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PageFieldStyle( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PageFieldStyle( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PageFieldWrapCount( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PageFieldWrapCount( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PreserveFormatting( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PreserveFormatting( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall _PivotSelect( 
            /* [in] */ BSTR Name,
            /* [defaultvalue][optional][in] */ XlPTSelectionMode Mode = xlDataAndLabel) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PivotSelection( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PivotSelection( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SelectionMode( 
            /* [retval][out] */ XlPTSelectionMode *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_SelectionMode( 
            /* [in] */ XlPTSelectionMode RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_TableStyle( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_TableStyle( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Tag( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Tag( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Update( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_VacatedStyle( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_VacatedStyle( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall Format( 
            /* [in] */ XlPivotFormatType Format) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PrintTitles( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PrintTitles( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CubeFields( 
            /* [retval][out] */ CubeFields **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_GrandTotalName( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_GrandTotalName( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SmallGrid( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_SmallGrid( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RepeatItemsOnEachPrintedPage( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_RepeatItemsOnEachPrintedPage( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TotalsAnnotation( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_TotalsAnnotation( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall PivotSelect( 
            /* [in] */ BSTR Name,
            /* [defaultvalue][optional][in] */ XlPTSelectionMode Mode,
            /* [optional][in] */ VARIANT UseStandardName) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PivotSelectionStandard( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PivotSelectionStandard( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall GetPivotData( 
            /* [optional][in] */ VARIANT DataField,
            /* [optional][in] */ VARIANT Field1,
            /* [optional][in] */ VARIANT Item1,
            /* [optional][in] */ VARIANT Field2,
            /* [optional][in] */ VARIANT Item2,
            /* [optional][in] */ VARIANT Field3,
            /* [optional][in] */ VARIANT Item3,
            /* [optional][in] */ VARIANT Field4,
            /* [optional][in] */ VARIANT Item4,
            /* [optional][in] */ VARIANT Field5,
            /* [optional][in] */ VARIANT Item5,
            /* [optional][in] */ VARIANT Field6,
            /* [optional][in] */ VARIANT Item6,
            /* [optional][in] */ VARIANT Field7,
            /* [optional][in] */ VARIANT Item7,
            /* [optional][in] */ VARIANT Field8,
            /* [optional][in] */ VARIANT Item8,
            /* [optional][in] */ VARIANT Field9,
            /* [optional][in] */ VARIANT Item9,
            /* [optional][in] */ VARIANT Field10,
            /* [optional][in] */ VARIANT Item10,
            /* [optional][in] */ VARIANT Field11,
            /* [optional][in] */ VARIANT Item11,
            /* [optional][in] */ VARIANT Field12,
            /* [optional][in] */ VARIANT Item12,
            /* [optional][in] */ VARIANT Field13,
            /* [optional][in] */ VARIANT Item13,
            /* [optional][in] */ VARIANT Field14,
            /* [optional][in] */ VARIANT Item14,
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DataPivotField( 
            /* [retval][out] */ PivotField	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_EnableDataValueEditing( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_EnableDataValueEditing( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall AddDataField( 
            /* [in] */ IDispatch *Field,
            /* [optional][in] */ VARIANT Caption,
            /* [optional][in] */ VARIANT Function,
            /* [retval][out] */ PivotField	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MDX( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ViewCalculatedMembers( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ViewCalculatedMembers( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CalculatedMembers( 
            /* [retval][out] */ CalculatedMembers	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DisplayImmediateItems( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DisplayImmediateItems( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall Dummy15( 
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_EnableFieldList( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_EnableFieldList( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_VisualTotals( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_VisualTotals( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShowPageMultipleItemLabel( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ShowPageMultipleItemLabel( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Version( 
            /* [retval][out] */ XlPivotTableVersionList *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CreateCubeFile( 
            /* [in] */ BSTR File,
            /* [optional][in] */ VARIANT Measures,
            /* [optional][in] */ VARIANT Levels,
            /* [optional][in] */ VARIANT Members,
            /* [optional][in] */ VARIANT Properties,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DisplayEmptyRow( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DisplayEmptyRow( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DisplayEmptyColumn( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DisplayEmptyColumn( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_ShowCellBackgroundFromOLAP( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_ShowCellBackgroundFromOLAP( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PivotColumnAxis( 
            /* [retval][out] */ PivotAxis	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PivotRowAxis( 
            /* [retval][out] */ PivotAxis	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShowDrillIndicators( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ShowDrillIndicators( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PrintDrillIndicators( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PrintDrillIndicators( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DisplayMemberPropertyTooltips( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DisplayMemberPropertyTooltips( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DisplayContextTooltips( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DisplayContextTooltips( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ClearTable( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CompactRowIndent( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_CompactRowIndent( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LayoutRowDefault( 
            /* [retval][out] */ XlLayoutRowType *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_LayoutRowDefault( 
            /* [in] */ XlLayoutRowType RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DisplayFieldCaptions( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DisplayFieldCaptions( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall RowAxisLayout( 
            /* [in] */ XlLayoutRowType RowLayout) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SubtotalLocation( 
            /* [in] */ XlSubtototalLocationType Location) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ActiveFilters( 
            /* [retval][out] */ PivotFilters	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_InGridDropZones( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_InGridDropZones( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ClearAllFilters( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TableStyle2( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_TableStyle2( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShowTableStyleLastColumn( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ShowTableStyleLastColumn( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShowTableStyleRowStripes( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ShowTableStyleRowStripes( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShowTableStyleColumnStripes( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ShowTableStyleColumnStripes( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShowTableStyleRowHeaders( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ShowTableStyleRowHeaders( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShowTableStyleColumnHeaders( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ShowTableStyleColumnHeaders( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ConvertToFormulas( 
            /* [in] */ VARIANT_BOOL ConvertFilters) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AllowMultipleFilters( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AllowMultipleFilters( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CompactLayoutRowHeader( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_CompactLayoutRowHeader( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CompactLayoutColumnHeader( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_CompactLayoutColumnHeader( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_FieldListSortAscending( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_FieldListSortAscending( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SortUsingCustomLists( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_SortUsingCustomLists( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ChangeConnection( 
            /* [in] */ WorkbookConnection	*conn) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ChangePivotCache( 
            /* [in] */ VARIANT PivotCache) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Location( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Location( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_EnableWriteback( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_EnableWriteback( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Allocation( 
            /* [retval][out] */ XlAllocation *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Allocation( 
            /* [in] */ XlAllocation RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AllocationValue( 
            /* [retval][out] */ XlAllocationValue *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AllocationValue( 
            /* [in] */ XlAllocationValue RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AllocationMethod( 
            /* [retval][out] */ XlAllocationMethod *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AllocationMethod( 
            /* [in] */ XlAllocationMethod RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AllocationWeightExpression( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AllocationWeightExpression( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall AllocateChanges( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CommitChanges( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall DiscardChanges( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall RefreshDataSourceValues( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall RepeatAllLabels( 
            /* [in] */ XlPivotFieldRepeatLabels Repeat) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ChangeList( 
            /* [retval][out] */ PivotTableChangeList	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Slicers( 
            /* [retval][out] */ Slicers	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AlternativeText( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AlternativeText( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Summary( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Summary( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_VisualTotalsForSets( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_VisualTotalsForSets( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShowValuesRow( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ShowValuesRow( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CalculatedMembersInFilters( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_CalculatedMembersInFilters( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall PivotValueCell( 
            /* [optional][in] */ VARIANT rowline,
            /* [optional][in] */ VARIANT columnline,
            /* [retval][out] */ PivotValueCell	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Hidden( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PivotChart( 
            /* [retval][out] */ Shape	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall DrillDown( 
            /* [in] */ PivotItem	*PivotItem,
            /* [optional][in] */ VARIANT PivotLine) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall DrillUp( 
            /* [in] */ PivotItem	*PivotItem,
            /* [optional][in] */ VARIANT PivotLine,
            /* [optional][in] */ VARIANT LevelUniqueName) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall DrillTo( 
            /* [in] */ PivotItem	*PivotItem,
            /* [in] */ CubeField *CubeField,
            /* [optional][in] */ VARIANT PivotLine) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall Dummy2( 
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IPivotTableVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IPivotTable * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IPivotTable * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IPivotTable * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IPivotTable * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IPivotTable * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IPivotTable * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IPivotTable * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IPivotTable * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IPivotTable * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IPivotTable * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *AddFields )( 
            IPivotTable * This,
            /* [optional][in] */ VARIANT RowFields,
            /* [optional][in] */ VARIANT ColumnFields,
            /* [optional][in] */ VARIANT PageFields,
            /* [optional][in] */ VARIANT AddToTable,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ColumnFields )( 
            IPivotTable * This,
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ColumnGrand )( 
            IPivotTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ColumnGrand )( 
            IPivotTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ColumnRange )( 
            IPivotTable * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ShowPages )( 
            IPivotTable * This,
            /* [optional][in] */ VARIANT PageField,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DataBodyRange )( 
            IPivotTable * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DataFields )( 
            IPivotTable * This,
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DataLabelRange )( 
            IPivotTable * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IPivotTable * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put__Default )( 
            IPivotTable * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HasAutoFormat )( 
            IPivotTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_HasAutoFormat )( 
            IPivotTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HiddenFields )( 
            IPivotTable * This,
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_InnerDetail )( 
            IPivotTable * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_InnerDetail )( 
            IPivotTable * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            IPivotTable * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Name )( 
            IPivotTable * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PageFields )( 
            IPivotTable * This,
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PageRange )( 
            IPivotTable * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PageRangeCells )( 
            IPivotTable * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *PivotFields )( 
            IPivotTable * This,
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RefreshDate )( 
            IPivotTable * This,
            /* [retval][out] */ DATE *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RefreshName )( 
            IPivotTable * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *RefreshTable )( 
            IPivotTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RowFields )( 
            IPivotTable * This,
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RowGrand )( 
            IPivotTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_RowGrand )( 
            IPivotTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RowRange )( 
            IPivotTable * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SaveData )( 
            IPivotTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_SaveData )( 
            IPivotTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SourceData )( 
            IPivotTable * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_SourceData )( 
            IPivotTable * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TableRange1 )( 
            IPivotTable * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TableRange2 )( 
            IPivotTable * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Value )( 
            IPivotTable * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Value )( 
            IPivotTable * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_VisibleFields )( 
            IPivotTable * This,
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CacheIndex )( 
            IPivotTable * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_CacheIndex )( 
            IPivotTable * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CalculatedFields )( 
            IPivotTable * This,
            /* [retval][out] */ CalculatedFields	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DisplayErrorString )( 
            IPivotTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DisplayErrorString )( 
            IPivotTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DisplayNullString )( 
            IPivotTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DisplayNullString )( 
            IPivotTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_EnableDrilldown )( 
            IPivotTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_EnableDrilldown )( 
            IPivotTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_EnableFieldDialog )( 
            IPivotTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_EnableFieldDialog )( 
            IPivotTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_EnableWizard )( 
            IPivotTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_EnableWizard )( 
            IPivotTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ErrorString )( 
            IPivotTable * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ErrorString )( 
            IPivotTable * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *GetData )( 
            IPivotTable * This,
            /* [in] */ BSTR Name,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ListFormulas )( 
            IPivotTable * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ManualUpdate )( 
            IPivotTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ManualUpdate )( 
            IPivotTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MergeLabels )( 
            IPivotTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_MergeLabels )( 
            IPivotTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_NullString )( 
            IPivotTable * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_NullString )( 
            IPivotTable * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *PivotCache )( 
            IPivotTable * This,
            /* [retval][out] */ PivotCache	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PivotFormulas )( 
            IPivotTable * This,
            /* [retval][out] */ PivotFormulas	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *PivotTableWizard )( 
            IPivotTable * This,
            /* [optional][in] */ VARIANT SourceType,
            /* [optional][in] */ VARIANT SourceData,
            /* [optional][in] */ VARIANT TableDestination,
            /* [optional][in] */ VARIANT TableName,
            /* [optional][in] */ VARIANT RowGrand,
            /* [optional][in] */ VARIANT ColumnGrand,
            /* [optional][in] */ VARIANT SaveData,
            /* [optional][in] */ VARIANT HasAutoFormat,
            /* [optional][in] */ VARIANT AutoPage,
            /* [optional][in] */ VARIANT Reserved,
            /* [optional][in] */ VARIANT BackgroundQuery,
            /* [optional][in] */ VARIANT OptimizeCache,
            /* [optional][in] */ VARIANT PageFieldOrder,
            /* [optional][in] */ VARIANT PageFieldWrapCount,
            /* [optional][in] */ VARIANT ReadData,
            /* [optional][in] */ VARIANT Connection);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SubtotalHiddenPageItems )( 
            IPivotTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_SubtotalHiddenPageItems )( 
            IPivotTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PageFieldOrder )( 
            IPivotTable * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PageFieldOrder )( 
            IPivotTable * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PageFieldStyle )( 
            IPivotTable * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PageFieldStyle )( 
            IPivotTable * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PageFieldWrapCount )( 
            IPivotTable * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PageFieldWrapCount )( 
            IPivotTable * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PreserveFormatting )( 
            IPivotTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PreserveFormatting )( 
            IPivotTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *_PivotSelect )( 
            IPivotTable * This,
            /* [in] */ BSTR Name,
            /* [defaultvalue][optional][in] */ XlPTSelectionMode Mode);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PivotSelection )( 
            IPivotTable * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PivotSelection )( 
            IPivotTable * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SelectionMode )( 
            IPivotTable * This,
            /* [retval][out] */ XlPTSelectionMode *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_SelectionMode )( 
            IPivotTable * This,
            /* [in] */ XlPTSelectionMode RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_TableStyle )( 
            IPivotTable * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_TableStyle )( 
            IPivotTable * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Tag )( 
            IPivotTable * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Tag )( 
            IPivotTable * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Update )( 
            IPivotTable * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_VacatedStyle )( 
            IPivotTable * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_VacatedStyle )( 
            IPivotTable * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *Format )( 
            IPivotTable * This,
            /* [in] */ XlPivotFormatType Format);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PrintTitles )( 
            IPivotTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PrintTitles )( 
            IPivotTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CubeFields )( 
            IPivotTable * This,
            /* [retval][out] */ CubeFields **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_GrandTotalName )( 
            IPivotTable * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_GrandTotalName )( 
            IPivotTable * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SmallGrid )( 
            IPivotTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_SmallGrid )( 
            IPivotTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RepeatItemsOnEachPrintedPage )( 
            IPivotTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_RepeatItemsOnEachPrintedPage )( 
            IPivotTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TotalsAnnotation )( 
            IPivotTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_TotalsAnnotation )( 
            IPivotTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *PivotSelect )( 
            IPivotTable * This,
            /* [in] */ BSTR Name,
            /* [defaultvalue][optional][in] */ XlPTSelectionMode Mode,
            /* [optional][in] */ VARIANT UseStandardName);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PivotSelectionStandard )( 
            IPivotTable * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PivotSelectionStandard )( 
            IPivotTable * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *GetPivotData )( 
            IPivotTable * This,
            /* [optional][in] */ VARIANT DataField,
            /* [optional][in] */ VARIANT Field1,
            /* [optional][in] */ VARIANT Item1,
            /* [optional][in] */ VARIANT Field2,
            /* [optional][in] */ VARIANT Item2,
            /* [optional][in] */ VARIANT Field3,
            /* [optional][in] */ VARIANT Item3,
            /* [optional][in] */ VARIANT Field4,
            /* [optional][in] */ VARIANT Item4,
            /* [optional][in] */ VARIANT Field5,
            /* [optional][in] */ VARIANT Item5,
            /* [optional][in] */ VARIANT Field6,
            /* [optional][in] */ VARIANT Item6,
            /* [optional][in] */ VARIANT Field7,
            /* [optional][in] */ VARIANT Item7,
            /* [optional][in] */ VARIANT Field8,
            /* [optional][in] */ VARIANT Item8,
            /* [optional][in] */ VARIANT Field9,
            /* [optional][in] */ VARIANT Item9,
            /* [optional][in] */ VARIANT Field10,
            /* [optional][in] */ VARIANT Item10,
            /* [optional][in] */ VARIANT Field11,
            /* [optional][in] */ VARIANT Item11,
            /* [optional][in] */ VARIANT Field12,
            /* [optional][in] */ VARIANT Item12,
            /* [optional][in] */ VARIANT Field13,
            /* [optional][in] */ VARIANT Item13,
            /* [optional][in] */ VARIANT Field14,
            /* [optional][in] */ VARIANT Item14,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DataPivotField )( 
            IPivotTable * This,
            /* [retval][out] */ PivotField	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_EnableDataValueEditing )( 
            IPivotTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_EnableDataValueEditing )( 
            IPivotTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *AddDataField )( 
            IPivotTable * This,
            /* [in] */ IDispatch *Field,
            /* [optional][in] */ VARIANT Caption,
            /* [optional][in] */ VARIANT Function,
            /* [retval][out] */ PivotField	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MDX )( 
            IPivotTable * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ViewCalculatedMembers )( 
            IPivotTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ViewCalculatedMembers )( 
            IPivotTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CalculatedMembers )( 
            IPivotTable * This,
            /* [retval][out] */ CalculatedMembers	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DisplayImmediateItems )( 
            IPivotTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DisplayImmediateItems )( 
            IPivotTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *Dummy15 )( 
            IPivotTable * This,
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_EnableFieldList )( 
            IPivotTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_EnableFieldList )( 
            IPivotTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_VisualTotals )( 
            IPivotTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_VisualTotals )( 
            IPivotTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShowPageMultipleItemLabel )( 
            IPivotTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ShowPageMultipleItemLabel )( 
            IPivotTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Version )( 
            IPivotTable * This,
            /* [retval][out] */ XlPivotTableVersionList *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CreateCubeFile )( 
            IPivotTable * This,
            /* [in] */ BSTR File,
            /* [optional][in] */ VARIANT Measures,
            /* [optional][in] */ VARIANT Levels,
            /* [optional][in] */ VARIANT Members,
            /* [optional][in] */ VARIANT Properties,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DisplayEmptyRow )( 
            IPivotTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DisplayEmptyRow )( 
            IPivotTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DisplayEmptyColumn )( 
            IPivotTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DisplayEmptyColumn )( 
            IPivotTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_ShowCellBackgroundFromOLAP )( 
            IPivotTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_ShowCellBackgroundFromOLAP )( 
            IPivotTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PivotColumnAxis )( 
            IPivotTable * This,
            /* [retval][out] */ PivotAxis	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PivotRowAxis )( 
            IPivotTable * This,
            /* [retval][out] */ PivotAxis	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShowDrillIndicators )( 
            IPivotTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ShowDrillIndicators )( 
            IPivotTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PrintDrillIndicators )( 
            IPivotTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PrintDrillIndicators )( 
            IPivotTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DisplayMemberPropertyTooltips )( 
            IPivotTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DisplayMemberPropertyTooltips )( 
            IPivotTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DisplayContextTooltips )( 
            IPivotTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DisplayContextTooltips )( 
            IPivotTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ClearTable )( 
            IPivotTable * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CompactRowIndent )( 
            IPivotTable * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_CompactRowIndent )( 
            IPivotTable * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LayoutRowDefault )( 
            IPivotTable * This,
            /* [retval][out] */ XlLayoutRowType *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_LayoutRowDefault )( 
            IPivotTable * This,
            /* [in] */ XlLayoutRowType RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DisplayFieldCaptions )( 
            IPivotTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DisplayFieldCaptions )( 
            IPivotTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *RowAxisLayout )( 
            IPivotTable * This,
            /* [in] */ XlLayoutRowType RowLayout);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SubtotalLocation )( 
            IPivotTable * This,
            /* [in] */ XlSubtototalLocationType Location);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ActiveFilters )( 
            IPivotTable * This,
            /* [retval][out] */ PivotFilters	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_InGridDropZones )( 
            IPivotTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_InGridDropZones )( 
            IPivotTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ClearAllFilters )( 
            IPivotTable * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TableStyle2 )( 
            IPivotTable * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_TableStyle2 )( 
            IPivotTable * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShowTableStyleLastColumn )( 
            IPivotTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ShowTableStyleLastColumn )( 
            IPivotTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShowTableStyleRowStripes )( 
            IPivotTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ShowTableStyleRowStripes )( 
            IPivotTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShowTableStyleColumnStripes )( 
            IPivotTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ShowTableStyleColumnStripes )( 
            IPivotTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShowTableStyleRowHeaders )( 
            IPivotTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ShowTableStyleRowHeaders )( 
            IPivotTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShowTableStyleColumnHeaders )( 
            IPivotTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ShowTableStyleColumnHeaders )( 
            IPivotTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ConvertToFormulas )( 
            IPivotTable * This,
            /* [in] */ VARIANT_BOOL ConvertFilters);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AllowMultipleFilters )( 
            IPivotTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AllowMultipleFilters )( 
            IPivotTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CompactLayoutRowHeader )( 
            IPivotTable * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_CompactLayoutRowHeader )( 
            IPivotTable * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CompactLayoutColumnHeader )( 
            IPivotTable * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_CompactLayoutColumnHeader )( 
            IPivotTable * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_FieldListSortAscending )( 
            IPivotTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_FieldListSortAscending )( 
            IPivotTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SortUsingCustomLists )( 
            IPivotTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_SortUsingCustomLists )( 
            IPivotTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ChangeConnection )( 
            IPivotTable * This,
            /* [in] */ WorkbookConnection	*conn);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ChangePivotCache )( 
            IPivotTable * This,
            /* [in] */ VARIANT PivotCache);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Location )( 
            IPivotTable * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Location )( 
            IPivotTable * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_EnableWriteback )( 
            IPivotTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_EnableWriteback )( 
            IPivotTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Allocation )( 
            IPivotTable * This,
            /* [retval][out] */ XlAllocation *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Allocation )( 
            IPivotTable * This,
            /* [in] */ XlAllocation RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AllocationValue )( 
            IPivotTable * This,
            /* [retval][out] */ XlAllocationValue *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AllocationValue )( 
            IPivotTable * This,
            /* [in] */ XlAllocationValue RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AllocationMethod )( 
            IPivotTable * This,
            /* [retval][out] */ XlAllocationMethod *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AllocationMethod )( 
            IPivotTable * This,
            /* [in] */ XlAllocationMethod RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AllocationWeightExpression )( 
            IPivotTable * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AllocationWeightExpression )( 
            IPivotTable * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *AllocateChanges )( 
            IPivotTable * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CommitChanges )( 
            IPivotTable * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *DiscardChanges )( 
            IPivotTable * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *RefreshDataSourceValues )( 
            IPivotTable * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *RepeatAllLabels )( 
            IPivotTable * This,
            /* [in] */ XlPivotFieldRepeatLabels Repeat);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ChangeList )( 
            IPivotTable * This,
            /* [retval][out] */ PivotTableChangeList	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Slicers )( 
            IPivotTable * This,
            /* [retval][out] */ Slicers	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AlternativeText )( 
            IPivotTable * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AlternativeText )( 
            IPivotTable * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Summary )( 
            IPivotTable * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Summary )( 
            IPivotTable * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_VisualTotalsForSets )( 
            IPivotTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_VisualTotalsForSets )( 
            IPivotTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShowValuesRow )( 
            IPivotTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ShowValuesRow )( 
            IPivotTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CalculatedMembersInFilters )( 
            IPivotTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_CalculatedMembersInFilters )( 
            IPivotTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *PivotValueCell )( 
            IPivotTable * This,
            /* [optional][in] */ VARIANT rowline,
            /* [optional][in] */ VARIANT columnline,
            /* [retval][out] */ PivotValueCell	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Hidden )( 
            IPivotTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PivotChart )( 
            IPivotTable * This,
            /* [retval][out] */ Shape	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *DrillDown )( 
            IPivotTable * This,
            /* [in] */ PivotItem	*PivotItem,
            /* [optional][in] */ VARIANT PivotLine);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *DrillUp )( 
            IPivotTable * This,
            /* [in] */ PivotItem	*PivotItem,
            /* [optional][in] */ VARIANT PivotLine,
            /* [optional][in] */ VARIANT LevelUniqueName);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *DrillTo )( 
            IPivotTable * This,
            /* [in] */ PivotItem	*PivotItem,
            /* [in] */ CubeField *CubeField,
            /* [optional][in] */ VARIANT PivotLine);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *Dummy2 )( 
            IPivotTable * This,
            /* [in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [retval][out] */ VARIANT *RHS);
        
        END_INTERFACE
    } IPivotTableVtbl;

    interface IPivotTable
    {
        CONST_VTBL struct IPivotTableVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IPivotTable_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IPivotTable_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IPivotTable_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IPivotTable_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IPivotTable_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IPivotTable_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IPivotTable_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IPivotTable_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IPivotTable_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IPivotTable_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IPivotTable_AddFields(This,RowFields,ColumnFields,PageFields,AddToTable,RHS)	\
    ( (This)->lpVtbl -> AddFields(This,RowFields,ColumnFields,PageFields,AddToTable,RHS) ) 

#define IPivotTable_get_ColumnFields(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_ColumnFields(This,Index,RHS) ) 

#define IPivotTable_get_ColumnGrand(This,RHS)	\
    ( (This)->lpVtbl -> get_ColumnGrand(This,RHS) ) 

#define IPivotTable_put_ColumnGrand(This,RHS)	\
    ( (This)->lpVtbl -> put_ColumnGrand(This,RHS) ) 

#define IPivotTable_get_ColumnRange(This,RHS)	\
    ( (This)->lpVtbl -> get_ColumnRange(This,RHS) ) 

#define IPivotTable_ShowPages(This,PageField,RHS)	\
    ( (This)->lpVtbl -> ShowPages(This,PageField,RHS) ) 

#define IPivotTable_get_DataBodyRange(This,RHS)	\
    ( (This)->lpVtbl -> get_DataBodyRange(This,RHS) ) 

#define IPivotTable_get_DataFields(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_DataFields(This,Index,RHS) ) 

#define IPivotTable_get_DataLabelRange(This,RHS)	\
    ( (This)->lpVtbl -> get_DataLabelRange(This,RHS) ) 

#define IPivotTable_get__Default(This,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,RHS) ) 

#define IPivotTable_put__Default(This,RHS)	\
    ( (This)->lpVtbl -> put__Default(This,RHS) ) 

#define IPivotTable_get_HasAutoFormat(This,RHS)	\
    ( (This)->lpVtbl -> get_HasAutoFormat(This,RHS) ) 

#define IPivotTable_put_HasAutoFormat(This,RHS)	\
    ( (This)->lpVtbl -> put_HasAutoFormat(This,RHS) ) 

#define IPivotTable_get_HiddenFields(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_HiddenFields(This,Index,RHS) ) 

#define IPivotTable_get_InnerDetail(This,RHS)	\
    ( (This)->lpVtbl -> get_InnerDetail(This,RHS) ) 

#define IPivotTable_put_InnerDetail(This,RHS)	\
    ( (This)->lpVtbl -> put_InnerDetail(This,RHS) ) 

#define IPivotTable_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define IPivotTable_put_Name(This,RHS)	\
    ( (This)->lpVtbl -> put_Name(This,RHS) ) 

#define IPivotTable_get_PageFields(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_PageFields(This,Index,RHS) ) 

#define IPivotTable_get_PageRange(This,RHS)	\
    ( (This)->lpVtbl -> get_PageRange(This,RHS) ) 

#define IPivotTable_get_PageRangeCells(This,RHS)	\
    ( (This)->lpVtbl -> get_PageRangeCells(This,RHS) ) 

#define IPivotTable_PivotFields(This,Index,RHS)	\
    ( (This)->lpVtbl -> PivotFields(This,Index,RHS) ) 

#define IPivotTable_get_RefreshDate(This,RHS)	\
    ( (This)->lpVtbl -> get_RefreshDate(This,RHS) ) 

#define IPivotTable_get_RefreshName(This,RHS)	\
    ( (This)->lpVtbl -> get_RefreshName(This,RHS) ) 

#define IPivotTable_RefreshTable(This,RHS)	\
    ( (This)->lpVtbl -> RefreshTable(This,RHS) ) 

#define IPivotTable_get_RowFields(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_RowFields(This,Index,RHS) ) 

#define IPivotTable_get_RowGrand(This,RHS)	\
    ( (This)->lpVtbl -> get_RowGrand(This,RHS) ) 

#define IPivotTable_put_RowGrand(This,RHS)	\
    ( (This)->lpVtbl -> put_RowGrand(This,RHS) ) 

#define IPivotTable_get_RowRange(This,RHS)	\
    ( (This)->lpVtbl -> get_RowRange(This,RHS) ) 

#define IPivotTable_get_SaveData(This,RHS)	\
    ( (This)->lpVtbl -> get_SaveData(This,RHS) ) 

#define IPivotTable_put_SaveData(This,RHS)	\
    ( (This)->lpVtbl -> put_SaveData(This,RHS) ) 

#define IPivotTable_get_SourceData(This,RHS)	\
    ( (This)->lpVtbl -> get_SourceData(This,RHS) ) 

#define IPivotTable_put_SourceData(This,RHS)	\
    ( (This)->lpVtbl -> put_SourceData(This,RHS) ) 

#define IPivotTable_get_TableRange1(This,RHS)	\
    ( (This)->lpVtbl -> get_TableRange1(This,RHS) ) 

#define IPivotTable_get_TableRange2(This,RHS)	\
    ( (This)->lpVtbl -> get_TableRange2(This,RHS) ) 

#define IPivotTable_get_Value(This,RHS)	\
    ( (This)->lpVtbl -> get_Value(This,RHS) ) 

#define IPivotTable_put_Value(This,RHS)	\
    ( (This)->lpVtbl -> put_Value(This,RHS) ) 

#define IPivotTable_get_VisibleFields(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_VisibleFields(This,Index,RHS) ) 

#define IPivotTable_get_CacheIndex(This,RHS)	\
    ( (This)->lpVtbl -> get_CacheIndex(This,RHS) ) 

#define IPivotTable_put_CacheIndex(This,RHS)	\
    ( (This)->lpVtbl -> put_CacheIndex(This,RHS) ) 

#define IPivotTable_CalculatedFields(This,RHS)	\
    ( (This)->lpVtbl -> CalculatedFields(This,RHS) ) 

#define IPivotTable_get_DisplayErrorString(This,RHS)	\
    ( (This)->lpVtbl -> get_DisplayErrorString(This,RHS) ) 

#define IPivotTable_put_DisplayErrorString(This,RHS)	\
    ( (This)->lpVtbl -> put_DisplayErrorString(This,RHS) ) 

#define IPivotTable_get_DisplayNullString(This,RHS)	\
    ( (This)->lpVtbl -> get_DisplayNullString(This,RHS) ) 

#define IPivotTable_put_DisplayNullString(This,RHS)	\
    ( (This)->lpVtbl -> put_DisplayNullString(This,RHS) ) 

#define IPivotTable_get_EnableDrilldown(This,RHS)	\
    ( (This)->lpVtbl -> get_EnableDrilldown(This,RHS) ) 

#define IPivotTable_put_EnableDrilldown(This,RHS)	\
    ( (This)->lpVtbl -> put_EnableDrilldown(This,RHS) ) 

#define IPivotTable_get_EnableFieldDialog(This,RHS)	\
    ( (This)->lpVtbl -> get_EnableFieldDialog(This,RHS) ) 

#define IPivotTable_put_EnableFieldDialog(This,RHS)	\
    ( (This)->lpVtbl -> put_EnableFieldDialog(This,RHS) ) 

#define IPivotTable_get_EnableWizard(This,RHS)	\
    ( (This)->lpVtbl -> get_EnableWizard(This,RHS) ) 

#define IPivotTable_put_EnableWizard(This,RHS)	\
    ( (This)->lpVtbl -> put_EnableWizard(This,RHS) ) 

#define IPivotTable_get_ErrorString(This,RHS)	\
    ( (This)->lpVtbl -> get_ErrorString(This,RHS) ) 

#define IPivotTable_put_ErrorString(This,RHS)	\
    ( (This)->lpVtbl -> put_ErrorString(This,RHS) ) 

#define IPivotTable_GetData(This,Name,RHS)	\
    ( (This)->lpVtbl -> GetData(This,Name,RHS) ) 

#define IPivotTable_ListFormulas(This)	\
    ( (This)->lpVtbl -> ListFormulas(This) ) 

#define IPivotTable_get_ManualUpdate(This,RHS)	\
    ( (This)->lpVtbl -> get_ManualUpdate(This,RHS) ) 

#define IPivotTable_put_ManualUpdate(This,RHS)	\
    ( (This)->lpVtbl -> put_ManualUpdate(This,RHS) ) 

#define IPivotTable_get_MergeLabels(This,RHS)	\
    ( (This)->lpVtbl -> get_MergeLabels(This,RHS) ) 

#define IPivotTable_put_MergeLabels(This,RHS)	\
    ( (This)->lpVtbl -> put_MergeLabels(This,RHS) ) 

#define IPivotTable_get_NullString(This,RHS)	\
    ( (This)->lpVtbl -> get_NullString(This,RHS) ) 

#define IPivotTable_put_NullString(This,RHS)	\
    ( (This)->lpVtbl -> put_NullString(This,RHS) ) 

#define IPivotTable_PivotCache(This,RHS)	\
    ( (This)->lpVtbl -> PivotCache(This,RHS) ) 

#define IPivotTable_get_PivotFormulas(This,RHS)	\
    ( (This)->lpVtbl -> get_PivotFormulas(This,RHS) ) 

#define IPivotTable_PivotTableWizard(This,SourceType,SourceData,TableDestination,TableName,RowGrand,ColumnGrand,SaveData,HasAutoFormat,AutoPage,Reserved,BackgroundQuery,OptimizeCache,PageFieldOrder,PageFieldWrapCount,ReadData,Connection)	\
    ( (This)->lpVtbl -> PivotTableWizard(This,SourceType,SourceData,TableDestination,TableName,RowGrand,ColumnGrand,SaveData,HasAutoFormat,AutoPage,Reserved,BackgroundQuery,OptimizeCache,PageFieldOrder,PageFieldWrapCount,ReadData,Connection) ) 

#define IPivotTable_get_SubtotalHiddenPageItems(This,RHS)	\
    ( (This)->lpVtbl -> get_SubtotalHiddenPageItems(This,RHS) ) 

#define IPivotTable_put_SubtotalHiddenPageItems(This,RHS)	\
    ( (This)->lpVtbl -> put_SubtotalHiddenPageItems(This,RHS) ) 

#define IPivotTable_get_PageFieldOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_PageFieldOrder(This,RHS) ) 

#define IPivotTable_put_PageFieldOrder(This,RHS)	\
    ( (This)->lpVtbl -> put_PageFieldOrder(This,RHS) ) 

#define IPivotTable_get_PageFieldStyle(This,RHS)	\
    ( (This)->lpVtbl -> get_PageFieldStyle(This,RHS) ) 

#define IPivotTable_put_PageFieldStyle(This,RHS)	\
    ( (This)->lpVtbl -> put_PageFieldStyle(This,RHS) ) 

#define IPivotTable_get_PageFieldWrapCount(This,RHS)	\
    ( (This)->lpVtbl -> get_PageFieldWrapCount(This,RHS) ) 

#define IPivotTable_put_PageFieldWrapCount(This,RHS)	\
    ( (This)->lpVtbl -> put_PageFieldWrapCount(This,RHS) ) 

#define IPivotTable_get_PreserveFormatting(This,RHS)	\
    ( (This)->lpVtbl -> get_PreserveFormatting(This,RHS) ) 

#define IPivotTable_put_PreserveFormatting(This,RHS)	\
    ( (This)->lpVtbl -> put_PreserveFormatting(This,RHS) ) 

#define IPivotTable__PivotSelect(This,Name,Mode)	\
    ( (This)->lpVtbl -> _PivotSelect(This,Name,Mode) ) 

#define IPivotTable_get_PivotSelection(This,RHS)	\
    ( (This)->lpVtbl -> get_PivotSelection(This,RHS) ) 

#define IPivotTable_put_PivotSelection(This,RHS)	\
    ( (This)->lpVtbl -> put_PivotSelection(This,RHS) ) 

#define IPivotTable_get_SelectionMode(This,RHS)	\
    ( (This)->lpVtbl -> get_SelectionMode(This,RHS) ) 

#define IPivotTable_put_SelectionMode(This,RHS)	\
    ( (This)->lpVtbl -> put_SelectionMode(This,RHS) ) 

#define IPivotTable_get_TableStyle(This,RHS)	\
    ( (This)->lpVtbl -> get_TableStyle(This,RHS) ) 

#define IPivotTable_put_TableStyle(This,RHS)	\
    ( (This)->lpVtbl -> put_TableStyle(This,RHS) ) 

#define IPivotTable_get_Tag(This,RHS)	\
    ( (This)->lpVtbl -> get_Tag(This,RHS) ) 

#define IPivotTable_put_Tag(This,RHS)	\
    ( (This)->lpVtbl -> put_Tag(This,RHS) ) 

#define IPivotTable_Update(This)	\
    ( (This)->lpVtbl -> Update(This) ) 

#define IPivotTable_get_VacatedStyle(This,RHS)	\
    ( (This)->lpVtbl -> get_VacatedStyle(This,RHS) ) 

#define IPivotTable_put_VacatedStyle(This,RHS)	\
    ( (This)->lpVtbl -> put_VacatedStyle(This,RHS) ) 

#define IPivotTable_Format(This,Format)	\
    ( (This)->lpVtbl -> Format(This,Format) ) 

#define IPivotTable_get_PrintTitles(This,RHS)	\
    ( (This)->lpVtbl -> get_PrintTitles(This,RHS) ) 

#define IPivotTable_put_PrintTitles(This,RHS)	\
    ( (This)->lpVtbl -> put_PrintTitles(This,RHS) ) 

#define IPivotTable_get_CubeFields(This,RHS)	\
    ( (This)->lpVtbl -> get_CubeFields(This,RHS) ) 

#define IPivotTable_get_GrandTotalName(This,RHS)	\
    ( (This)->lpVtbl -> get_GrandTotalName(This,RHS) ) 

#define IPivotTable_put_GrandTotalName(This,RHS)	\
    ( (This)->lpVtbl -> put_GrandTotalName(This,RHS) ) 

#define IPivotTable_get_SmallGrid(This,RHS)	\
    ( (This)->lpVtbl -> get_SmallGrid(This,RHS) ) 

#define IPivotTable_put_SmallGrid(This,RHS)	\
    ( (This)->lpVtbl -> put_SmallGrid(This,RHS) ) 

#define IPivotTable_get_RepeatItemsOnEachPrintedPage(This,RHS)	\
    ( (This)->lpVtbl -> get_RepeatItemsOnEachPrintedPage(This,RHS) ) 

#define IPivotTable_put_RepeatItemsOnEachPrintedPage(This,RHS)	\
    ( (This)->lpVtbl -> put_RepeatItemsOnEachPrintedPage(This,RHS) ) 

#define IPivotTable_get_TotalsAnnotation(This,RHS)	\
    ( (This)->lpVtbl -> get_TotalsAnnotation(This,RHS) ) 

#define IPivotTable_put_TotalsAnnotation(This,RHS)	\
    ( (This)->lpVtbl -> put_TotalsAnnotation(This,RHS) ) 

#define IPivotTable_PivotSelect(This,Name,Mode,UseStandardName)	\
    ( (This)->lpVtbl -> PivotSelect(This,Name,Mode,UseStandardName) ) 

#define IPivotTable_get_PivotSelectionStandard(This,RHS)	\
    ( (This)->lpVtbl -> get_PivotSelectionStandard(This,RHS) ) 

#define IPivotTable_put_PivotSelectionStandard(This,RHS)	\
    ( (This)->lpVtbl -> put_PivotSelectionStandard(This,RHS) ) 

#define IPivotTable_GetPivotData(This,DataField,Field1,Item1,Field2,Item2,Field3,Item3,Field4,Item4,Field5,Item5,Field6,Item6,Field7,Item7,Field8,Item8,Field9,Item9,Field10,Item10,Field11,Item11,Field12,Item12,Field13,Item13,Field14,Item14,RHS)	\
    ( (This)->lpVtbl -> GetPivotData(This,DataField,Field1,Item1,Field2,Item2,Field3,Item3,Field4,Item4,Field5,Item5,Field6,Item6,Field7,Item7,Field8,Item8,Field9,Item9,Field10,Item10,Field11,Item11,Field12,Item12,Field13,Item13,Field14,Item14,RHS) ) 

#define IPivotTable_get_DataPivotField(This,RHS)	\
    ( (This)->lpVtbl -> get_DataPivotField(This,RHS) ) 

#define IPivotTable_get_EnableDataValueEditing(This,RHS)	\
    ( (This)->lpVtbl -> get_EnableDataValueEditing(This,RHS) ) 

#define IPivotTable_put_EnableDataValueEditing(This,RHS)	\
    ( (This)->lpVtbl -> put_EnableDataValueEditing(This,RHS) ) 

#define IPivotTable_AddDataField(This,Field,Caption,Function,RHS)	\
    ( (This)->lpVtbl -> AddDataField(This,Field,Caption,Function,RHS) ) 

#define IPivotTable_get_MDX(This,RHS)	\
    ( (This)->lpVtbl -> get_MDX(This,RHS) ) 

#define IPivotTable_get_ViewCalculatedMembers(This,RHS)	\
    ( (This)->lpVtbl -> get_ViewCalculatedMembers(This,RHS) ) 

#define IPivotTable_put_ViewCalculatedMembers(This,RHS)	\
    ( (This)->lpVtbl -> put_ViewCalculatedMembers(This,RHS) ) 

#define IPivotTable_get_CalculatedMembers(This,RHS)	\
    ( (This)->lpVtbl -> get_CalculatedMembers(This,RHS) ) 

#define IPivotTable_get_DisplayImmediateItems(This,RHS)	\
    ( (This)->lpVtbl -> get_DisplayImmediateItems(This,RHS) ) 

#define IPivotTable_put_DisplayImmediateItems(This,RHS)	\
    ( (This)->lpVtbl -> put_DisplayImmediateItems(This,RHS) ) 

#define IPivotTable_Dummy15(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS)	\
    ( (This)->lpVtbl -> Dummy15(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS) ) 

#define IPivotTable_get_EnableFieldList(This,RHS)	\
    ( (This)->lpVtbl -> get_EnableFieldList(This,RHS) ) 

#define IPivotTable_put_EnableFieldList(This,RHS)	\
    ( (This)->lpVtbl -> put_EnableFieldList(This,RHS) ) 

#define IPivotTable_get_VisualTotals(This,RHS)	\
    ( (This)->lpVtbl -> get_VisualTotals(This,RHS) ) 

#define IPivotTable_put_VisualTotals(This,RHS)	\
    ( (This)->lpVtbl -> put_VisualTotals(This,RHS) ) 

#define IPivotTable_get_ShowPageMultipleItemLabel(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowPageMultipleItemLabel(This,RHS) ) 

#define IPivotTable_put_ShowPageMultipleItemLabel(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowPageMultipleItemLabel(This,RHS) ) 

#define IPivotTable_get_Version(This,RHS)	\
    ( (This)->lpVtbl -> get_Version(This,RHS) ) 

#define IPivotTable_CreateCubeFile(This,File,Measures,Levels,Members,Properties,RHS)	\
    ( (This)->lpVtbl -> CreateCubeFile(This,File,Measures,Levels,Members,Properties,RHS) ) 

#define IPivotTable_get_DisplayEmptyRow(This,RHS)	\
    ( (This)->lpVtbl -> get_DisplayEmptyRow(This,RHS) ) 

#define IPivotTable_put_DisplayEmptyRow(This,RHS)	\
    ( (This)->lpVtbl -> put_DisplayEmptyRow(This,RHS) ) 

#define IPivotTable_get_DisplayEmptyColumn(This,RHS)	\
    ( (This)->lpVtbl -> get_DisplayEmptyColumn(This,RHS) ) 

#define IPivotTable_put_DisplayEmptyColumn(This,RHS)	\
    ( (This)->lpVtbl -> put_DisplayEmptyColumn(This,RHS) ) 

#define IPivotTable_get_ShowCellBackgroundFromOLAP(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowCellBackgroundFromOLAP(This,RHS) ) 

#define IPivotTable_put_ShowCellBackgroundFromOLAP(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowCellBackgroundFromOLAP(This,RHS) ) 

#define IPivotTable_get_PivotColumnAxis(This,RHS)	\
    ( (This)->lpVtbl -> get_PivotColumnAxis(This,RHS) ) 

#define IPivotTable_get_PivotRowAxis(This,RHS)	\
    ( (This)->lpVtbl -> get_PivotRowAxis(This,RHS) ) 

#define IPivotTable_get_ShowDrillIndicators(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowDrillIndicators(This,RHS) ) 

#define IPivotTable_put_ShowDrillIndicators(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowDrillIndicators(This,RHS) ) 

#define IPivotTable_get_PrintDrillIndicators(This,RHS)	\
    ( (This)->lpVtbl -> get_PrintDrillIndicators(This,RHS) ) 

#define IPivotTable_put_PrintDrillIndicators(This,RHS)	\
    ( (This)->lpVtbl -> put_PrintDrillIndicators(This,RHS) ) 

#define IPivotTable_get_DisplayMemberPropertyTooltips(This,RHS)	\
    ( (This)->lpVtbl -> get_DisplayMemberPropertyTooltips(This,RHS) ) 

#define IPivotTable_put_DisplayMemberPropertyTooltips(This,RHS)	\
    ( (This)->lpVtbl -> put_DisplayMemberPropertyTooltips(This,RHS) ) 

#define IPivotTable_get_DisplayContextTooltips(This,RHS)	\
    ( (This)->lpVtbl -> get_DisplayContextTooltips(This,RHS) ) 

#define IPivotTable_put_DisplayContextTooltips(This,RHS)	\
    ( (This)->lpVtbl -> put_DisplayContextTooltips(This,RHS) ) 

#define IPivotTable_ClearTable(This)	\
    ( (This)->lpVtbl -> ClearTable(This) ) 

#define IPivotTable_get_CompactRowIndent(This,RHS)	\
    ( (This)->lpVtbl -> get_CompactRowIndent(This,RHS) ) 

#define IPivotTable_put_CompactRowIndent(This,RHS)	\
    ( (This)->lpVtbl -> put_CompactRowIndent(This,RHS) ) 

#define IPivotTable_get_LayoutRowDefault(This,RHS)	\
    ( (This)->lpVtbl -> get_LayoutRowDefault(This,RHS) ) 

#define IPivotTable_put_LayoutRowDefault(This,RHS)	\
    ( (This)->lpVtbl -> put_LayoutRowDefault(This,RHS) ) 

#define IPivotTable_get_DisplayFieldCaptions(This,RHS)	\
    ( (This)->lpVtbl -> get_DisplayFieldCaptions(This,RHS) ) 

#define IPivotTable_put_DisplayFieldCaptions(This,RHS)	\
    ( (This)->lpVtbl -> put_DisplayFieldCaptions(This,RHS) ) 

#define IPivotTable_RowAxisLayout(This,RowLayout)	\
    ( (This)->lpVtbl -> RowAxisLayout(This,RowLayout) ) 

#define IPivotTable_SubtotalLocation(This,Location)	\
    ( (This)->lpVtbl -> SubtotalLocation(This,Location) ) 

#define IPivotTable_get_ActiveFilters(This,RHS)	\
    ( (This)->lpVtbl -> get_ActiveFilters(This,RHS) ) 

#define IPivotTable_get_InGridDropZones(This,RHS)	\
    ( (This)->lpVtbl -> get_InGridDropZones(This,RHS) ) 

#define IPivotTable_put_InGridDropZones(This,RHS)	\
    ( (This)->lpVtbl -> put_InGridDropZones(This,RHS) ) 

#define IPivotTable_ClearAllFilters(This)	\
    ( (This)->lpVtbl -> ClearAllFilters(This) ) 

#define IPivotTable_get_TableStyle2(This,RHS)	\
    ( (This)->lpVtbl -> get_TableStyle2(This,RHS) ) 

#define IPivotTable_put_TableStyle2(This,RHS)	\
    ( (This)->lpVtbl -> put_TableStyle2(This,RHS) ) 

#define IPivotTable_get_ShowTableStyleLastColumn(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowTableStyleLastColumn(This,RHS) ) 

#define IPivotTable_put_ShowTableStyleLastColumn(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowTableStyleLastColumn(This,RHS) ) 

#define IPivotTable_get_ShowTableStyleRowStripes(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowTableStyleRowStripes(This,RHS) ) 

#define IPivotTable_put_ShowTableStyleRowStripes(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowTableStyleRowStripes(This,RHS) ) 

#define IPivotTable_get_ShowTableStyleColumnStripes(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowTableStyleColumnStripes(This,RHS) ) 

#define IPivotTable_put_ShowTableStyleColumnStripes(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowTableStyleColumnStripes(This,RHS) ) 

#define IPivotTable_get_ShowTableStyleRowHeaders(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowTableStyleRowHeaders(This,RHS) ) 

#define IPivotTable_put_ShowTableStyleRowHeaders(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowTableStyleRowHeaders(This,RHS) ) 

#define IPivotTable_get_ShowTableStyleColumnHeaders(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowTableStyleColumnHeaders(This,RHS) ) 

#define IPivotTable_put_ShowTableStyleColumnHeaders(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowTableStyleColumnHeaders(This,RHS) ) 

#define IPivotTable_ConvertToFormulas(This,ConvertFilters)	\
    ( (This)->lpVtbl -> ConvertToFormulas(This,ConvertFilters) ) 

#define IPivotTable_get_AllowMultipleFilters(This,RHS)	\
    ( (This)->lpVtbl -> get_AllowMultipleFilters(This,RHS) ) 

#define IPivotTable_put_AllowMultipleFilters(This,RHS)	\
    ( (This)->lpVtbl -> put_AllowMultipleFilters(This,RHS) ) 

#define IPivotTable_get_CompactLayoutRowHeader(This,RHS)	\
    ( (This)->lpVtbl -> get_CompactLayoutRowHeader(This,RHS) ) 

#define IPivotTable_put_CompactLayoutRowHeader(This,RHS)	\
    ( (This)->lpVtbl -> put_CompactLayoutRowHeader(This,RHS) ) 

#define IPivotTable_get_CompactLayoutColumnHeader(This,RHS)	\
    ( (This)->lpVtbl -> get_CompactLayoutColumnHeader(This,RHS) ) 

#define IPivotTable_put_CompactLayoutColumnHeader(This,RHS)	\
    ( (This)->lpVtbl -> put_CompactLayoutColumnHeader(This,RHS) ) 

#define IPivotTable_get_FieldListSortAscending(This,RHS)	\
    ( (This)->lpVtbl -> get_FieldListSortAscending(This,RHS) ) 

#define IPivotTable_put_FieldListSortAscending(This,RHS)	\
    ( (This)->lpVtbl -> put_FieldListSortAscending(This,RHS) ) 

#define IPivotTable_get_SortUsingCustomLists(This,RHS)	\
    ( (This)->lpVtbl -> get_SortUsingCustomLists(This,RHS) ) 

#define IPivotTable_put_SortUsingCustomLists(This,RHS)	\
    ( (This)->lpVtbl -> put_SortUsingCustomLists(This,RHS) ) 

#define IPivotTable_ChangeConnection(This,conn)	\
    ( (This)->lpVtbl -> ChangeConnection(This,conn) ) 

#define IPivotTable_ChangePivotCache(This,PivotCache)	\
    ( (This)->lpVtbl -> ChangePivotCache(This,PivotCache) ) 

#define IPivotTable_get_Location(This,RHS)	\
    ( (This)->lpVtbl -> get_Location(This,RHS) ) 

#define IPivotTable_put_Location(This,RHS)	\
    ( (This)->lpVtbl -> put_Location(This,RHS) ) 

#define IPivotTable_get_EnableWriteback(This,RHS)	\
    ( (This)->lpVtbl -> get_EnableWriteback(This,RHS) ) 

#define IPivotTable_put_EnableWriteback(This,RHS)	\
    ( (This)->lpVtbl -> put_EnableWriteback(This,RHS) ) 

#define IPivotTable_get_Allocation(This,RHS)	\
    ( (This)->lpVtbl -> get_Allocation(This,RHS) ) 

#define IPivotTable_put_Allocation(This,RHS)	\
    ( (This)->lpVtbl -> put_Allocation(This,RHS) ) 

#define IPivotTable_get_AllocationValue(This,RHS)	\
    ( (This)->lpVtbl -> get_AllocationValue(This,RHS) ) 

#define IPivotTable_put_AllocationValue(This,RHS)	\
    ( (This)->lpVtbl -> put_AllocationValue(This,RHS) ) 

#define IPivotTable_get_AllocationMethod(This,RHS)	\
    ( (This)->lpVtbl -> get_AllocationMethod(This,RHS) ) 

#define IPivotTable_put_AllocationMethod(This,RHS)	\
    ( (This)->lpVtbl -> put_AllocationMethod(This,RHS) ) 

#define IPivotTable_get_AllocationWeightExpression(This,RHS)	\
    ( (This)->lpVtbl -> get_AllocationWeightExpression(This,RHS) ) 

#define IPivotTable_put_AllocationWeightExpression(This,RHS)	\
    ( (This)->lpVtbl -> put_AllocationWeightExpression(This,RHS) ) 

#define IPivotTable_AllocateChanges(This)	\
    ( (This)->lpVtbl -> AllocateChanges(This) ) 

#define IPivotTable_CommitChanges(This)	\
    ( (This)->lpVtbl -> CommitChanges(This) ) 

#define IPivotTable_DiscardChanges(This)	\
    ( (This)->lpVtbl -> DiscardChanges(This) ) 

#define IPivotTable_RefreshDataSourceValues(This)	\
    ( (This)->lpVtbl -> RefreshDataSourceValues(This) ) 

#define IPivotTable_RepeatAllLabels(This,Repeat)	\
    ( (This)->lpVtbl -> RepeatAllLabels(This,Repeat) ) 

#define IPivotTable_get_ChangeList(This,RHS)	\
    ( (This)->lpVtbl -> get_ChangeList(This,RHS) ) 

#define IPivotTable_get_Slicers(This,RHS)	\
    ( (This)->lpVtbl -> get_Slicers(This,RHS) ) 

#define IPivotTable_get_AlternativeText(This,RHS)	\
    ( (This)->lpVtbl -> get_AlternativeText(This,RHS) ) 

#define IPivotTable_put_AlternativeText(This,RHS)	\
    ( (This)->lpVtbl -> put_AlternativeText(This,RHS) ) 

#define IPivotTable_get_Summary(This,RHS)	\
    ( (This)->lpVtbl -> get_Summary(This,RHS) ) 

#define IPivotTable_put_Summary(This,RHS)	\
    ( (This)->lpVtbl -> put_Summary(This,RHS) ) 

#define IPivotTable_get_VisualTotalsForSets(This,RHS)	\
    ( (This)->lpVtbl -> get_VisualTotalsForSets(This,RHS) ) 

#define IPivotTable_put_VisualTotalsForSets(This,RHS)	\
    ( (This)->lpVtbl -> put_VisualTotalsForSets(This,RHS) ) 

#define IPivotTable_get_ShowValuesRow(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowValuesRow(This,RHS) ) 

#define IPivotTable_put_ShowValuesRow(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowValuesRow(This,RHS) ) 

#define IPivotTable_get_CalculatedMembersInFilters(This,RHS)	\
    ( (This)->lpVtbl -> get_CalculatedMembersInFilters(This,RHS) ) 

#define IPivotTable_put_CalculatedMembersInFilters(This,RHS)	\
    ( (This)->lpVtbl -> put_CalculatedMembersInFilters(This,RHS) ) 

#define IPivotTable_PivotValueCell(This,rowline,columnline,RHS)	\
    ( (This)->lpVtbl -> PivotValueCell(This,rowline,columnline,RHS) ) 

#define IPivotTable_get_Hidden(This,RHS)	\
    ( (This)->lpVtbl -> get_Hidden(This,RHS) ) 

#define IPivotTable_get_PivotChart(This,RHS)	\
    ( (This)->lpVtbl -> get_PivotChart(This,RHS) ) 

#define IPivotTable_DrillDown(This,PivotItem,PivotLine)	\
    ( (This)->lpVtbl -> DrillDown(This,PivotItem,PivotLine) ) 

#define IPivotTable_DrillUp(This,PivotItem,PivotLine,LevelUniqueName)	\
    ( (This)->lpVtbl -> DrillUp(This,PivotItem,PivotLine,LevelUniqueName) ) 

#define IPivotTable_DrillTo(This,PivotItem,CubeField,PivotLine)	\
    ( (This)->lpVtbl -> DrillTo(This,PivotItem,CubeField,PivotLine) ) 

#define IPivotTable_Dummy2(This,Arg1,Arg2,Arg3,Arg4,RHS)	\
    ( (This)->lpVtbl -> Dummy2(This,Arg1,Arg2,Arg3,Arg4,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */



/* [helpcontext][propput][id] */ HRESULT __stdcall IPivotTable_put_ShowPageMultipleItemLabel_Proxy( 
    IPivotTable * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB IPivotTable_put_ShowPageMultipleItemLabel_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IPivotTable_get_Version_Proxy( 
    IPivotTable * This,
    /* [retval][out] */ XlPivotTableVersionList *RHS);


void __RPC_STUB IPivotTable_get_Version_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IPivotTable_CreateCubeFile_Proxy( 
    IPivotTable * This,
    /* [in] */ BSTR File,
    /* [optional][in] */ VARIANT Measures,
    /* [optional][in] */ VARIANT Levels,
    /* [optional][in] */ VARIANT Members,
    /* [optional][in] */ VARIANT Properties,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB IPivotTable_CreateCubeFile_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IPivotTable_get_DisplayEmptyRow_Proxy( 
    IPivotTable * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB IPivotTable_get_DisplayEmptyRow_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT __stdcall IPivotTable_put_DisplayEmptyRow_Proxy( 
    IPivotTable * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB IPivotTable_put_DisplayEmptyRow_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IPivotTable_get_DisplayEmptyColumn_Proxy( 
    IPivotTable * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB IPivotTable_get_DisplayEmptyColumn_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT __stdcall IPivotTable_put_DisplayEmptyColumn_Proxy( 
    IPivotTable * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB IPivotTable_put_DisplayEmptyColumn_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][propget][id] */ HRESULT __stdcall IPivotTable_get_ShowCellBackgroundFromOLAP_Proxy( 
    IPivotTable * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB IPivotTable_get_ShowCellBackgroundFromOLAP_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][propput][id] */ HRESULT __stdcall IPivotTable_put_ShowCellBackgroundFromOLAP_Proxy( 
    IPivotTable * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB IPivotTable_put_ShowCellBackgroundFromOLAP_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IPivotTable_get_PivotColumnAxis_Proxy( 
    IPivotTable * This,
    /* [retval][out] */ PivotAxis	**RHS);


void __RPC_STUB IPivotTable_get_PivotColumnAxis_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IPivotTable_get_PivotRowAxis_Proxy( 
    IPivotTable * This,
    /* [retval][out] */ PivotAxis	**RHS);


void __RPC_STUB IPivotTable_get_PivotRowAxis_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IPivotTable_get_ShowDrillIndicators_Proxy( 
    IPivotTable * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB IPivotTable_get_ShowDrillIndicators_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT __stdcall IPivotTable_put_ShowDrillIndicators_Proxy( 
    IPivotTable * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB IPivotTable_put_ShowDrillIndicators_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IPivotTable_get_PrintDrillIndicators_Proxy( 
    IPivotTable * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB IPivotTable_get_PrintDrillIndicators_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT __stdcall IPivotTable_put_PrintDrillIndicators_Proxy( 
    IPivotTable * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB IPivotTable_put_PrintDrillIndicators_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IPivotTable_get_DisplayMemberPropertyTooltips_Proxy( 
    IPivotTable * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB IPivotTable_get_DisplayMemberPropertyTooltips_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT __stdcall IPivotTable_put_DisplayMemberPropertyTooltips_Proxy( 
    IPivotTable * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB IPivotTable_put_DisplayMemberPropertyTooltips_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IPivotTable_get_DisplayContextTooltips_Proxy( 
    IPivotTable * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB IPivotTable_get_DisplayContextTooltips_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT __stdcall IPivotTable_put_DisplayContextTooltips_Proxy( 
    IPivotTable * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB IPivotTable_put_DisplayContextTooltips_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IPivotTable_ClearTable_Proxy( 
    IPivotTable * This);


void __RPC_STUB IPivotTable_ClearTable_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IPivotTable_get_CompactRowIndent_Proxy( 
    IPivotTable * This,
    /* [retval][out] */ long *RHS);


void __RPC_STUB IPivotTable_get_CompactRowIndent_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT __stdcall IPivotTable_put_CompactRowIndent_Proxy( 
    IPivotTable * This,
    /* [in] */ long RHS);


void __RPC_STUB IPivotTable_put_CompactRowIndent_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IPivotTable_get_LayoutRowDefault_Proxy( 
    IPivotTable * This,
    /* [retval][out] */ XlLayoutRowType *RHS);


void __RPC_STUB IPivotTable_get_LayoutRowDefault_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT __stdcall IPivotTable_put_LayoutRowDefault_Proxy( 
    IPivotTable * This,
    /* [in] */ XlLayoutRowType RHS);


void __RPC_STUB IPivotTable_put_LayoutRowDefault_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IPivotTable_get_DisplayFieldCaptions_Proxy( 
    IPivotTable * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB IPivotTable_get_DisplayFieldCaptions_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT __stdcall IPivotTable_put_DisplayFieldCaptions_Proxy( 
    IPivotTable * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB IPivotTable_put_DisplayFieldCaptions_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IPivotTable_RowAxisLayout_Proxy( 
    IPivotTable * This,
    /* [in] */ XlLayoutRowType RowLayout);


void __RPC_STUB IPivotTable_RowAxisLayout_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IPivotTable_SubtotalLocation_Proxy( 
    IPivotTable * This,
    /* [in] */ XlSubtototalLocationType Location);


void __RPC_STUB IPivotTable_SubtotalLocation_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IPivotTable_get_ActiveFilters_Proxy( 
    IPivotTable * This,
    /* [retval][out] */ PivotFilters	**RHS);


void __RPC_STUB IPivotTable_get_ActiveFilters_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IPivotTable_get_InGridDropZones_Proxy( 
    IPivotTable * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB IPivotTable_get_InGridDropZones_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT __stdcall IPivotTable_put_InGridDropZones_Proxy( 
    IPivotTable * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB IPivotTable_put_InGridDropZones_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IPivotTable_ClearAllFilters_Proxy( 
    IPivotTable * This);


void __RPC_STUB IPivotTable_ClearAllFilters_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IPivotTable_get_TableStyle2_Proxy( 
    IPivotTable * This,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB IPivotTable_get_TableStyle2_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT __stdcall IPivotTable_put_TableStyle2_Proxy( 
    IPivotTable * This,
    /* [in] */ VARIANT RHS);


void __RPC_STUB IPivotTable_put_TableStyle2_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IPivotTable_get_ShowTableStyleLastColumn_Proxy( 
    IPivotTable * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB IPivotTable_get_ShowTableStyleLastColumn_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT __stdcall IPivotTable_put_ShowTableStyleLastColumn_Proxy( 
    IPivotTable * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB IPivotTable_put_ShowTableStyleLastColumn_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IPivotTable_get_ShowTableStyleRowStripes_Proxy( 
    IPivotTable * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB IPivotTable_get_ShowTableStyleRowStripes_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT __stdcall IPivotTable_put_ShowTableStyleRowStripes_Proxy( 
    IPivotTable * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB IPivotTable_put_ShowTableStyleRowStripes_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IPivotTable_get_ShowTableStyleColumnStripes_Proxy( 
    IPivotTable * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB IPivotTable_get_ShowTableStyleColumnStripes_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT __stdcall IPivotTable_put_ShowTableStyleColumnStripes_Proxy( 
    IPivotTable * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB IPivotTable_put_ShowTableStyleColumnStripes_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IPivotTable_get_ShowTableStyleRowHeaders_Proxy( 
    IPivotTable * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB IPivotTable_get_ShowTableStyleRowHeaders_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT __stdcall IPivotTable_put_ShowTableStyleRowHeaders_Proxy( 
    IPivotTable * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB IPivotTable_put_ShowTableStyleRowHeaders_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IPivotTable_get_ShowTableStyleColumnHeaders_Proxy( 
    IPivotTable * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB IPivotTable_get_ShowTableStyleColumnHeaders_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT __stdcall IPivotTable_put_ShowTableStyleColumnHeaders_Proxy( 
    IPivotTable * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB IPivotTable_put_ShowTableStyleColumnHeaders_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IPivotTable_ConvertToFormulas_Proxy( 
    IPivotTable * This,
    /* [in] */ VARIANT_BOOL ConvertFilters);


void __RPC_STUB IPivotTable_ConvertToFormulas_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IPivotTable_get_AllowMultipleFilters_Proxy( 
    IPivotTable * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB IPivotTable_get_AllowMultipleFilters_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT __stdcall IPivotTable_put_AllowMultipleFilters_Proxy( 
    IPivotTable * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB IPivotTable_put_AllowMultipleFilters_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IPivotTable_get_CompactLayoutRowHeader_Proxy( 
    IPivotTable * This,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB IPivotTable_get_CompactLayoutRowHeader_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT __stdcall IPivotTable_put_CompactLayoutRowHeader_Proxy( 
    IPivotTable * This,
    /* [in] */ BSTR RHS);


void __RPC_STUB IPivotTable_put_CompactLayoutRowHeader_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IPivotTable_get_CompactLayoutColumnHeader_Proxy( 
    IPivotTable * This,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB IPivotTable_get_CompactLayoutColumnHeader_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT __stdcall IPivotTable_put_CompactLayoutColumnHeader_Proxy( 
    IPivotTable * This,
    /* [in] */ BSTR RHS);


void __RPC_STUB IPivotTable_put_CompactLayoutColumnHeader_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IPivotTable_get_FieldListSortAscending_Proxy( 
    IPivotTable * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB IPivotTable_get_FieldListSortAscending_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT __stdcall IPivotTable_put_FieldListSortAscending_Proxy( 
    IPivotTable * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB IPivotTable_put_FieldListSortAscending_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IPivotTable_get_SortUsingCustomLists_Proxy( 
    IPivotTable * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB IPivotTable_get_SortUsingCustomLists_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT __stdcall IPivotTable_put_SortUsingCustomLists_Proxy( 
    IPivotTable * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB IPivotTable_put_SortUsingCustomLists_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IPivotTable_ChangeConnection_Proxy( 
    IPivotTable * This,
    /* [in] */ WorkbookConnection	*conn);


void __RPC_STUB IPivotTable_ChangeConnection_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IPivotTable_ChangePivotCache_Proxy( 
    IPivotTable * This,
    /* [in] */ VARIANT PivotCache);


void __RPC_STUB IPivotTable_ChangePivotCache_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IPivotTable_get_Location_Proxy( 
    IPivotTable * This,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB IPivotTable_get_Location_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT __stdcall IPivotTable_put_Location_Proxy( 
    IPivotTable * This,
    /* [in] */ BSTR RHS);


void __RPC_STUB IPivotTable_put_Location_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IPivotTable_get_EnableWriteback_Proxy( 
    IPivotTable * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB IPivotTable_get_EnableWriteback_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT __stdcall IPivotTable_put_EnableWriteback_Proxy( 
    IPivotTable * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB IPivotTable_put_EnableWriteback_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IPivotTable_get_Allocation_Proxy( 
    IPivotTable * This,
    /* [retval][out] */ XlAllocation *RHS);


void __RPC_STUB IPivotTable_get_Allocation_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT __stdcall IPivotTable_put_Allocation_Proxy( 
    IPivotTable * This,
    /* [in] */ XlAllocation RHS);


void __RPC_STUB IPivotTable_put_Allocation_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IPivotTable_get_AllocationValue_Proxy( 
    IPivotTable * This,
    /* [retval][out] */ XlAllocationValue *RHS);


void __RPC_STUB IPivotTable_get_AllocationValue_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT __stdcall IPivotTable_put_AllocationValue_Proxy( 
    IPivotTable * This,
    /* [in] */ XlAllocationValue RHS);


void __RPC_STUB IPivotTable_put_AllocationValue_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IPivotTable_get_AllocationMethod_Proxy( 
    IPivotTable * This,
    /* [retval][out] */ XlAllocationMethod *RHS);


void __RPC_STUB IPivotTable_get_AllocationMethod_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT __stdcall IPivotTable_put_AllocationMethod_Proxy( 
    IPivotTable * This,
    /* [in] */ XlAllocationMethod RHS);


void __RPC_STUB IPivotTable_put_AllocationMethod_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IPivotTable_get_AllocationWeightExpression_Proxy( 
    IPivotTable * This,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB IPivotTable_get_AllocationWeightExpression_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT __stdcall IPivotTable_put_AllocationWeightExpression_Proxy( 
    IPivotTable * This,
    /* [in] */ BSTR RHS);


void __RPC_STUB IPivotTable_put_AllocationWeightExpression_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IPivotTable_AllocateChanges_Proxy( 
    IPivotTable * This);


void __RPC_STUB IPivotTable_AllocateChanges_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IPivotTable_CommitChanges_Proxy( 
    IPivotTable * This);


void __RPC_STUB IPivotTable_CommitChanges_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IPivotTable_DiscardChanges_Proxy( 
    IPivotTable * This);


void __RPC_STUB IPivotTable_DiscardChanges_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IPivotTable_RefreshDataSourceValues_Proxy( 
    IPivotTable * This);


void __RPC_STUB IPivotTable_RefreshDataSourceValues_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IPivotTable_RepeatAllLabels_Proxy( 
    IPivotTable * This,
    /* [in] */ XlPivotFieldRepeatLabels Repeat);


void __RPC_STUB IPivotTable_RepeatAllLabels_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IPivotTable_get_ChangeList_Proxy( 
    IPivotTable * This,
    /* [retval][out] */ PivotTableChangeList	**RHS);


void __RPC_STUB IPivotTable_get_ChangeList_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IPivotTable_get_Slicers_Proxy( 
    IPivotTable * This,
    /* [retval][out] */ Slicers	**RHS);


void __RPC_STUB IPivotTable_get_Slicers_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IPivotTable_get_AlternativeText_Proxy( 
    IPivotTable * This,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB IPivotTable_get_AlternativeText_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT __stdcall IPivotTable_put_AlternativeText_Proxy( 
    IPivotTable * This,
    /* [in] */ BSTR RHS);


void __RPC_STUB IPivotTable_put_AlternativeText_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IPivotTable_get_Summary_Proxy( 
    IPivotTable * This,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB IPivotTable_get_Summary_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT __stdcall IPivotTable_put_Summary_Proxy( 
    IPivotTable * This,
    /* [in] */ BSTR RHS);


void __RPC_STUB IPivotTable_put_Summary_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IPivotTable_get_VisualTotalsForSets_Proxy( 
    IPivotTable * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB IPivotTable_get_VisualTotalsForSets_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT __stdcall IPivotTable_put_VisualTotalsForSets_Proxy( 
    IPivotTable * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB IPivotTable_put_VisualTotalsForSets_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IPivotTable_get_ShowValuesRow_Proxy( 
    IPivotTable * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB IPivotTable_get_ShowValuesRow_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT __stdcall IPivotTable_put_ShowValuesRow_Proxy( 
    IPivotTable * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB IPivotTable_put_ShowValuesRow_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IPivotTable_get_CalculatedMembersInFilters_Proxy( 
    IPivotTable * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB IPivotTable_get_CalculatedMembersInFilters_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT __stdcall IPivotTable_put_CalculatedMembersInFilters_Proxy( 
    IPivotTable * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB IPivotTable_put_CalculatedMembersInFilters_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IPivotTable_PivotValueCell_Proxy( 
    IPivotTable * This,
    /* [optional][in] */ VARIANT rowline,
    /* [optional][in] */ VARIANT columnline,
    /* [retval][out] */ PivotValueCell	**RHS);


void __RPC_STUB IPivotTable_PivotValueCell_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IPivotTable_get_Hidden_Proxy( 
    IPivotTable * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB IPivotTable_get_Hidden_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IPivotTable_get_PivotChart_Proxy( 
    IPivotTable * This,
    /* [retval][out] */ Shape	**RHS);


void __RPC_STUB IPivotTable_get_PivotChart_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IPivotTable_DrillDown_Proxy( 
    IPivotTable * This,
    /* [in] */ PivotItem	*PivotItem,
    /* [optional][in] */ VARIANT PivotLine);


void __RPC_STUB IPivotTable_DrillDown_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IPivotTable_DrillUp_Proxy( 
    IPivotTable * This,
    /* [in] */ PivotItem	*PivotItem,
    /* [optional][in] */ VARIANT PivotLine,
    /* [optional][in] */ VARIANT LevelUniqueName);


void __RPC_STUB IPivotTable_DrillUp_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IPivotTable_DrillTo_Proxy( 
    IPivotTable * This,
    /* [in] */ PivotItem	*PivotItem,
    /* [in] */ CubeField *CubeField,
    /* [optional][in] */ VARIANT PivotLine);


void __RPC_STUB IPivotTable_DrillTo_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][id] */ HRESULT __stdcall IPivotTable_Dummy2_Proxy( 
    IPivotTable * This,
    /* [in] */ VARIANT Arg1,
    /* [optional][in] */ VARIANT Arg2,
    /* [optional][in] */ VARIANT Arg3,
    /* [optional][in] */ VARIANT Arg4,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB IPivotTable_Dummy2_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);



#endif 	/* __IPivotTable_INTERFACE_DEFINED__ */


#ifndef __IPivotTables_INTERFACE_DEFINED__
#define __IPivotTables_INTERFACE_DEFINED__

/* interface IPivotTables */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IPivotTables;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00020873-0001-0000-C000-000000000046")
    IPivotTables : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ PivotTable	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall _NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add( 
            /* [in] */ PivotCache	*PivotCache,
            /* [in] */ VARIANT TableDestination,
            /* [optional][in] */ VARIANT TableName,
            /* [optional][in] */ VARIANT ReadData,
            /* [optional][in] */ VARIANT DefaultVersion,
            /* [retval][out] */ PivotTable	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IPivotTablesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IPivotTables * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IPivotTables * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IPivotTables * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IPivotTables * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IPivotTables * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IPivotTables * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IPivotTables * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IPivotTables * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IPivotTables * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IPivotTables * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IPivotTables * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Item )( 
            IPivotTables * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ PivotTable	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *_NewEnum )( 
            IPivotTables * This,
            /* [retval][out] */ IUnknown **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add )( 
            IPivotTables * This,
            /* [in] */ PivotCache	*PivotCache,
            /* [in] */ VARIANT TableDestination,
            /* [optional][in] */ VARIANT TableName,
            /* [optional][in] */ VARIANT ReadData,
            /* [optional][in] */ VARIANT DefaultVersion,
            /* [retval][out] */ PivotTable	**RHS);
        
        END_INTERFACE
    } IPivotTablesVtbl;

    interface IPivotTables
    {
        CONST_VTBL struct IPivotTablesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IPivotTables_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IPivotTables_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IPivotTables_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IPivotTables_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IPivotTables_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IPivotTables_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IPivotTables_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IPivotTables_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IPivotTables_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IPivotTables_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IPivotTables_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IPivotTables_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> Item(This,Index,RHS) ) 

#define IPivotTables__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> _NewEnum(This,RHS) ) 

#define IPivotTables_Add(This,PivotCache,TableDestination,TableName,ReadData,DefaultVersion,RHS)	\
    ( (This)->lpVtbl -> Add(This,PivotCache,TableDestination,TableName,ReadData,DefaultVersion,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IPivotTables_INTERFACE_DEFINED__ */


#ifndef __IPivotField_INTERFACE_DEFINED__
#define __IPivotField_INTERFACE_DEFINED__

/* interface IPivotField */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IPivotField;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00020874-0001-0000-C000-000000000046")
    IPivotField : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Calculation( 
            /* [retval][out] */ XlPivotFieldCalculation *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Calculation( 
            /* [in] */ XlPivotFieldCalculation RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ChildField( 
            /* [retval][out] */ PivotField	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ChildItems( 
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CurrentPage( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_CurrentPage( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DataRange( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DataType( 
            /* [retval][out] */ XlPivotFieldDataType *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put__Default( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Function( 
            /* [retval][out] */ XlConsolidationFunction *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Function( 
            /* [in] */ XlConsolidationFunction RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_GroupLevel( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HiddenItems( 
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LabelRange( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Name( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_NumberFormat( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_NumberFormat( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Orientation( 
            /* [retval][out] */ XlPivotFieldOrientation *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Orientation( 
            /* [in] */ XlPivotFieldOrientation RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShowAllItems( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ShowAllItems( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ParentField( 
            /* [retval][out] */ PivotField	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ParentItems( 
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall PivotItems( 
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Position( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Position( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SourceName( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Subtotals( 
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Subtotals( 
            /* [optional][in] */ VARIANT Index,
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_BaseField( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_BaseField( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_BaseItem( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_BaseItem( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TotalLevels( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Value( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Value( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_VisibleItems( 
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CalculatedItems( 
            /* [retval][out] */ CalculatedItems	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DragToColumn( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DragToColumn( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DragToHide( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DragToHide( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DragToPage( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DragToPage( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DragToRow( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DragToRow( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DragToData( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DragToData( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Formula( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Formula( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_IsCalculated( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MemoryUsed( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ServerBased( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ServerBased( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [custom][helpcontext][hidden][id] */ HRESULT __stdcall _AutoSort( 
            /* [in] */ long Order,
            /* [in] */ BSTR Field) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall AutoShow( 
            /* [in] */ long Type,
            /* [in] */ long Range,
            /* [in] */ long Count,
            /* [in] */ BSTR Field) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AutoSortOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AutoSortField( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AutoShowType( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AutoShowRange( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AutoShowCount( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AutoShowField( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LayoutBlankLine( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_LayoutBlankLine( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LayoutSubtotalLocation( 
            /* [retval][out] */ XlSubtototalLocationType *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_LayoutSubtotalLocation( 
            /* [in] */ XlSubtototalLocationType RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LayoutPageBreak( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_LayoutPageBreak( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LayoutForm( 
            /* [retval][out] */ XlLayoutFormType *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_LayoutForm( 
            /* [in] */ XlLayoutFormType RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SubtotalName( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_SubtotalName( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Caption( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Caption( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DrilledDown( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DrilledDown( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CubeField( 
            /* [retval][out] */ CubeField **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CurrentPageName( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_CurrentPageName( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_StandardFormula( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_StandardFormula( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HiddenItemsList( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_HiddenItemsList( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DatabaseSort( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DatabaseSort( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_IsMemberProperty( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PropertyParentField( 
            /* [retval][out] */ PivotField	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PropertyOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PropertyOrder( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_EnableItemSelection( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_EnableItemSelection( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CurrentPageList( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_CurrentPageList( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall AddPageItem( 
            /* [in] */ BSTR Item,
            /* [optional][in] */ VARIANT ClearList) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Hidden( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Hidden( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall DrillTo( 
            /* [in] */ BSTR Field) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_UseMemberPropertyAsCaption( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_UseMemberPropertyAsCaption( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MemberPropertyCaption( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_MemberPropertyCaption( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DisplayAsTooltip( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DisplayAsTooltip( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DisplayInReport( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DisplayInReport( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DisplayAsCaption( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LayoutCompactRow( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_LayoutCompactRow( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_IncludeNewItemsInFilter( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_IncludeNewItemsInFilter( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_VisibleItemsList( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_VisibleItemsList( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PivotFilters( 
            /* [retval][out] */ PivotFilters	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AutoSortPivotLine( 
            /* [retval][out] */ PivotLine	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AutoSortCustomSubtotal( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShowingInAxis( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_EnableMultiplePageItems( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_EnableMultiplePageItems( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AllItemsVisible( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ClearManualFilter( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ClearAllFilters( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ClearValueFilters( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ClearLabelFilters( void) = 0;
        
        virtual /* [custom][helpcontext][id] */ HRESULT __stdcall AutoSort( 
            /* [in] */ long Order,
            /* [in] */ BSTR Field,
            /* [optional][in] */ VARIANT PivotLine,
            /* [optional][in] */ VARIANT CustomSubtotal) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SourceCaption( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShowDetail( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ShowDetail( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RepeatLabels( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_RepeatLabels( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IPivotFieldVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IPivotField * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IPivotField * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IPivotField * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IPivotField * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IPivotField * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IPivotField * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IPivotField * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IPivotField * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IPivotField * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IPivotField * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Calculation )( 
            IPivotField * This,
            /* [retval][out] */ XlPivotFieldCalculation *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Calculation )( 
            IPivotField * This,
            /* [in] */ XlPivotFieldCalculation RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ChildField )( 
            IPivotField * This,
            /* [retval][out] */ PivotField	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ChildItems )( 
            IPivotField * This,
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CurrentPage )( 
            IPivotField * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_CurrentPage )( 
            IPivotField * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DataRange )( 
            IPivotField * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DataType )( 
            IPivotField * This,
            /* [retval][out] */ XlPivotFieldDataType *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IPivotField * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put__Default )( 
            IPivotField * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Function )( 
            IPivotField * This,
            /* [retval][out] */ XlConsolidationFunction *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Function )( 
            IPivotField * This,
            /* [in] */ XlConsolidationFunction RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_GroupLevel )( 
            IPivotField * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HiddenItems )( 
            IPivotField * This,
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LabelRange )( 
            IPivotField * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            IPivotField * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Name )( 
            IPivotField * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_NumberFormat )( 
            IPivotField * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_NumberFormat )( 
            IPivotField * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Orientation )( 
            IPivotField * This,
            /* [retval][out] */ XlPivotFieldOrientation *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Orientation )( 
            IPivotField * This,
            /* [in] */ XlPivotFieldOrientation RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShowAllItems )( 
            IPivotField * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ShowAllItems )( 
            IPivotField * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ParentField )( 
            IPivotField * This,
            /* [retval][out] */ PivotField	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ParentItems )( 
            IPivotField * This,
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *PivotItems )( 
            IPivotField * This,
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Position )( 
            IPivotField * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Position )( 
            IPivotField * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SourceName )( 
            IPivotField * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Subtotals )( 
            IPivotField * This,
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Subtotals )( 
            IPivotField * This,
            /* [optional][in] */ VARIANT Index,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_BaseField )( 
            IPivotField * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_BaseField )( 
            IPivotField * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_BaseItem )( 
            IPivotField * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_BaseItem )( 
            IPivotField * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TotalLevels )( 
            IPivotField * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Value )( 
            IPivotField * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Value )( 
            IPivotField * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_VisibleItems )( 
            IPivotField * This,
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CalculatedItems )( 
            IPivotField * This,
            /* [retval][out] */ CalculatedItems	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IPivotField * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DragToColumn )( 
            IPivotField * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DragToColumn )( 
            IPivotField * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DragToHide )( 
            IPivotField * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DragToHide )( 
            IPivotField * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DragToPage )( 
            IPivotField * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DragToPage )( 
            IPivotField * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DragToRow )( 
            IPivotField * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DragToRow )( 
            IPivotField * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DragToData )( 
            IPivotField * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DragToData )( 
            IPivotField * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Formula )( 
            IPivotField * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Formula )( 
            IPivotField * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_IsCalculated )( 
            IPivotField * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MemoryUsed )( 
            IPivotField * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ServerBased )( 
            IPivotField * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ServerBased )( 
            IPivotField * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [custom][helpcontext][hidden][id] */ HRESULT ( __stdcall *_AutoSort )( 
            IPivotField * This,
            /* [in] */ long Order,
            /* [in] */ BSTR Field);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *AutoShow )( 
            IPivotField * This,
            /* [in] */ long Type,
            /* [in] */ long Range,
            /* [in] */ long Count,
            /* [in] */ BSTR Field);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AutoSortOrder )( 
            IPivotField * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AutoSortField )( 
            IPivotField * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AutoShowType )( 
            IPivotField * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AutoShowRange )( 
            IPivotField * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AutoShowCount )( 
            IPivotField * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AutoShowField )( 
            IPivotField * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LayoutBlankLine )( 
            IPivotField * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_LayoutBlankLine )( 
            IPivotField * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LayoutSubtotalLocation )( 
            IPivotField * This,
            /* [retval][out] */ XlSubtototalLocationType *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_LayoutSubtotalLocation )( 
            IPivotField * This,
            /* [in] */ XlSubtototalLocationType RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LayoutPageBreak )( 
            IPivotField * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_LayoutPageBreak )( 
            IPivotField * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LayoutForm )( 
            IPivotField * This,
            /* [retval][out] */ XlLayoutFormType *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_LayoutForm )( 
            IPivotField * This,
            /* [in] */ XlLayoutFormType RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SubtotalName )( 
            IPivotField * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_SubtotalName )( 
            IPivotField * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Caption )( 
            IPivotField * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Caption )( 
            IPivotField * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DrilledDown )( 
            IPivotField * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DrilledDown )( 
            IPivotField * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CubeField )( 
            IPivotField * This,
            /* [retval][out] */ CubeField **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CurrentPageName )( 
            IPivotField * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_CurrentPageName )( 
            IPivotField * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_StandardFormula )( 
            IPivotField * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_StandardFormula )( 
            IPivotField * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HiddenItemsList )( 
            IPivotField * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_HiddenItemsList )( 
            IPivotField * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DatabaseSort )( 
            IPivotField * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DatabaseSort )( 
            IPivotField * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_IsMemberProperty )( 
            IPivotField * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PropertyParentField )( 
            IPivotField * This,
            /* [retval][out] */ PivotField	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PropertyOrder )( 
            IPivotField * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PropertyOrder )( 
            IPivotField * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_EnableItemSelection )( 
            IPivotField * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_EnableItemSelection )( 
            IPivotField * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CurrentPageList )( 
            IPivotField * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_CurrentPageList )( 
            IPivotField * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *AddPageItem )( 
            IPivotField * This,
            /* [in] */ BSTR Item,
            /* [optional][in] */ VARIANT ClearList);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Hidden )( 
            IPivotField * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Hidden )( 
            IPivotField * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *DrillTo )( 
            IPivotField * This,
            /* [in] */ BSTR Field);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_UseMemberPropertyAsCaption )( 
            IPivotField * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_UseMemberPropertyAsCaption )( 
            IPivotField * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MemberPropertyCaption )( 
            IPivotField * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_MemberPropertyCaption )( 
            IPivotField * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DisplayAsTooltip )( 
            IPivotField * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DisplayAsTooltip )( 
            IPivotField * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DisplayInReport )( 
            IPivotField * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DisplayInReport )( 
            IPivotField * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DisplayAsCaption )( 
            IPivotField * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LayoutCompactRow )( 
            IPivotField * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_LayoutCompactRow )( 
            IPivotField * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_IncludeNewItemsInFilter )( 
            IPivotField * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_IncludeNewItemsInFilter )( 
            IPivotField * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_VisibleItemsList )( 
            IPivotField * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_VisibleItemsList )( 
            IPivotField * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PivotFilters )( 
            IPivotField * This,
            /* [retval][out] */ PivotFilters	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AutoSortPivotLine )( 
            IPivotField * This,
            /* [retval][out] */ PivotLine	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AutoSortCustomSubtotal )( 
            IPivotField * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShowingInAxis )( 
            IPivotField * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_EnableMultiplePageItems )( 
            IPivotField * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_EnableMultiplePageItems )( 
            IPivotField * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AllItemsVisible )( 
            IPivotField * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ClearManualFilter )( 
            IPivotField * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ClearAllFilters )( 
            IPivotField * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ClearValueFilters )( 
            IPivotField * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ClearLabelFilters )( 
            IPivotField * This);
        
        /* [custom][helpcontext][id] */ HRESULT ( __stdcall *AutoSort )( 
            IPivotField * This,
            /* [in] */ long Order,
            /* [in] */ BSTR Field,
            /* [optional][in] */ VARIANT PivotLine,
            /* [optional][in] */ VARIANT CustomSubtotal);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SourceCaption )( 
            IPivotField * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShowDetail )( 
            IPivotField * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ShowDetail )( 
            IPivotField * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RepeatLabels )( 
            IPivotField * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_RepeatLabels )( 
            IPivotField * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        END_INTERFACE
    } IPivotFieldVtbl;

    interface IPivotField
    {
        CONST_VTBL struct IPivotFieldVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IPivotField_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IPivotField_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IPivotField_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IPivotField_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IPivotField_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IPivotField_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IPivotField_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IPivotField_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IPivotField_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IPivotField_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IPivotField_get_Calculation(This,RHS)	\
    ( (This)->lpVtbl -> get_Calculation(This,RHS) ) 

#define IPivotField_put_Calculation(This,RHS)	\
    ( (This)->lpVtbl -> put_Calculation(This,RHS) ) 

#define IPivotField_get_ChildField(This,RHS)	\
    ( (This)->lpVtbl -> get_ChildField(This,RHS) ) 

#define IPivotField_get_ChildItems(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_ChildItems(This,Index,RHS) ) 

#define IPivotField_get_CurrentPage(This,RHS)	\
    ( (This)->lpVtbl -> get_CurrentPage(This,RHS) ) 

#define IPivotField_put_CurrentPage(This,RHS)	\
    ( (This)->lpVtbl -> put_CurrentPage(This,RHS) ) 

#define IPivotField_get_DataRange(This,RHS)	\
    ( (This)->lpVtbl -> get_DataRange(This,RHS) ) 

#define IPivotField_get_DataType(This,RHS)	\
    ( (This)->lpVtbl -> get_DataType(This,RHS) ) 

#define IPivotField_get__Default(This,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,RHS) ) 

#define IPivotField_put__Default(This,RHS)	\
    ( (This)->lpVtbl -> put__Default(This,RHS) ) 

#define IPivotField_get_Function(This,RHS)	\
    ( (This)->lpVtbl -> get_Function(This,RHS) ) 

#define IPivotField_put_Function(This,RHS)	\
    ( (This)->lpVtbl -> put_Function(This,RHS) ) 

#define IPivotField_get_GroupLevel(This,RHS)	\
    ( (This)->lpVtbl -> get_GroupLevel(This,RHS) ) 

#define IPivotField_get_HiddenItems(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_HiddenItems(This,Index,RHS) ) 

#define IPivotField_get_LabelRange(This,RHS)	\
    ( (This)->lpVtbl -> get_LabelRange(This,RHS) ) 

#define IPivotField_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define IPivotField_put_Name(This,RHS)	\
    ( (This)->lpVtbl -> put_Name(This,RHS) ) 

#define IPivotField_get_NumberFormat(This,RHS)	\
    ( (This)->lpVtbl -> get_NumberFormat(This,RHS) ) 

#define IPivotField_put_NumberFormat(This,RHS)	\
    ( (This)->lpVtbl -> put_NumberFormat(This,RHS) ) 

#define IPivotField_get_Orientation(This,RHS)	\
    ( (This)->lpVtbl -> get_Orientation(This,RHS) ) 

#define IPivotField_put_Orientation(This,RHS)	\
    ( (This)->lpVtbl -> put_Orientation(This,RHS) ) 

#define IPivotField_get_ShowAllItems(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowAllItems(This,RHS) ) 

#define IPivotField_put_ShowAllItems(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowAllItems(This,RHS) ) 

#define IPivotField_get_ParentField(This,RHS)	\
    ( (This)->lpVtbl -> get_ParentField(This,RHS) ) 

#define IPivotField_get_ParentItems(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_ParentItems(This,Index,RHS) ) 

#define IPivotField_PivotItems(This,Index,RHS)	\
    ( (This)->lpVtbl -> PivotItems(This,Index,RHS) ) 

#define IPivotField_get_Position(This,RHS)	\
    ( (This)->lpVtbl -> get_Position(This,RHS) ) 

#define IPivotField_put_Position(This,RHS)	\
    ( (This)->lpVtbl -> put_Position(This,RHS) ) 

#define IPivotField_get_SourceName(This,RHS)	\
    ( (This)->lpVtbl -> get_SourceName(This,RHS) ) 

#define IPivotField_get_Subtotals(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Subtotals(This,Index,RHS) ) 

#define IPivotField_put_Subtotals(This,Index,RHS)	\
    ( (This)->lpVtbl -> put_Subtotals(This,Index,RHS) ) 

#define IPivotField_get_BaseField(This,RHS)	\
    ( (This)->lpVtbl -> get_BaseField(This,RHS) ) 

#define IPivotField_put_BaseField(This,RHS)	\
    ( (This)->lpVtbl -> put_BaseField(This,RHS) ) 

#define IPivotField_get_BaseItem(This,RHS)	\
    ( (This)->lpVtbl -> get_BaseItem(This,RHS) ) 

#define IPivotField_put_BaseItem(This,RHS)	\
    ( (This)->lpVtbl -> put_BaseItem(This,RHS) ) 

#define IPivotField_get_TotalLevels(This,RHS)	\
    ( (This)->lpVtbl -> get_TotalLevels(This,RHS) ) 

#define IPivotField_get_Value(This,RHS)	\
    ( (This)->lpVtbl -> get_Value(This,RHS) ) 

#define IPivotField_put_Value(This,RHS)	\
    ( (This)->lpVtbl -> put_Value(This,RHS) ) 

#define IPivotField_get_VisibleItems(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_VisibleItems(This,Index,RHS) ) 

#define IPivotField_CalculatedItems(This,RHS)	\
    ( (This)->lpVtbl -> CalculatedItems(This,RHS) ) 

#define IPivotField_Delete(This)	\
    ( (This)->lpVtbl -> Delete(This) ) 

#define IPivotField_get_DragToColumn(This,RHS)	\
    ( (This)->lpVtbl -> get_DragToColumn(This,RHS) ) 

#define IPivotField_put_DragToColumn(This,RHS)	\
    ( (This)->lpVtbl -> put_DragToColumn(This,RHS) ) 

#define IPivotField_get_DragToHide(This,RHS)	\
    ( (This)->lpVtbl -> get_DragToHide(This,RHS) ) 

#define IPivotField_put_DragToHide(This,RHS)	\
    ( (This)->lpVtbl -> put_DragToHide(This,RHS) ) 

#define IPivotField_get_DragToPage(This,RHS)	\
    ( (This)->lpVtbl -> get_DragToPage(This,RHS) ) 

#define IPivotField_put_DragToPage(This,RHS)	\
    ( (This)->lpVtbl -> put_DragToPage(This,RHS) ) 

#define IPivotField_get_DragToRow(This,RHS)	\
    ( (This)->lpVtbl -> get_DragToRow(This,RHS) ) 

#define IPivotField_put_DragToRow(This,RHS)	\
    ( (This)->lpVtbl -> put_DragToRow(This,RHS) ) 

#define IPivotField_get_DragToData(This,RHS)	\
    ( (This)->lpVtbl -> get_DragToData(This,RHS) ) 

#define IPivotField_put_DragToData(This,RHS)	\
    ( (This)->lpVtbl -> put_DragToData(This,RHS) ) 

#define IPivotField_get_Formula(This,RHS)	\
    ( (This)->lpVtbl -> get_Formula(This,RHS) ) 

#define IPivotField_put_Formula(This,RHS)	\
    ( (This)->lpVtbl -> put_Formula(This,RHS) ) 

#define IPivotField_get_IsCalculated(This,RHS)	\
    ( (This)->lpVtbl -> get_IsCalculated(This,RHS) ) 

#define IPivotField_get_MemoryUsed(This,RHS)	\
    ( (This)->lpVtbl -> get_MemoryUsed(This,RHS) ) 

#define IPivotField_get_ServerBased(This,RHS)	\
    ( (This)->lpVtbl -> get_ServerBased(This,RHS) ) 

#define IPivotField_put_ServerBased(This,RHS)	\
    ( (This)->lpVtbl -> put_ServerBased(This,RHS) ) 

#define IPivotField__AutoSort(This,Order,Field)	\
    ( (This)->lpVtbl -> _AutoSort(This,Order,Field) ) 

#define IPivotField_AutoShow(This,Type,Range,Count,Field)	\
    ( (This)->lpVtbl -> AutoShow(This,Type,Range,Count,Field) ) 

#define IPivotField_get_AutoSortOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoSortOrder(This,RHS) ) 

#define IPivotField_get_AutoSortField(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoSortField(This,RHS) ) 

#define IPivotField_get_AutoShowType(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoShowType(This,RHS) ) 

#define IPivotField_get_AutoShowRange(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoShowRange(This,RHS) ) 

#define IPivotField_get_AutoShowCount(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoShowCount(This,RHS) ) 

#define IPivotField_get_AutoShowField(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoShowField(This,RHS) ) 

#define IPivotField_get_LayoutBlankLine(This,RHS)	\
    ( (This)->lpVtbl -> get_LayoutBlankLine(This,RHS) ) 

#define IPivotField_put_LayoutBlankLine(This,RHS)	\
    ( (This)->lpVtbl -> put_LayoutBlankLine(This,RHS) ) 

#define IPivotField_get_LayoutSubtotalLocation(This,RHS)	\
    ( (This)->lpVtbl -> get_LayoutSubtotalLocation(This,RHS) ) 

#define IPivotField_put_LayoutSubtotalLocation(This,RHS)	\
    ( (This)->lpVtbl -> put_LayoutSubtotalLocation(This,RHS) ) 

#define IPivotField_get_LayoutPageBreak(This,RHS)	\
    ( (This)->lpVtbl -> get_LayoutPageBreak(This,RHS) ) 

#define IPivotField_put_LayoutPageBreak(This,RHS)	\
    ( (This)->lpVtbl -> put_LayoutPageBreak(This,RHS) ) 

#define IPivotField_get_LayoutForm(This,RHS)	\
    ( (This)->lpVtbl -> get_LayoutForm(This,RHS) ) 

#define IPivotField_put_LayoutForm(This,RHS)	\
    ( (This)->lpVtbl -> put_LayoutForm(This,RHS) ) 

#define IPivotField_get_SubtotalName(This,RHS)	\
    ( (This)->lpVtbl -> get_SubtotalName(This,RHS) ) 

#define IPivotField_put_SubtotalName(This,RHS)	\
    ( (This)->lpVtbl -> put_SubtotalName(This,RHS) ) 

#define IPivotField_get_Caption(This,RHS)	\
    ( (This)->lpVtbl -> get_Caption(This,RHS) ) 

#define IPivotField_put_Caption(This,RHS)	\
    ( (This)->lpVtbl -> put_Caption(This,RHS) ) 

#define IPivotField_get_DrilledDown(This,RHS)	\
    ( (This)->lpVtbl -> get_DrilledDown(This,RHS) ) 

#define IPivotField_put_DrilledDown(This,RHS)	\
    ( (This)->lpVtbl -> put_DrilledDown(This,RHS) ) 

#define IPivotField_get_CubeField(This,RHS)	\
    ( (This)->lpVtbl -> get_CubeField(This,RHS) ) 

#define IPivotField_get_CurrentPageName(This,RHS)	\
    ( (This)->lpVtbl -> get_CurrentPageName(This,RHS) ) 

#define IPivotField_put_CurrentPageName(This,RHS)	\
    ( (This)->lpVtbl -> put_CurrentPageName(This,RHS) ) 

#define IPivotField_get_StandardFormula(This,RHS)	\
    ( (This)->lpVtbl -> get_StandardFormula(This,RHS) ) 

#define IPivotField_put_StandardFormula(This,RHS)	\
    ( (This)->lpVtbl -> put_StandardFormula(This,RHS) ) 

#define IPivotField_get_HiddenItemsList(This,RHS)	\
    ( (This)->lpVtbl -> get_HiddenItemsList(This,RHS) ) 

#define IPivotField_put_HiddenItemsList(This,RHS)	\
    ( (This)->lpVtbl -> put_HiddenItemsList(This,RHS) ) 

#define IPivotField_get_DatabaseSort(This,RHS)	\
    ( (This)->lpVtbl -> get_DatabaseSort(This,RHS) ) 

#define IPivotField_put_DatabaseSort(This,RHS)	\
    ( (This)->lpVtbl -> put_DatabaseSort(This,RHS) ) 

#define IPivotField_get_IsMemberProperty(This,RHS)	\
    ( (This)->lpVtbl -> get_IsMemberProperty(This,RHS) ) 

#define IPivotField_get_PropertyParentField(This,RHS)	\
    ( (This)->lpVtbl -> get_PropertyParentField(This,RHS) ) 

#define IPivotField_get_PropertyOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_PropertyOrder(This,RHS) ) 

#define IPivotField_put_PropertyOrder(This,RHS)	\
    ( (This)->lpVtbl -> put_PropertyOrder(This,RHS) ) 

#define IPivotField_get_EnableItemSelection(This,RHS)	\
    ( (This)->lpVtbl -> get_EnableItemSelection(This,RHS) ) 

#define IPivotField_put_EnableItemSelection(This,RHS)	\
    ( (This)->lpVtbl -> put_EnableItemSelection(This,RHS) ) 

#define IPivotField_get_CurrentPageList(This,RHS)	\
    ( (This)->lpVtbl -> get_CurrentPageList(This,RHS) ) 

#define IPivotField_put_CurrentPageList(This,RHS)	\
    ( (This)->lpVtbl -> put_CurrentPageList(This,RHS) ) 

#define IPivotField_AddPageItem(This,Item,ClearList)	\
    ( (This)->lpVtbl -> AddPageItem(This,Item,ClearList) ) 

#define IPivotField_get_Hidden(This,RHS)	\
    ( (This)->lpVtbl -> get_Hidden(This,RHS) ) 

#define IPivotField_put_Hidden(This,RHS)	\
    ( (This)->lpVtbl -> put_Hidden(This,RHS) ) 

#define IPivotField_DrillTo(This,Field)	\
    ( (This)->lpVtbl -> DrillTo(This,Field) ) 

#define IPivotField_get_UseMemberPropertyAsCaption(This,RHS)	\
    ( (This)->lpVtbl -> get_UseMemberPropertyAsCaption(This,RHS) ) 

#define IPivotField_put_UseMemberPropertyAsCaption(This,RHS)	\
    ( (This)->lpVtbl -> put_UseMemberPropertyAsCaption(This,RHS) ) 

#define IPivotField_get_MemberPropertyCaption(This,RHS)	\
    ( (This)->lpVtbl -> get_MemberPropertyCaption(This,RHS) ) 

#define IPivotField_put_MemberPropertyCaption(This,RHS)	\
    ( (This)->lpVtbl -> put_MemberPropertyCaption(This,RHS) ) 

#define IPivotField_get_DisplayAsTooltip(This,RHS)	\
    ( (This)->lpVtbl -> get_DisplayAsTooltip(This,RHS) ) 

#define IPivotField_put_DisplayAsTooltip(This,RHS)	\
    ( (This)->lpVtbl -> put_DisplayAsTooltip(This,RHS) ) 

#define IPivotField_get_DisplayInReport(This,RHS)	\
    ( (This)->lpVtbl -> get_DisplayInReport(This,RHS) ) 

#define IPivotField_put_DisplayInReport(This,RHS)	\
    ( (This)->lpVtbl -> put_DisplayInReport(This,RHS) ) 

#define IPivotField_get_DisplayAsCaption(This,RHS)	\
    ( (This)->lpVtbl -> get_DisplayAsCaption(This,RHS) ) 

#define IPivotField_get_LayoutCompactRow(This,RHS)	\
    ( (This)->lpVtbl -> get_LayoutCompactRow(This,RHS) ) 

#define IPivotField_put_LayoutCompactRow(This,RHS)	\
    ( (This)->lpVtbl -> put_LayoutCompactRow(This,RHS) ) 

#define IPivotField_get_IncludeNewItemsInFilter(This,RHS)	\
    ( (This)->lpVtbl -> get_IncludeNewItemsInFilter(This,RHS) ) 

#define IPivotField_put_IncludeNewItemsInFilter(This,RHS)	\
    ( (This)->lpVtbl -> put_IncludeNewItemsInFilter(This,RHS) ) 

#define IPivotField_get_VisibleItemsList(This,RHS)	\
    ( (This)->lpVtbl -> get_VisibleItemsList(This,RHS) ) 

#define IPivotField_put_VisibleItemsList(This,RHS)	\
    ( (This)->lpVtbl -> put_VisibleItemsList(This,RHS) ) 

#define IPivotField_get_PivotFilters(This,RHS)	\
    ( (This)->lpVtbl -> get_PivotFilters(This,RHS) ) 

#define IPivotField_get_AutoSortPivotLine(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoSortPivotLine(This,RHS) ) 

#define IPivotField_get_AutoSortCustomSubtotal(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoSortCustomSubtotal(This,RHS) ) 

#define IPivotField_get_ShowingInAxis(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowingInAxis(This,RHS) ) 

#define IPivotField_get_EnableMultiplePageItems(This,RHS)	\
    ( (This)->lpVtbl -> get_EnableMultiplePageItems(This,RHS) ) 

#define IPivotField_put_EnableMultiplePageItems(This,RHS)	\
    ( (This)->lpVtbl -> put_EnableMultiplePageItems(This,RHS) ) 

#define IPivotField_get_AllItemsVisible(This,RHS)	\
    ( (This)->lpVtbl -> get_AllItemsVisible(This,RHS) ) 

#define IPivotField_ClearManualFilter(This)	\
    ( (This)->lpVtbl -> ClearManualFilter(This) ) 

#define IPivotField_ClearAllFilters(This)	\
    ( (This)->lpVtbl -> ClearAllFilters(This) ) 

#define IPivotField_ClearValueFilters(This)	\
    ( (This)->lpVtbl -> ClearValueFilters(This) ) 

#define IPivotField_ClearLabelFilters(This)	\
    ( (This)->lpVtbl -> ClearLabelFilters(This) ) 

#define IPivotField_AutoSort(This,Order,Field,PivotLine,CustomSubtotal)	\
    ( (This)->lpVtbl -> AutoSort(This,Order,Field,PivotLine,CustomSubtotal) ) 

#define IPivotField_get_SourceCaption(This,RHS)	\
    ( (This)->lpVtbl -> get_SourceCaption(This,RHS) ) 

#define IPivotField_get_ShowDetail(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowDetail(This,RHS) ) 

#define IPivotField_put_ShowDetail(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowDetail(This,RHS) ) 

#define IPivotField_get_RepeatLabels(This,RHS)	\
    ( (This)->lpVtbl -> get_RepeatLabels(This,RHS) ) 

#define IPivotField_put_RepeatLabels(This,RHS)	\
    ( (This)->lpVtbl -> put_RepeatLabels(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */



/* [helpcontext][propget][id] */ HRESULT __stdcall IPivotField_get_ShowingInAxis_Proxy( 
    IPivotField * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB IPivotField_get_ShowingInAxis_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IPivotField_get_EnableMultiplePageItems_Proxy( 
    IPivotField * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB IPivotField_get_EnableMultiplePageItems_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT __stdcall IPivotField_put_EnableMultiplePageItems_Proxy( 
    IPivotField * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB IPivotField_put_EnableMultiplePageItems_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IPivotField_get_AllItemsVisible_Proxy( 
    IPivotField * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB IPivotField_get_AllItemsVisible_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IPivotField_ClearManualFilter_Proxy( 
    IPivotField * This);


void __RPC_STUB IPivotField_ClearManualFilter_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IPivotField_ClearAllFilters_Proxy( 
    IPivotField * This);


void __RPC_STUB IPivotField_ClearAllFilters_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IPivotField_ClearValueFilters_Proxy( 
    IPivotField * This);


void __RPC_STUB IPivotField_ClearValueFilters_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IPivotField_ClearLabelFilters_Proxy( 
    IPivotField * This);


void __RPC_STUB IPivotField_ClearLabelFilters_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [custom][helpcontext][id] */ HRESULT __stdcall IPivotField_AutoSort_Proxy( 
    IPivotField * This,
    /* [in] */ long Order,
    /* [in] */ BSTR Field,
    /* [optional][in] */ VARIANT PivotLine,
    /* [optional][in] */ VARIANT CustomSubtotal);


void __RPC_STUB IPivotField_AutoSort_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IPivotField_get_SourceCaption_Proxy( 
    IPivotField * This,
    /* [retval][out] */ BSTR *RHS);


void __RPC_STUB IPivotField_get_SourceCaption_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IPivotField_get_ShowDetail_Proxy( 
    IPivotField * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB IPivotField_get_ShowDetail_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT __stdcall IPivotField_put_ShowDetail_Proxy( 
    IPivotField * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB IPivotField_put_ShowDetail_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IPivotField_get_RepeatLabels_Proxy( 
    IPivotField * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB IPivotField_get_RepeatLabels_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT __stdcall IPivotField_put_RepeatLabels_Proxy( 
    IPivotField * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB IPivotField_put_RepeatLabels_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);



#endif 	/* __IPivotField_INTERFACE_DEFINED__ */


#ifndef __IPivotFields_INTERFACE_DEFINED__
#define __IPivotFields_INTERFACE_DEFINED__

/* interface IPivotFields */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IPivotFields;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00020875-0001-0000-C000-000000000046")
    IPivotFields : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ PivotTable	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall _NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IPivotFieldsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IPivotFields * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IPivotFields * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IPivotFields * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IPivotFields * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IPivotFields * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IPivotFields * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IPivotFields * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IPivotFields * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IPivotFields * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IPivotFields * This,
            /* [retval][out] */ PivotTable	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IPivotFields * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Item )( 
            IPivotFields * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *_NewEnum )( 
            IPivotFields * This,
            /* [retval][out] */ IUnknown **RHS);
        
        END_INTERFACE
    } IPivotFieldsVtbl;

    interface IPivotFields
    {
        CONST_VTBL struct IPivotFieldsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IPivotFields_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IPivotFields_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IPivotFields_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IPivotFields_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IPivotFields_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IPivotFields_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IPivotFields_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IPivotFields_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IPivotFields_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IPivotFields_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IPivotFields_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IPivotFields_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> Item(This,Index,RHS) ) 

#define IPivotFields__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> _NewEnum(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IPivotFields_INTERFACE_DEFINED__ */


#ifndef __ICalculatedFields_INTERFACE_DEFINED__
#define __ICalculatedFields_INTERFACE_DEFINED__

/* interface ICalculatedFields */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ICalculatedFields;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024420-0001-0000-C000-000000000046")
    ICalculatedFields : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall _Add( 
            /* [in] */ BSTR Name,
            /* [in] */ BSTR Formula,
            /* [retval][out] */ PivotField	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ PivotField	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Field,
            /* [retval][out] */ PivotField	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall _NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add( 
            /* [in] */ BSTR Name,
            /* [in] */ BSTR Formula,
            /* [optional][in] */ VARIANT UseStandardFormula,
            /* [retval][out] */ PivotField	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ICalculatedFieldsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ICalculatedFields * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ICalculatedFields * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ICalculatedFields * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ICalculatedFields * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ICalculatedFields * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ICalculatedFields * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ICalculatedFields * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ICalculatedFields * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ICalculatedFields * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ICalculatedFields * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            ICalculatedFields * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *_Add )( 
            ICalculatedFields * This,
            /* [in] */ BSTR Name,
            /* [in] */ BSTR Formula,
            /* [retval][out] */ PivotField	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Item )( 
            ICalculatedFields * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ PivotField	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            ICalculatedFields * This,
            /* [in] */ VARIANT Field,
            /* [retval][out] */ PivotField	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *_NewEnum )( 
            ICalculatedFields * This,
            /* [retval][out] */ IUnknown **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add )( 
            ICalculatedFields * This,
            /* [in] */ BSTR Name,
            /* [in] */ BSTR Formula,
            /* [optional][in] */ VARIANT UseStandardFormula,
            /* [retval][out] */ PivotField	**RHS);
        
        END_INTERFACE
    } ICalculatedFieldsVtbl;

    interface ICalculatedFields
    {
        CONST_VTBL struct ICalculatedFieldsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ICalculatedFields_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ICalculatedFields_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ICalculatedFields_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ICalculatedFields_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ICalculatedFields_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ICalculatedFields_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ICalculatedFields_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ICalculatedFields_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ICalculatedFields_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ICalculatedFields_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ICalculatedFields_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define ICalculatedFields__Add(This,Name,Formula,RHS)	\
    ( (This)->lpVtbl -> _Add(This,Name,Formula,RHS) ) 

#define ICalculatedFields_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> Item(This,Index,RHS) ) 

#define ICalculatedFields_get__Default(This,Field,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Field,RHS) ) 

#define ICalculatedFields__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> _NewEnum(This,RHS) ) 

#define ICalculatedFields_Add(This,Name,Formula,UseStandardFormula,RHS)	\
    ( (This)->lpVtbl -> Add(This,Name,Formula,UseStandardFormula,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ICalculatedFields_INTERFACE_DEFINED__ */


#ifndef __IPivotItem_INTERFACE_DEFINED__
#define __IPivotItem_INTERFACE_DEFINED__

/* interface IPivotItem */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IPivotItem;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00020876-0001-0000-C000-000000000046")
    IPivotItem : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ PivotField	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ChildItems( 
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DataRange( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put__Default( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LabelRange( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Name( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ParentItem( 
            /* [retval][out] */ PivotItem	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ParentShowDetail( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Position( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Position( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShowDetail( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ShowDetail( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SourceName( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Value( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Value( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Visible( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Visible( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_IsCalculated( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RecordCount( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Formula( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Formula( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Caption( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Caption( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DrilledDown( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DrilledDown( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_StandardFormula( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_StandardFormula( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SourceNameStandard( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall DrillTo( 
            /* [in] */ BSTR Field) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IPivotItemVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IPivotItem * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IPivotItem * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IPivotItem * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IPivotItem * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IPivotItem * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IPivotItem * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IPivotItem * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IPivotItem * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IPivotItem * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IPivotItem * This,
            /* [retval][out] */ PivotField	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ChildItems )( 
            IPivotItem * This,
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DataRange )( 
            IPivotItem * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IPivotItem * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put__Default )( 
            IPivotItem * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LabelRange )( 
            IPivotItem * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            IPivotItem * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Name )( 
            IPivotItem * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ParentItem )( 
            IPivotItem * This,
            /* [retval][out] */ PivotItem	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ParentShowDetail )( 
            IPivotItem * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Position )( 
            IPivotItem * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Position )( 
            IPivotItem * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShowDetail )( 
            IPivotItem * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ShowDetail )( 
            IPivotItem * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SourceName )( 
            IPivotItem * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Value )( 
            IPivotItem * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Value )( 
            IPivotItem * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Visible )( 
            IPivotItem * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Visible )( 
            IPivotItem * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IPivotItem * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_IsCalculated )( 
            IPivotItem * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RecordCount )( 
            IPivotItem * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Formula )( 
            IPivotItem * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Formula )( 
            IPivotItem * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Caption )( 
            IPivotItem * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Caption )( 
            IPivotItem * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DrilledDown )( 
            IPivotItem * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DrilledDown )( 
            IPivotItem * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_StandardFormula )( 
            IPivotItem * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_StandardFormula )( 
            IPivotItem * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SourceNameStandard )( 
            IPivotItem * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *DrillTo )( 
            IPivotItem * This,
            /* [in] */ BSTR Field);
        
        END_INTERFACE
    } IPivotItemVtbl;

    interface IPivotItem
    {
        CONST_VTBL struct IPivotItemVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IPivotItem_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IPivotItem_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IPivotItem_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IPivotItem_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IPivotItem_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IPivotItem_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IPivotItem_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IPivotItem_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IPivotItem_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IPivotItem_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IPivotItem_get_ChildItems(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_ChildItems(This,Index,RHS) ) 

#define IPivotItem_get_DataRange(This,RHS)	\
    ( (This)->lpVtbl -> get_DataRange(This,RHS) ) 

#define IPivotItem_get__Default(This,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,RHS) ) 

#define IPivotItem_put__Default(This,RHS)	\
    ( (This)->lpVtbl -> put__Default(This,RHS) ) 

#define IPivotItem_get_LabelRange(This,RHS)	\
    ( (This)->lpVtbl -> get_LabelRange(This,RHS) ) 

#define IPivotItem_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define IPivotItem_put_Name(This,RHS)	\
    ( (This)->lpVtbl -> put_Name(This,RHS) ) 

#define IPivotItem_get_ParentItem(This,RHS)	\
    ( (This)->lpVtbl -> get_ParentItem(This,RHS) ) 

#define IPivotItem_get_ParentShowDetail(This,RHS)	\
    ( (This)->lpVtbl -> get_ParentShowDetail(This,RHS) ) 

#define IPivotItem_get_Position(This,RHS)	\
    ( (This)->lpVtbl -> get_Position(This,RHS) ) 

#define IPivotItem_put_Position(This,RHS)	\
    ( (This)->lpVtbl -> put_Position(This,RHS) ) 

#define IPivotItem_get_ShowDetail(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowDetail(This,RHS) ) 

#define IPivotItem_put_ShowDetail(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowDetail(This,RHS) ) 

#define IPivotItem_get_SourceName(This,RHS)	\
    ( (This)->lpVtbl -> get_SourceName(This,RHS) ) 

#define IPivotItem_get_Value(This,RHS)	\
    ( (This)->lpVtbl -> get_Value(This,RHS) ) 

#define IPivotItem_put_Value(This,RHS)	\
    ( (This)->lpVtbl -> put_Value(This,RHS) ) 

#define IPivotItem_get_Visible(This,RHS)	\
    ( (This)->lpVtbl -> get_Visible(This,RHS) ) 

#define IPivotItem_put_Visible(This,RHS)	\
    ( (This)->lpVtbl -> put_Visible(This,RHS) ) 

#define IPivotItem_Delete(This)	\
    ( (This)->lpVtbl -> Delete(This) ) 

#define IPivotItem_get_IsCalculated(This,RHS)	\
    ( (This)->lpVtbl -> get_IsCalculated(This,RHS) ) 

#define IPivotItem_get_RecordCount(This,RHS)	\
    ( (This)->lpVtbl -> get_RecordCount(This,RHS) ) 

#define IPivotItem_get_Formula(This,RHS)	\
    ( (This)->lpVtbl -> get_Formula(This,RHS) ) 

#define IPivotItem_put_Formula(This,RHS)	\
    ( (This)->lpVtbl -> put_Formula(This,RHS) ) 

#define IPivotItem_get_Caption(This,RHS)	\
    ( (This)->lpVtbl -> get_Caption(This,RHS) ) 

#define IPivotItem_put_Caption(This,RHS)	\
    ( (This)->lpVtbl -> put_Caption(This,RHS) ) 

#define IPivotItem_get_DrilledDown(This,RHS)	\
    ( (This)->lpVtbl -> get_DrilledDown(This,RHS) ) 

#define IPivotItem_put_DrilledDown(This,RHS)	\
    ( (This)->lpVtbl -> put_DrilledDown(This,RHS) ) 

#define IPivotItem_get_StandardFormula(This,RHS)	\
    ( (This)->lpVtbl -> get_StandardFormula(This,RHS) ) 

#define IPivotItem_put_StandardFormula(This,RHS)	\
    ( (This)->lpVtbl -> put_StandardFormula(This,RHS) ) 

#define IPivotItem_get_SourceNameStandard(This,RHS)	\
    ( (This)->lpVtbl -> get_SourceNameStandard(This,RHS) ) 

#define IPivotItem_DrillTo(This,Field)	\
    ( (This)->lpVtbl -> DrillTo(This,Field) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IPivotItem_INTERFACE_DEFINED__ */


#ifndef __IPivotItems_INTERFACE_DEFINED__
#define __IPivotItems_INTERFACE_DEFINED__

/* interface IPivotItems */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IPivotItems;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00020877-0001-0000-C000-000000000046")
    IPivotItems : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ PivotField	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add( 
            /* [in] */ BSTR Name) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall _NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IPivotItemsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IPivotItems * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IPivotItems * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IPivotItems * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IPivotItems * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IPivotItems * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IPivotItems * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IPivotItems * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IPivotItems * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IPivotItems * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IPivotItems * This,
            /* [retval][out] */ PivotField	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add )( 
            IPivotItems * This,
            /* [in] */ BSTR Name);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IPivotItems * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Item )( 
            IPivotItems * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *_NewEnum )( 
            IPivotItems * This,
            /* [retval][out] */ IUnknown **RHS);
        
        END_INTERFACE
    } IPivotItemsVtbl;

    interface IPivotItems
    {
        CONST_VTBL struct IPivotItemsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IPivotItems_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IPivotItems_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IPivotItems_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IPivotItems_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IPivotItems_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IPivotItems_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IPivotItems_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IPivotItems_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IPivotItems_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IPivotItems_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IPivotItems_Add(This,Name)	\
    ( (This)->lpVtbl -> Add(This,Name) ) 

#define IPivotItems_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IPivotItems_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> Item(This,Index,RHS) ) 

#define IPivotItems__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> _NewEnum(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IPivotItems_INTERFACE_DEFINED__ */


#ifndef __ICalculatedItems_INTERFACE_DEFINED__
#define __ICalculatedItems_INTERFACE_DEFINED__

/* interface ICalculatedItems */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ICalculatedItems;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024421-0001-0000-C000-000000000046")
    ICalculatedItems : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall _Add( 
            /* [in] */ BSTR Name,
            /* [in] */ BSTR Formula,
            /* [retval][out] */ PivotItem	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ PivotItem	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Field,
            /* [retval][out] */ PivotItem	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall _NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add( 
            /* [in] */ BSTR Name,
            /* [in] */ BSTR Formula,
            /* [optional][in] */ VARIANT UseStandardFormula,
            /* [retval][out] */ PivotItem	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ICalculatedItemsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ICalculatedItems * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ICalculatedItems * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ICalculatedItems * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ICalculatedItems * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ICalculatedItems * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ICalculatedItems * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ICalculatedItems * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ICalculatedItems * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ICalculatedItems * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ICalculatedItems * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            ICalculatedItems * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *_Add )( 
            ICalculatedItems * This,
            /* [in] */ BSTR Name,
            /* [in] */ BSTR Formula,
            /* [retval][out] */ PivotItem	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Item )( 
            ICalculatedItems * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ PivotItem	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            ICalculatedItems * This,
            /* [in] */ VARIANT Field,
            /* [retval][out] */ PivotItem	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *_NewEnum )( 
            ICalculatedItems * This,
            /* [retval][out] */ IUnknown **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add )( 
            ICalculatedItems * This,
            /* [in] */ BSTR Name,
            /* [in] */ BSTR Formula,
            /* [optional][in] */ VARIANT UseStandardFormula,
            /* [retval][out] */ PivotItem	**RHS);
        
        END_INTERFACE
    } ICalculatedItemsVtbl;

    interface ICalculatedItems
    {
        CONST_VTBL struct ICalculatedItemsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ICalculatedItems_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ICalculatedItems_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ICalculatedItems_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ICalculatedItems_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ICalculatedItems_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ICalculatedItems_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ICalculatedItems_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ICalculatedItems_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ICalculatedItems_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ICalculatedItems_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ICalculatedItems_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define ICalculatedItems__Add(This,Name,Formula,RHS)	\
    ( (This)->lpVtbl -> _Add(This,Name,Formula,RHS) ) 

#define ICalculatedItems_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> Item(This,Index,RHS) ) 

#define ICalculatedItems_get__Default(This,Field,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Field,RHS) ) 

#define ICalculatedItems__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> _NewEnum(This,RHS) ) 

#define ICalculatedItems_Add(This,Name,Formula,UseStandardFormula,RHS)	\
    ( (This)->lpVtbl -> Add(This,Name,Formula,UseStandardFormula,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ICalculatedItems_INTERFACE_DEFINED__ */


#ifndef __ICharacters_INTERFACE_DEFINED__
#define __ICharacters_INTERFACE_DEFINED__

/* interface ICharacters */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ICharacters;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00020878-0001-0000-C000-000000000046")
    ICharacters : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Caption( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Caption( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Font( 
            /* [retval][out] */ Font	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Insert( 
            /* [in] */ BSTR String,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Text( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Text( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PhoneticCharacters( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PhoneticCharacters( 
            /* [in] */ BSTR RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ICharactersVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ICharacters * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ICharacters * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ICharacters * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ICharacters * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ICharacters * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ICharacters * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ICharacters * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ICharacters * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ICharacters * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ICharacters * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Caption )( 
            ICharacters * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Caption )( 
            ICharacters * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            ICharacters * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            ICharacters * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Font )( 
            ICharacters * This,
            /* [retval][out] */ Font	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Insert )( 
            ICharacters * This,
            /* [in] */ BSTR String,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Text )( 
            ICharacters * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Text )( 
            ICharacters * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PhoneticCharacters )( 
            ICharacters * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PhoneticCharacters )( 
            ICharacters * This,
            /* [in] */ BSTR RHS);
        
        END_INTERFACE
    } ICharactersVtbl;

    interface ICharacters
    {
        CONST_VTBL struct ICharactersVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ICharacters_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ICharacters_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ICharacters_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ICharacters_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ICharacters_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ICharacters_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ICharacters_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ICharacters_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ICharacters_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ICharacters_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ICharacters_get_Caption(This,RHS)	\
    ( (This)->lpVtbl -> get_Caption(This,RHS) ) 

#define ICharacters_put_Caption(This,RHS)	\
    ( (This)->lpVtbl -> put_Caption(This,RHS) ) 

#define ICharacters_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define ICharacters_Delete(This,RHS)	\
    ( (This)->lpVtbl -> Delete(This,RHS) ) 

#define ICharacters_get_Font(This,RHS)	\
    ( (This)->lpVtbl -> get_Font(This,RHS) ) 

#define ICharacters_Insert(This,String,RHS)	\
    ( (This)->lpVtbl -> Insert(This,String,RHS) ) 

#define ICharacters_get_Text(This,RHS)	\
    ( (This)->lpVtbl -> get_Text(This,RHS) ) 

#define ICharacters_put_Text(This,RHS)	\
    ( (This)->lpVtbl -> put_Text(This,RHS) ) 

#define ICharacters_get_PhoneticCharacters(This,RHS)	\
    ( (This)->lpVtbl -> get_PhoneticCharacters(This,RHS) ) 

#define ICharacters_put_PhoneticCharacters(This,RHS)	\
    ( (This)->lpVtbl -> put_PhoneticCharacters(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ICharacters_INTERFACE_DEFINED__ */


#ifndef __IDialogs_INTERFACE_DEFINED__
#define __IDialogs_INTERFACE_DEFINED__

/* interface IDialogs */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IDialogs;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00020879-0001-0000-C000-000000000046")
    IDialogs : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Item( 
            /* [in] */ XlBuiltInDialog Index,
            /* [retval][out] */ Dialog	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ XlBuiltInDialog Index,
            /* [retval][out] */ Dialog	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IDialogsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IDialogs * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IDialogs * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IDialogs * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IDialogs * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IDialogs * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IDialogs * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IDialogs * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IDialogs * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IDialogs * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IDialogs * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IDialogs * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Item )( 
            IDialogs * This,
            /* [in] */ XlBuiltInDialog Index,
            /* [retval][out] */ Dialog	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IDialogs * This,
            /* [in] */ XlBuiltInDialog Index,
            /* [retval][out] */ Dialog	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            IDialogs * This,
            /* [retval][out] */ IUnknown **RHS);
        
        END_INTERFACE
    } IDialogsVtbl;

    interface IDialogs
    {
        CONST_VTBL struct IDialogsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IDialogs_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IDialogs_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IDialogs_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IDialogs_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IDialogs_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IDialogs_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IDialogs_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IDialogs_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IDialogs_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IDialogs_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IDialogs_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IDialogs_get_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Item(This,Index,RHS) ) 

#define IDialogs_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define IDialogs_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IDialogs_INTERFACE_DEFINED__ */


#ifndef __IDialog_INTERFACE_DEFINED__
#define __IDialog_INTERFACE_DEFINED__

/* interface IDialog */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IDialog;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002087A-0001-0000-C000-000000000046")
    IDialog : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Show( 
            /* [optional][in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IDialogVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IDialog * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IDialog * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IDialog * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IDialog * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IDialog * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IDialog * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IDialog * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IDialog * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IDialog * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IDialog * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Show )( 
            IDialog * This,
            /* [optional][in] */ VARIANT Arg1,
            /* [optional][in] */ VARIANT Arg2,
            /* [optional][in] */ VARIANT Arg3,
            /* [optional][in] */ VARIANT Arg4,
            /* [optional][in] */ VARIANT Arg5,
            /* [optional][in] */ VARIANT Arg6,
            /* [optional][in] */ VARIANT Arg7,
            /* [optional][in] */ VARIANT Arg8,
            /* [optional][in] */ VARIANT Arg9,
            /* [optional][in] */ VARIANT Arg10,
            /* [optional][in] */ VARIANT Arg11,
            /* [optional][in] */ VARIANT Arg12,
            /* [optional][in] */ VARIANT Arg13,
            /* [optional][in] */ VARIANT Arg14,
            /* [optional][in] */ VARIANT Arg15,
            /* [optional][in] */ VARIANT Arg16,
            /* [optional][in] */ VARIANT Arg17,
            /* [optional][in] */ VARIANT Arg18,
            /* [optional][in] */ VARIANT Arg19,
            /* [optional][in] */ VARIANT Arg20,
            /* [optional][in] */ VARIANT Arg21,
            /* [optional][in] */ VARIANT Arg22,
            /* [optional][in] */ VARIANT Arg23,
            /* [optional][in] */ VARIANT Arg24,
            /* [optional][in] */ VARIANT Arg25,
            /* [optional][in] */ VARIANT Arg26,
            /* [optional][in] */ VARIANT Arg27,
            /* [optional][in] */ VARIANT Arg28,
            /* [optional][in] */ VARIANT Arg29,
            /* [optional][in] */ VARIANT Arg30,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        END_INTERFACE
    } IDialogVtbl;

    interface IDialog
    {
        CONST_VTBL struct IDialogVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IDialog_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IDialog_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IDialog_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IDialog_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IDialog_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IDialog_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IDialog_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IDialog_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IDialog_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IDialog_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IDialog_Show(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS)	\
    ( (This)->lpVtbl -> Show(This,Arg1,Arg2,Arg3,Arg4,Arg5,Arg6,Arg7,Arg8,Arg9,Arg10,Arg11,Arg12,Arg13,Arg14,Arg15,Arg16,Arg17,Arg18,Arg19,Arg20,Arg21,Arg22,Arg23,Arg24,Arg25,Arg26,Arg27,Arg28,Arg29,Arg30,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IDialog_INTERFACE_DEFINED__ */


#ifndef __ISoundNote_INTERFACE_DEFINED__
#define __ISoundNote_INTERFACE_DEFINED__

/* interface ISoundNote */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ISoundNote;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002087B-0001-0000-C000-000000000046")
    ISoundNote : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Import( 
            /* [in] */ BSTR Filename,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Play( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Record( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ISoundNoteVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ISoundNote * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ISoundNote * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ISoundNote * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ISoundNote * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ISoundNote * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ISoundNote * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ISoundNote * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ISoundNote * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ISoundNote * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ISoundNote * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            ISoundNote * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Import )( 
            ISoundNote * This,
            /* [in] */ BSTR Filename,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Play )( 
            ISoundNote * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Record )( 
            ISoundNote * This,
            /* [retval][out] */ VARIANT *RHS);
        
        END_INTERFACE
    } ISoundNoteVtbl;

    interface ISoundNote
    {
        CONST_VTBL struct ISoundNoteVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ISoundNote_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ISoundNote_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ISoundNote_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ISoundNote_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ISoundNote_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ISoundNote_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ISoundNote_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ISoundNote_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ISoundNote_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ISoundNote_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ISoundNote_Delete(This,RHS)	\
    ( (This)->lpVtbl -> Delete(This,RHS) ) 

#define ISoundNote_Import(This,Filename,RHS)	\
    ( (This)->lpVtbl -> Import(This,Filename,RHS) ) 

#define ISoundNote_Play(This,RHS)	\
    ( (This)->lpVtbl -> Play(This,RHS) ) 

#define ISoundNote_Record(This,RHS)	\
    ( (This)->lpVtbl -> Record(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ISoundNote_INTERFACE_DEFINED__ */


#ifndef __IButton_INTERFACE_DEFINED__
#define __IButton_INTERFACE_DEFINED__

/* interface IButton */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IButton;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002087D-0001-0000-C000-000000000046")
    IButton : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_BottomRightCell( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall BringToFront( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Copy( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CopyPicture( 
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Cut( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Duplicate( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Enabled( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Enabled( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Height( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Height( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Index( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Left( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Left( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Locked( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Locked( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Name( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_OnAction( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_OnAction( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Placement( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Placement( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PrintObject( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PrintObject( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SendToBack( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Top( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Top( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TopLeftCell( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Visible( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Visible( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Width( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Width( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ZOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShapeRange( 
            /* [retval][out] */ ShapeRange	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AddIndent( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AddIndent( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AutoScaleFont( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AutoScaleFont( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AutoSize( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AutoSize( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Caption( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Caption( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Characters( 
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Length,
            /* [retval][out] */ Characters	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CheckSpelling( 
            /* [optional][in] */ VARIANT CustomDictionary,
            /* [optional][in] */ VARIANT IgnoreUppercase,
            /* [optional][in] */ VARIANT AlwaysSuggest,
            /* [optional][in] */ VARIANT SpellLang,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Font( 
            /* [retval][out] */ Font	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Formula( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Formula( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HorizontalAlignment( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_HorizontalAlignment( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LockedText( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_LockedText( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Orientation( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Orientation( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Text( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Text( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_VerticalAlignment( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_VerticalAlignment( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ReadingOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ReadingOrder( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Accelerator( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Accelerator( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CancelButton( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_CancelButton( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DefaultButton( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DefaultButton( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DismissButton( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DismissButton( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HelpButton( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_HelpButton( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PhoneticAccelerator( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PhoneticAccelerator( 
            /* [in] */ VARIANT RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IButtonVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IButton * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IButton * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IButton * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IButton * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IButton * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IButton * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IButton * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IButton * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IButton * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IButton * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_BottomRightCell )( 
            IButton * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *BringToFront )( 
            IButton * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Copy )( 
            IButton * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CopyPicture )( 
            IButton * This,
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Cut )( 
            IButton * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IButton * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Duplicate )( 
            IButton * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Enabled )( 
            IButton * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Enabled )( 
            IButton * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Height )( 
            IButton * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Height )( 
            IButton * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Index )( 
            IButton * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Left )( 
            IButton * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Left )( 
            IButton * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Locked )( 
            IButton * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Locked )( 
            IButton * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            IButton * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Name )( 
            IButton * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_OnAction )( 
            IButton * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_OnAction )( 
            IButton * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Placement )( 
            IButton * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Placement )( 
            IButton * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PrintObject )( 
            IButton * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PrintObject )( 
            IButton * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            IButton * This,
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SendToBack )( 
            IButton * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Top )( 
            IButton * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Top )( 
            IButton * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TopLeftCell )( 
            IButton * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Visible )( 
            IButton * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Visible )( 
            IButton * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Width )( 
            IButton * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Width )( 
            IButton * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ZOrder )( 
            IButton * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShapeRange )( 
            IButton * This,
            /* [retval][out] */ ShapeRange	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AddIndent )( 
            IButton * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AddIndent )( 
            IButton * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AutoScaleFont )( 
            IButton * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AutoScaleFont )( 
            IButton * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AutoSize )( 
            IButton * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AutoSize )( 
            IButton * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Caption )( 
            IButton * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Caption )( 
            IButton * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Characters )( 
            IButton * This,
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Length,
            /* [retval][out] */ Characters	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CheckSpelling )( 
            IButton * This,
            /* [optional][in] */ VARIANT CustomDictionary,
            /* [optional][in] */ VARIANT IgnoreUppercase,
            /* [optional][in] */ VARIANT AlwaysSuggest,
            /* [optional][in] */ VARIANT SpellLang,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Font )( 
            IButton * This,
            /* [retval][out] */ Font	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Formula )( 
            IButton * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Formula )( 
            IButton * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HorizontalAlignment )( 
            IButton * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_HorizontalAlignment )( 
            IButton * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LockedText )( 
            IButton * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_LockedText )( 
            IButton * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Orientation )( 
            IButton * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Orientation )( 
            IButton * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Text )( 
            IButton * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Text )( 
            IButton * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_VerticalAlignment )( 
            IButton * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_VerticalAlignment )( 
            IButton * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ReadingOrder )( 
            IButton * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ReadingOrder )( 
            IButton * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Accelerator )( 
            IButton * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Accelerator )( 
            IButton * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CancelButton )( 
            IButton * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_CancelButton )( 
            IButton * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DefaultButton )( 
            IButton * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DefaultButton )( 
            IButton * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DismissButton )( 
            IButton * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DismissButton )( 
            IButton * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HelpButton )( 
            IButton * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_HelpButton )( 
            IButton * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PhoneticAccelerator )( 
            IButton * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PhoneticAccelerator )( 
            IButton * This,
            /* [in] */ VARIANT RHS);
        
        END_INTERFACE
    } IButtonVtbl;

    interface IButton
    {
        CONST_VTBL struct IButtonVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IButton_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IButton_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IButton_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IButton_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IButton_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IButton_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IButton_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IButton_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IButton_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IButton_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IButton_get_BottomRightCell(This,RHS)	\
    ( (This)->lpVtbl -> get_BottomRightCell(This,RHS) ) 

#define IButton_BringToFront(This,RHS)	\
    ( (This)->lpVtbl -> BringToFront(This,RHS) ) 

#define IButton_Copy(This,RHS)	\
    ( (This)->lpVtbl -> Copy(This,RHS) ) 

#define IButton_CopyPicture(This,Appearance,Format,RHS)	\
    ( (This)->lpVtbl -> CopyPicture(This,Appearance,Format,RHS) ) 

#define IButton_Cut(This,RHS)	\
    ( (This)->lpVtbl -> Cut(This,RHS) ) 

#define IButton_Delete(This,RHS)	\
    ( (This)->lpVtbl -> Delete(This,RHS) ) 

#define IButton_Duplicate(This,RHS)	\
    ( (This)->lpVtbl -> Duplicate(This,RHS) ) 

#define IButton_get_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> get_Enabled(This,RHS) ) 

#define IButton_put_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> put_Enabled(This,RHS) ) 

#define IButton_get_Height(This,RHS)	\
    ( (This)->lpVtbl -> get_Height(This,RHS) ) 

#define IButton_put_Height(This,RHS)	\
    ( (This)->lpVtbl -> put_Height(This,RHS) ) 

#define IButton_get_Index(This,RHS)	\
    ( (This)->lpVtbl -> get_Index(This,RHS) ) 

#define IButton_get_Left(This,RHS)	\
    ( (This)->lpVtbl -> get_Left(This,RHS) ) 

#define IButton_put_Left(This,RHS)	\
    ( (This)->lpVtbl -> put_Left(This,RHS) ) 

#define IButton_get_Locked(This,RHS)	\
    ( (This)->lpVtbl -> get_Locked(This,RHS) ) 

#define IButton_put_Locked(This,RHS)	\
    ( (This)->lpVtbl -> put_Locked(This,RHS) ) 

#define IButton_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define IButton_put_Name(This,RHS)	\
    ( (This)->lpVtbl -> put_Name(This,RHS) ) 

#define IButton_get_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> get_OnAction(This,RHS) ) 

#define IButton_put_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> put_OnAction(This,RHS) ) 

#define IButton_get_Placement(This,RHS)	\
    ( (This)->lpVtbl -> get_Placement(This,RHS) ) 

#define IButton_put_Placement(This,RHS)	\
    ( (This)->lpVtbl -> put_Placement(This,RHS) ) 

#define IButton_get_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> get_PrintObject(This,RHS) ) 

#define IButton_put_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> put_PrintObject(This,RHS) ) 

#define IButton_Select(This,Replace,RHS)	\
    ( (This)->lpVtbl -> Select(This,Replace,RHS) ) 

#define IButton_SendToBack(This,RHS)	\
    ( (This)->lpVtbl -> SendToBack(This,RHS) ) 

#define IButton_get_Top(This,RHS)	\
    ( (This)->lpVtbl -> get_Top(This,RHS) ) 

#define IButton_put_Top(This,RHS)	\
    ( (This)->lpVtbl -> put_Top(This,RHS) ) 

#define IButton_get_TopLeftCell(This,RHS)	\
    ( (This)->lpVtbl -> get_TopLeftCell(This,RHS) ) 

#define IButton_get_Visible(This,RHS)	\
    ( (This)->lpVtbl -> get_Visible(This,RHS) ) 

#define IButton_put_Visible(This,RHS)	\
    ( (This)->lpVtbl -> put_Visible(This,RHS) ) 

#define IButton_get_Width(This,RHS)	\
    ( (This)->lpVtbl -> get_Width(This,RHS) ) 

#define IButton_put_Width(This,RHS)	\
    ( (This)->lpVtbl -> put_Width(This,RHS) ) 

#define IButton_get_ZOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_ZOrder(This,RHS) ) 

#define IButton_get_ShapeRange(This,RHS)	\
    ( (This)->lpVtbl -> get_ShapeRange(This,RHS) ) 

#define IButton_get_AddIndent(This,RHS)	\
    ( (This)->lpVtbl -> get_AddIndent(This,RHS) ) 

#define IButton_put_AddIndent(This,RHS)	\
    ( (This)->lpVtbl -> put_AddIndent(This,RHS) ) 

#define IButton_get_AutoScaleFont(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoScaleFont(This,RHS) ) 

#define IButton_put_AutoScaleFont(This,RHS)	\
    ( (This)->lpVtbl -> put_AutoScaleFont(This,RHS) ) 

#define IButton_get_AutoSize(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoSize(This,RHS) ) 

#define IButton_put_AutoSize(This,RHS)	\
    ( (This)->lpVtbl -> put_AutoSize(This,RHS) ) 

#define IButton_get_Caption(This,RHS)	\
    ( (This)->lpVtbl -> get_Caption(This,RHS) ) 

#define IButton_put_Caption(This,RHS)	\
    ( (This)->lpVtbl -> put_Caption(This,RHS) ) 

#define IButton_get_Characters(This,Start,Length,RHS)	\
    ( (This)->lpVtbl -> get_Characters(This,Start,Length,RHS) ) 

#define IButton_CheckSpelling(This,CustomDictionary,IgnoreUppercase,AlwaysSuggest,SpellLang,RHS)	\
    ( (This)->lpVtbl -> CheckSpelling(This,CustomDictionary,IgnoreUppercase,AlwaysSuggest,SpellLang,RHS) ) 

#define IButton_get_Font(This,RHS)	\
    ( (This)->lpVtbl -> get_Font(This,RHS) ) 

#define IButton_get_Formula(This,RHS)	\
    ( (This)->lpVtbl -> get_Formula(This,RHS) ) 

#define IButton_put_Formula(This,RHS)	\
    ( (This)->lpVtbl -> put_Formula(This,RHS) ) 

#define IButton_get_HorizontalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> get_HorizontalAlignment(This,RHS) ) 

#define IButton_put_HorizontalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> put_HorizontalAlignment(This,RHS) ) 

#define IButton_get_LockedText(This,RHS)	\
    ( (This)->lpVtbl -> get_LockedText(This,RHS) ) 

#define IButton_put_LockedText(This,RHS)	\
    ( (This)->lpVtbl -> put_LockedText(This,RHS) ) 

#define IButton_get_Orientation(This,RHS)	\
    ( (This)->lpVtbl -> get_Orientation(This,RHS) ) 

#define IButton_put_Orientation(This,RHS)	\
    ( (This)->lpVtbl -> put_Orientation(This,RHS) ) 

#define IButton_get_Text(This,RHS)	\
    ( (This)->lpVtbl -> get_Text(This,RHS) ) 

#define IButton_put_Text(This,RHS)	\
    ( (This)->lpVtbl -> put_Text(This,RHS) ) 

#define IButton_get_VerticalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> get_VerticalAlignment(This,RHS) ) 

#define IButton_put_VerticalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> put_VerticalAlignment(This,RHS) ) 

#define IButton_get_ReadingOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_ReadingOrder(This,RHS) ) 

#define IButton_put_ReadingOrder(This,RHS)	\
    ( (This)->lpVtbl -> put_ReadingOrder(This,RHS) ) 

#define IButton_get_Accelerator(This,RHS)	\
    ( (This)->lpVtbl -> get_Accelerator(This,RHS) ) 

#define IButton_put_Accelerator(This,RHS)	\
    ( (This)->lpVtbl -> put_Accelerator(This,RHS) ) 

#define IButton_get_CancelButton(This,RHS)	\
    ( (This)->lpVtbl -> get_CancelButton(This,RHS) ) 

#define IButton_put_CancelButton(This,RHS)	\
    ( (This)->lpVtbl -> put_CancelButton(This,RHS) ) 

#define IButton_get_DefaultButton(This,RHS)	\
    ( (This)->lpVtbl -> get_DefaultButton(This,RHS) ) 

#define IButton_put_DefaultButton(This,RHS)	\
    ( (This)->lpVtbl -> put_DefaultButton(This,RHS) ) 

#define IButton_get_DismissButton(This,RHS)	\
    ( (This)->lpVtbl -> get_DismissButton(This,RHS) ) 

#define IButton_put_DismissButton(This,RHS)	\
    ( (This)->lpVtbl -> put_DismissButton(This,RHS) ) 

#define IButton_get_HelpButton(This,RHS)	\
    ( (This)->lpVtbl -> get_HelpButton(This,RHS) ) 

#define IButton_put_HelpButton(This,RHS)	\
    ( (This)->lpVtbl -> put_HelpButton(This,RHS) ) 

#define IButton_get_PhoneticAccelerator(This,RHS)	\
    ( (This)->lpVtbl -> get_PhoneticAccelerator(This,RHS) ) 

#define IButton_put_PhoneticAccelerator(This,RHS)	\
    ( (This)->lpVtbl -> put_PhoneticAccelerator(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IButton_INTERFACE_DEFINED__ */


#ifndef __IButtons_INTERFACE_DEFINED__
#define __IButtons_INTERFACE_DEFINED__

/* interface IButtons */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IButtons;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002087E-0001-0000-C000-000000000046")
    IButtons : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy3( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall BringToFront( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Copy( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CopyPicture( 
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Cut( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Duplicate( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Enabled( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Enabled( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Height( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Height( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy12( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Left( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Left( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Locked( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Locked( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy15( void) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_OnAction( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_OnAction( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Placement( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Placement( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PrintObject( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PrintObject( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SendToBack( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Top( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Top( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy22( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Visible( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Visible( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Width( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Width( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ZOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShapeRange( 
            /* [retval][out] */ ShapeRange	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AddIndent( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AddIndent( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AutoScaleFont( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AutoScaleFont( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AutoSize( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AutoSize( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Caption( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Caption( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Characters( 
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Length,
            /* [retval][out] */ Characters	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CheckSpelling( 
            /* [optional][in] */ VARIANT CustomDictionary,
            /* [optional][in] */ VARIANT IgnoreUppercase,
            /* [optional][in] */ VARIANT AlwaysSuggest,
            /* [optional][in] */ VARIANT SpellLang,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Font( 
            /* [retval][out] */ Font	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Formula( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Formula( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HorizontalAlignment( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_HorizontalAlignment( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LockedText( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_LockedText( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Orientation( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Orientation( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Text( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Text( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_VerticalAlignment( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_VerticalAlignment( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ReadingOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ReadingOrder( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Accelerator( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Accelerator( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CancelButton( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_CancelButton( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DefaultButton( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DefaultButton( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DismissButton( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DismissButton( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HelpButton( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_HelpButton( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PhoneticAccelerator( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PhoneticAccelerator( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add( 
            /* [in] */ double Left,
            /* [in] */ double Top,
            /* [in] */ double Width,
            /* [in] */ double Height,
            /* [retval][out] */ Button	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Group( 
            /* [retval][out] */ GroupObject	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall _NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IButtonsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IButtons * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IButtons * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IButtons * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IButtons * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IButtons * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IButtons * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IButtons * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IButtons * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IButtons * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IButtons * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy3 )( 
            IButtons * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *BringToFront )( 
            IButtons * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Copy )( 
            IButtons * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CopyPicture )( 
            IButtons * This,
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Cut )( 
            IButtons * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IButtons * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Duplicate )( 
            IButtons * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Enabled )( 
            IButtons * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Enabled )( 
            IButtons * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Height )( 
            IButtons * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Height )( 
            IButtons * This,
            /* [in] */ double RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy12 )( 
            IButtons * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Left )( 
            IButtons * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Left )( 
            IButtons * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Locked )( 
            IButtons * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Locked )( 
            IButtons * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy15 )( 
            IButtons * This);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_OnAction )( 
            IButtons * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_OnAction )( 
            IButtons * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Placement )( 
            IButtons * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Placement )( 
            IButtons * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PrintObject )( 
            IButtons * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PrintObject )( 
            IButtons * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            IButtons * This,
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SendToBack )( 
            IButtons * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Top )( 
            IButtons * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Top )( 
            IButtons * This,
            /* [in] */ double RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy22 )( 
            IButtons * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Visible )( 
            IButtons * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Visible )( 
            IButtons * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Width )( 
            IButtons * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Width )( 
            IButtons * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ZOrder )( 
            IButtons * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShapeRange )( 
            IButtons * This,
            /* [retval][out] */ ShapeRange	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AddIndent )( 
            IButtons * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AddIndent )( 
            IButtons * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AutoScaleFont )( 
            IButtons * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AutoScaleFont )( 
            IButtons * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AutoSize )( 
            IButtons * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AutoSize )( 
            IButtons * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Caption )( 
            IButtons * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Caption )( 
            IButtons * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Characters )( 
            IButtons * This,
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Length,
            /* [retval][out] */ Characters	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CheckSpelling )( 
            IButtons * This,
            /* [optional][in] */ VARIANT CustomDictionary,
            /* [optional][in] */ VARIANT IgnoreUppercase,
            /* [optional][in] */ VARIANT AlwaysSuggest,
            /* [optional][in] */ VARIANT SpellLang,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Font )( 
            IButtons * This,
            /* [retval][out] */ Font	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Formula )( 
            IButtons * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Formula )( 
            IButtons * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HorizontalAlignment )( 
            IButtons * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_HorizontalAlignment )( 
            IButtons * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LockedText )( 
            IButtons * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_LockedText )( 
            IButtons * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Orientation )( 
            IButtons * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Orientation )( 
            IButtons * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Text )( 
            IButtons * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Text )( 
            IButtons * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_VerticalAlignment )( 
            IButtons * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_VerticalAlignment )( 
            IButtons * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ReadingOrder )( 
            IButtons * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ReadingOrder )( 
            IButtons * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Accelerator )( 
            IButtons * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Accelerator )( 
            IButtons * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CancelButton )( 
            IButtons * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_CancelButton )( 
            IButtons * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DefaultButton )( 
            IButtons * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DefaultButton )( 
            IButtons * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DismissButton )( 
            IButtons * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DismissButton )( 
            IButtons * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HelpButton )( 
            IButtons * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_HelpButton )( 
            IButtons * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PhoneticAccelerator )( 
            IButtons * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PhoneticAccelerator )( 
            IButtons * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add )( 
            IButtons * This,
            /* [in] */ double Left,
            /* [in] */ double Top,
            /* [in] */ double Width,
            /* [in] */ double Height,
            /* [retval][out] */ Button	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IButtons * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Group )( 
            IButtons * This,
            /* [retval][out] */ GroupObject	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Item )( 
            IButtons * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *_NewEnum )( 
            IButtons * This,
            /* [retval][out] */ IUnknown **RHS);
        
        END_INTERFACE
    } IButtonsVtbl;

    interface IButtons
    {
        CONST_VTBL struct IButtonsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IButtons_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IButtons_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IButtons_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IButtons_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IButtons_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IButtons_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IButtons_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IButtons_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IButtons_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IButtons_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IButtons__Dummy3(This)	\
    ( (This)->lpVtbl -> _Dummy3(This) ) 

#define IButtons_BringToFront(This,RHS)	\
    ( (This)->lpVtbl -> BringToFront(This,RHS) ) 

#define IButtons_Copy(This,RHS)	\
    ( (This)->lpVtbl -> Copy(This,RHS) ) 

#define IButtons_CopyPicture(This,Appearance,Format,RHS)	\
    ( (This)->lpVtbl -> CopyPicture(This,Appearance,Format,RHS) ) 

#define IButtons_Cut(This,RHS)	\
    ( (This)->lpVtbl -> Cut(This,RHS) ) 

#define IButtons_Delete(This,RHS)	\
    ( (This)->lpVtbl -> Delete(This,RHS) ) 

#define IButtons_Duplicate(This,RHS)	\
    ( (This)->lpVtbl -> Duplicate(This,RHS) ) 

#define IButtons_get_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> get_Enabled(This,RHS) ) 

#define IButtons_put_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> put_Enabled(This,RHS) ) 

#define IButtons_get_Height(This,RHS)	\
    ( (This)->lpVtbl -> get_Height(This,RHS) ) 

#define IButtons_put_Height(This,RHS)	\
    ( (This)->lpVtbl -> put_Height(This,RHS) ) 

#define IButtons__Dummy12(This)	\
    ( (This)->lpVtbl -> _Dummy12(This) ) 

#define IButtons_get_Left(This,RHS)	\
    ( (This)->lpVtbl -> get_Left(This,RHS) ) 

#define IButtons_put_Left(This,RHS)	\
    ( (This)->lpVtbl -> put_Left(This,RHS) ) 

#define IButtons_get_Locked(This,RHS)	\
    ( (This)->lpVtbl -> get_Locked(This,RHS) ) 

#define IButtons_put_Locked(This,RHS)	\
    ( (This)->lpVtbl -> put_Locked(This,RHS) ) 

#define IButtons__Dummy15(This)	\
    ( (This)->lpVtbl -> _Dummy15(This) ) 

#define IButtons_get_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> get_OnAction(This,RHS) ) 

#define IButtons_put_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> put_OnAction(This,RHS) ) 

#define IButtons_get_Placement(This,RHS)	\
    ( (This)->lpVtbl -> get_Placement(This,RHS) ) 

#define IButtons_put_Placement(This,RHS)	\
    ( (This)->lpVtbl -> put_Placement(This,RHS) ) 

#define IButtons_get_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> get_PrintObject(This,RHS) ) 

#define IButtons_put_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> put_PrintObject(This,RHS) ) 

#define IButtons_Select(This,Replace,RHS)	\
    ( (This)->lpVtbl -> Select(This,Replace,RHS) ) 

#define IButtons_SendToBack(This,RHS)	\
    ( (This)->lpVtbl -> SendToBack(This,RHS) ) 

#define IButtons_get_Top(This,RHS)	\
    ( (This)->lpVtbl -> get_Top(This,RHS) ) 

#define IButtons_put_Top(This,RHS)	\
    ( (This)->lpVtbl -> put_Top(This,RHS) ) 

#define IButtons__Dummy22(This)	\
    ( (This)->lpVtbl -> _Dummy22(This) ) 

#define IButtons_get_Visible(This,RHS)	\
    ( (This)->lpVtbl -> get_Visible(This,RHS) ) 

#define IButtons_put_Visible(This,RHS)	\
    ( (This)->lpVtbl -> put_Visible(This,RHS) ) 

#define IButtons_get_Width(This,RHS)	\
    ( (This)->lpVtbl -> get_Width(This,RHS) ) 

#define IButtons_put_Width(This,RHS)	\
    ( (This)->lpVtbl -> put_Width(This,RHS) ) 

#define IButtons_get_ZOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_ZOrder(This,RHS) ) 

#define IButtons_get_ShapeRange(This,RHS)	\
    ( (This)->lpVtbl -> get_ShapeRange(This,RHS) ) 

#define IButtons_get_AddIndent(This,RHS)	\
    ( (This)->lpVtbl -> get_AddIndent(This,RHS) ) 

#define IButtons_put_AddIndent(This,RHS)	\
    ( (This)->lpVtbl -> put_AddIndent(This,RHS) ) 

#define IButtons_get_AutoScaleFont(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoScaleFont(This,RHS) ) 

#define IButtons_put_AutoScaleFont(This,RHS)	\
    ( (This)->lpVtbl -> put_AutoScaleFont(This,RHS) ) 

#define IButtons_get_AutoSize(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoSize(This,RHS) ) 

#define IButtons_put_AutoSize(This,RHS)	\
    ( (This)->lpVtbl -> put_AutoSize(This,RHS) ) 

#define IButtons_get_Caption(This,RHS)	\
    ( (This)->lpVtbl -> get_Caption(This,RHS) ) 

#define IButtons_put_Caption(This,RHS)	\
    ( (This)->lpVtbl -> put_Caption(This,RHS) ) 

#define IButtons_get_Characters(This,Start,Length,RHS)	\
    ( (This)->lpVtbl -> get_Characters(This,Start,Length,RHS) ) 

#define IButtons_CheckSpelling(This,CustomDictionary,IgnoreUppercase,AlwaysSuggest,SpellLang,RHS)	\
    ( (This)->lpVtbl -> CheckSpelling(This,CustomDictionary,IgnoreUppercase,AlwaysSuggest,SpellLang,RHS) ) 

#define IButtons_get_Font(This,RHS)	\
    ( (This)->lpVtbl -> get_Font(This,RHS) ) 

#define IButtons_get_Formula(This,RHS)	\
    ( (This)->lpVtbl -> get_Formula(This,RHS) ) 

#define IButtons_put_Formula(This,RHS)	\
    ( (This)->lpVtbl -> put_Formula(This,RHS) ) 

#define IButtons_get_HorizontalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> get_HorizontalAlignment(This,RHS) ) 

#define IButtons_put_HorizontalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> put_HorizontalAlignment(This,RHS) ) 

#define IButtons_get_LockedText(This,RHS)	\
    ( (This)->lpVtbl -> get_LockedText(This,RHS) ) 

#define IButtons_put_LockedText(This,RHS)	\
    ( (This)->lpVtbl -> put_LockedText(This,RHS) ) 

#define IButtons_get_Orientation(This,RHS)	\
    ( (This)->lpVtbl -> get_Orientation(This,RHS) ) 

#define IButtons_put_Orientation(This,RHS)	\
    ( (This)->lpVtbl -> put_Orientation(This,RHS) ) 

#define IButtons_get_Text(This,RHS)	\
    ( (This)->lpVtbl -> get_Text(This,RHS) ) 

#define IButtons_put_Text(This,RHS)	\
    ( (This)->lpVtbl -> put_Text(This,RHS) ) 

#define IButtons_get_VerticalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> get_VerticalAlignment(This,RHS) ) 

#define IButtons_put_VerticalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> put_VerticalAlignment(This,RHS) ) 

#define IButtons_get_ReadingOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_ReadingOrder(This,RHS) ) 

#define IButtons_put_ReadingOrder(This,RHS)	\
    ( (This)->lpVtbl -> put_ReadingOrder(This,RHS) ) 

#define IButtons_get_Accelerator(This,RHS)	\
    ( (This)->lpVtbl -> get_Accelerator(This,RHS) ) 

#define IButtons_put_Accelerator(This,RHS)	\
    ( (This)->lpVtbl -> put_Accelerator(This,RHS) ) 

#define IButtons_get_CancelButton(This,RHS)	\
    ( (This)->lpVtbl -> get_CancelButton(This,RHS) ) 

#define IButtons_put_CancelButton(This,RHS)	\
    ( (This)->lpVtbl -> put_CancelButton(This,RHS) ) 

#define IButtons_get_DefaultButton(This,RHS)	\
    ( (This)->lpVtbl -> get_DefaultButton(This,RHS) ) 

#define IButtons_put_DefaultButton(This,RHS)	\
    ( (This)->lpVtbl -> put_DefaultButton(This,RHS) ) 

#define IButtons_get_DismissButton(This,RHS)	\
    ( (This)->lpVtbl -> get_DismissButton(This,RHS) ) 

#define IButtons_put_DismissButton(This,RHS)	\
    ( (This)->lpVtbl -> put_DismissButton(This,RHS) ) 

#define IButtons_get_HelpButton(This,RHS)	\
    ( (This)->lpVtbl -> get_HelpButton(This,RHS) ) 

#define IButtons_put_HelpButton(This,RHS)	\
    ( (This)->lpVtbl -> put_HelpButton(This,RHS) ) 

#define IButtons_get_PhoneticAccelerator(This,RHS)	\
    ( (This)->lpVtbl -> get_PhoneticAccelerator(This,RHS) ) 

#define IButtons_put_PhoneticAccelerator(This,RHS)	\
    ( (This)->lpVtbl -> put_PhoneticAccelerator(This,RHS) ) 

#define IButtons_Add(This,Left,Top,Width,Height,RHS)	\
    ( (This)->lpVtbl -> Add(This,Left,Top,Width,Height,RHS) ) 

#define IButtons_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IButtons_Group(This,RHS)	\
    ( (This)->lpVtbl -> Group(This,RHS) ) 

#define IButtons_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> Item(This,Index,RHS) ) 

#define IButtons__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> _NewEnum(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IButtons_INTERFACE_DEFINED__ */


#ifndef __ICheckBox_INTERFACE_DEFINED__
#define __ICheckBox_INTERFACE_DEFINED__

/* interface ICheckBox */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ICheckBox;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002087F-0001-0000-C000-000000000046")
    ICheckBox : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_BottomRightCell( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall BringToFront( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Copy( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CopyPicture( 
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Cut( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Duplicate( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Enabled( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Enabled( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Height( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Height( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Index( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Left( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Left( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Locked( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Locked( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Name( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_OnAction( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_OnAction( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Placement( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Placement( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PrintObject( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PrintObject( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SendToBack( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Top( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Top( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TopLeftCell( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Visible( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Visible( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Width( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Width( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ZOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShapeRange( 
            /* [retval][out] */ ShapeRange	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Caption( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Caption( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Characters( 
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Length,
            /* [retval][out] */ Characters	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CheckSpelling( 
            /* [optional][in] */ VARIANT CustomDictionary,
            /* [optional][in] */ VARIANT IgnoreUppercase,
            /* [optional][in] */ VARIANT AlwaysSuggest,
            /* [optional][in] */ VARIANT SpellLang,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LockedText( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_LockedText( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Text( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Text( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Accelerator( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Accelerator( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Border( 
            /* [retval][out] */ Border	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put__Default( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Display3DShading( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Display3DShading( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Interior( 
            /* [retval][out] */ Interior	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LinkedCell( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_LinkedCell( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PhoneticAccelerator( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PhoneticAccelerator( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Value( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Value( 
            /* [in] */ VARIANT RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ICheckBoxVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ICheckBox * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ICheckBox * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ICheckBox * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ICheckBox * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ICheckBox * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ICheckBox * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ICheckBox * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ICheckBox * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ICheckBox * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ICheckBox * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_BottomRightCell )( 
            ICheckBox * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *BringToFront )( 
            ICheckBox * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Copy )( 
            ICheckBox * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CopyPicture )( 
            ICheckBox * This,
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Cut )( 
            ICheckBox * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            ICheckBox * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Duplicate )( 
            ICheckBox * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Enabled )( 
            ICheckBox * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Enabled )( 
            ICheckBox * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Height )( 
            ICheckBox * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Height )( 
            ICheckBox * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Index )( 
            ICheckBox * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Left )( 
            ICheckBox * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Left )( 
            ICheckBox * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Locked )( 
            ICheckBox * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Locked )( 
            ICheckBox * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            ICheckBox * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Name )( 
            ICheckBox * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_OnAction )( 
            ICheckBox * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_OnAction )( 
            ICheckBox * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Placement )( 
            ICheckBox * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Placement )( 
            ICheckBox * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PrintObject )( 
            ICheckBox * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PrintObject )( 
            ICheckBox * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            ICheckBox * This,
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SendToBack )( 
            ICheckBox * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Top )( 
            ICheckBox * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Top )( 
            ICheckBox * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TopLeftCell )( 
            ICheckBox * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Visible )( 
            ICheckBox * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Visible )( 
            ICheckBox * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Width )( 
            ICheckBox * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Width )( 
            ICheckBox * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ZOrder )( 
            ICheckBox * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShapeRange )( 
            ICheckBox * This,
            /* [retval][out] */ ShapeRange	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Caption )( 
            ICheckBox * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Caption )( 
            ICheckBox * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Characters )( 
            ICheckBox * This,
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Length,
            /* [retval][out] */ Characters	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CheckSpelling )( 
            ICheckBox * This,
            /* [optional][in] */ VARIANT CustomDictionary,
            /* [optional][in] */ VARIANT IgnoreUppercase,
            /* [optional][in] */ VARIANT AlwaysSuggest,
            /* [optional][in] */ VARIANT SpellLang,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LockedText )( 
            ICheckBox * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_LockedText )( 
            ICheckBox * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Text )( 
            ICheckBox * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Text )( 
            ICheckBox * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Accelerator )( 
            ICheckBox * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Accelerator )( 
            ICheckBox * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Border )( 
            ICheckBox * This,
            /* [retval][out] */ Border	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            ICheckBox * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put__Default )( 
            ICheckBox * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Display3DShading )( 
            ICheckBox * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Display3DShading )( 
            ICheckBox * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Interior )( 
            ICheckBox * This,
            /* [retval][out] */ Interior	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LinkedCell )( 
            ICheckBox * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_LinkedCell )( 
            ICheckBox * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PhoneticAccelerator )( 
            ICheckBox * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PhoneticAccelerator )( 
            ICheckBox * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Value )( 
            ICheckBox * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Value )( 
            ICheckBox * This,
            /* [in] */ VARIANT RHS);
        
        END_INTERFACE
    } ICheckBoxVtbl;

    interface ICheckBox
    {
        CONST_VTBL struct ICheckBoxVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ICheckBox_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ICheckBox_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ICheckBox_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ICheckBox_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ICheckBox_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ICheckBox_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ICheckBox_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ICheckBox_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ICheckBox_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ICheckBox_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ICheckBox_get_BottomRightCell(This,RHS)	\
    ( (This)->lpVtbl -> get_BottomRightCell(This,RHS) ) 

#define ICheckBox_BringToFront(This,RHS)	\
    ( (This)->lpVtbl -> BringToFront(This,RHS) ) 

#define ICheckBox_Copy(This,RHS)	\
    ( (This)->lpVtbl -> Copy(This,RHS) ) 

#define ICheckBox_CopyPicture(This,Appearance,Format,RHS)	\
    ( (This)->lpVtbl -> CopyPicture(This,Appearance,Format,RHS) ) 

#define ICheckBox_Cut(This,RHS)	\
    ( (This)->lpVtbl -> Cut(This,RHS) ) 

#define ICheckBox_Delete(This,RHS)	\
    ( (This)->lpVtbl -> Delete(This,RHS) ) 

#define ICheckBox_Duplicate(This,RHS)	\
    ( (This)->lpVtbl -> Duplicate(This,RHS) ) 

#define ICheckBox_get_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> get_Enabled(This,RHS) ) 

#define ICheckBox_put_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> put_Enabled(This,RHS) ) 

#define ICheckBox_get_Height(This,RHS)	\
    ( (This)->lpVtbl -> get_Height(This,RHS) ) 

#define ICheckBox_put_Height(This,RHS)	\
    ( (This)->lpVtbl -> put_Height(This,RHS) ) 

#define ICheckBox_get_Index(This,RHS)	\
    ( (This)->lpVtbl -> get_Index(This,RHS) ) 

#define ICheckBox_get_Left(This,RHS)	\
    ( (This)->lpVtbl -> get_Left(This,RHS) ) 

#define ICheckBox_put_Left(This,RHS)	\
    ( (This)->lpVtbl -> put_Left(This,RHS) ) 

#define ICheckBox_get_Locked(This,RHS)	\
    ( (This)->lpVtbl -> get_Locked(This,RHS) ) 

#define ICheckBox_put_Locked(This,RHS)	\
    ( (This)->lpVtbl -> put_Locked(This,RHS) ) 

#define ICheckBox_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define ICheckBox_put_Name(This,RHS)	\
    ( (This)->lpVtbl -> put_Name(This,RHS) ) 

#define ICheckBox_get_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> get_OnAction(This,RHS) ) 

#define ICheckBox_put_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> put_OnAction(This,RHS) ) 

#define ICheckBox_get_Placement(This,RHS)	\
    ( (This)->lpVtbl -> get_Placement(This,RHS) ) 

#define ICheckBox_put_Placement(This,RHS)	\
    ( (This)->lpVtbl -> put_Placement(This,RHS) ) 

#define ICheckBox_get_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> get_PrintObject(This,RHS) ) 

#define ICheckBox_put_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> put_PrintObject(This,RHS) ) 

#define ICheckBox_Select(This,Replace,RHS)	\
    ( (This)->lpVtbl -> Select(This,Replace,RHS) ) 

#define ICheckBox_SendToBack(This,RHS)	\
    ( (This)->lpVtbl -> SendToBack(This,RHS) ) 

#define ICheckBox_get_Top(This,RHS)	\
    ( (This)->lpVtbl -> get_Top(This,RHS) ) 

#define ICheckBox_put_Top(This,RHS)	\
    ( (This)->lpVtbl -> put_Top(This,RHS) ) 

#define ICheckBox_get_TopLeftCell(This,RHS)	\
    ( (This)->lpVtbl -> get_TopLeftCell(This,RHS) ) 

#define ICheckBox_get_Visible(This,RHS)	\
    ( (This)->lpVtbl -> get_Visible(This,RHS) ) 

#define ICheckBox_put_Visible(This,RHS)	\
    ( (This)->lpVtbl -> put_Visible(This,RHS) ) 

#define ICheckBox_get_Width(This,RHS)	\
    ( (This)->lpVtbl -> get_Width(This,RHS) ) 

#define ICheckBox_put_Width(This,RHS)	\
    ( (This)->lpVtbl -> put_Width(This,RHS) ) 

#define ICheckBox_get_ZOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_ZOrder(This,RHS) ) 

#define ICheckBox_get_ShapeRange(This,RHS)	\
    ( (This)->lpVtbl -> get_ShapeRange(This,RHS) ) 

#define ICheckBox_get_Caption(This,RHS)	\
    ( (This)->lpVtbl -> get_Caption(This,RHS) ) 

#define ICheckBox_put_Caption(This,RHS)	\
    ( (This)->lpVtbl -> put_Caption(This,RHS) ) 

#define ICheckBox_get_Characters(This,Start,Length,RHS)	\
    ( (This)->lpVtbl -> get_Characters(This,Start,Length,RHS) ) 

#define ICheckBox_CheckSpelling(This,CustomDictionary,IgnoreUppercase,AlwaysSuggest,SpellLang,RHS)	\
    ( (This)->lpVtbl -> CheckSpelling(This,CustomDictionary,IgnoreUppercase,AlwaysSuggest,SpellLang,RHS) ) 

#define ICheckBox_get_LockedText(This,RHS)	\
    ( (This)->lpVtbl -> get_LockedText(This,RHS) ) 

#define ICheckBox_put_LockedText(This,RHS)	\
    ( (This)->lpVtbl -> put_LockedText(This,RHS) ) 

#define ICheckBox_get_Text(This,RHS)	\
    ( (This)->lpVtbl -> get_Text(This,RHS) ) 

#define ICheckBox_put_Text(This,RHS)	\
    ( (This)->lpVtbl -> put_Text(This,RHS) ) 

#define ICheckBox_get_Accelerator(This,RHS)	\
    ( (This)->lpVtbl -> get_Accelerator(This,RHS) ) 

#define ICheckBox_put_Accelerator(This,RHS)	\
    ( (This)->lpVtbl -> put_Accelerator(This,RHS) ) 

#define ICheckBox_get_Border(This,RHS)	\
    ( (This)->lpVtbl -> get_Border(This,RHS) ) 

#define ICheckBox_get__Default(This,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,RHS) ) 

#define ICheckBox_put__Default(This,RHS)	\
    ( (This)->lpVtbl -> put__Default(This,RHS) ) 

#define ICheckBox_get_Display3DShading(This,RHS)	\
    ( (This)->lpVtbl -> get_Display3DShading(This,RHS) ) 

#define ICheckBox_put_Display3DShading(This,RHS)	\
    ( (This)->lpVtbl -> put_Display3DShading(This,RHS) ) 

#define ICheckBox_get_Interior(This,RHS)	\
    ( (This)->lpVtbl -> get_Interior(This,RHS) ) 

#define ICheckBox_get_LinkedCell(This,RHS)	\
    ( (This)->lpVtbl -> get_LinkedCell(This,RHS) ) 

#define ICheckBox_put_LinkedCell(This,RHS)	\
    ( (This)->lpVtbl -> put_LinkedCell(This,RHS) ) 

#define ICheckBox_get_PhoneticAccelerator(This,RHS)	\
    ( (This)->lpVtbl -> get_PhoneticAccelerator(This,RHS) ) 

#define ICheckBox_put_PhoneticAccelerator(This,RHS)	\
    ( (This)->lpVtbl -> put_PhoneticAccelerator(This,RHS) ) 

#define ICheckBox_get_Value(This,RHS)	\
    ( (This)->lpVtbl -> get_Value(This,RHS) ) 

#define ICheckBox_put_Value(This,RHS)	\
    ( (This)->lpVtbl -> put_Value(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ICheckBox_INTERFACE_DEFINED__ */


#ifndef __ICheckBoxes_INTERFACE_DEFINED__
#define __ICheckBoxes_INTERFACE_DEFINED__

/* interface ICheckBoxes */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ICheckBoxes;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00020880-0001-0000-C000-000000000046")
    ICheckBoxes : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy3( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall BringToFront( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Copy( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CopyPicture( 
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Cut( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Duplicate( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Enabled( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Enabled( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Height( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Height( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy12( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Left( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Left( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Locked( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Locked( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy15( void) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_OnAction( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_OnAction( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Placement( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Placement( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PrintObject( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PrintObject( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SendToBack( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Top( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Top( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy22( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Visible( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Visible( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Width( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Width( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ZOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShapeRange( 
            /* [retval][out] */ ShapeRange	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Caption( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Caption( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Characters( 
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Length,
            /* [retval][out] */ Characters	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CheckSpelling( 
            /* [optional][in] */ VARIANT CustomDictionary,
            /* [optional][in] */ VARIANT IgnoreUppercase,
            /* [optional][in] */ VARIANT AlwaysSuggest,
            /* [optional][in] */ VARIANT SpellLang,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LockedText( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_LockedText( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Text( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Text( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Accelerator( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Accelerator( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Border( 
            /* [retval][out] */ Border	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put__Default( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Display3DShading( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Display3DShading( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Interior( 
            /* [retval][out] */ Interior	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LinkedCell( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_LinkedCell( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PhoneticAccelerator( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PhoneticAccelerator( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Value( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Value( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add( 
            /* [in] */ double Left,
            /* [in] */ double Top,
            /* [in] */ double Width,
            /* [in] */ double Height,
            /* [retval][out] */ CheckBox	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Group( 
            /* [retval][out] */ GroupObject	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall _NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ICheckBoxesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ICheckBoxes * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ICheckBoxes * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ICheckBoxes * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ICheckBoxes * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ICheckBoxes * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ICheckBoxes * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ICheckBoxes * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ICheckBoxes * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ICheckBoxes * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ICheckBoxes * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy3 )( 
            ICheckBoxes * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *BringToFront )( 
            ICheckBoxes * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Copy )( 
            ICheckBoxes * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CopyPicture )( 
            ICheckBoxes * This,
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Cut )( 
            ICheckBoxes * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            ICheckBoxes * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Duplicate )( 
            ICheckBoxes * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Enabled )( 
            ICheckBoxes * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Enabled )( 
            ICheckBoxes * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Height )( 
            ICheckBoxes * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Height )( 
            ICheckBoxes * This,
            /* [in] */ double RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy12 )( 
            ICheckBoxes * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Left )( 
            ICheckBoxes * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Left )( 
            ICheckBoxes * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Locked )( 
            ICheckBoxes * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Locked )( 
            ICheckBoxes * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy15 )( 
            ICheckBoxes * This);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_OnAction )( 
            ICheckBoxes * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_OnAction )( 
            ICheckBoxes * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Placement )( 
            ICheckBoxes * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Placement )( 
            ICheckBoxes * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PrintObject )( 
            ICheckBoxes * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PrintObject )( 
            ICheckBoxes * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            ICheckBoxes * This,
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SendToBack )( 
            ICheckBoxes * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Top )( 
            ICheckBoxes * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Top )( 
            ICheckBoxes * This,
            /* [in] */ double RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy22 )( 
            ICheckBoxes * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Visible )( 
            ICheckBoxes * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Visible )( 
            ICheckBoxes * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Width )( 
            ICheckBoxes * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Width )( 
            ICheckBoxes * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ZOrder )( 
            ICheckBoxes * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShapeRange )( 
            ICheckBoxes * This,
            /* [retval][out] */ ShapeRange	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Caption )( 
            ICheckBoxes * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Caption )( 
            ICheckBoxes * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Characters )( 
            ICheckBoxes * This,
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Length,
            /* [retval][out] */ Characters	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CheckSpelling )( 
            ICheckBoxes * This,
            /* [optional][in] */ VARIANT CustomDictionary,
            /* [optional][in] */ VARIANT IgnoreUppercase,
            /* [optional][in] */ VARIANT AlwaysSuggest,
            /* [optional][in] */ VARIANT SpellLang,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LockedText )( 
            ICheckBoxes * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_LockedText )( 
            ICheckBoxes * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Text )( 
            ICheckBoxes * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Text )( 
            ICheckBoxes * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Accelerator )( 
            ICheckBoxes * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Accelerator )( 
            ICheckBoxes * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Border )( 
            ICheckBoxes * This,
            /* [retval][out] */ Border	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            ICheckBoxes * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put__Default )( 
            ICheckBoxes * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Display3DShading )( 
            ICheckBoxes * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Display3DShading )( 
            ICheckBoxes * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Interior )( 
            ICheckBoxes * This,
            /* [retval][out] */ Interior	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LinkedCell )( 
            ICheckBoxes * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_LinkedCell )( 
            ICheckBoxes * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PhoneticAccelerator )( 
            ICheckBoxes * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PhoneticAccelerator )( 
            ICheckBoxes * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Value )( 
            ICheckBoxes * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Value )( 
            ICheckBoxes * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add )( 
            ICheckBoxes * This,
            /* [in] */ double Left,
            /* [in] */ double Top,
            /* [in] */ double Width,
            /* [in] */ double Height,
            /* [retval][out] */ CheckBox	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            ICheckBoxes * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Group )( 
            ICheckBoxes * This,
            /* [retval][out] */ GroupObject	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Item )( 
            ICheckBoxes * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *_NewEnum )( 
            ICheckBoxes * This,
            /* [retval][out] */ IUnknown **RHS);
        
        END_INTERFACE
    } ICheckBoxesVtbl;

    interface ICheckBoxes
    {
        CONST_VTBL struct ICheckBoxesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ICheckBoxes_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ICheckBoxes_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ICheckBoxes_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ICheckBoxes_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ICheckBoxes_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ICheckBoxes_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ICheckBoxes_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ICheckBoxes_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ICheckBoxes_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ICheckBoxes_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ICheckBoxes__Dummy3(This)	\
    ( (This)->lpVtbl -> _Dummy3(This) ) 

#define ICheckBoxes_BringToFront(This,RHS)	\
    ( (This)->lpVtbl -> BringToFront(This,RHS) ) 

#define ICheckBoxes_Copy(This,RHS)	\
    ( (This)->lpVtbl -> Copy(This,RHS) ) 

#define ICheckBoxes_CopyPicture(This,Appearance,Format,RHS)	\
    ( (This)->lpVtbl -> CopyPicture(This,Appearance,Format,RHS) ) 

#define ICheckBoxes_Cut(This,RHS)	\
    ( (This)->lpVtbl -> Cut(This,RHS) ) 

#define ICheckBoxes_Delete(This,RHS)	\
    ( (This)->lpVtbl -> Delete(This,RHS) ) 

#define ICheckBoxes_Duplicate(This,RHS)	\
    ( (This)->lpVtbl -> Duplicate(This,RHS) ) 

#define ICheckBoxes_get_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> get_Enabled(This,RHS) ) 

#define ICheckBoxes_put_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> put_Enabled(This,RHS) ) 

#define ICheckBoxes_get_Height(This,RHS)	\
    ( (This)->lpVtbl -> get_Height(This,RHS) ) 

#define ICheckBoxes_put_Height(This,RHS)	\
    ( (This)->lpVtbl -> put_Height(This,RHS) ) 

#define ICheckBoxes__Dummy12(This)	\
    ( (This)->lpVtbl -> _Dummy12(This) ) 

#define ICheckBoxes_get_Left(This,RHS)	\
    ( (This)->lpVtbl -> get_Left(This,RHS) ) 

#define ICheckBoxes_put_Left(This,RHS)	\
    ( (This)->lpVtbl -> put_Left(This,RHS) ) 

#define ICheckBoxes_get_Locked(This,RHS)	\
    ( (This)->lpVtbl -> get_Locked(This,RHS) ) 

#define ICheckBoxes_put_Locked(This,RHS)	\
    ( (This)->lpVtbl -> put_Locked(This,RHS) ) 

#define ICheckBoxes__Dummy15(This)	\
    ( (This)->lpVtbl -> _Dummy15(This) ) 

#define ICheckBoxes_get_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> get_OnAction(This,RHS) ) 

#define ICheckBoxes_put_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> put_OnAction(This,RHS) ) 

#define ICheckBoxes_get_Placement(This,RHS)	\
    ( (This)->lpVtbl -> get_Placement(This,RHS) ) 

#define ICheckBoxes_put_Placement(This,RHS)	\
    ( (This)->lpVtbl -> put_Placement(This,RHS) ) 

#define ICheckBoxes_get_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> get_PrintObject(This,RHS) ) 

#define ICheckBoxes_put_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> put_PrintObject(This,RHS) ) 

#define ICheckBoxes_Select(This,Replace,RHS)	\
    ( (This)->lpVtbl -> Select(This,Replace,RHS) ) 

#define ICheckBoxes_SendToBack(This,RHS)	\
    ( (This)->lpVtbl -> SendToBack(This,RHS) ) 

#define ICheckBoxes_get_Top(This,RHS)	\
    ( (This)->lpVtbl -> get_Top(This,RHS) ) 

#define ICheckBoxes_put_Top(This,RHS)	\
    ( (This)->lpVtbl -> put_Top(This,RHS) ) 

#define ICheckBoxes__Dummy22(This)	\
    ( (This)->lpVtbl -> _Dummy22(This) ) 

#define ICheckBoxes_get_Visible(This,RHS)	\
    ( (This)->lpVtbl -> get_Visible(This,RHS) ) 

#define ICheckBoxes_put_Visible(This,RHS)	\
    ( (This)->lpVtbl -> put_Visible(This,RHS) ) 

#define ICheckBoxes_get_Width(This,RHS)	\
    ( (This)->lpVtbl -> get_Width(This,RHS) ) 

#define ICheckBoxes_put_Width(This,RHS)	\
    ( (This)->lpVtbl -> put_Width(This,RHS) ) 

#define ICheckBoxes_get_ZOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_ZOrder(This,RHS) ) 

#define ICheckBoxes_get_ShapeRange(This,RHS)	\
    ( (This)->lpVtbl -> get_ShapeRange(This,RHS) ) 

#define ICheckBoxes_get_Caption(This,RHS)	\
    ( (This)->lpVtbl -> get_Caption(This,RHS) ) 

#define ICheckBoxes_put_Caption(This,RHS)	\
    ( (This)->lpVtbl -> put_Caption(This,RHS) ) 

#define ICheckBoxes_get_Characters(This,Start,Length,RHS)	\
    ( (This)->lpVtbl -> get_Characters(This,Start,Length,RHS) ) 

#define ICheckBoxes_CheckSpelling(This,CustomDictionary,IgnoreUppercase,AlwaysSuggest,SpellLang,RHS)	\
    ( (This)->lpVtbl -> CheckSpelling(This,CustomDictionary,IgnoreUppercase,AlwaysSuggest,SpellLang,RHS) ) 

#define ICheckBoxes_get_LockedText(This,RHS)	\
    ( (This)->lpVtbl -> get_LockedText(This,RHS) ) 

#define ICheckBoxes_put_LockedText(This,RHS)	\
    ( (This)->lpVtbl -> put_LockedText(This,RHS) ) 

#define ICheckBoxes_get_Text(This,RHS)	\
    ( (This)->lpVtbl -> get_Text(This,RHS) ) 

#define ICheckBoxes_put_Text(This,RHS)	\
    ( (This)->lpVtbl -> put_Text(This,RHS) ) 

#define ICheckBoxes_get_Accelerator(This,RHS)	\
    ( (This)->lpVtbl -> get_Accelerator(This,RHS) ) 

#define ICheckBoxes_put_Accelerator(This,RHS)	\
    ( (This)->lpVtbl -> put_Accelerator(This,RHS) ) 

#define ICheckBoxes_get_Border(This,RHS)	\
    ( (This)->lpVtbl -> get_Border(This,RHS) ) 

#define ICheckBoxes_get__Default(This,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,RHS) ) 

#define ICheckBoxes_put__Default(This,RHS)	\
    ( (This)->lpVtbl -> put__Default(This,RHS) ) 

#define ICheckBoxes_get_Display3DShading(This,RHS)	\
    ( (This)->lpVtbl -> get_Display3DShading(This,RHS) ) 

#define ICheckBoxes_put_Display3DShading(This,RHS)	\
    ( (This)->lpVtbl -> put_Display3DShading(This,RHS) ) 

#define ICheckBoxes_get_Interior(This,RHS)	\
    ( (This)->lpVtbl -> get_Interior(This,RHS) ) 

#define ICheckBoxes_get_LinkedCell(This,RHS)	\
    ( (This)->lpVtbl -> get_LinkedCell(This,RHS) ) 

#define ICheckBoxes_put_LinkedCell(This,RHS)	\
    ( (This)->lpVtbl -> put_LinkedCell(This,RHS) ) 

#define ICheckBoxes_get_PhoneticAccelerator(This,RHS)	\
    ( (This)->lpVtbl -> get_PhoneticAccelerator(This,RHS) ) 

#define ICheckBoxes_put_PhoneticAccelerator(This,RHS)	\
    ( (This)->lpVtbl -> put_PhoneticAccelerator(This,RHS) ) 

#define ICheckBoxes_get_Value(This,RHS)	\
    ( (This)->lpVtbl -> get_Value(This,RHS) ) 

#define ICheckBoxes_put_Value(This,RHS)	\
    ( (This)->lpVtbl -> put_Value(This,RHS) ) 

#define ICheckBoxes_Add(This,Left,Top,Width,Height,RHS)	\
    ( (This)->lpVtbl -> Add(This,Left,Top,Width,Height,RHS) ) 

#define ICheckBoxes_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define ICheckBoxes_Group(This,RHS)	\
    ( (This)->lpVtbl -> Group(This,RHS) ) 

#define ICheckBoxes_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> Item(This,Index,RHS) ) 

#define ICheckBoxes__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> _NewEnum(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ICheckBoxes_INTERFACE_DEFINED__ */


#ifndef __IOptionButton_INTERFACE_DEFINED__
#define __IOptionButton_INTERFACE_DEFINED__

/* interface IOptionButton */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IOptionButton;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00020881-0001-0000-C000-000000000046")
    IOptionButton : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_BottomRightCell( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall BringToFront( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Copy( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CopyPicture( 
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Cut( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Duplicate( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Enabled( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Enabled( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Height( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Height( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Index( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Left( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Left( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Locked( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Locked( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Name( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_OnAction( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_OnAction( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Placement( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Placement( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PrintObject( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PrintObject( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SendToBack( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Top( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Top( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TopLeftCell( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Visible( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Visible( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Width( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Width( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ZOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShapeRange( 
            /* [retval][out] */ ShapeRange	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Caption( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Caption( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Characters( 
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Length,
            /* [retval][out] */ Characters	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CheckSpelling( 
            /* [optional][in] */ VARIANT CustomDictionary,
            /* [optional][in] */ VARIANT IgnoreUppercase,
            /* [optional][in] */ VARIANT AlwaysSuggest,
            /* [optional][in] */ VARIANT SpellLang,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LockedText( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_LockedText( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Text( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Text( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Accelerator( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Accelerator( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Border( 
            /* [retval][out] */ Border	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put__Default( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Display3DShading( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Display3DShading( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Interior( 
            /* [retval][out] */ Interior	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LinkedCell( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_LinkedCell( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PhoneticAccelerator( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PhoneticAccelerator( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Value( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Value( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_GroupBox( 
            /* [retval][out] */ GroupBox	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IOptionButtonVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IOptionButton * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IOptionButton * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IOptionButton * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IOptionButton * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IOptionButton * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IOptionButton * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IOptionButton * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IOptionButton * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IOptionButton * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IOptionButton * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_BottomRightCell )( 
            IOptionButton * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *BringToFront )( 
            IOptionButton * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Copy )( 
            IOptionButton * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CopyPicture )( 
            IOptionButton * This,
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Cut )( 
            IOptionButton * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IOptionButton * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Duplicate )( 
            IOptionButton * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Enabled )( 
            IOptionButton * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Enabled )( 
            IOptionButton * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Height )( 
            IOptionButton * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Height )( 
            IOptionButton * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Index )( 
            IOptionButton * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Left )( 
            IOptionButton * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Left )( 
            IOptionButton * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Locked )( 
            IOptionButton * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Locked )( 
            IOptionButton * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            IOptionButton * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Name )( 
            IOptionButton * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_OnAction )( 
            IOptionButton * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_OnAction )( 
            IOptionButton * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Placement )( 
            IOptionButton * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Placement )( 
            IOptionButton * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PrintObject )( 
            IOptionButton * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PrintObject )( 
            IOptionButton * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            IOptionButton * This,
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SendToBack )( 
            IOptionButton * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Top )( 
            IOptionButton * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Top )( 
            IOptionButton * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TopLeftCell )( 
            IOptionButton * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Visible )( 
            IOptionButton * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Visible )( 
            IOptionButton * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Width )( 
            IOptionButton * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Width )( 
            IOptionButton * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ZOrder )( 
            IOptionButton * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShapeRange )( 
            IOptionButton * This,
            /* [retval][out] */ ShapeRange	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Caption )( 
            IOptionButton * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Caption )( 
            IOptionButton * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Characters )( 
            IOptionButton * This,
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Length,
            /* [retval][out] */ Characters	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CheckSpelling )( 
            IOptionButton * This,
            /* [optional][in] */ VARIANT CustomDictionary,
            /* [optional][in] */ VARIANT IgnoreUppercase,
            /* [optional][in] */ VARIANT AlwaysSuggest,
            /* [optional][in] */ VARIANT SpellLang,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LockedText )( 
            IOptionButton * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_LockedText )( 
            IOptionButton * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Text )( 
            IOptionButton * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Text )( 
            IOptionButton * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Accelerator )( 
            IOptionButton * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Accelerator )( 
            IOptionButton * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Border )( 
            IOptionButton * This,
            /* [retval][out] */ Border	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IOptionButton * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put__Default )( 
            IOptionButton * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Display3DShading )( 
            IOptionButton * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Display3DShading )( 
            IOptionButton * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Interior )( 
            IOptionButton * This,
            /* [retval][out] */ Interior	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LinkedCell )( 
            IOptionButton * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_LinkedCell )( 
            IOptionButton * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PhoneticAccelerator )( 
            IOptionButton * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PhoneticAccelerator )( 
            IOptionButton * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Value )( 
            IOptionButton * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Value )( 
            IOptionButton * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_GroupBox )( 
            IOptionButton * This,
            /* [retval][out] */ GroupBox	**RHS);
        
        END_INTERFACE
    } IOptionButtonVtbl;

    interface IOptionButton
    {
        CONST_VTBL struct IOptionButtonVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IOptionButton_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IOptionButton_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IOptionButton_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IOptionButton_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IOptionButton_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IOptionButton_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IOptionButton_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IOptionButton_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IOptionButton_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IOptionButton_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IOptionButton_get_BottomRightCell(This,RHS)	\
    ( (This)->lpVtbl -> get_BottomRightCell(This,RHS) ) 

#define IOptionButton_BringToFront(This,RHS)	\
    ( (This)->lpVtbl -> BringToFront(This,RHS) ) 

#define IOptionButton_Copy(This,RHS)	\
    ( (This)->lpVtbl -> Copy(This,RHS) ) 

#define IOptionButton_CopyPicture(This,Appearance,Format,RHS)	\
    ( (This)->lpVtbl -> CopyPicture(This,Appearance,Format,RHS) ) 

#define IOptionButton_Cut(This,RHS)	\
    ( (This)->lpVtbl -> Cut(This,RHS) ) 

#define IOptionButton_Delete(This,RHS)	\
    ( (This)->lpVtbl -> Delete(This,RHS) ) 

#define IOptionButton_Duplicate(This,RHS)	\
    ( (This)->lpVtbl -> Duplicate(This,RHS) ) 

#define IOptionButton_get_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> get_Enabled(This,RHS) ) 

#define IOptionButton_put_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> put_Enabled(This,RHS) ) 

#define IOptionButton_get_Height(This,RHS)	\
    ( (This)->lpVtbl -> get_Height(This,RHS) ) 

#define IOptionButton_put_Height(This,RHS)	\
    ( (This)->lpVtbl -> put_Height(This,RHS) ) 

#define IOptionButton_get_Index(This,RHS)	\
    ( (This)->lpVtbl -> get_Index(This,RHS) ) 

#define IOptionButton_get_Left(This,RHS)	\
    ( (This)->lpVtbl -> get_Left(This,RHS) ) 

#define IOptionButton_put_Left(This,RHS)	\
    ( (This)->lpVtbl -> put_Left(This,RHS) ) 

#define IOptionButton_get_Locked(This,RHS)	\
    ( (This)->lpVtbl -> get_Locked(This,RHS) ) 

#define IOptionButton_put_Locked(This,RHS)	\
    ( (This)->lpVtbl -> put_Locked(This,RHS) ) 

#define IOptionButton_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define IOptionButton_put_Name(This,RHS)	\
    ( (This)->lpVtbl -> put_Name(This,RHS) ) 

#define IOptionButton_get_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> get_OnAction(This,RHS) ) 

#define IOptionButton_put_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> put_OnAction(This,RHS) ) 

#define IOptionButton_get_Placement(This,RHS)	\
    ( (This)->lpVtbl -> get_Placement(This,RHS) ) 

#define IOptionButton_put_Placement(This,RHS)	\
    ( (This)->lpVtbl -> put_Placement(This,RHS) ) 

#define IOptionButton_get_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> get_PrintObject(This,RHS) ) 

#define IOptionButton_put_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> put_PrintObject(This,RHS) ) 

#define IOptionButton_Select(This,Replace,RHS)	\
    ( (This)->lpVtbl -> Select(This,Replace,RHS) ) 

#define IOptionButton_SendToBack(This,RHS)	\
    ( (This)->lpVtbl -> SendToBack(This,RHS) ) 

#define IOptionButton_get_Top(This,RHS)	\
    ( (This)->lpVtbl -> get_Top(This,RHS) ) 

#define IOptionButton_put_Top(This,RHS)	\
    ( (This)->lpVtbl -> put_Top(This,RHS) ) 

#define IOptionButton_get_TopLeftCell(This,RHS)	\
    ( (This)->lpVtbl -> get_TopLeftCell(This,RHS) ) 

#define IOptionButton_get_Visible(This,RHS)	\
    ( (This)->lpVtbl -> get_Visible(This,RHS) ) 

#define IOptionButton_put_Visible(This,RHS)	\
    ( (This)->lpVtbl -> put_Visible(This,RHS) ) 

#define IOptionButton_get_Width(This,RHS)	\
    ( (This)->lpVtbl -> get_Width(This,RHS) ) 

#define IOptionButton_put_Width(This,RHS)	\
    ( (This)->lpVtbl -> put_Width(This,RHS) ) 

#define IOptionButton_get_ZOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_ZOrder(This,RHS) ) 

#define IOptionButton_get_ShapeRange(This,RHS)	\
    ( (This)->lpVtbl -> get_ShapeRange(This,RHS) ) 

#define IOptionButton_get_Caption(This,RHS)	\
    ( (This)->lpVtbl -> get_Caption(This,RHS) ) 

#define IOptionButton_put_Caption(This,RHS)	\
    ( (This)->lpVtbl -> put_Caption(This,RHS) ) 

#define IOptionButton_get_Characters(This,Start,Length,RHS)	\
    ( (This)->lpVtbl -> get_Characters(This,Start,Length,RHS) ) 

#define IOptionButton_CheckSpelling(This,CustomDictionary,IgnoreUppercase,AlwaysSuggest,SpellLang,RHS)	\
    ( (This)->lpVtbl -> CheckSpelling(This,CustomDictionary,IgnoreUppercase,AlwaysSuggest,SpellLang,RHS) ) 

#define IOptionButton_get_LockedText(This,RHS)	\
    ( (This)->lpVtbl -> get_LockedText(This,RHS) ) 

#define IOptionButton_put_LockedText(This,RHS)	\
    ( (This)->lpVtbl -> put_LockedText(This,RHS) ) 

#define IOptionButton_get_Text(This,RHS)	\
    ( (This)->lpVtbl -> get_Text(This,RHS) ) 

#define IOptionButton_put_Text(This,RHS)	\
    ( (This)->lpVtbl -> put_Text(This,RHS) ) 

#define IOptionButton_get_Accelerator(This,RHS)	\
    ( (This)->lpVtbl -> get_Accelerator(This,RHS) ) 

#define IOptionButton_put_Accelerator(This,RHS)	\
    ( (This)->lpVtbl -> put_Accelerator(This,RHS) ) 

#define IOptionButton_get_Border(This,RHS)	\
    ( (This)->lpVtbl -> get_Border(This,RHS) ) 

#define IOptionButton_get__Default(This,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,RHS) ) 

#define IOptionButton_put__Default(This,RHS)	\
    ( (This)->lpVtbl -> put__Default(This,RHS) ) 

#define IOptionButton_get_Display3DShading(This,RHS)	\
    ( (This)->lpVtbl -> get_Display3DShading(This,RHS) ) 

#define IOptionButton_put_Display3DShading(This,RHS)	\
    ( (This)->lpVtbl -> put_Display3DShading(This,RHS) ) 

#define IOptionButton_get_Interior(This,RHS)	\
    ( (This)->lpVtbl -> get_Interior(This,RHS) ) 

#define IOptionButton_get_LinkedCell(This,RHS)	\
    ( (This)->lpVtbl -> get_LinkedCell(This,RHS) ) 

#define IOptionButton_put_LinkedCell(This,RHS)	\
    ( (This)->lpVtbl -> put_LinkedCell(This,RHS) ) 

#define IOptionButton_get_PhoneticAccelerator(This,RHS)	\
    ( (This)->lpVtbl -> get_PhoneticAccelerator(This,RHS) ) 

#define IOptionButton_put_PhoneticAccelerator(This,RHS)	\
    ( (This)->lpVtbl -> put_PhoneticAccelerator(This,RHS) ) 

#define IOptionButton_get_Value(This,RHS)	\
    ( (This)->lpVtbl -> get_Value(This,RHS) ) 

#define IOptionButton_put_Value(This,RHS)	\
    ( (This)->lpVtbl -> put_Value(This,RHS) ) 

#define IOptionButton_get_GroupBox(This,RHS)	\
    ( (This)->lpVtbl -> get_GroupBox(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IOptionButton_INTERFACE_DEFINED__ */


#ifndef __IOptionButtons_INTERFACE_DEFINED__
#define __IOptionButtons_INTERFACE_DEFINED__

/* interface IOptionButtons */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IOptionButtons;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00020882-0001-0000-C000-000000000046")
    IOptionButtons : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy3( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall BringToFront( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Copy( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CopyPicture( 
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Cut( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Duplicate( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Enabled( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Enabled( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Height( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Height( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy12( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Left( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Left( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Locked( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Locked( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy15( void) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_OnAction( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_OnAction( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Placement( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Placement( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PrintObject( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PrintObject( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SendToBack( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Top( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Top( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy22( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Visible( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Visible( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Width( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Width( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ZOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShapeRange( 
            /* [retval][out] */ ShapeRange	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Caption( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Caption( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Characters( 
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Length,
            /* [retval][out] */ Characters	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CheckSpelling( 
            /* [optional][in] */ VARIANT CustomDictionary,
            /* [optional][in] */ VARIANT IgnoreUppercase,
            /* [optional][in] */ VARIANT AlwaysSuggest,
            /* [optional][in] */ VARIANT SpellLang,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LockedText( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_LockedText( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Text( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Text( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Accelerator( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Accelerator( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Border( 
            /* [retval][out] */ Border	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put__Default( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Display3DShading( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Display3DShading( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Interior( 
            /* [retval][out] */ Interior	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LinkedCell( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_LinkedCell( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PhoneticAccelerator( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PhoneticAccelerator( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Value( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Value( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_GroupBox( 
            /* [retval][out] */ GroupBox	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add( 
            /* [in] */ double Left,
            /* [in] */ double Top,
            /* [in] */ double Width,
            /* [in] */ double Height,
            /* [retval][out] */ OptionButton	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Group( 
            /* [retval][out] */ GroupObject	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall _NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IOptionButtonsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IOptionButtons * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IOptionButtons * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IOptionButtons * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IOptionButtons * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IOptionButtons * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IOptionButtons * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IOptionButtons * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IOptionButtons * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IOptionButtons * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IOptionButtons * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy3 )( 
            IOptionButtons * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *BringToFront )( 
            IOptionButtons * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Copy )( 
            IOptionButtons * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CopyPicture )( 
            IOptionButtons * This,
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Cut )( 
            IOptionButtons * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IOptionButtons * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Duplicate )( 
            IOptionButtons * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Enabled )( 
            IOptionButtons * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Enabled )( 
            IOptionButtons * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Height )( 
            IOptionButtons * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Height )( 
            IOptionButtons * This,
            /* [in] */ double RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy12 )( 
            IOptionButtons * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Left )( 
            IOptionButtons * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Left )( 
            IOptionButtons * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Locked )( 
            IOptionButtons * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Locked )( 
            IOptionButtons * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy15 )( 
            IOptionButtons * This);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_OnAction )( 
            IOptionButtons * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_OnAction )( 
            IOptionButtons * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Placement )( 
            IOptionButtons * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Placement )( 
            IOptionButtons * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PrintObject )( 
            IOptionButtons * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PrintObject )( 
            IOptionButtons * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            IOptionButtons * This,
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SendToBack )( 
            IOptionButtons * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Top )( 
            IOptionButtons * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Top )( 
            IOptionButtons * This,
            /* [in] */ double RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy22 )( 
            IOptionButtons * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Visible )( 
            IOptionButtons * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Visible )( 
            IOptionButtons * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Width )( 
            IOptionButtons * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Width )( 
            IOptionButtons * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ZOrder )( 
            IOptionButtons * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShapeRange )( 
            IOptionButtons * This,
            /* [retval][out] */ ShapeRange	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Caption )( 
            IOptionButtons * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Caption )( 
            IOptionButtons * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Characters )( 
            IOptionButtons * This,
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Length,
            /* [retval][out] */ Characters	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CheckSpelling )( 
            IOptionButtons * This,
            /* [optional][in] */ VARIANT CustomDictionary,
            /* [optional][in] */ VARIANT IgnoreUppercase,
            /* [optional][in] */ VARIANT AlwaysSuggest,
            /* [optional][in] */ VARIANT SpellLang,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LockedText )( 
            IOptionButtons * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_LockedText )( 
            IOptionButtons * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Text )( 
            IOptionButtons * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Text )( 
            IOptionButtons * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Accelerator )( 
            IOptionButtons * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Accelerator )( 
            IOptionButtons * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Border )( 
            IOptionButtons * This,
            /* [retval][out] */ Border	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IOptionButtons * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put__Default )( 
            IOptionButtons * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Display3DShading )( 
            IOptionButtons * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Display3DShading )( 
            IOptionButtons * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Interior )( 
            IOptionButtons * This,
            /* [retval][out] */ Interior	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LinkedCell )( 
            IOptionButtons * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_LinkedCell )( 
            IOptionButtons * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PhoneticAccelerator )( 
            IOptionButtons * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PhoneticAccelerator )( 
            IOptionButtons * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Value )( 
            IOptionButtons * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Value )( 
            IOptionButtons * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_GroupBox )( 
            IOptionButtons * This,
            /* [retval][out] */ GroupBox	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add )( 
            IOptionButtons * This,
            /* [in] */ double Left,
            /* [in] */ double Top,
            /* [in] */ double Width,
            /* [in] */ double Height,
            /* [retval][out] */ OptionButton	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IOptionButtons * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Group )( 
            IOptionButtons * This,
            /* [retval][out] */ GroupObject	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Item )( 
            IOptionButtons * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *_NewEnum )( 
            IOptionButtons * This,
            /* [retval][out] */ IUnknown **RHS);
        
        END_INTERFACE
    } IOptionButtonsVtbl;

    interface IOptionButtons
    {
        CONST_VTBL struct IOptionButtonsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IOptionButtons_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IOptionButtons_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IOptionButtons_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IOptionButtons_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IOptionButtons_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IOptionButtons_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IOptionButtons_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IOptionButtons_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IOptionButtons_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IOptionButtons_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IOptionButtons__Dummy3(This)	\
    ( (This)->lpVtbl -> _Dummy3(This) ) 

#define IOptionButtons_BringToFront(This,RHS)	\
    ( (This)->lpVtbl -> BringToFront(This,RHS) ) 

#define IOptionButtons_Copy(This,RHS)	\
    ( (This)->lpVtbl -> Copy(This,RHS) ) 

#define IOptionButtons_CopyPicture(This,Appearance,Format,RHS)	\
    ( (This)->lpVtbl -> CopyPicture(This,Appearance,Format,RHS) ) 

#define IOptionButtons_Cut(This,RHS)	\
    ( (This)->lpVtbl -> Cut(This,RHS) ) 

#define IOptionButtons_Delete(This,RHS)	\
    ( (This)->lpVtbl -> Delete(This,RHS) ) 

#define IOptionButtons_Duplicate(This,RHS)	\
    ( (This)->lpVtbl -> Duplicate(This,RHS) ) 

#define IOptionButtons_get_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> get_Enabled(This,RHS) ) 

#define IOptionButtons_put_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> put_Enabled(This,RHS) ) 

#define IOptionButtons_get_Height(This,RHS)	\
    ( (This)->lpVtbl -> get_Height(This,RHS) ) 

#define IOptionButtons_put_Height(This,RHS)	\
    ( (This)->lpVtbl -> put_Height(This,RHS) ) 

#define IOptionButtons__Dummy12(This)	\
    ( (This)->lpVtbl -> _Dummy12(This) ) 

#define IOptionButtons_get_Left(This,RHS)	\
    ( (This)->lpVtbl -> get_Left(This,RHS) ) 

#define IOptionButtons_put_Left(This,RHS)	\
    ( (This)->lpVtbl -> put_Left(This,RHS) ) 

#define IOptionButtons_get_Locked(This,RHS)	\
    ( (This)->lpVtbl -> get_Locked(This,RHS) ) 

#define IOptionButtons_put_Locked(This,RHS)	\
    ( (This)->lpVtbl -> put_Locked(This,RHS) ) 

#define IOptionButtons__Dummy15(This)	\
    ( (This)->lpVtbl -> _Dummy15(This) ) 

#define IOptionButtons_get_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> get_OnAction(This,RHS) ) 

#define IOptionButtons_put_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> put_OnAction(This,RHS) ) 

#define IOptionButtons_get_Placement(This,RHS)	\
    ( (This)->lpVtbl -> get_Placement(This,RHS) ) 

#define IOptionButtons_put_Placement(This,RHS)	\
    ( (This)->lpVtbl -> put_Placement(This,RHS) ) 

#define IOptionButtons_get_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> get_PrintObject(This,RHS) ) 

#define IOptionButtons_put_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> put_PrintObject(This,RHS) ) 

#define IOptionButtons_Select(This,Replace,RHS)	\
    ( (This)->lpVtbl -> Select(This,Replace,RHS) ) 

#define IOptionButtons_SendToBack(This,RHS)	\
    ( (This)->lpVtbl -> SendToBack(This,RHS) ) 

#define IOptionButtons_get_Top(This,RHS)	\
    ( (This)->lpVtbl -> get_Top(This,RHS) ) 

#define IOptionButtons_put_Top(This,RHS)	\
    ( (This)->lpVtbl -> put_Top(This,RHS) ) 

#define IOptionButtons__Dummy22(This)	\
    ( (This)->lpVtbl -> _Dummy22(This) ) 

#define IOptionButtons_get_Visible(This,RHS)	\
    ( (This)->lpVtbl -> get_Visible(This,RHS) ) 

#define IOptionButtons_put_Visible(This,RHS)	\
    ( (This)->lpVtbl -> put_Visible(This,RHS) ) 

#define IOptionButtons_get_Width(This,RHS)	\
    ( (This)->lpVtbl -> get_Width(This,RHS) ) 

#define IOptionButtons_put_Width(This,RHS)	\
    ( (This)->lpVtbl -> put_Width(This,RHS) ) 

#define IOptionButtons_get_ZOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_ZOrder(This,RHS) ) 

#define IOptionButtons_get_ShapeRange(This,RHS)	\
    ( (This)->lpVtbl -> get_ShapeRange(This,RHS) ) 

#define IOptionButtons_get_Caption(This,RHS)	\
    ( (This)->lpVtbl -> get_Caption(This,RHS) ) 

#define IOptionButtons_put_Caption(This,RHS)	\
    ( (This)->lpVtbl -> put_Caption(This,RHS) ) 

#define IOptionButtons_get_Characters(This,Start,Length,RHS)	\
    ( (This)->lpVtbl -> get_Characters(This,Start,Length,RHS) ) 

#define IOptionButtons_CheckSpelling(This,CustomDictionary,IgnoreUppercase,AlwaysSuggest,SpellLang,RHS)	\
    ( (This)->lpVtbl -> CheckSpelling(This,CustomDictionary,IgnoreUppercase,AlwaysSuggest,SpellLang,RHS) ) 

#define IOptionButtons_get_LockedText(This,RHS)	\
    ( (This)->lpVtbl -> get_LockedText(This,RHS) ) 

#define IOptionButtons_put_LockedText(This,RHS)	\
    ( (This)->lpVtbl -> put_LockedText(This,RHS) ) 

#define IOptionButtons_get_Text(This,RHS)	\
    ( (This)->lpVtbl -> get_Text(This,RHS) ) 

#define IOptionButtons_put_Text(This,RHS)	\
    ( (This)->lpVtbl -> put_Text(This,RHS) ) 

#define IOptionButtons_get_Accelerator(This,RHS)	\
    ( (This)->lpVtbl -> get_Accelerator(This,RHS) ) 

#define IOptionButtons_put_Accelerator(This,RHS)	\
    ( (This)->lpVtbl -> put_Accelerator(This,RHS) ) 

#define IOptionButtons_get_Border(This,RHS)	\
    ( (This)->lpVtbl -> get_Border(This,RHS) ) 

#define IOptionButtons_get__Default(This,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,RHS) ) 

#define IOptionButtons_put__Default(This,RHS)	\
    ( (This)->lpVtbl -> put__Default(This,RHS) ) 

#define IOptionButtons_get_Display3DShading(This,RHS)	\
    ( (This)->lpVtbl -> get_Display3DShading(This,RHS) ) 

#define IOptionButtons_put_Display3DShading(This,RHS)	\
    ( (This)->lpVtbl -> put_Display3DShading(This,RHS) ) 

#define IOptionButtons_get_Interior(This,RHS)	\
    ( (This)->lpVtbl -> get_Interior(This,RHS) ) 

#define IOptionButtons_get_LinkedCell(This,RHS)	\
    ( (This)->lpVtbl -> get_LinkedCell(This,RHS) ) 

#define IOptionButtons_put_LinkedCell(This,RHS)	\
    ( (This)->lpVtbl -> put_LinkedCell(This,RHS) ) 

#define IOptionButtons_get_PhoneticAccelerator(This,RHS)	\
    ( (This)->lpVtbl -> get_PhoneticAccelerator(This,RHS) ) 

#define IOptionButtons_put_PhoneticAccelerator(This,RHS)	\
    ( (This)->lpVtbl -> put_PhoneticAccelerator(This,RHS) ) 

#define IOptionButtons_get_Value(This,RHS)	\
    ( (This)->lpVtbl -> get_Value(This,RHS) ) 

#define IOptionButtons_put_Value(This,RHS)	\
    ( (This)->lpVtbl -> put_Value(This,RHS) ) 

#define IOptionButtons_get_GroupBox(This,RHS)	\
    ( (This)->lpVtbl -> get_GroupBox(This,RHS) ) 

#define IOptionButtons_Add(This,Left,Top,Width,Height,RHS)	\
    ( (This)->lpVtbl -> Add(This,Left,Top,Width,Height,RHS) ) 

#define IOptionButtons_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IOptionButtons_Group(This,RHS)	\
    ( (This)->lpVtbl -> Group(This,RHS) ) 

#define IOptionButtons_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> Item(This,Index,RHS) ) 

#define IOptionButtons__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> _NewEnum(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IOptionButtons_INTERFACE_DEFINED__ */


#ifndef __IEditBox_INTERFACE_DEFINED__
#define __IEditBox_INTERFACE_DEFINED__

/* interface IEditBox */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IEditBox;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00020883-0001-0000-C000-000000000046")
    IEditBox : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_BottomRightCell( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall BringToFront( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Copy( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CopyPicture( 
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Cut( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Duplicate( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Enabled( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Enabled( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Height( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Height( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Index( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Left( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Left( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Locked( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Locked( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Name( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_OnAction( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_OnAction( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Placement( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Placement( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PrintObject( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PrintObject( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SendToBack( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Top( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Top( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TopLeftCell( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Visible( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Visible( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Width( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Width( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ZOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShapeRange( 
            /* [retval][out] */ ShapeRange	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Caption( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Caption( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Characters( 
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Length,
            /* [retval][out] */ Characters	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CheckSpelling( 
            /* [optional][in] */ VARIANT CustomDictionary,
            /* [optional][in] */ VARIANT IgnoreUppercase,
            /* [optional][in] */ VARIANT AlwaysSuggest,
            /* [optional][in] */ VARIANT SpellLang,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LockedText( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_LockedText( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Text( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Text( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DisplayVerticalScrollBar( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DisplayVerticalScrollBar( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_InputType( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_InputType( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LinkedObject( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MultiLine( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_MultiLine( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PasswordEdit( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PasswordEdit( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IEditBoxVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IEditBox * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IEditBox * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IEditBox * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IEditBox * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IEditBox * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IEditBox * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IEditBox * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IEditBox * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IEditBox * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IEditBox * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_BottomRightCell )( 
            IEditBox * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *BringToFront )( 
            IEditBox * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Copy )( 
            IEditBox * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CopyPicture )( 
            IEditBox * This,
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Cut )( 
            IEditBox * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IEditBox * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Duplicate )( 
            IEditBox * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Enabled )( 
            IEditBox * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Enabled )( 
            IEditBox * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Height )( 
            IEditBox * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Height )( 
            IEditBox * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Index )( 
            IEditBox * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Left )( 
            IEditBox * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Left )( 
            IEditBox * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Locked )( 
            IEditBox * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Locked )( 
            IEditBox * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            IEditBox * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Name )( 
            IEditBox * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_OnAction )( 
            IEditBox * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_OnAction )( 
            IEditBox * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Placement )( 
            IEditBox * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Placement )( 
            IEditBox * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PrintObject )( 
            IEditBox * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PrintObject )( 
            IEditBox * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            IEditBox * This,
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SendToBack )( 
            IEditBox * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Top )( 
            IEditBox * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Top )( 
            IEditBox * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TopLeftCell )( 
            IEditBox * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Visible )( 
            IEditBox * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Visible )( 
            IEditBox * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Width )( 
            IEditBox * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Width )( 
            IEditBox * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ZOrder )( 
            IEditBox * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShapeRange )( 
            IEditBox * This,
            /* [retval][out] */ ShapeRange	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Caption )( 
            IEditBox * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Caption )( 
            IEditBox * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Characters )( 
            IEditBox * This,
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Length,
            /* [retval][out] */ Characters	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CheckSpelling )( 
            IEditBox * This,
            /* [optional][in] */ VARIANT CustomDictionary,
            /* [optional][in] */ VARIANT IgnoreUppercase,
            /* [optional][in] */ VARIANT AlwaysSuggest,
            /* [optional][in] */ VARIANT SpellLang,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LockedText )( 
            IEditBox * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_LockedText )( 
            IEditBox * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Text )( 
            IEditBox * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Text )( 
            IEditBox * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DisplayVerticalScrollBar )( 
            IEditBox * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DisplayVerticalScrollBar )( 
            IEditBox * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_InputType )( 
            IEditBox * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_InputType )( 
            IEditBox * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LinkedObject )( 
            IEditBox * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MultiLine )( 
            IEditBox * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_MultiLine )( 
            IEditBox * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PasswordEdit )( 
            IEditBox * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PasswordEdit )( 
            IEditBox * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        END_INTERFACE
    } IEditBoxVtbl;

    interface IEditBox
    {
        CONST_VTBL struct IEditBoxVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IEditBox_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IEditBox_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IEditBox_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IEditBox_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IEditBox_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IEditBox_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IEditBox_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IEditBox_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IEditBox_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IEditBox_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IEditBox_get_BottomRightCell(This,RHS)	\
    ( (This)->lpVtbl -> get_BottomRightCell(This,RHS) ) 

#define IEditBox_BringToFront(This,RHS)	\
    ( (This)->lpVtbl -> BringToFront(This,RHS) ) 

#define IEditBox_Copy(This,RHS)	\
    ( (This)->lpVtbl -> Copy(This,RHS) ) 

#define IEditBox_CopyPicture(This,Appearance,Format,RHS)	\
    ( (This)->lpVtbl -> CopyPicture(This,Appearance,Format,RHS) ) 

#define IEditBox_Cut(This,RHS)	\
    ( (This)->lpVtbl -> Cut(This,RHS) ) 

#define IEditBox_Delete(This,RHS)	\
    ( (This)->lpVtbl -> Delete(This,RHS) ) 

#define IEditBox_Duplicate(This,RHS)	\
    ( (This)->lpVtbl -> Duplicate(This,RHS) ) 

#define IEditBox_get_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> get_Enabled(This,RHS) ) 

#define IEditBox_put_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> put_Enabled(This,RHS) ) 

#define IEditBox_get_Height(This,RHS)	\
    ( (This)->lpVtbl -> get_Height(This,RHS) ) 

#define IEditBox_put_Height(This,RHS)	\
    ( (This)->lpVtbl -> put_Height(This,RHS) ) 

#define IEditBox_get_Index(This,RHS)	\
    ( (This)->lpVtbl -> get_Index(This,RHS) ) 

#define IEditBox_get_Left(This,RHS)	\
    ( (This)->lpVtbl -> get_Left(This,RHS) ) 

#define IEditBox_put_Left(This,RHS)	\
    ( (This)->lpVtbl -> put_Left(This,RHS) ) 

#define IEditBox_get_Locked(This,RHS)	\
    ( (This)->lpVtbl -> get_Locked(This,RHS) ) 

#define IEditBox_put_Locked(This,RHS)	\
    ( (This)->lpVtbl -> put_Locked(This,RHS) ) 

#define IEditBox_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define IEditBox_put_Name(This,RHS)	\
    ( (This)->lpVtbl -> put_Name(This,RHS) ) 

#define IEditBox_get_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> get_OnAction(This,RHS) ) 

#define IEditBox_put_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> put_OnAction(This,RHS) ) 

#define IEditBox_get_Placement(This,RHS)	\
    ( (This)->lpVtbl -> get_Placement(This,RHS) ) 

#define IEditBox_put_Placement(This,RHS)	\
    ( (This)->lpVtbl -> put_Placement(This,RHS) ) 

#define IEditBox_get_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> get_PrintObject(This,RHS) ) 

#define IEditBox_put_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> put_PrintObject(This,RHS) ) 

#define IEditBox_Select(This,Replace,RHS)	\
    ( (This)->lpVtbl -> Select(This,Replace,RHS) ) 

#define IEditBox_SendToBack(This,RHS)	\
    ( (This)->lpVtbl -> SendToBack(This,RHS) ) 

#define IEditBox_get_Top(This,RHS)	\
    ( (This)->lpVtbl -> get_Top(This,RHS) ) 

#define IEditBox_put_Top(This,RHS)	\
    ( (This)->lpVtbl -> put_Top(This,RHS) ) 

#define IEditBox_get_TopLeftCell(This,RHS)	\
    ( (This)->lpVtbl -> get_TopLeftCell(This,RHS) ) 

#define IEditBox_get_Visible(This,RHS)	\
    ( (This)->lpVtbl -> get_Visible(This,RHS) ) 

#define IEditBox_put_Visible(This,RHS)	\
    ( (This)->lpVtbl -> put_Visible(This,RHS) ) 

#define IEditBox_get_Width(This,RHS)	\
    ( (This)->lpVtbl -> get_Width(This,RHS) ) 

#define IEditBox_put_Width(This,RHS)	\
    ( (This)->lpVtbl -> put_Width(This,RHS) ) 

#define IEditBox_get_ZOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_ZOrder(This,RHS) ) 

#define IEditBox_get_ShapeRange(This,RHS)	\
    ( (This)->lpVtbl -> get_ShapeRange(This,RHS) ) 

#define IEditBox_get_Caption(This,RHS)	\
    ( (This)->lpVtbl -> get_Caption(This,RHS) ) 

#define IEditBox_put_Caption(This,RHS)	\
    ( (This)->lpVtbl -> put_Caption(This,RHS) ) 

#define IEditBox_get_Characters(This,Start,Length,RHS)	\
    ( (This)->lpVtbl -> get_Characters(This,Start,Length,RHS) ) 

#define IEditBox_CheckSpelling(This,CustomDictionary,IgnoreUppercase,AlwaysSuggest,SpellLang,RHS)	\
    ( (This)->lpVtbl -> CheckSpelling(This,CustomDictionary,IgnoreUppercase,AlwaysSuggest,SpellLang,RHS) ) 

#define IEditBox_get_LockedText(This,RHS)	\
    ( (This)->lpVtbl -> get_LockedText(This,RHS) ) 

#define IEditBox_put_LockedText(This,RHS)	\
    ( (This)->lpVtbl -> put_LockedText(This,RHS) ) 

#define IEditBox_get_Text(This,RHS)	\
    ( (This)->lpVtbl -> get_Text(This,RHS) ) 

#define IEditBox_put_Text(This,RHS)	\
    ( (This)->lpVtbl -> put_Text(This,RHS) ) 

#define IEditBox_get_DisplayVerticalScrollBar(This,RHS)	\
    ( (This)->lpVtbl -> get_DisplayVerticalScrollBar(This,RHS) ) 

#define IEditBox_put_DisplayVerticalScrollBar(This,RHS)	\
    ( (This)->lpVtbl -> put_DisplayVerticalScrollBar(This,RHS) ) 

#define IEditBox_get_InputType(This,RHS)	\
    ( (This)->lpVtbl -> get_InputType(This,RHS) ) 

#define IEditBox_put_InputType(This,RHS)	\
    ( (This)->lpVtbl -> put_InputType(This,RHS) ) 

#define IEditBox_get_LinkedObject(This,RHS)	\
    ( (This)->lpVtbl -> get_LinkedObject(This,RHS) ) 

#define IEditBox_get_MultiLine(This,RHS)	\
    ( (This)->lpVtbl -> get_MultiLine(This,RHS) ) 

#define IEditBox_put_MultiLine(This,RHS)	\
    ( (This)->lpVtbl -> put_MultiLine(This,RHS) ) 

#define IEditBox_get_PasswordEdit(This,RHS)	\
    ( (This)->lpVtbl -> get_PasswordEdit(This,RHS) ) 

#define IEditBox_put_PasswordEdit(This,RHS)	\
    ( (This)->lpVtbl -> put_PasswordEdit(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IEditBox_INTERFACE_DEFINED__ */


#ifndef __IEditBoxes_INTERFACE_DEFINED__
#define __IEditBoxes_INTERFACE_DEFINED__

/* interface IEditBoxes */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IEditBoxes;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00020884-0001-0000-C000-000000000046")
    IEditBoxes : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy3( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall BringToFront( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Copy( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CopyPicture( 
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Cut( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Duplicate( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Enabled( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Enabled( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Height( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Height( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy12( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Left( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Left( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Locked( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Locked( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy15( void) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_OnAction( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_OnAction( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Placement( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Placement( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PrintObject( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PrintObject( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SendToBack( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Top( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Top( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy22( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Visible( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Visible( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Width( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Width( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ZOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShapeRange( 
            /* [retval][out] */ ShapeRange	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Caption( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Caption( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Characters( 
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Length,
            /* [retval][out] */ Characters	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CheckSpelling( 
            /* [optional][in] */ VARIANT CustomDictionary,
            /* [optional][in] */ VARIANT IgnoreUppercase,
            /* [optional][in] */ VARIANT AlwaysSuggest,
            /* [optional][in] */ VARIANT SpellLang,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LockedText( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_LockedText( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Text( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Text( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DisplayVerticalScrollBar( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DisplayVerticalScrollBar( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_InputType( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_InputType( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy34( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MultiLine( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_MultiLine( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PasswordEdit( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PasswordEdit( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add( 
            /* [in] */ double Left,
            /* [in] */ double Top,
            /* [in] */ double Width,
            /* [in] */ double Height,
            /* [retval][out] */ EditBox	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Group( 
            /* [retval][out] */ GroupObject	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall _NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IEditBoxesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IEditBoxes * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IEditBoxes * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IEditBoxes * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IEditBoxes * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IEditBoxes * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IEditBoxes * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IEditBoxes * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IEditBoxes * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IEditBoxes * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IEditBoxes * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy3 )( 
            IEditBoxes * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *BringToFront )( 
            IEditBoxes * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Copy )( 
            IEditBoxes * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CopyPicture )( 
            IEditBoxes * This,
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Cut )( 
            IEditBoxes * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IEditBoxes * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Duplicate )( 
            IEditBoxes * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Enabled )( 
            IEditBoxes * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Enabled )( 
            IEditBoxes * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Height )( 
            IEditBoxes * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Height )( 
            IEditBoxes * This,
            /* [in] */ double RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy12 )( 
            IEditBoxes * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Left )( 
            IEditBoxes * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Left )( 
            IEditBoxes * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Locked )( 
            IEditBoxes * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Locked )( 
            IEditBoxes * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy15 )( 
            IEditBoxes * This);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_OnAction )( 
            IEditBoxes * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_OnAction )( 
            IEditBoxes * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Placement )( 
            IEditBoxes * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Placement )( 
            IEditBoxes * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PrintObject )( 
            IEditBoxes * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PrintObject )( 
            IEditBoxes * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            IEditBoxes * This,
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SendToBack )( 
            IEditBoxes * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Top )( 
            IEditBoxes * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Top )( 
            IEditBoxes * This,
            /* [in] */ double RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy22 )( 
            IEditBoxes * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Visible )( 
            IEditBoxes * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Visible )( 
            IEditBoxes * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Width )( 
            IEditBoxes * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Width )( 
            IEditBoxes * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ZOrder )( 
            IEditBoxes * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShapeRange )( 
            IEditBoxes * This,
            /* [retval][out] */ ShapeRange	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Caption )( 
            IEditBoxes * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Caption )( 
            IEditBoxes * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Characters )( 
            IEditBoxes * This,
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Length,
            /* [retval][out] */ Characters	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CheckSpelling )( 
            IEditBoxes * This,
            /* [optional][in] */ VARIANT CustomDictionary,
            /* [optional][in] */ VARIANT IgnoreUppercase,
            /* [optional][in] */ VARIANT AlwaysSuggest,
            /* [optional][in] */ VARIANT SpellLang,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LockedText )( 
            IEditBoxes * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_LockedText )( 
            IEditBoxes * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Text )( 
            IEditBoxes * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Text )( 
            IEditBoxes * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DisplayVerticalScrollBar )( 
            IEditBoxes * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DisplayVerticalScrollBar )( 
            IEditBoxes * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_InputType )( 
            IEditBoxes * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_InputType )( 
            IEditBoxes * This,
            /* [in] */ long RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy34 )( 
            IEditBoxes * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MultiLine )( 
            IEditBoxes * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_MultiLine )( 
            IEditBoxes * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PasswordEdit )( 
            IEditBoxes * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PasswordEdit )( 
            IEditBoxes * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add )( 
            IEditBoxes * This,
            /* [in] */ double Left,
            /* [in] */ double Top,
            /* [in] */ double Width,
            /* [in] */ double Height,
            /* [retval][out] */ EditBox	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IEditBoxes * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Group )( 
            IEditBoxes * This,
            /* [retval][out] */ GroupObject	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Item )( 
            IEditBoxes * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *_NewEnum )( 
            IEditBoxes * This,
            /* [retval][out] */ IUnknown **RHS);
        
        END_INTERFACE
    } IEditBoxesVtbl;

    interface IEditBoxes
    {
        CONST_VTBL struct IEditBoxesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IEditBoxes_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IEditBoxes_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IEditBoxes_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IEditBoxes_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IEditBoxes_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IEditBoxes_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IEditBoxes_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IEditBoxes_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IEditBoxes_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IEditBoxes_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IEditBoxes__Dummy3(This)	\
    ( (This)->lpVtbl -> _Dummy3(This) ) 

#define IEditBoxes_BringToFront(This,RHS)	\
    ( (This)->lpVtbl -> BringToFront(This,RHS) ) 

#define IEditBoxes_Copy(This,RHS)	\
    ( (This)->lpVtbl -> Copy(This,RHS) ) 

#define IEditBoxes_CopyPicture(This,Appearance,Format,RHS)	\
    ( (This)->lpVtbl -> CopyPicture(This,Appearance,Format,RHS) ) 

#define IEditBoxes_Cut(This,RHS)	\
    ( (This)->lpVtbl -> Cut(This,RHS) ) 

#define IEditBoxes_Delete(This,RHS)	\
    ( (This)->lpVtbl -> Delete(This,RHS) ) 

#define IEditBoxes_Duplicate(This,RHS)	\
    ( (This)->lpVtbl -> Duplicate(This,RHS) ) 

#define IEditBoxes_get_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> get_Enabled(This,RHS) ) 

#define IEditBoxes_put_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> put_Enabled(This,RHS) ) 

#define IEditBoxes_get_Height(This,RHS)	\
    ( (This)->lpVtbl -> get_Height(This,RHS) ) 

#define IEditBoxes_put_Height(This,RHS)	\
    ( (This)->lpVtbl -> put_Height(This,RHS) ) 

#define IEditBoxes__Dummy12(This)	\
    ( (This)->lpVtbl -> _Dummy12(This) ) 

#define IEditBoxes_get_Left(This,RHS)	\
    ( (This)->lpVtbl -> get_Left(This,RHS) ) 

#define IEditBoxes_put_Left(This,RHS)	\
    ( (This)->lpVtbl -> put_Left(This,RHS) ) 

#define IEditBoxes_get_Locked(This,RHS)	\
    ( (This)->lpVtbl -> get_Locked(This,RHS) ) 

#define IEditBoxes_put_Locked(This,RHS)	\
    ( (This)->lpVtbl -> put_Locked(This,RHS) ) 

#define IEditBoxes__Dummy15(This)	\
    ( (This)->lpVtbl -> _Dummy15(This) ) 

#define IEditBoxes_get_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> get_OnAction(This,RHS) ) 

#define IEditBoxes_put_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> put_OnAction(This,RHS) ) 

#define IEditBoxes_get_Placement(This,RHS)	\
    ( (This)->lpVtbl -> get_Placement(This,RHS) ) 

#define IEditBoxes_put_Placement(This,RHS)	\
    ( (This)->lpVtbl -> put_Placement(This,RHS) ) 

#define IEditBoxes_get_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> get_PrintObject(This,RHS) ) 

#define IEditBoxes_put_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> put_PrintObject(This,RHS) ) 

#define IEditBoxes_Select(This,Replace,RHS)	\
    ( (This)->lpVtbl -> Select(This,Replace,RHS) ) 

#define IEditBoxes_SendToBack(This,RHS)	\
    ( (This)->lpVtbl -> SendToBack(This,RHS) ) 

#define IEditBoxes_get_Top(This,RHS)	\
    ( (This)->lpVtbl -> get_Top(This,RHS) ) 

#define IEditBoxes_put_Top(This,RHS)	\
    ( (This)->lpVtbl -> put_Top(This,RHS) ) 

#define IEditBoxes__Dummy22(This)	\
    ( (This)->lpVtbl -> _Dummy22(This) ) 

#define IEditBoxes_get_Visible(This,RHS)	\
    ( (This)->lpVtbl -> get_Visible(This,RHS) ) 

#define IEditBoxes_put_Visible(This,RHS)	\
    ( (This)->lpVtbl -> put_Visible(This,RHS) ) 

#define IEditBoxes_get_Width(This,RHS)	\
    ( (This)->lpVtbl -> get_Width(This,RHS) ) 

#define IEditBoxes_put_Width(This,RHS)	\
    ( (This)->lpVtbl -> put_Width(This,RHS) ) 

#define IEditBoxes_get_ZOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_ZOrder(This,RHS) ) 

#define IEditBoxes_get_ShapeRange(This,RHS)	\
    ( (This)->lpVtbl -> get_ShapeRange(This,RHS) ) 

#define IEditBoxes_get_Caption(This,RHS)	\
    ( (This)->lpVtbl -> get_Caption(This,RHS) ) 

#define IEditBoxes_put_Caption(This,RHS)	\
    ( (This)->lpVtbl -> put_Caption(This,RHS) ) 

#define IEditBoxes_get_Characters(This,Start,Length,RHS)	\
    ( (This)->lpVtbl -> get_Characters(This,Start,Length,RHS) ) 

#define IEditBoxes_CheckSpelling(This,CustomDictionary,IgnoreUppercase,AlwaysSuggest,SpellLang,RHS)	\
    ( (This)->lpVtbl -> CheckSpelling(This,CustomDictionary,IgnoreUppercase,AlwaysSuggest,SpellLang,RHS) ) 

#define IEditBoxes_get_LockedText(This,RHS)	\
    ( (This)->lpVtbl -> get_LockedText(This,RHS) ) 

#define IEditBoxes_put_LockedText(This,RHS)	\
    ( (This)->lpVtbl -> put_LockedText(This,RHS) ) 

#define IEditBoxes_get_Text(This,RHS)	\
    ( (This)->lpVtbl -> get_Text(This,RHS) ) 

#define IEditBoxes_put_Text(This,RHS)	\
    ( (This)->lpVtbl -> put_Text(This,RHS) ) 

#define IEditBoxes_get_DisplayVerticalScrollBar(This,RHS)	\
    ( (This)->lpVtbl -> get_DisplayVerticalScrollBar(This,RHS) ) 

#define IEditBoxes_put_DisplayVerticalScrollBar(This,RHS)	\
    ( (This)->lpVtbl -> put_DisplayVerticalScrollBar(This,RHS) ) 

#define IEditBoxes_get_InputType(This,RHS)	\
    ( (This)->lpVtbl -> get_InputType(This,RHS) ) 

#define IEditBoxes_put_InputType(This,RHS)	\
    ( (This)->lpVtbl -> put_InputType(This,RHS) ) 

#define IEditBoxes__Dummy34(This)	\
    ( (This)->lpVtbl -> _Dummy34(This) ) 

#define IEditBoxes_get_MultiLine(This,RHS)	\
    ( (This)->lpVtbl -> get_MultiLine(This,RHS) ) 

#define IEditBoxes_put_MultiLine(This,RHS)	\
    ( (This)->lpVtbl -> put_MultiLine(This,RHS) ) 

#define IEditBoxes_get_PasswordEdit(This,RHS)	\
    ( (This)->lpVtbl -> get_PasswordEdit(This,RHS) ) 

#define IEditBoxes_put_PasswordEdit(This,RHS)	\
    ( (This)->lpVtbl -> put_PasswordEdit(This,RHS) ) 

#define IEditBoxes_Add(This,Left,Top,Width,Height,RHS)	\
    ( (This)->lpVtbl -> Add(This,Left,Top,Width,Height,RHS) ) 

#define IEditBoxes_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IEditBoxes_Group(This,RHS)	\
    ( (This)->lpVtbl -> Group(This,RHS) ) 

#define IEditBoxes_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> Item(This,Index,RHS) ) 

#define IEditBoxes__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> _NewEnum(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IEditBoxes_INTERFACE_DEFINED__ */


#ifndef __IScrollBar_INTERFACE_DEFINED__
#define __IScrollBar_INTERFACE_DEFINED__

/* interface IScrollBar */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IScrollBar;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00020885-0001-0000-C000-000000000046")
    IScrollBar : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_BottomRightCell( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall BringToFront( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Copy( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CopyPicture( 
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Cut( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Duplicate( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Enabled( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Enabled( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Height( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Height( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Index( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Left( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Left( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Locked( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Locked( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Name( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_OnAction( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_OnAction( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Placement( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Placement( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PrintObject( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PrintObject( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SendToBack( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Top( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Top( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TopLeftCell( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Visible( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Visible( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Width( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Width( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ZOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShapeRange( 
            /* [retval][out] */ ShapeRange	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put__Default( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Display3DShading( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Display3DShading( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LinkedCell( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_LinkedCell( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Max( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Max( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Min( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Min( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SmallChange( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_SmallChange( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Value( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Value( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LargeChange( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_LargeChange( 
            /* [in] */ long RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IScrollBarVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IScrollBar * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IScrollBar * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IScrollBar * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IScrollBar * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IScrollBar * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IScrollBar * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IScrollBar * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IScrollBar * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IScrollBar * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IScrollBar * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_BottomRightCell )( 
            IScrollBar * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *BringToFront )( 
            IScrollBar * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Copy )( 
            IScrollBar * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CopyPicture )( 
            IScrollBar * This,
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Cut )( 
            IScrollBar * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IScrollBar * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Duplicate )( 
            IScrollBar * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Enabled )( 
            IScrollBar * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Enabled )( 
            IScrollBar * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Height )( 
            IScrollBar * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Height )( 
            IScrollBar * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Index )( 
            IScrollBar * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Left )( 
            IScrollBar * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Left )( 
            IScrollBar * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Locked )( 
            IScrollBar * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Locked )( 
            IScrollBar * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            IScrollBar * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Name )( 
            IScrollBar * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_OnAction )( 
            IScrollBar * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_OnAction )( 
            IScrollBar * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Placement )( 
            IScrollBar * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Placement )( 
            IScrollBar * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PrintObject )( 
            IScrollBar * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PrintObject )( 
            IScrollBar * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            IScrollBar * This,
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SendToBack )( 
            IScrollBar * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Top )( 
            IScrollBar * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Top )( 
            IScrollBar * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TopLeftCell )( 
            IScrollBar * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Visible )( 
            IScrollBar * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Visible )( 
            IScrollBar * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Width )( 
            IScrollBar * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Width )( 
            IScrollBar * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ZOrder )( 
            IScrollBar * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShapeRange )( 
            IScrollBar * This,
            /* [retval][out] */ ShapeRange	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IScrollBar * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put__Default )( 
            IScrollBar * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Display3DShading )( 
            IScrollBar * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Display3DShading )( 
            IScrollBar * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LinkedCell )( 
            IScrollBar * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_LinkedCell )( 
            IScrollBar * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Max )( 
            IScrollBar * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Max )( 
            IScrollBar * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Min )( 
            IScrollBar * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Min )( 
            IScrollBar * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SmallChange )( 
            IScrollBar * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_SmallChange )( 
            IScrollBar * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Value )( 
            IScrollBar * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Value )( 
            IScrollBar * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LargeChange )( 
            IScrollBar * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_LargeChange )( 
            IScrollBar * This,
            /* [in] */ long RHS);
        
        END_INTERFACE
    } IScrollBarVtbl;

    interface IScrollBar
    {
        CONST_VTBL struct IScrollBarVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IScrollBar_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IScrollBar_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IScrollBar_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IScrollBar_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IScrollBar_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IScrollBar_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IScrollBar_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IScrollBar_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IScrollBar_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IScrollBar_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IScrollBar_get_BottomRightCell(This,RHS)	\
    ( (This)->lpVtbl -> get_BottomRightCell(This,RHS) ) 

#define IScrollBar_BringToFront(This,RHS)	\
    ( (This)->lpVtbl -> BringToFront(This,RHS) ) 

#define IScrollBar_Copy(This,RHS)	\
    ( (This)->lpVtbl -> Copy(This,RHS) ) 

#define IScrollBar_CopyPicture(This,Appearance,Format,RHS)	\
    ( (This)->lpVtbl -> CopyPicture(This,Appearance,Format,RHS) ) 

#define IScrollBar_Cut(This,RHS)	\
    ( (This)->lpVtbl -> Cut(This,RHS) ) 

#define IScrollBar_Delete(This,RHS)	\
    ( (This)->lpVtbl -> Delete(This,RHS) ) 

#define IScrollBar_Duplicate(This,RHS)	\
    ( (This)->lpVtbl -> Duplicate(This,RHS) ) 

#define IScrollBar_get_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> get_Enabled(This,RHS) ) 

#define IScrollBar_put_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> put_Enabled(This,RHS) ) 

#define IScrollBar_get_Height(This,RHS)	\
    ( (This)->lpVtbl -> get_Height(This,RHS) ) 

#define IScrollBar_put_Height(This,RHS)	\
    ( (This)->lpVtbl -> put_Height(This,RHS) ) 

#define IScrollBar_get_Index(This,RHS)	\
    ( (This)->lpVtbl -> get_Index(This,RHS) ) 

#define IScrollBar_get_Left(This,RHS)	\
    ( (This)->lpVtbl -> get_Left(This,RHS) ) 

#define IScrollBar_put_Left(This,RHS)	\
    ( (This)->lpVtbl -> put_Left(This,RHS) ) 

#define IScrollBar_get_Locked(This,RHS)	\
    ( (This)->lpVtbl -> get_Locked(This,RHS) ) 

#define IScrollBar_put_Locked(This,RHS)	\
    ( (This)->lpVtbl -> put_Locked(This,RHS) ) 

#define IScrollBar_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define IScrollBar_put_Name(This,RHS)	\
    ( (This)->lpVtbl -> put_Name(This,RHS) ) 

#define IScrollBar_get_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> get_OnAction(This,RHS) ) 

#define IScrollBar_put_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> put_OnAction(This,RHS) ) 

#define IScrollBar_get_Placement(This,RHS)	\
    ( (This)->lpVtbl -> get_Placement(This,RHS) ) 

#define IScrollBar_put_Placement(This,RHS)	\
    ( (This)->lpVtbl -> put_Placement(This,RHS) ) 

#define IScrollBar_get_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> get_PrintObject(This,RHS) ) 

#define IScrollBar_put_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> put_PrintObject(This,RHS) ) 

#define IScrollBar_Select(This,Replace,RHS)	\
    ( (This)->lpVtbl -> Select(This,Replace,RHS) ) 

#define IScrollBar_SendToBack(This,RHS)	\
    ( (This)->lpVtbl -> SendToBack(This,RHS) ) 

#define IScrollBar_get_Top(This,RHS)	\
    ( (This)->lpVtbl -> get_Top(This,RHS) ) 

#define IScrollBar_put_Top(This,RHS)	\
    ( (This)->lpVtbl -> put_Top(This,RHS) ) 

#define IScrollBar_get_TopLeftCell(This,RHS)	\
    ( (This)->lpVtbl -> get_TopLeftCell(This,RHS) ) 

#define IScrollBar_get_Visible(This,RHS)	\
    ( (This)->lpVtbl -> get_Visible(This,RHS) ) 

#define IScrollBar_put_Visible(This,RHS)	\
    ( (This)->lpVtbl -> put_Visible(This,RHS) ) 

#define IScrollBar_get_Width(This,RHS)	\
    ( (This)->lpVtbl -> get_Width(This,RHS) ) 

#define IScrollBar_put_Width(This,RHS)	\
    ( (This)->lpVtbl -> put_Width(This,RHS) ) 

#define IScrollBar_get_ZOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_ZOrder(This,RHS) ) 

#define IScrollBar_get_ShapeRange(This,RHS)	\
    ( (This)->lpVtbl -> get_ShapeRange(This,RHS) ) 

#define IScrollBar_get__Default(This,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,RHS) ) 

#define IScrollBar_put__Default(This,RHS)	\
    ( (This)->lpVtbl -> put__Default(This,RHS) ) 

#define IScrollBar_get_Display3DShading(This,RHS)	\
    ( (This)->lpVtbl -> get_Display3DShading(This,RHS) ) 

#define IScrollBar_put_Display3DShading(This,RHS)	\
    ( (This)->lpVtbl -> put_Display3DShading(This,RHS) ) 

#define IScrollBar_get_LinkedCell(This,RHS)	\
    ( (This)->lpVtbl -> get_LinkedCell(This,RHS) ) 

#define IScrollBar_put_LinkedCell(This,RHS)	\
    ( (This)->lpVtbl -> put_LinkedCell(This,RHS) ) 

#define IScrollBar_get_Max(This,RHS)	\
    ( (This)->lpVtbl -> get_Max(This,RHS) ) 

#define IScrollBar_put_Max(This,RHS)	\
    ( (This)->lpVtbl -> put_Max(This,RHS) ) 

#define IScrollBar_get_Min(This,RHS)	\
    ( (This)->lpVtbl -> get_Min(This,RHS) ) 

#define IScrollBar_put_Min(This,RHS)	\
    ( (This)->lpVtbl -> put_Min(This,RHS) ) 

#define IScrollBar_get_SmallChange(This,RHS)	\
    ( (This)->lpVtbl -> get_SmallChange(This,RHS) ) 

#define IScrollBar_put_SmallChange(This,RHS)	\
    ( (This)->lpVtbl -> put_SmallChange(This,RHS) ) 

#define IScrollBar_get_Value(This,RHS)	\
    ( (This)->lpVtbl -> get_Value(This,RHS) ) 

#define IScrollBar_put_Value(This,RHS)	\
    ( (This)->lpVtbl -> put_Value(This,RHS) ) 

#define IScrollBar_get_LargeChange(This,RHS)	\
    ( (This)->lpVtbl -> get_LargeChange(This,RHS) ) 

#define IScrollBar_put_LargeChange(This,RHS)	\
    ( (This)->lpVtbl -> put_LargeChange(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IScrollBar_INTERFACE_DEFINED__ */


#ifndef __IScrollBars_INTERFACE_DEFINED__
#define __IScrollBars_INTERFACE_DEFINED__

/* interface IScrollBars */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IScrollBars;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00020886-0001-0000-C000-000000000046")
    IScrollBars : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy3( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall BringToFront( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Copy( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CopyPicture( 
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Cut( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Duplicate( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Enabled( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Enabled( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Height( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Height( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy12( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Left( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Left( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Locked( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Locked( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy15( void) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_OnAction( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_OnAction( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Placement( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Placement( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PrintObject( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PrintObject( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SendToBack( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Top( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Top( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy22( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Visible( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Visible( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Width( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Width( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ZOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShapeRange( 
            /* [retval][out] */ ShapeRange	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put__Default( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Display3DShading( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Display3DShading( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LinkedCell( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_LinkedCell( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Max( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Max( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Min( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Min( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SmallChange( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_SmallChange( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Value( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Value( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LargeChange( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_LargeChange( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add( 
            /* [in] */ double Left,
            /* [in] */ double Top,
            /* [in] */ double Width,
            /* [in] */ double Height,
            /* [retval][out] */ ScrollBar	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Group( 
            /* [retval][out] */ GroupObject	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall _NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IScrollBarsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IScrollBars * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IScrollBars * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IScrollBars * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IScrollBars * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IScrollBars * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IScrollBars * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IScrollBars * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IScrollBars * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IScrollBars * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IScrollBars * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy3 )( 
            IScrollBars * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *BringToFront )( 
            IScrollBars * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Copy )( 
            IScrollBars * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CopyPicture )( 
            IScrollBars * This,
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Cut )( 
            IScrollBars * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IScrollBars * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Duplicate )( 
            IScrollBars * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Enabled )( 
            IScrollBars * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Enabled )( 
            IScrollBars * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Height )( 
            IScrollBars * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Height )( 
            IScrollBars * This,
            /* [in] */ double RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy12 )( 
            IScrollBars * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Left )( 
            IScrollBars * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Left )( 
            IScrollBars * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Locked )( 
            IScrollBars * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Locked )( 
            IScrollBars * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy15 )( 
            IScrollBars * This);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_OnAction )( 
            IScrollBars * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_OnAction )( 
            IScrollBars * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Placement )( 
            IScrollBars * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Placement )( 
            IScrollBars * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PrintObject )( 
            IScrollBars * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PrintObject )( 
            IScrollBars * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            IScrollBars * This,
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SendToBack )( 
            IScrollBars * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Top )( 
            IScrollBars * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Top )( 
            IScrollBars * This,
            /* [in] */ double RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy22 )( 
            IScrollBars * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Visible )( 
            IScrollBars * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Visible )( 
            IScrollBars * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Width )( 
            IScrollBars * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Width )( 
            IScrollBars * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ZOrder )( 
            IScrollBars * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShapeRange )( 
            IScrollBars * This,
            /* [retval][out] */ ShapeRange	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IScrollBars * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put__Default )( 
            IScrollBars * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Display3DShading )( 
            IScrollBars * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Display3DShading )( 
            IScrollBars * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LinkedCell )( 
            IScrollBars * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_LinkedCell )( 
            IScrollBars * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Max )( 
            IScrollBars * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Max )( 
            IScrollBars * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Min )( 
            IScrollBars * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Min )( 
            IScrollBars * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SmallChange )( 
            IScrollBars * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_SmallChange )( 
            IScrollBars * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Value )( 
            IScrollBars * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Value )( 
            IScrollBars * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LargeChange )( 
            IScrollBars * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_LargeChange )( 
            IScrollBars * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add )( 
            IScrollBars * This,
            /* [in] */ double Left,
            /* [in] */ double Top,
            /* [in] */ double Width,
            /* [in] */ double Height,
            /* [retval][out] */ ScrollBar	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IScrollBars * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Group )( 
            IScrollBars * This,
            /* [retval][out] */ GroupObject	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Item )( 
            IScrollBars * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *_NewEnum )( 
            IScrollBars * This,
            /* [retval][out] */ IUnknown **RHS);
        
        END_INTERFACE
    } IScrollBarsVtbl;

    interface IScrollBars
    {
        CONST_VTBL struct IScrollBarsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IScrollBars_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IScrollBars_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IScrollBars_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IScrollBars_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IScrollBars_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IScrollBars_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IScrollBars_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IScrollBars_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IScrollBars_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IScrollBars_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IScrollBars__Dummy3(This)	\
    ( (This)->lpVtbl -> _Dummy3(This) ) 

#define IScrollBars_BringToFront(This,RHS)	\
    ( (This)->lpVtbl -> BringToFront(This,RHS) ) 

#define IScrollBars_Copy(This,RHS)	\
    ( (This)->lpVtbl -> Copy(This,RHS) ) 

#define IScrollBars_CopyPicture(This,Appearance,Format,RHS)	\
    ( (This)->lpVtbl -> CopyPicture(This,Appearance,Format,RHS) ) 

#define IScrollBars_Cut(This,RHS)	\
    ( (This)->lpVtbl -> Cut(This,RHS) ) 

#define IScrollBars_Delete(This,RHS)	\
    ( (This)->lpVtbl -> Delete(This,RHS) ) 

#define IScrollBars_Duplicate(This,RHS)	\
    ( (This)->lpVtbl -> Duplicate(This,RHS) ) 

#define IScrollBars_get_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> get_Enabled(This,RHS) ) 

#define IScrollBars_put_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> put_Enabled(This,RHS) ) 

#define IScrollBars_get_Height(This,RHS)	\
    ( (This)->lpVtbl -> get_Height(This,RHS) ) 

#define IScrollBars_put_Height(This,RHS)	\
    ( (This)->lpVtbl -> put_Height(This,RHS) ) 

#define IScrollBars__Dummy12(This)	\
    ( (This)->lpVtbl -> _Dummy12(This) ) 

#define IScrollBars_get_Left(This,RHS)	\
    ( (This)->lpVtbl -> get_Left(This,RHS) ) 

#define IScrollBars_put_Left(This,RHS)	\
    ( (This)->lpVtbl -> put_Left(This,RHS) ) 

#define IScrollBars_get_Locked(This,RHS)	\
    ( (This)->lpVtbl -> get_Locked(This,RHS) ) 

#define IScrollBars_put_Locked(This,RHS)	\
    ( (This)->lpVtbl -> put_Locked(This,RHS) ) 

#define IScrollBars__Dummy15(This)	\
    ( (This)->lpVtbl -> _Dummy15(This) ) 

#define IScrollBars_get_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> get_OnAction(This,RHS) ) 

#define IScrollBars_put_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> put_OnAction(This,RHS) ) 

#define IScrollBars_get_Placement(This,RHS)	\
    ( (This)->lpVtbl -> get_Placement(This,RHS) ) 

#define IScrollBars_put_Placement(This,RHS)	\
    ( (This)->lpVtbl -> put_Placement(This,RHS) ) 

#define IScrollBars_get_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> get_PrintObject(This,RHS) ) 

#define IScrollBars_put_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> put_PrintObject(This,RHS) ) 

#define IScrollBars_Select(This,Replace,RHS)	\
    ( (This)->lpVtbl -> Select(This,Replace,RHS) ) 

#define IScrollBars_SendToBack(This,RHS)	\
    ( (This)->lpVtbl -> SendToBack(This,RHS) ) 

#define IScrollBars_get_Top(This,RHS)	\
    ( (This)->lpVtbl -> get_Top(This,RHS) ) 

#define IScrollBars_put_Top(This,RHS)	\
    ( (This)->lpVtbl -> put_Top(This,RHS) ) 

#define IScrollBars__Dummy22(This)	\
    ( (This)->lpVtbl -> _Dummy22(This) ) 

#define IScrollBars_get_Visible(This,RHS)	\
    ( (This)->lpVtbl -> get_Visible(This,RHS) ) 

#define IScrollBars_put_Visible(This,RHS)	\
    ( (This)->lpVtbl -> put_Visible(This,RHS) ) 

#define IScrollBars_get_Width(This,RHS)	\
    ( (This)->lpVtbl -> get_Width(This,RHS) ) 

#define IScrollBars_put_Width(This,RHS)	\
    ( (This)->lpVtbl -> put_Width(This,RHS) ) 

#define IScrollBars_get_ZOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_ZOrder(This,RHS) ) 

#define IScrollBars_get_ShapeRange(This,RHS)	\
    ( (This)->lpVtbl -> get_ShapeRange(This,RHS) ) 

#define IScrollBars_get__Default(This,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,RHS) ) 

#define IScrollBars_put__Default(This,RHS)	\
    ( (This)->lpVtbl -> put__Default(This,RHS) ) 

#define IScrollBars_get_Display3DShading(This,RHS)	\
    ( (This)->lpVtbl -> get_Display3DShading(This,RHS) ) 

#define IScrollBars_put_Display3DShading(This,RHS)	\
    ( (This)->lpVtbl -> put_Display3DShading(This,RHS) ) 

#define IScrollBars_get_LinkedCell(This,RHS)	\
    ( (This)->lpVtbl -> get_LinkedCell(This,RHS) ) 

#define IScrollBars_put_LinkedCell(This,RHS)	\
    ( (This)->lpVtbl -> put_LinkedCell(This,RHS) ) 

#define IScrollBars_get_Max(This,RHS)	\
    ( (This)->lpVtbl -> get_Max(This,RHS) ) 

#define IScrollBars_put_Max(This,RHS)	\
    ( (This)->lpVtbl -> put_Max(This,RHS) ) 

#define IScrollBars_get_Min(This,RHS)	\
    ( (This)->lpVtbl -> get_Min(This,RHS) ) 

#define IScrollBars_put_Min(This,RHS)	\
    ( (This)->lpVtbl -> put_Min(This,RHS) ) 

#define IScrollBars_get_SmallChange(This,RHS)	\
    ( (This)->lpVtbl -> get_SmallChange(This,RHS) ) 

#define IScrollBars_put_SmallChange(This,RHS)	\
    ( (This)->lpVtbl -> put_SmallChange(This,RHS) ) 

#define IScrollBars_get_Value(This,RHS)	\
    ( (This)->lpVtbl -> get_Value(This,RHS) ) 

#define IScrollBars_put_Value(This,RHS)	\
    ( (This)->lpVtbl -> put_Value(This,RHS) ) 

#define IScrollBars_get_LargeChange(This,RHS)	\
    ( (This)->lpVtbl -> get_LargeChange(This,RHS) ) 

#define IScrollBars_put_LargeChange(This,RHS)	\
    ( (This)->lpVtbl -> put_LargeChange(This,RHS) ) 

#define IScrollBars_Add(This,Left,Top,Width,Height,RHS)	\
    ( (This)->lpVtbl -> Add(This,Left,Top,Width,Height,RHS) ) 

#define IScrollBars_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IScrollBars_Group(This,RHS)	\
    ( (This)->lpVtbl -> Group(This,RHS) ) 

#define IScrollBars_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> Item(This,Index,RHS) ) 

#define IScrollBars__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> _NewEnum(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IScrollBars_INTERFACE_DEFINED__ */


#ifndef __IListBox_INTERFACE_DEFINED__
#define __IListBox_INTERFACE_DEFINED__

/* interface IListBox */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IListBox;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00020887-0001-0000-C000-000000000046")
    IListBox : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_BottomRightCell( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall BringToFront( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Copy( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CopyPicture( 
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Cut( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Duplicate( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Enabled( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Enabled( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Height( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Height( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Index( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Left( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Left( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Locked( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Locked( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Name( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_OnAction( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_OnAction( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Placement( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Placement( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PrintObject( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PrintObject( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SendToBack( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Top( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Top( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TopLeftCell( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Visible( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Visible( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Width( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Width( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ZOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShapeRange( 
            /* [retval][out] */ ShapeRange	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall AddItem( 
            /* [in] */ VARIANT Text,
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Display3DShading( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Display3DShading( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put__Default( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LinkedCell( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_LinkedCell( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LinkedObject( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_List( 
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_List( 
            /* [optional][in] */ VARIANT Index,
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ListCount( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ListFillRange( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ListFillRange( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ListIndex( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ListIndex( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MultiSelect( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_MultiSelect( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall RemoveAllItems( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall RemoveItem( 
            /* [in] */ long Index,
            /* [optional][in] */ VARIANT Count,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Selected( 
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Selected( 
            /* [optional][in] */ VARIANT Index,
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Value( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Value( 
            /* [in] */ long RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IListBoxVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IListBox * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IListBox * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IListBox * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IListBox * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IListBox * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IListBox * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IListBox * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IListBox * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IListBox * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IListBox * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_BottomRightCell )( 
            IListBox * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *BringToFront )( 
            IListBox * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Copy )( 
            IListBox * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CopyPicture )( 
            IListBox * This,
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Cut )( 
            IListBox * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IListBox * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Duplicate )( 
            IListBox * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Enabled )( 
            IListBox * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Enabled )( 
            IListBox * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Height )( 
            IListBox * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Height )( 
            IListBox * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Index )( 
            IListBox * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Left )( 
            IListBox * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Left )( 
            IListBox * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Locked )( 
            IListBox * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Locked )( 
            IListBox * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            IListBox * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Name )( 
            IListBox * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_OnAction )( 
            IListBox * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_OnAction )( 
            IListBox * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Placement )( 
            IListBox * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Placement )( 
            IListBox * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PrintObject )( 
            IListBox * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PrintObject )( 
            IListBox * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            IListBox * This,
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SendToBack )( 
            IListBox * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Top )( 
            IListBox * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Top )( 
            IListBox * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TopLeftCell )( 
            IListBox * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Visible )( 
            IListBox * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Visible )( 
            IListBox * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Width )( 
            IListBox * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Width )( 
            IListBox * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ZOrder )( 
            IListBox * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShapeRange )( 
            IListBox * This,
            /* [retval][out] */ ShapeRange	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *AddItem )( 
            IListBox * This,
            /* [in] */ VARIANT Text,
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Display3DShading )( 
            IListBox * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Display3DShading )( 
            IListBox * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IListBox * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put__Default )( 
            IListBox * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LinkedCell )( 
            IListBox * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_LinkedCell )( 
            IListBox * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LinkedObject )( 
            IListBox * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_List )( 
            IListBox * This,
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_List )( 
            IListBox * This,
            /* [optional][in] */ VARIANT Index,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ListCount )( 
            IListBox * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ListFillRange )( 
            IListBox * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ListFillRange )( 
            IListBox * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ListIndex )( 
            IListBox * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ListIndex )( 
            IListBox * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MultiSelect )( 
            IListBox * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_MultiSelect )( 
            IListBox * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *RemoveAllItems )( 
            IListBox * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *RemoveItem )( 
            IListBox * This,
            /* [in] */ long Index,
            /* [optional][in] */ VARIANT Count,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Selected )( 
            IListBox * This,
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Selected )( 
            IListBox * This,
            /* [optional][in] */ VARIANT Index,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Value )( 
            IListBox * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Value )( 
            IListBox * This,
            /* [in] */ long RHS);
        
        END_INTERFACE
    } IListBoxVtbl;

    interface IListBox
    {
        CONST_VTBL struct IListBoxVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IListBox_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IListBox_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IListBox_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IListBox_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IListBox_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IListBox_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IListBox_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IListBox_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IListBox_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IListBox_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IListBox_get_BottomRightCell(This,RHS)	\
    ( (This)->lpVtbl -> get_BottomRightCell(This,RHS) ) 

#define IListBox_BringToFront(This,RHS)	\
    ( (This)->lpVtbl -> BringToFront(This,RHS) ) 

#define IListBox_Copy(This,RHS)	\
    ( (This)->lpVtbl -> Copy(This,RHS) ) 

#define IListBox_CopyPicture(This,Appearance,Format,RHS)	\
    ( (This)->lpVtbl -> CopyPicture(This,Appearance,Format,RHS) ) 

#define IListBox_Cut(This,RHS)	\
    ( (This)->lpVtbl -> Cut(This,RHS) ) 

#define IListBox_Delete(This,RHS)	\
    ( (This)->lpVtbl -> Delete(This,RHS) ) 

#define IListBox_Duplicate(This,RHS)	\
    ( (This)->lpVtbl -> Duplicate(This,RHS) ) 

#define IListBox_get_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> get_Enabled(This,RHS) ) 

#define IListBox_put_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> put_Enabled(This,RHS) ) 

#define IListBox_get_Height(This,RHS)	\
    ( (This)->lpVtbl -> get_Height(This,RHS) ) 

#define IListBox_put_Height(This,RHS)	\
    ( (This)->lpVtbl -> put_Height(This,RHS) ) 

#define IListBox_get_Index(This,RHS)	\
    ( (This)->lpVtbl -> get_Index(This,RHS) ) 

#define IListBox_get_Left(This,RHS)	\
    ( (This)->lpVtbl -> get_Left(This,RHS) ) 

#define IListBox_put_Left(This,RHS)	\
    ( (This)->lpVtbl -> put_Left(This,RHS) ) 

#define IListBox_get_Locked(This,RHS)	\
    ( (This)->lpVtbl -> get_Locked(This,RHS) ) 

#define IListBox_put_Locked(This,RHS)	\
    ( (This)->lpVtbl -> put_Locked(This,RHS) ) 

#define IListBox_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define IListBox_put_Name(This,RHS)	\
    ( (This)->lpVtbl -> put_Name(This,RHS) ) 

#define IListBox_get_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> get_OnAction(This,RHS) ) 

#define IListBox_put_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> put_OnAction(This,RHS) ) 

#define IListBox_get_Placement(This,RHS)	\
    ( (This)->lpVtbl -> get_Placement(This,RHS) ) 

#define IListBox_put_Placement(This,RHS)	\
    ( (This)->lpVtbl -> put_Placement(This,RHS) ) 

#define IListBox_get_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> get_PrintObject(This,RHS) ) 

#define IListBox_put_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> put_PrintObject(This,RHS) ) 

#define IListBox_Select(This,Replace,RHS)	\
    ( (This)->lpVtbl -> Select(This,Replace,RHS) ) 

#define IListBox_SendToBack(This,RHS)	\
    ( (This)->lpVtbl -> SendToBack(This,RHS) ) 

#define IListBox_get_Top(This,RHS)	\
    ( (This)->lpVtbl -> get_Top(This,RHS) ) 

#define IListBox_put_Top(This,RHS)	\
    ( (This)->lpVtbl -> put_Top(This,RHS) ) 

#define IListBox_get_TopLeftCell(This,RHS)	\
    ( (This)->lpVtbl -> get_TopLeftCell(This,RHS) ) 

#define IListBox_get_Visible(This,RHS)	\
    ( (This)->lpVtbl -> get_Visible(This,RHS) ) 

#define IListBox_put_Visible(This,RHS)	\
    ( (This)->lpVtbl -> put_Visible(This,RHS) ) 

#define IListBox_get_Width(This,RHS)	\
    ( (This)->lpVtbl -> get_Width(This,RHS) ) 

#define IListBox_put_Width(This,RHS)	\
    ( (This)->lpVtbl -> put_Width(This,RHS) ) 

#define IListBox_get_ZOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_ZOrder(This,RHS) ) 

#define IListBox_get_ShapeRange(This,RHS)	\
    ( (This)->lpVtbl -> get_ShapeRange(This,RHS) ) 

#define IListBox_AddItem(This,Text,Index,RHS)	\
    ( (This)->lpVtbl -> AddItem(This,Text,Index,RHS) ) 

#define IListBox_get_Display3DShading(This,RHS)	\
    ( (This)->lpVtbl -> get_Display3DShading(This,RHS) ) 

#define IListBox_put_Display3DShading(This,RHS)	\
    ( (This)->lpVtbl -> put_Display3DShading(This,RHS) ) 

#define IListBox_get__Default(This,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,RHS) ) 

#define IListBox_put__Default(This,RHS)	\
    ( (This)->lpVtbl -> put__Default(This,RHS) ) 

#define IListBox_get_LinkedCell(This,RHS)	\
    ( (This)->lpVtbl -> get_LinkedCell(This,RHS) ) 

#define IListBox_put_LinkedCell(This,RHS)	\
    ( (This)->lpVtbl -> put_LinkedCell(This,RHS) ) 

#define IListBox_get_LinkedObject(This,RHS)	\
    ( (This)->lpVtbl -> get_LinkedObject(This,RHS) ) 

#define IListBox_get_List(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_List(This,Index,RHS) ) 

#define IListBox_put_List(This,Index,RHS)	\
    ( (This)->lpVtbl -> put_List(This,Index,RHS) ) 

#define IListBox_get_ListCount(This,RHS)	\
    ( (This)->lpVtbl -> get_ListCount(This,RHS) ) 

#define IListBox_get_ListFillRange(This,RHS)	\
    ( (This)->lpVtbl -> get_ListFillRange(This,RHS) ) 

#define IListBox_put_ListFillRange(This,RHS)	\
    ( (This)->lpVtbl -> put_ListFillRange(This,RHS) ) 

#define IListBox_get_ListIndex(This,RHS)	\
    ( (This)->lpVtbl -> get_ListIndex(This,RHS) ) 

#define IListBox_put_ListIndex(This,RHS)	\
    ( (This)->lpVtbl -> put_ListIndex(This,RHS) ) 

#define IListBox_get_MultiSelect(This,RHS)	\
    ( (This)->lpVtbl -> get_MultiSelect(This,RHS) ) 

#define IListBox_put_MultiSelect(This,RHS)	\
    ( (This)->lpVtbl -> put_MultiSelect(This,RHS) ) 

#define IListBox_RemoveAllItems(This,RHS)	\
    ( (This)->lpVtbl -> RemoveAllItems(This,RHS) ) 

#define IListBox_RemoveItem(This,Index,Count,RHS)	\
    ( (This)->lpVtbl -> RemoveItem(This,Index,Count,RHS) ) 

#define IListBox_get_Selected(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Selected(This,Index,RHS) ) 

#define IListBox_put_Selected(This,Index,RHS)	\
    ( (This)->lpVtbl -> put_Selected(This,Index,RHS) ) 

#define IListBox_get_Value(This,RHS)	\
    ( (This)->lpVtbl -> get_Value(This,RHS) ) 

#define IListBox_put_Value(This,RHS)	\
    ( (This)->lpVtbl -> put_Value(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IListBox_INTERFACE_DEFINED__ */


#ifndef __IListBoxes_INTERFACE_DEFINED__
#define __IListBoxes_INTERFACE_DEFINED__

/* interface IListBoxes */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IListBoxes;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00020888-0001-0000-C000-000000000046")
    IListBoxes : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy3( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall BringToFront( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Copy( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CopyPicture( 
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Cut( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Duplicate( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Enabled( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Enabled( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Height( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Height( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy12( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Left( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Left( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Locked( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Locked( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy15( void) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_OnAction( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_OnAction( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Placement( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Placement( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PrintObject( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PrintObject( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SendToBack( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Top( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Top( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy22( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Visible( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Visible( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Width( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Width( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ZOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShapeRange( 
            /* [retval][out] */ ShapeRange	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall AddItem( 
            /* [in] */ VARIANT Text,
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Display3DShading( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Display3DShading( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put__Default( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LinkedCell( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_LinkedCell( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy31( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_List( 
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_List( 
            /* [optional][in] */ VARIANT Index,
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy33( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ListFillRange( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ListFillRange( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ListIndex( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ListIndex( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MultiSelect( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_MultiSelect( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall RemoveAllItems( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall RemoveItem( 
            /* [in] */ long Index,
            /* [optional][in] */ VARIANT Count,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Selected( 
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Selected( 
            /* [optional][in] */ VARIANT Index,
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Value( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Value( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add( 
            /* [in] */ double Left,
            /* [in] */ double Top,
            /* [in] */ double Width,
            /* [in] */ double Height,
            /* [retval][out] */ ListBox	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Group( 
            /* [retval][out] */ GroupObject	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall _NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IListBoxesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IListBoxes * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IListBoxes * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IListBoxes * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IListBoxes * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IListBoxes * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IListBoxes * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IListBoxes * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IListBoxes * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IListBoxes * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IListBoxes * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy3 )( 
            IListBoxes * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *BringToFront )( 
            IListBoxes * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Copy )( 
            IListBoxes * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CopyPicture )( 
            IListBoxes * This,
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Cut )( 
            IListBoxes * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IListBoxes * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Duplicate )( 
            IListBoxes * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Enabled )( 
            IListBoxes * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Enabled )( 
            IListBoxes * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Height )( 
            IListBoxes * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Height )( 
            IListBoxes * This,
            /* [in] */ double RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy12 )( 
            IListBoxes * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Left )( 
            IListBoxes * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Left )( 
            IListBoxes * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Locked )( 
            IListBoxes * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Locked )( 
            IListBoxes * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy15 )( 
            IListBoxes * This);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_OnAction )( 
            IListBoxes * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_OnAction )( 
            IListBoxes * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Placement )( 
            IListBoxes * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Placement )( 
            IListBoxes * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PrintObject )( 
            IListBoxes * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PrintObject )( 
            IListBoxes * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            IListBoxes * This,
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SendToBack )( 
            IListBoxes * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Top )( 
            IListBoxes * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Top )( 
            IListBoxes * This,
            /* [in] */ double RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy22 )( 
            IListBoxes * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Visible )( 
            IListBoxes * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Visible )( 
            IListBoxes * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Width )( 
            IListBoxes * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Width )( 
            IListBoxes * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ZOrder )( 
            IListBoxes * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShapeRange )( 
            IListBoxes * This,
            /* [retval][out] */ ShapeRange	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *AddItem )( 
            IListBoxes * This,
            /* [in] */ VARIANT Text,
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Display3DShading )( 
            IListBoxes * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Display3DShading )( 
            IListBoxes * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IListBoxes * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put__Default )( 
            IListBoxes * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LinkedCell )( 
            IListBoxes * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_LinkedCell )( 
            IListBoxes * This,
            /* [in] */ BSTR RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy31 )( 
            IListBoxes * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_List )( 
            IListBoxes * This,
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_List )( 
            IListBoxes * This,
            /* [optional][in] */ VARIANT Index,
            /* [in] */ VARIANT RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy33 )( 
            IListBoxes * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ListFillRange )( 
            IListBoxes * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ListFillRange )( 
            IListBoxes * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ListIndex )( 
            IListBoxes * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ListIndex )( 
            IListBoxes * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MultiSelect )( 
            IListBoxes * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_MultiSelect )( 
            IListBoxes * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *RemoveAllItems )( 
            IListBoxes * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *RemoveItem )( 
            IListBoxes * This,
            /* [in] */ long Index,
            /* [optional][in] */ VARIANT Count,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Selected )( 
            IListBoxes * This,
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Selected )( 
            IListBoxes * This,
            /* [optional][in] */ VARIANT Index,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Value )( 
            IListBoxes * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Value )( 
            IListBoxes * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add )( 
            IListBoxes * This,
            /* [in] */ double Left,
            /* [in] */ double Top,
            /* [in] */ double Width,
            /* [in] */ double Height,
            /* [retval][out] */ ListBox	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IListBoxes * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Group )( 
            IListBoxes * This,
            /* [retval][out] */ GroupObject	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Item )( 
            IListBoxes * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *_NewEnum )( 
            IListBoxes * This,
            /* [retval][out] */ IUnknown **RHS);
        
        END_INTERFACE
    } IListBoxesVtbl;

    interface IListBoxes
    {
        CONST_VTBL struct IListBoxesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IListBoxes_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IListBoxes_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IListBoxes_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IListBoxes_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IListBoxes_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IListBoxes_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IListBoxes_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IListBoxes_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IListBoxes_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IListBoxes_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IListBoxes__Dummy3(This)	\
    ( (This)->lpVtbl -> _Dummy3(This) ) 

#define IListBoxes_BringToFront(This,RHS)	\
    ( (This)->lpVtbl -> BringToFront(This,RHS) ) 

#define IListBoxes_Copy(This,RHS)	\
    ( (This)->lpVtbl -> Copy(This,RHS) ) 

#define IListBoxes_CopyPicture(This,Appearance,Format,RHS)	\
    ( (This)->lpVtbl -> CopyPicture(This,Appearance,Format,RHS) ) 

#define IListBoxes_Cut(This,RHS)	\
    ( (This)->lpVtbl -> Cut(This,RHS) ) 

#define IListBoxes_Delete(This,RHS)	\
    ( (This)->lpVtbl -> Delete(This,RHS) ) 

#define IListBoxes_Duplicate(This,RHS)	\
    ( (This)->lpVtbl -> Duplicate(This,RHS) ) 

#define IListBoxes_get_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> get_Enabled(This,RHS) ) 

#define IListBoxes_put_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> put_Enabled(This,RHS) ) 

#define IListBoxes_get_Height(This,RHS)	\
    ( (This)->lpVtbl -> get_Height(This,RHS) ) 

#define IListBoxes_put_Height(This,RHS)	\
    ( (This)->lpVtbl -> put_Height(This,RHS) ) 

#define IListBoxes__Dummy12(This)	\
    ( (This)->lpVtbl -> _Dummy12(This) ) 

#define IListBoxes_get_Left(This,RHS)	\
    ( (This)->lpVtbl -> get_Left(This,RHS) ) 

#define IListBoxes_put_Left(This,RHS)	\
    ( (This)->lpVtbl -> put_Left(This,RHS) ) 

#define IListBoxes_get_Locked(This,RHS)	\
    ( (This)->lpVtbl -> get_Locked(This,RHS) ) 

#define IListBoxes_put_Locked(This,RHS)	\
    ( (This)->lpVtbl -> put_Locked(This,RHS) ) 

#define IListBoxes__Dummy15(This)	\
    ( (This)->lpVtbl -> _Dummy15(This) ) 

#define IListBoxes_get_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> get_OnAction(This,RHS) ) 

#define IListBoxes_put_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> put_OnAction(This,RHS) ) 

#define IListBoxes_get_Placement(This,RHS)	\
    ( (This)->lpVtbl -> get_Placement(This,RHS) ) 

#define IListBoxes_put_Placement(This,RHS)	\
    ( (This)->lpVtbl -> put_Placement(This,RHS) ) 

#define IListBoxes_get_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> get_PrintObject(This,RHS) ) 

#define IListBoxes_put_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> put_PrintObject(This,RHS) ) 

#define IListBoxes_Select(This,Replace,RHS)	\
    ( (This)->lpVtbl -> Select(This,Replace,RHS) ) 

#define IListBoxes_SendToBack(This,RHS)	\
    ( (This)->lpVtbl -> SendToBack(This,RHS) ) 

#define IListBoxes_get_Top(This,RHS)	\
    ( (This)->lpVtbl -> get_Top(This,RHS) ) 

#define IListBoxes_put_Top(This,RHS)	\
    ( (This)->lpVtbl -> put_Top(This,RHS) ) 

#define IListBoxes__Dummy22(This)	\
    ( (This)->lpVtbl -> _Dummy22(This) ) 

#define IListBoxes_get_Visible(This,RHS)	\
    ( (This)->lpVtbl -> get_Visible(This,RHS) ) 

#define IListBoxes_put_Visible(This,RHS)	\
    ( (This)->lpVtbl -> put_Visible(This,RHS) ) 

#define IListBoxes_get_Width(This,RHS)	\
    ( (This)->lpVtbl -> get_Width(This,RHS) ) 

#define IListBoxes_put_Width(This,RHS)	\
    ( (This)->lpVtbl -> put_Width(This,RHS) ) 

#define IListBoxes_get_ZOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_ZOrder(This,RHS) ) 

#define IListBoxes_get_ShapeRange(This,RHS)	\
    ( (This)->lpVtbl -> get_ShapeRange(This,RHS) ) 

#define IListBoxes_AddItem(This,Text,Index,RHS)	\
    ( (This)->lpVtbl -> AddItem(This,Text,Index,RHS) ) 

#define IListBoxes_get_Display3DShading(This,RHS)	\
    ( (This)->lpVtbl -> get_Display3DShading(This,RHS) ) 

#define IListBoxes_put_Display3DShading(This,RHS)	\
    ( (This)->lpVtbl -> put_Display3DShading(This,RHS) ) 

#define IListBoxes_get__Default(This,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,RHS) ) 

#define IListBoxes_put__Default(This,RHS)	\
    ( (This)->lpVtbl -> put__Default(This,RHS) ) 

#define IListBoxes_get_LinkedCell(This,RHS)	\
    ( (This)->lpVtbl -> get_LinkedCell(This,RHS) ) 

#define IListBoxes_put_LinkedCell(This,RHS)	\
    ( (This)->lpVtbl -> put_LinkedCell(This,RHS) ) 

#define IListBoxes__Dummy31(This)	\
    ( (This)->lpVtbl -> _Dummy31(This) ) 

#define IListBoxes_get_List(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_List(This,Index,RHS) ) 

#define IListBoxes_put_List(This,Index,RHS)	\
    ( (This)->lpVtbl -> put_List(This,Index,RHS) ) 

#define IListBoxes__Dummy33(This)	\
    ( (This)->lpVtbl -> _Dummy33(This) ) 

#define IListBoxes_get_ListFillRange(This,RHS)	\
    ( (This)->lpVtbl -> get_ListFillRange(This,RHS) ) 

#define IListBoxes_put_ListFillRange(This,RHS)	\
    ( (This)->lpVtbl -> put_ListFillRange(This,RHS) ) 

#define IListBoxes_get_ListIndex(This,RHS)	\
    ( (This)->lpVtbl -> get_ListIndex(This,RHS) ) 

#define IListBoxes_put_ListIndex(This,RHS)	\
    ( (This)->lpVtbl -> put_ListIndex(This,RHS) ) 

#define IListBoxes_get_MultiSelect(This,RHS)	\
    ( (This)->lpVtbl -> get_MultiSelect(This,RHS) ) 

#define IListBoxes_put_MultiSelect(This,RHS)	\
    ( (This)->lpVtbl -> put_MultiSelect(This,RHS) ) 

#define IListBoxes_RemoveAllItems(This,RHS)	\
    ( (This)->lpVtbl -> RemoveAllItems(This,RHS) ) 

#define IListBoxes_RemoveItem(This,Index,Count,RHS)	\
    ( (This)->lpVtbl -> RemoveItem(This,Index,Count,RHS) ) 

#define IListBoxes_get_Selected(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Selected(This,Index,RHS) ) 

#define IListBoxes_put_Selected(This,Index,RHS)	\
    ( (This)->lpVtbl -> put_Selected(This,Index,RHS) ) 

#define IListBoxes_get_Value(This,RHS)	\
    ( (This)->lpVtbl -> get_Value(This,RHS) ) 

#define IListBoxes_put_Value(This,RHS)	\
    ( (This)->lpVtbl -> put_Value(This,RHS) ) 

#define IListBoxes_Add(This,Left,Top,Width,Height,RHS)	\
    ( (This)->lpVtbl -> Add(This,Left,Top,Width,Height,RHS) ) 

#define IListBoxes_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IListBoxes_Group(This,RHS)	\
    ( (This)->lpVtbl -> Group(This,RHS) ) 

#define IListBoxes_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> Item(This,Index,RHS) ) 

#define IListBoxes__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> _NewEnum(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IListBoxes_INTERFACE_DEFINED__ */


#ifndef __IGroupBox_INTERFACE_DEFINED__
#define __IGroupBox_INTERFACE_DEFINED__

/* interface IGroupBox */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IGroupBox;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00020889-0001-0000-C000-000000000046")
    IGroupBox : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_BottomRightCell( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall BringToFront( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Copy( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CopyPicture( 
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Cut( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Duplicate( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Enabled( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Enabled( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Height( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Height( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Index( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Left( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Left( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Locked( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Locked( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Name( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_OnAction( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_OnAction( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Placement( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Placement( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PrintObject( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PrintObject( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SendToBack( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Top( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Top( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TopLeftCell( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Visible( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Visible( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Width( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Width( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ZOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShapeRange( 
            /* [retval][out] */ ShapeRange	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Caption( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Caption( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Characters( 
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Length,
            /* [retval][out] */ Characters	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CheckSpelling( 
            /* [optional][in] */ VARIANT CustomDictionary,
            /* [optional][in] */ VARIANT IgnoreUppercase,
            /* [optional][in] */ VARIANT AlwaysSuggest,
            /* [optional][in] */ VARIANT SpellLang,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LockedText( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_LockedText( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Text( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Text( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Accelerator( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Accelerator( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Display3DShading( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Display3DShading( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PhoneticAccelerator( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PhoneticAccelerator( 
            /* [in] */ VARIANT RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IGroupBoxVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IGroupBox * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IGroupBox * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IGroupBox * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IGroupBox * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IGroupBox * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IGroupBox * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IGroupBox * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IGroupBox * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IGroupBox * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IGroupBox * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_BottomRightCell )( 
            IGroupBox * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *BringToFront )( 
            IGroupBox * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Copy )( 
            IGroupBox * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CopyPicture )( 
            IGroupBox * This,
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Cut )( 
            IGroupBox * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IGroupBox * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Duplicate )( 
            IGroupBox * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Enabled )( 
            IGroupBox * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Enabled )( 
            IGroupBox * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Height )( 
            IGroupBox * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Height )( 
            IGroupBox * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Index )( 
            IGroupBox * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Left )( 
            IGroupBox * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Left )( 
            IGroupBox * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Locked )( 
            IGroupBox * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Locked )( 
            IGroupBox * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            IGroupBox * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Name )( 
            IGroupBox * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_OnAction )( 
            IGroupBox * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_OnAction )( 
            IGroupBox * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Placement )( 
            IGroupBox * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Placement )( 
            IGroupBox * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PrintObject )( 
            IGroupBox * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PrintObject )( 
            IGroupBox * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            IGroupBox * This,
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SendToBack )( 
            IGroupBox * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Top )( 
            IGroupBox * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Top )( 
            IGroupBox * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TopLeftCell )( 
            IGroupBox * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Visible )( 
            IGroupBox * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Visible )( 
            IGroupBox * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Width )( 
            IGroupBox * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Width )( 
            IGroupBox * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ZOrder )( 
            IGroupBox * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShapeRange )( 
            IGroupBox * This,
            /* [retval][out] */ ShapeRange	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Caption )( 
            IGroupBox * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Caption )( 
            IGroupBox * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Characters )( 
            IGroupBox * This,
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Length,
            /* [retval][out] */ Characters	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CheckSpelling )( 
            IGroupBox * This,
            /* [optional][in] */ VARIANT CustomDictionary,
            /* [optional][in] */ VARIANT IgnoreUppercase,
            /* [optional][in] */ VARIANT AlwaysSuggest,
            /* [optional][in] */ VARIANT SpellLang,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LockedText )( 
            IGroupBox * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_LockedText )( 
            IGroupBox * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Text )( 
            IGroupBox * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Text )( 
            IGroupBox * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Accelerator )( 
            IGroupBox * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Accelerator )( 
            IGroupBox * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Display3DShading )( 
            IGroupBox * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Display3DShading )( 
            IGroupBox * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PhoneticAccelerator )( 
            IGroupBox * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PhoneticAccelerator )( 
            IGroupBox * This,
            /* [in] */ VARIANT RHS);
        
        END_INTERFACE
    } IGroupBoxVtbl;

    interface IGroupBox
    {
        CONST_VTBL struct IGroupBoxVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IGroupBox_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IGroupBox_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IGroupBox_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IGroupBox_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IGroupBox_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IGroupBox_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IGroupBox_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IGroupBox_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IGroupBox_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IGroupBox_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IGroupBox_get_BottomRightCell(This,RHS)	\
    ( (This)->lpVtbl -> get_BottomRightCell(This,RHS) ) 

#define IGroupBox_BringToFront(This,RHS)	\
    ( (This)->lpVtbl -> BringToFront(This,RHS) ) 

#define IGroupBox_Copy(This,RHS)	\
    ( (This)->lpVtbl -> Copy(This,RHS) ) 

#define IGroupBox_CopyPicture(This,Appearance,Format,RHS)	\
    ( (This)->lpVtbl -> CopyPicture(This,Appearance,Format,RHS) ) 

#define IGroupBox_Cut(This,RHS)	\
    ( (This)->lpVtbl -> Cut(This,RHS) ) 

#define IGroupBox_Delete(This,RHS)	\
    ( (This)->lpVtbl -> Delete(This,RHS) ) 

#define IGroupBox_Duplicate(This,RHS)	\
    ( (This)->lpVtbl -> Duplicate(This,RHS) ) 

#define IGroupBox_get_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> get_Enabled(This,RHS) ) 

#define IGroupBox_put_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> put_Enabled(This,RHS) ) 

#define IGroupBox_get_Height(This,RHS)	\
    ( (This)->lpVtbl -> get_Height(This,RHS) ) 

#define IGroupBox_put_Height(This,RHS)	\
    ( (This)->lpVtbl -> put_Height(This,RHS) ) 

#define IGroupBox_get_Index(This,RHS)	\
    ( (This)->lpVtbl -> get_Index(This,RHS) ) 

#define IGroupBox_get_Left(This,RHS)	\
    ( (This)->lpVtbl -> get_Left(This,RHS) ) 

#define IGroupBox_put_Left(This,RHS)	\
    ( (This)->lpVtbl -> put_Left(This,RHS) ) 

#define IGroupBox_get_Locked(This,RHS)	\
    ( (This)->lpVtbl -> get_Locked(This,RHS) ) 

#define IGroupBox_put_Locked(This,RHS)	\
    ( (This)->lpVtbl -> put_Locked(This,RHS) ) 

#define IGroupBox_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define IGroupBox_put_Name(This,RHS)	\
    ( (This)->lpVtbl -> put_Name(This,RHS) ) 

#define IGroupBox_get_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> get_OnAction(This,RHS) ) 

#define IGroupBox_put_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> put_OnAction(This,RHS) ) 

#define IGroupBox_get_Placement(This,RHS)	\
    ( (This)->lpVtbl -> get_Placement(This,RHS) ) 

#define IGroupBox_put_Placement(This,RHS)	\
    ( (This)->lpVtbl -> put_Placement(This,RHS) ) 

#define IGroupBox_get_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> get_PrintObject(This,RHS) ) 

#define IGroupBox_put_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> put_PrintObject(This,RHS) ) 

#define IGroupBox_Select(This,Replace,RHS)	\
    ( (This)->lpVtbl -> Select(This,Replace,RHS) ) 

#define IGroupBox_SendToBack(This,RHS)	\
    ( (This)->lpVtbl -> SendToBack(This,RHS) ) 

#define IGroupBox_get_Top(This,RHS)	\
    ( (This)->lpVtbl -> get_Top(This,RHS) ) 

#define IGroupBox_put_Top(This,RHS)	\
    ( (This)->lpVtbl -> put_Top(This,RHS) ) 

#define IGroupBox_get_TopLeftCell(This,RHS)	\
    ( (This)->lpVtbl -> get_TopLeftCell(This,RHS) ) 

#define IGroupBox_get_Visible(This,RHS)	\
    ( (This)->lpVtbl -> get_Visible(This,RHS) ) 

#define IGroupBox_put_Visible(This,RHS)	\
    ( (This)->lpVtbl -> put_Visible(This,RHS) ) 

#define IGroupBox_get_Width(This,RHS)	\
    ( (This)->lpVtbl -> get_Width(This,RHS) ) 

#define IGroupBox_put_Width(This,RHS)	\
    ( (This)->lpVtbl -> put_Width(This,RHS) ) 

#define IGroupBox_get_ZOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_ZOrder(This,RHS) ) 

#define IGroupBox_get_ShapeRange(This,RHS)	\
    ( (This)->lpVtbl -> get_ShapeRange(This,RHS) ) 

#define IGroupBox_get_Caption(This,RHS)	\
    ( (This)->lpVtbl -> get_Caption(This,RHS) ) 

#define IGroupBox_put_Caption(This,RHS)	\
    ( (This)->lpVtbl -> put_Caption(This,RHS) ) 

#define IGroupBox_get_Characters(This,Start,Length,RHS)	\
    ( (This)->lpVtbl -> get_Characters(This,Start,Length,RHS) ) 

#define IGroupBox_CheckSpelling(This,CustomDictionary,IgnoreUppercase,AlwaysSuggest,SpellLang,RHS)	\
    ( (This)->lpVtbl -> CheckSpelling(This,CustomDictionary,IgnoreUppercase,AlwaysSuggest,SpellLang,RHS) ) 

#define IGroupBox_get_LockedText(This,RHS)	\
    ( (This)->lpVtbl -> get_LockedText(This,RHS) ) 

#define IGroupBox_put_LockedText(This,RHS)	\
    ( (This)->lpVtbl -> put_LockedText(This,RHS) ) 

#define IGroupBox_get_Text(This,RHS)	\
    ( (This)->lpVtbl -> get_Text(This,RHS) ) 

#define IGroupBox_put_Text(This,RHS)	\
    ( (This)->lpVtbl -> put_Text(This,RHS) ) 

#define IGroupBox_get_Accelerator(This,RHS)	\
    ( (This)->lpVtbl -> get_Accelerator(This,RHS) ) 

#define IGroupBox_put_Accelerator(This,RHS)	\
    ( (This)->lpVtbl -> put_Accelerator(This,RHS) ) 

#define IGroupBox_get_Display3DShading(This,RHS)	\
    ( (This)->lpVtbl -> get_Display3DShading(This,RHS) ) 

#define IGroupBox_put_Display3DShading(This,RHS)	\
    ( (This)->lpVtbl -> put_Display3DShading(This,RHS) ) 

#define IGroupBox_get_PhoneticAccelerator(This,RHS)	\
    ( (This)->lpVtbl -> get_PhoneticAccelerator(This,RHS) ) 

#define IGroupBox_put_PhoneticAccelerator(This,RHS)	\
    ( (This)->lpVtbl -> put_PhoneticAccelerator(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IGroupBox_INTERFACE_DEFINED__ */


#ifndef __IGroupBoxes_INTERFACE_DEFINED__
#define __IGroupBoxes_INTERFACE_DEFINED__

/* interface IGroupBoxes */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IGroupBoxes;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002088A-0001-0000-C000-000000000046")
    IGroupBoxes : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy3( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall BringToFront( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Copy( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CopyPicture( 
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Cut( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Duplicate( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Enabled( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Enabled( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Height( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Height( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy12( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Left( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Left( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Locked( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Locked( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy15( void) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_OnAction( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_OnAction( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Placement( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Placement( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PrintObject( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PrintObject( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SendToBack( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Top( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Top( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy22( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Visible( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Visible( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Width( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Width( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ZOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShapeRange( 
            /* [retval][out] */ ShapeRange	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Caption( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Caption( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Characters( 
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Length,
            /* [retval][out] */ Characters	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CheckSpelling( 
            /* [optional][in] */ VARIANT CustomDictionary,
            /* [optional][in] */ VARIANT IgnoreUppercase,
            /* [optional][in] */ VARIANT AlwaysSuggest,
            /* [optional][in] */ VARIANT SpellLang,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LockedText( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_LockedText( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Text( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Text( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Accelerator( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Accelerator( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Display3DShading( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Display3DShading( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PhoneticAccelerator( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PhoneticAccelerator( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add( 
            /* [in] */ double Left,
            /* [in] */ double Top,
            /* [in] */ double Width,
            /* [in] */ double Height,
            /* [retval][out] */ GroupBox	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Group( 
            /* [retval][out] */ GroupObject	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall _NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IGroupBoxesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IGroupBoxes * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IGroupBoxes * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IGroupBoxes * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IGroupBoxes * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IGroupBoxes * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IGroupBoxes * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IGroupBoxes * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IGroupBoxes * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IGroupBoxes * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IGroupBoxes * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy3 )( 
            IGroupBoxes * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *BringToFront )( 
            IGroupBoxes * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Copy )( 
            IGroupBoxes * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CopyPicture )( 
            IGroupBoxes * This,
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Cut )( 
            IGroupBoxes * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IGroupBoxes * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Duplicate )( 
            IGroupBoxes * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Enabled )( 
            IGroupBoxes * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Enabled )( 
            IGroupBoxes * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Height )( 
            IGroupBoxes * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Height )( 
            IGroupBoxes * This,
            /* [in] */ double RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy12 )( 
            IGroupBoxes * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Left )( 
            IGroupBoxes * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Left )( 
            IGroupBoxes * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Locked )( 
            IGroupBoxes * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Locked )( 
            IGroupBoxes * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy15 )( 
            IGroupBoxes * This);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_OnAction )( 
            IGroupBoxes * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_OnAction )( 
            IGroupBoxes * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Placement )( 
            IGroupBoxes * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Placement )( 
            IGroupBoxes * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PrintObject )( 
            IGroupBoxes * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PrintObject )( 
            IGroupBoxes * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            IGroupBoxes * This,
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SendToBack )( 
            IGroupBoxes * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Top )( 
            IGroupBoxes * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Top )( 
            IGroupBoxes * This,
            /* [in] */ double RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy22 )( 
            IGroupBoxes * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Visible )( 
            IGroupBoxes * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Visible )( 
            IGroupBoxes * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Width )( 
            IGroupBoxes * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Width )( 
            IGroupBoxes * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ZOrder )( 
            IGroupBoxes * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShapeRange )( 
            IGroupBoxes * This,
            /* [retval][out] */ ShapeRange	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Caption )( 
            IGroupBoxes * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Caption )( 
            IGroupBoxes * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Characters )( 
            IGroupBoxes * This,
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Length,
            /* [retval][out] */ Characters	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CheckSpelling )( 
            IGroupBoxes * This,
            /* [optional][in] */ VARIANT CustomDictionary,
            /* [optional][in] */ VARIANT IgnoreUppercase,
            /* [optional][in] */ VARIANT AlwaysSuggest,
            /* [optional][in] */ VARIANT SpellLang,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LockedText )( 
            IGroupBoxes * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_LockedText )( 
            IGroupBoxes * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Text )( 
            IGroupBoxes * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Text )( 
            IGroupBoxes * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Accelerator )( 
            IGroupBoxes * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Accelerator )( 
            IGroupBoxes * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Display3DShading )( 
            IGroupBoxes * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Display3DShading )( 
            IGroupBoxes * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PhoneticAccelerator )( 
            IGroupBoxes * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PhoneticAccelerator )( 
            IGroupBoxes * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add )( 
            IGroupBoxes * This,
            /* [in] */ double Left,
            /* [in] */ double Top,
            /* [in] */ double Width,
            /* [in] */ double Height,
            /* [retval][out] */ GroupBox	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IGroupBoxes * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Group )( 
            IGroupBoxes * This,
            /* [retval][out] */ GroupObject	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Item )( 
            IGroupBoxes * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *_NewEnum )( 
            IGroupBoxes * This,
            /* [retval][out] */ IUnknown **RHS);
        
        END_INTERFACE
    } IGroupBoxesVtbl;

    interface IGroupBoxes
    {
        CONST_VTBL struct IGroupBoxesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IGroupBoxes_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IGroupBoxes_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IGroupBoxes_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IGroupBoxes_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IGroupBoxes_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IGroupBoxes_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IGroupBoxes_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IGroupBoxes_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IGroupBoxes_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IGroupBoxes_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IGroupBoxes__Dummy3(This)	\
    ( (This)->lpVtbl -> _Dummy3(This) ) 

#define IGroupBoxes_BringToFront(This,RHS)	\
    ( (This)->lpVtbl -> BringToFront(This,RHS) ) 

#define IGroupBoxes_Copy(This,RHS)	\
    ( (This)->lpVtbl -> Copy(This,RHS) ) 

#define IGroupBoxes_CopyPicture(This,Appearance,Format,RHS)	\
    ( (This)->lpVtbl -> CopyPicture(This,Appearance,Format,RHS) ) 

#define IGroupBoxes_Cut(This,RHS)	\
    ( (This)->lpVtbl -> Cut(This,RHS) ) 

#define IGroupBoxes_Delete(This,RHS)	\
    ( (This)->lpVtbl -> Delete(This,RHS) ) 

#define IGroupBoxes_Duplicate(This,RHS)	\
    ( (This)->lpVtbl -> Duplicate(This,RHS) ) 

#define IGroupBoxes_get_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> get_Enabled(This,RHS) ) 

#define IGroupBoxes_put_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> put_Enabled(This,RHS) ) 

#define IGroupBoxes_get_Height(This,RHS)	\
    ( (This)->lpVtbl -> get_Height(This,RHS) ) 

#define IGroupBoxes_put_Height(This,RHS)	\
    ( (This)->lpVtbl -> put_Height(This,RHS) ) 

#define IGroupBoxes__Dummy12(This)	\
    ( (This)->lpVtbl -> _Dummy12(This) ) 

#define IGroupBoxes_get_Left(This,RHS)	\
    ( (This)->lpVtbl -> get_Left(This,RHS) ) 

#define IGroupBoxes_put_Left(This,RHS)	\
    ( (This)->lpVtbl -> put_Left(This,RHS) ) 

#define IGroupBoxes_get_Locked(This,RHS)	\
    ( (This)->lpVtbl -> get_Locked(This,RHS) ) 

#define IGroupBoxes_put_Locked(This,RHS)	\
    ( (This)->lpVtbl -> put_Locked(This,RHS) ) 

#define IGroupBoxes__Dummy15(This)	\
    ( (This)->lpVtbl -> _Dummy15(This) ) 

#define IGroupBoxes_get_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> get_OnAction(This,RHS) ) 

#define IGroupBoxes_put_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> put_OnAction(This,RHS) ) 

#define IGroupBoxes_get_Placement(This,RHS)	\
    ( (This)->lpVtbl -> get_Placement(This,RHS) ) 

#define IGroupBoxes_put_Placement(This,RHS)	\
    ( (This)->lpVtbl -> put_Placement(This,RHS) ) 

#define IGroupBoxes_get_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> get_PrintObject(This,RHS) ) 

#define IGroupBoxes_put_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> put_PrintObject(This,RHS) ) 

#define IGroupBoxes_Select(This,Replace,RHS)	\
    ( (This)->lpVtbl -> Select(This,Replace,RHS) ) 

#define IGroupBoxes_SendToBack(This,RHS)	\
    ( (This)->lpVtbl -> SendToBack(This,RHS) ) 

#define IGroupBoxes_get_Top(This,RHS)	\
    ( (This)->lpVtbl -> get_Top(This,RHS) ) 

#define IGroupBoxes_put_Top(This,RHS)	\
    ( (This)->lpVtbl -> put_Top(This,RHS) ) 

#define IGroupBoxes__Dummy22(This)	\
    ( (This)->lpVtbl -> _Dummy22(This) ) 

#define IGroupBoxes_get_Visible(This,RHS)	\
    ( (This)->lpVtbl -> get_Visible(This,RHS) ) 

#define IGroupBoxes_put_Visible(This,RHS)	\
    ( (This)->lpVtbl -> put_Visible(This,RHS) ) 

#define IGroupBoxes_get_Width(This,RHS)	\
    ( (This)->lpVtbl -> get_Width(This,RHS) ) 

#define IGroupBoxes_put_Width(This,RHS)	\
    ( (This)->lpVtbl -> put_Width(This,RHS) ) 

#define IGroupBoxes_get_ZOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_ZOrder(This,RHS) ) 

#define IGroupBoxes_get_ShapeRange(This,RHS)	\
    ( (This)->lpVtbl -> get_ShapeRange(This,RHS) ) 

#define IGroupBoxes_get_Caption(This,RHS)	\
    ( (This)->lpVtbl -> get_Caption(This,RHS) ) 

#define IGroupBoxes_put_Caption(This,RHS)	\
    ( (This)->lpVtbl -> put_Caption(This,RHS) ) 

#define IGroupBoxes_get_Characters(This,Start,Length,RHS)	\
    ( (This)->lpVtbl -> get_Characters(This,Start,Length,RHS) ) 

#define IGroupBoxes_CheckSpelling(This,CustomDictionary,IgnoreUppercase,AlwaysSuggest,SpellLang,RHS)	\
    ( (This)->lpVtbl -> CheckSpelling(This,CustomDictionary,IgnoreUppercase,AlwaysSuggest,SpellLang,RHS) ) 

#define IGroupBoxes_get_LockedText(This,RHS)	\
    ( (This)->lpVtbl -> get_LockedText(This,RHS) ) 

#define IGroupBoxes_put_LockedText(This,RHS)	\
    ( (This)->lpVtbl -> put_LockedText(This,RHS) ) 

#define IGroupBoxes_get_Text(This,RHS)	\
    ( (This)->lpVtbl -> get_Text(This,RHS) ) 

#define IGroupBoxes_put_Text(This,RHS)	\
    ( (This)->lpVtbl -> put_Text(This,RHS) ) 

#define IGroupBoxes_get_Accelerator(This,RHS)	\
    ( (This)->lpVtbl -> get_Accelerator(This,RHS) ) 

#define IGroupBoxes_put_Accelerator(This,RHS)	\
    ( (This)->lpVtbl -> put_Accelerator(This,RHS) ) 

#define IGroupBoxes_get_Display3DShading(This,RHS)	\
    ( (This)->lpVtbl -> get_Display3DShading(This,RHS) ) 

#define IGroupBoxes_put_Display3DShading(This,RHS)	\
    ( (This)->lpVtbl -> put_Display3DShading(This,RHS) ) 

#define IGroupBoxes_get_PhoneticAccelerator(This,RHS)	\
    ( (This)->lpVtbl -> get_PhoneticAccelerator(This,RHS) ) 

#define IGroupBoxes_put_PhoneticAccelerator(This,RHS)	\
    ( (This)->lpVtbl -> put_PhoneticAccelerator(This,RHS) ) 

#define IGroupBoxes_Add(This,Left,Top,Width,Height,RHS)	\
    ( (This)->lpVtbl -> Add(This,Left,Top,Width,Height,RHS) ) 

#define IGroupBoxes_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IGroupBoxes_Group(This,RHS)	\
    ( (This)->lpVtbl -> Group(This,RHS) ) 

#define IGroupBoxes_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> Item(This,Index,RHS) ) 

#define IGroupBoxes__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> _NewEnum(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IGroupBoxes_INTERFACE_DEFINED__ */


#ifndef __IDropDown_INTERFACE_DEFINED__
#define __IDropDown_INTERFACE_DEFINED__

/* interface IDropDown */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IDropDown;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002088B-0001-0000-C000-000000000046")
    IDropDown : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_BottomRightCell( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall BringToFront( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Copy( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CopyPicture( 
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Cut( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Duplicate( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Enabled( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Enabled( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Height( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Height( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Index( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Left( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Left( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Locked( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Locked( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Name( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_OnAction( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_OnAction( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Placement( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Placement( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PrintObject( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PrintObject( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SendToBack( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Top( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Top( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TopLeftCell( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Visible( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Visible( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Width( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Width( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ZOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShapeRange( 
            /* [retval][out] */ ShapeRange	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall AddItem( 
            /* [in] */ VARIANT Text,
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Display3DShading( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Display3DShading( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put__Default( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LinkedCell( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_LinkedCell( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LinkedObject( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_List( 
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_List( 
            /* [optional][in] */ VARIANT Index,
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ListCount( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ListFillRange( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ListFillRange( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ListIndex( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ListIndex( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy36( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall RemoveAllItems( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall RemoveItem( 
            /* [in] */ long Index,
            /* [optional][in] */ VARIANT Count,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Selected( 
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Selected( 
            /* [optional][in] */ VARIANT Index,
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Value( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Value( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Caption( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Caption( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Characters( 
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Length,
            /* [retval][out] */ Characters	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DropDownLines( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DropDownLines( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Text( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Text( 
            /* [in] */ BSTR RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IDropDownVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IDropDown * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IDropDown * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IDropDown * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IDropDown * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IDropDown * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IDropDown * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IDropDown * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IDropDown * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IDropDown * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IDropDown * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_BottomRightCell )( 
            IDropDown * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *BringToFront )( 
            IDropDown * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Copy )( 
            IDropDown * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CopyPicture )( 
            IDropDown * This,
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Cut )( 
            IDropDown * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IDropDown * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Duplicate )( 
            IDropDown * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Enabled )( 
            IDropDown * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Enabled )( 
            IDropDown * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Height )( 
            IDropDown * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Height )( 
            IDropDown * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Index )( 
            IDropDown * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Left )( 
            IDropDown * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Left )( 
            IDropDown * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Locked )( 
            IDropDown * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Locked )( 
            IDropDown * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            IDropDown * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Name )( 
            IDropDown * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_OnAction )( 
            IDropDown * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_OnAction )( 
            IDropDown * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Placement )( 
            IDropDown * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Placement )( 
            IDropDown * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PrintObject )( 
            IDropDown * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PrintObject )( 
            IDropDown * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            IDropDown * This,
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SendToBack )( 
            IDropDown * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Top )( 
            IDropDown * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Top )( 
            IDropDown * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TopLeftCell )( 
            IDropDown * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Visible )( 
            IDropDown * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Visible )( 
            IDropDown * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Width )( 
            IDropDown * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Width )( 
            IDropDown * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ZOrder )( 
            IDropDown * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShapeRange )( 
            IDropDown * This,
            /* [retval][out] */ ShapeRange	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *AddItem )( 
            IDropDown * This,
            /* [in] */ VARIANT Text,
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Display3DShading )( 
            IDropDown * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Display3DShading )( 
            IDropDown * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IDropDown * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put__Default )( 
            IDropDown * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LinkedCell )( 
            IDropDown * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_LinkedCell )( 
            IDropDown * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LinkedObject )( 
            IDropDown * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_List )( 
            IDropDown * This,
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_List )( 
            IDropDown * This,
            /* [optional][in] */ VARIANT Index,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ListCount )( 
            IDropDown * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ListFillRange )( 
            IDropDown * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ListFillRange )( 
            IDropDown * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ListIndex )( 
            IDropDown * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ListIndex )( 
            IDropDown * This,
            /* [in] */ long RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy36 )( 
            IDropDown * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *RemoveAllItems )( 
            IDropDown * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *RemoveItem )( 
            IDropDown * This,
            /* [in] */ long Index,
            /* [optional][in] */ VARIANT Count,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Selected )( 
            IDropDown * This,
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Selected )( 
            IDropDown * This,
            /* [optional][in] */ VARIANT Index,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Value )( 
            IDropDown * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Value )( 
            IDropDown * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Caption )( 
            IDropDown * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Caption )( 
            IDropDown * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Characters )( 
            IDropDown * This,
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Length,
            /* [retval][out] */ Characters	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DropDownLines )( 
            IDropDown * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DropDownLines )( 
            IDropDown * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Text )( 
            IDropDown * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Text )( 
            IDropDown * This,
            /* [in] */ BSTR RHS);
        
        END_INTERFACE
    } IDropDownVtbl;

    interface IDropDown
    {
        CONST_VTBL struct IDropDownVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IDropDown_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IDropDown_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IDropDown_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IDropDown_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IDropDown_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IDropDown_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IDropDown_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IDropDown_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IDropDown_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IDropDown_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IDropDown_get_BottomRightCell(This,RHS)	\
    ( (This)->lpVtbl -> get_BottomRightCell(This,RHS) ) 

#define IDropDown_BringToFront(This,RHS)	\
    ( (This)->lpVtbl -> BringToFront(This,RHS) ) 

#define IDropDown_Copy(This,RHS)	\
    ( (This)->lpVtbl -> Copy(This,RHS) ) 

#define IDropDown_CopyPicture(This,Appearance,Format,RHS)	\
    ( (This)->lpVtbl -> CopyPicture(This,Appearance,Format,RHS) ) 

#define IDropDown_Cut(This,RHS)	\
    ( (This)->lpVtbl -> Cut(This,RHS) ) 

#define IDropDown_Delete(This,RHS)	\
    ( (This)->lpVtbl -> Delete(This,RHS) ) 

#define IDropDown_Duplicate(This,RHS)	\
    ( (This)->lpVtbl -> Duplicate(This,RHS) ) 

#define IDropDown_get_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> get_Enabled(This,RHS) ) 

#define IDropDown_put_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> put_Enabled(This,RHS) ) 

#define IDropDown_get_Height(This,RHS)	\
    ( (This)->lpVtbl -> get_Height(This,RHS) ) 

#define IDropDown_put_Height(This,RHS)	\
    ( (This)->lpVtbl -> put_Height(This,RHS) ) 

#define IDropDown_get_Index(This,RHS)	\
    ( (This)->lpVtbl -> get_Index(This,RHS) ) 

#define IDropDown_get_Left(This,RHS)	\
    ( (This)->lpVtbl -> get_Left(This,RHS) ) 

#define IDropDown_put_Left(This,RHS)	\
    ( (This)->lpVtbl -> put_Left(This,RHS) ) 

#define IDropDown_get_Locked(This,RHS)	\
    ( (This)->lpVtbl -> get_Locked(This,RHS) ) 

#define IDropDown_put_Locked(This,RHS)	\
    ( (This)->lpVtbl -> put_Locked(This,RHS) ) 

#define IDropDown_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define IDropDown_put_Name(This,RHS)	\
    ( (This)->lpVtbl -> put_Name(This,RHS) ) 

#define IDropDown_get_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> get_OnAction(This,RHS) ) 

#define IDropDown_put_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> put_OnAction(This,RHS) ) 

#define IDropDown_get_Placement(This,RHS)	\
    ( (This)->lpVtbl -> get_Placement(This,RHS) ) 

#define IDropDown_put_Placement(This,RHS)	\
    ( (This)->lpVtbl -> put_Placement(This,RHS) ) 

#define IDropDown_get_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> get_PrintObject(This,RHS) ) 

#define IDropDown_put_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> put_PrintObject(This,RHS) ) 

#define IDropDown_Select(This,Replace,RHS)	\
    ( (This)->lpVtbl -> Select(This,Replace,RHS) ) 

#define IDropDown_SendToBack(This,RHS)	\
    ( (This)->lpVtbl -> SendToBack(This,RHS) ) 

#define IDropDown_get_Top(This,RHS)	\
    ( (This)->lpVtbl -> get_Top(This,RHS) ) 

#define IDropDown_put_Top(This,RHS)	\
    ( (This)->lpVtbl -> put_Top(This,RHS) ) 

#define IDropDown_get_TopLeftCell(This,RHS)	\
    ( (This)->lpVtbl -> get_TopLeftCell(This,RHS) ) 

#define IDropDown_get_Visible(This,RHS)	\
    ( (This)->lpVtbl -> get_Visible(This,RHS) ) 

#define IDropDown_put_Visible(This,RHS)	\
    ( (This)->lpVtbl -> put_Visible(This,RHS) ) 

#define IDropDown_get_Width(This,RHS)	\
    ( (This)->lpVtbl -> get_Width(This,RHS) ) 

#define IDropDown_put_Width(This,RHS)	\
    ( (This)->lpVtbl -> put_Width(This,RHS) ) 

#define IDropDown_get_ZOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_ZOrder(This,RHS) ) 

#define IDropDown_get_ShapeRange(This,RHS)	\
    ( (This)->lpVtbl -> get_ShapeRange(This,RHS) ) 

#define IDropDown_AddItem(This,Text,Index,RHS)	\
    ( (This)->lpVtbl -> AddItem(This,Text,Index,RHS) ) 

#define IDropDown_get_Display3DShading(This,RHS)	\
    ( (This)->lpVtbl -> get_Display3DShading(This,RHS) ) 

#define IDropDown_put_Display3DShading(This,RHS)	\
    ( (This)->lpVtbl -> put_Display3DShading(This,RHS) ) 

#define IDropDown_get__Default(This,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,RHS) ) 

#define IDropDown_put__Default(This,RHS)	\
    ( (This)->lpVtbl -> put__Default(This,RHS) ) 

#define IDropDown_get_LinkedCell(This,RHS)	\
    ( (This)->lpVtbl -> get_LinkedCell(This,RHS) ) 

#define IDropDown_put_LinkedCell(This,RHS)	\
    ( (This)->lpVtbl -> put_LinkedCell(This,RHS) ) 

#define IDropDown_get_LinkedObject(This,RHS)	\
    ( (This)->lpVtbl -> get_LinkedObject(This,RHS) ) 

#define IDropDown_get_List(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_List(This,Index,RHS) ) 

#define IDropDown_put_List(This,Index,RHS)	\
    ( (This)->lpVtbl -> put_List(This,Index,RHS) ) 

#define IDropDown_get_ListCount(This,RHS)	\
    ( (This)->lpVtbl -> get_ListCount(This,RHS) ) 

#define IDropDown_get_ListFillRange(This,RHS)	\
    ( (This)->lpVtbl -> get_ListFillRange(This,RHS) ) 

#define IDropDown_put_ListFillRange(This,RHS)	\
    ( (This)->lpVtbl -> put_ListFillRange(This,RHS) ) 

#define IDropDown_get_ListIndex(This,RHS)	\
    ( (This)->lpVtbl -> get_ListIndex(This,RHS) ) 

#define IDropDown_put_ListIndex(This,RHS)	\
    ( (This)->lpVtbl -> put_ListIndex(This,RHS) ) 

#define IDropDown__Dummy36(This)	\
    ( (This)->lpVtbl -> _Dummy36(This) ) 

#define IDropDown_RemoveAllItems(This,RHS)	\
    ( (This)->lpVtbl -> RemoveAllItems(This,RHS) ) 

#define IDropDown_RemoveItem(This,Index,Count,RHS)	\
    ( (This)->lpVtbl -> RemoveItem(This,Index,Count,RHS) ) 

#define IDropDown_get_Selected(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Selected(This,Index,RHS) ) 

#define IDropDown_put_Selected(This,Index,RHS)	\
    ( (This)->lpVtbl -> put_Selected(This,Index,RHS) ) 

#define IDropDown_get_Value(This,RHS)	\
    ( (This)->lpVtbl -> get_Value(This,RHS) ) 

#define IDropDown_put_Value(This,RHS)	\
    ( (This)->lpVtbl -> put_Value(This,RHS) ) 

#define IDropDown_get_Caption(This,RHS)	\
    ( (This)->lpVtbl -> get_Caption(This,RHS) ) 

#define IDropDown_put_Caption(This,RHS)	\
    ( (This)->lpVtbl -> put_Caption(This,RHS) ) 

#define IDropDown_get_Characters(This,Start,Length,RHS)	\
    ( (This)->lpVtbl -> get_Characters(This,Start,Length,RHS) ) 

#define IDropDown_get_DropDownLines(This,RHS)	\
    ( (This)->lpVtbl -> get_DropDownLines(This,RHS) ) 

#define IDropDown_put_DropDownLines(This,RHS)	\
    ( (This)->lpVtbl -> put_DropDownLines(This,RHS) ) 

#define IDropDown_get_Text(This,RHS)	\
    ( (This)->lpVtbl -> get_Text(This,RHS) ) 

#define IDropDown_put_Text(This,RHS)	\
    ( (This)->lpVtbl -> put_Text(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IDropDown_INTERFACE_DEFINED__ */


#ifndef __IDropDowns_INTERFACE_DEFINED__
#define __IDropDowns_INTERFACE_DEFINED__

/* interface IDropDowns */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IDropDowns;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002088C-0001-0000-C000-000000000046")
    IDropDowns : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy3( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall BringToFront( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Copy( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CopyPicture( 
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Cut( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Duplicate( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Enabled( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Enabled( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Height( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Height( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy12( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Left( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Left( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Locked( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Locked( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy15( void) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_OnAction( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_OnAction( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Placement( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Placement( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PrintObject( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PrintObject( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SendToBack( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Top( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Top( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy22( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Visible( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Visible( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Width( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Width( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ZOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShapeRange( 
            /* [retval][out] */ ShapeRange	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall AddItem( 
            /* [in] */ VARIANT Text,
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Display3DShading( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Display3DShading( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put__Default( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LinkedCell( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_LinkedCell( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy31( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_List( 
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_List( 
            /* [optional][in] */ VARIANT Index,
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy33( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ListFillRange( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ListFillRange( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ListIndex( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ListIndex( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy36( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall RemoveAllItems( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall RemoveItem( 
            /* [in] */ long Index,
            /* [optional][in] */ VARIANT Count,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Selected( 
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Selected( 
            /* [optional][in] */ VARIANT Index,
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Value( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Value( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Caption( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Caption( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Characters( 
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Length,
            /* [retval][out] */ Characters	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DropDownLines( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DropDownLines( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Text( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Text( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add( 
            /* [in] */ double Left,
            /* [in] */ double Top,
            /* [in] */ double Width,
            /* [in] */ double Height,
            /* [optional][in] */ VARIANT Editable,
            /* [retval][out] */ DropDown	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Group( 
            /* [retval][out] */ GroupObject	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall _NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IDropDownsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IDropDowns * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IDropDowns * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IDropDowns * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IDropDowns * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IDropDowns * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IDropDowns * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IDropDowns * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IDropDowns * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IDropDowns * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IDropDowns * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy3 )( 
            IDropDowns * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *BringToFront )( 
            IDropDowns * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Copy )( 
            IDropDowns * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CopyPicture )( 
            IDropDowns * This,
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Cut )( 
            IDropDowns * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IDropDowns * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Duplicate )( 
            IDropDowns * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Enabled )( 
            IDropDowns * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Enabled )( 
            IDropDowns * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Height )( 
            IDropDowns * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Height )( 
            IDropDowns * This,
            /* [in] */ double RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy12 )( 
            IDropDowns * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Left )( 
            IDropDowns * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Left )( 
            IDropDowns * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Locked )( 
            IDropDowns * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Locked )( 
            IDropDowns * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy15 )( 
            IDropDowns * This);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_OnAction )( 
            IDropDowns * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_OnAction )( 
            IDropDowns * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Placement )( 
            IDropDowns * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Placement )( 
            IDropDowns * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PrintObject )( 
            IDropDowns * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PrintObject )( 
            IDropDowns * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            IDropDowns * This,
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SendToBack )( 
            IDropDowns * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Top )( 
            IDropDowns * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Top )( 
            IDropDowns * This,
            /* [in] */ double RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy22 )( 
            IDropDowns * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Visible )( 
            IDropDowns * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Visible )( 
            IDropDowns * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Width )( 
            IDropDowns * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Width )( 
            IDropDowns * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ZOrder )( 
            IDropDowns * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShapeRange )( 
            IDropDowns * This,
            /* [retval][out] */ ShapeRange	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *AddItem )( 
            IDropDowns * This,
            /* [in] */ VARIANT Text,
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Display3DShading )( 
            IDropDowns * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Display3DShading )( 
            IDropDowns * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IDropDowns * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put__Default )( 
            IDropDowns * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LinkedCell )( 
            IDropDowns * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_LinkedCell )( 
            IDropDowns * This,
            /* [in] */ BSTR RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy31 )( 
            IDropDowns * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_List )( 
            IDropDowns * This,
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_List )( 
            IDropDowns * This,
            /* [optional][in] */ VARIANT Index,
            /* [in] */ VARIANT RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy33 )( 
            IDropDowns * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ListFillRange )( 
            IDropDowns * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ListFillRange )( 
            IDropDowns * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ListIndex )( 
            IDropDowns * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ListIndex )( 
            IDropDowns * This,
            /* [in] */ long RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy36 )( 
            IDropDowns * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *RemoveAllItems )( 
            IDropDowns * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *RemoveItem )( 
            IDropDowns * This,
            /* [in] */ long Index,
            /* [optional][in] */ VARIANT Count,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Selected )( 
            IDropDowns * This,
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Selected )( 
            IDropDowns * This,
            /* [optional][in] */ VARIANT Index,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Value )( 
            IDropDowns * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Value )( 
            IDropDowns * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Caption )( 
            IDropDowns * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Caption )( 
            IDropDowns * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Characters )( 
            IDropDowns * This,
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Length,
            /* [retval][out] */ Characters	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DropDownLines )( 
            IDropDowns * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DropDownLines )( 
            IDropDowns * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Text )( 
            IDropDowns * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Text )( 
            IDropDowns * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add )( 
            IDropDowns * This,
            /* [in] */ double Left,
            /* [in] */ double Top,
            /* [in] */ double Width,
            /* [in] */ double Height,
            /* [optional][in] */ VARIANT Editable,
            /* [retval][out] */ DropDown	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IDropDowns * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Group )( 
            IDropDowns * This,
            /* [retval][out] */ GroupObject	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Item )( 
            IDropDowns * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *_NewEnum )( 
            IDropDowns * This,
            /* [retval][out] */ IUnknown **RHS);
        
        END_INTERFACE
    } IDropDownsVtbl;

    interface IDropDowns
    {
        CONST_VTBL struct IDropDownsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IDropDowns_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IDropDowns_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IDropDowns_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IDropDowns_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IDropDowns_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IDropDowns_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IDropDowns_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IDropDowns_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IDropDowns_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IDropDowns_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IDropDowns__Dummy3(This)	\
    ( (This)->lpVtbl -> _Dummy3(This) ) 

#define IDropDowns_BringToFront(This,RHS)	\
    ( (This)->lpVtbl -> BringToFront(This,RHS) ) 

#define IDropDowns_Copy(This,RHS)	\
    ( (This)->lpVtbl -> Copy(This,RHS) ) 

#define IDropDowns_CopyPicture(This,Appearance,Format,RHS)	\
    ( (This)->lpVtbl -> CopyPicture(This,Appearance,Format,RHS) ) 

#define IDropDowns_Cut(This,RHS)	\
    ( (This)->lpVtbl -> Cut(This,RHS) ) 

#define IDropDowns_Delete(This,RHS)	\
    ( (This)->lpVtbl -> Delete(This,RHS) ) 

#define IDropDowns_Duplicate(This,RHS)	\
    ( (This)->lpVtbl -> Duplicate(This,RHS) ) 

#define IDropDowns_get_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> get_Enabled(This,RHS) ) 

#define IDropDowns_put_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> put_Enabled(This,RHS) ) 

#define IDropDowns_get_Height(This,RHS)	\
    ( (This)->lpVtbl -> get_Height(This,RHS) ) 

#define IDropDowns_put_Height(This,RHS)	\
    ( (This)->lpVtbl -> put_Height(This,RHS) ) 

#define IDropDowns__Dummy12(This)	\
    ( (This)->lpVtbl -> _Dummy12(This) ) 

#define IDropDowns_get_Left(This,RHS)	\
    ( (This)->lpVtbl -> get_Left(This,RHS) ) 

#define IDropDowns_put_Left(This,RHS)	\
    ( (This)->lpVtbl -> put_Left(This,RHS) ) 

#define IDropDowns_get_Locked(This,RHS)	\
    ( (This)->lpVtbl -> get_Locked(This,RHS) ) 

#define IDropDowns_put_Locked(This,RHS)	\
    ( (This)->lpVtbl -> put_Locked(This,RHS) ) 

#define IDropDowns__Dummy15(This)	\
    ( (This)->lpVtbl -> _Dummy15(This) ) 

#define IDropDowns_get_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> get_OnAction(This,RHS) ) 

#define IDropDowns_put_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> put_OnAction(This,RHS) ) 

#define IDropDowns_get_Placement(This,RHS)	\
    ( (This)->lpVtbl -> get_Placement(This,RHS) ) 

#define IDropDowns_put_Placement(This,RHS)	\
    ( (This)->lpVtbl -> put_Placement(This,RHS) ) 

#define IDropDowns_get_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> get_PrintObject(This,RHS) ) 

#define IDropDowns_put_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> put_PrintObject(This,RHS) ) 

#define IDropDowns_Select(This,Replace,RHS)	\
    ( (This)->lpVtbl -> Select(This,Replace,RHS) ) 

#define IDropDowns_SendToBack(This,RHS)	\
    ( (This)->lpVtbl -> SendToBack(This,RHS) ) 

#define IDropDowns_get_Top(This,RHS)	\
    ( (This)->lpVtbl -> get_Top(This,RHS) ) 

#define IDropDowns_put_Top(This,RHS)	\
    ( (This)->lpVtbl -> put_Top(This,RHS) ) 

#define IDropDowns__Dummy22(This)	\
    ( (This)->lpVtbl -> _Dummy22(This) ) 

#define IDropDowns_get_Visible(This,RHS)	\
    ( (This)->lpVtbl -> get_Visible(This,RHS) ) 

#define IDropDowns_put_Visible(This,RHS)	\
    ( (This)->lpVtbl -> put_Visible(This,RHS) ) 

#define IDropDowns_get_Width(This,RHS)	\
    ( (This)->lpVtbl -> get_Width(This,RHS) ) 

#define IDropDowns_put_Width(This,RHS)	\
    ( (This)->lpVtbl -> put_Width(This,RHS) ) 

#define IDropDowns_get_ZOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_ZOrder(This,RHS) ) 

#define IDropDowns_get_ShapeRange(This,RHS)	\
    ( (This)->lpVtbl -> get_ShapeRange(This,RHS) ) 

#define IDropDowns_AddItem(This,Text,Index,RHS)	\
    ( (This)->lpVtbl -> AddItem(This,Text,Index,RHS) ) 

#define IDropDowns_get_Display3DShading(This,RHS)	\
    ( (This)->lpVtbl -> get_Display3DShading(This,RHS) ) 

#define IDropDowns_put_Display3DShading(This,RHS)	\
    ( (This)->lpVtbl -> put_Display3DShading(This,RHS) ) 

#define IDropDowns_get__Default(This,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,RHS) ) 

#define IDropDowns_put__Default(This,RHS)	\
    ( (This)->lpVtbl -> put__Default(This,RHS) ) 

#define IDropDowns_get_LinkedCell(This,RHS)	\
    ( (This)->lpVtbl -> get_LinkedCell(This,RHS) ) 

#define IDropDowns_put_LinkedCell(This,RHS)	\
    ( (This)->lpVtbl -> put_LinkedCell(This,RHS) ) 

#define IDropDowns__Dummy31(This)	\
    ( (This)->lpVtbl -> _Dummy31(This) ) 

#define IDropDowns_get_List(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_List(This,Index,RHS) ) 

#define IDropDowns_put_List(This,Index,RHS)	\
    ( (This)->lpVtbl -> put_List(This,Index,RHS) ) 

#define IDropDowns__Dummy33(This)	\
    ( (This)->lpVtbl -> _Dummy33(This) ) 

#define IDropDowns_get_ListFillRange(This,RHS)	\
    ( (This)->lpVtbl -> get_ListFillRange(This,RHS) ) 

#define IDropDowns_put_ListFillRange(This,RHS)	\
    ( (This)->lpVtbl -> put_ListFillRange(This,RHS) ) 

#define IDropDowns_get_ListIndex(This,RHS)	\
    ( (This)->lpVtbl -> get_ListIndex(This,RHS) ) 

#define IDropDowns_put_ListIndex(This,RHS)	\
    ( (This)->lpVtbl -> put_ListIndex(This,RHS) ) 

#define IDropDowns__Dummy36(This)	\
    ( (This)->lpVtbl -> _Dummy36(This) ) 

#define IDropDowns_RemoveAllItems(This,RHS)	\
    ( (This)->lpVtbl -> RemoveAllItems(This,RHS) ) 

#define IDropDowns_RemoveItem(This,Index,Count,RHS)	\
    ( (This)->lpVtbl -> RemoveItem(This,Index,Count,RHS) ) 

#define IDropDowns_get_Selected(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Selected(This,Index,RHS) ) 

#define IDropDowns_put_Selected(This,Index,RHS)	\
    ( (This)->lpVtbl -> put_Selected(This,Index,RHS) ) 

#define IDropDowns_get_Value(This,RHS)	\
    ( (This)->lpVtbl -> get_Value(This,RHS) ) 

#define IDropDowns_put_Value(This,RHS)	\
    ( (This)->lpVtbl -> put_Value(This,RHS) ) 

#define IDropDowns_get_Caption(This,RHS)	\
    ( (This)->lpVtbl -> get_Caption(This,RHS) ) 

#define IDropDowns_put_Caption(This,RHS)	\
    ( (This)->lpVtbl -> put_Caption(This,RHS) ) 

#define IDropDowns_get_Characters(This,Start,Length,RHS)	\
    ( (This)->lpVtbl -> get_Characters(This,Start,Length,RHS) ) 

#define IDropDowns_get_DropDownLines(This,RHS)	\
    ( (This)->lpVtbl -> get_DropDownLines(This,RHS) ) 

#define IDropDowns_put_DropDownLines(This,RHS)	\
    ( (This)->lpVtbl -> put_DropDownLines(This,RHS) ) 

#define IDropDowns_get_Text(This,RHS)	\
    ( (This)->lpVtbl -> get_Text(This,RHS) ) 

#define IDropDowns_put_Text(This,RHS)	\
    ( (This)->lpVtbl -> put_Text(This,RHS) ) 

#define IDropDowns_Add(This,Left,Top,Width,Height,Editable,RHS)	\
    ( (This)->lpVtbl -> Add(This,Left,Top,Width,Height,Editable,RHS) ) 

#define IDropDowns_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IDropDowns_Group(This,RHS)	\
    ( (This)->lpVtbl -> Group(This,RHS) ) 

#define IDropDowns_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> Item(This,Index,RHS) ) 

#define IDropDowns__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> _NewEnum(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IDropDowns_INTERFACE_DEFINED__ */


#ifndef __ISpinner_INTERFACE_DEFINED__
#define __ISpinner_INTERFACE_DEFINED__

/* interface ISpinner */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ISpinner;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002088D-0001-0000-C000-000000000046")
    ISpinner : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_BottomRightCell( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall BringToFront( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Copy( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CopyPicture( 
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Cut( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Duplicate( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Enabled( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Enabled( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Height( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Height( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Index( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Left( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Left( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Locked( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Locked( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Name( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_OnAction( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_OnAction( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Placement( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Placement( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PrintObject( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PrintObject( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SendToBack( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Top( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Top( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TopLeftCell( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Visible( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Visible( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Width( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Width( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ZOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShapeRange( 
            /* [retval][out] */ ShapeRange	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put__Default( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Display3DShading( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Display3DShading( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LinkedCell( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_LinkedCell( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Max( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Max( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Min( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Min( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SmallChange( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_SmallChange( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Value( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Value( 
            /* [in] */ long RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ISpinnerVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ISpinner * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ISpinner * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ISpinner * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ISpinner * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ISpinner * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ISpinner * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ISpinner * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ISpinner * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ISpinner * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ISpinner * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_BottomRightCell )( 
            ISpinner * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *BringToFront )( 
            ISpinner * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Copy )( 
            ISpinner * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CopyPicture )( 
            ISpinner * This,
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Cut )( 
            ISpinner * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            ISpinner * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Duplicate )( 
            ISpinner * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Enabled )( 
            ISpinner * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Enabled )( 
            ISpinner * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Height )( 
            ISpinner * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Height )( 
            ISpinner * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Index )( 
            ISpinner * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Left )( 
            ISpinner * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Left )( 
            ISpinner * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Locked )( 
            ISpinner * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Locked )( 
            ISpinner * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            ISpinner * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Name )( 
            ISpinner * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_OnAction )( 
            ISpinner * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_OnAction )( 
            ISpinner * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Placement )( 
            ISpinner * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Placement )( 
            ISpinner * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PrintObject )( 
            ISpinner * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PrintObject )( 
            ISpinner * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            ISpinner * This,
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SendToBack )( 
            ISpinner * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Top )( 
            ISpinner * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Top )( 
            ISpinner * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TopLeftCell )( 
            ISpinner * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Visible )( 
            ISpinner * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Visible )( 
            ISpinner * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Width )( 
            ISpinner * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Width )( 
            ISpinner * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ZOrder )( 
            ISpinner * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShapeRange )( 
            ISpinner * This,
            /* [retval][out] */ ShapeRange	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            ISpinner * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put__Default )( 
            ISpinner * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Display3DShading )( 
            ISpinner * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Display3DShading )( 
            ISpinner * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LinkedCell )( 
            ISpinner * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_LinkedCell )( 
            ISpinner * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Max )( 
            ISpinner * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Max )( 
            ISpinner * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Min )( 
            ISpinner * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Min )( 
            ISpinner * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SmallChange )( 
            ISpinner * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_SmallChange )( 
            ISpinner * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Value )( 
            ISpinner * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Value )( 
            ISpinner * This,
            /* [in] */ long RHS);
        
        END_INTERFACE
    } ISpinnerVtbl;

    interface ISpinner
    {
        CONST_VTBL struct ISpinnerVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ISpinner_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ISpinner_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ISpinner_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ISpinner_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ISpinner_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ISpinner_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ISpinner_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ISpinner_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ISpinner_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ISpinner_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ISpinner_get_BottomRightCell(This,RHS)	\
    ( (This)->lpVtbl -> get_BottomRightCell(This,RHS) ) 

#define ISpinner_BringToFront(This,RHS)	\
    ( (This)->lpVtbl -> BringToFront(This,RHS) ) 

#define ISpinner_Copy(This,RHS)	\
    ( (This)->lpVtbl -> Copy(This,RHS) ) 

#define ISpinner_CopyPicture(This,Appearance,Format,RHS)	\
    ( (This)->lpVtbl -> CopyPicture(This,Appearance,Format,RHS) ) 

#define ISpinner_Cut(This,RHS)	\
    ( (This)->lpVtbl -> Cut(This,RHS) ) 

#define ISpinner_Delete(This,RHS)	\
    ( (This)->lpVtbl -> Delete(This,RHS) ) 

#define ISpinner_Duplicate(This,RHS)	\
    ( (This)->lpVtbl -> Duplicate(This,RHS) ) 

#define ISpinner_get_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> get_Enabled(This,RHS) ) 

#define ISpinner_put_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> put_Enabled(This,RHS) ) 

#define ISpinner_get_Height(This,RHS)	\
    ( (This)->lpVtbl -> get_Height(This,RHS) ) 

#define ISpinner_put_Height(This,RHS)	\
    ( (This)->lpVtbl -> put_Height(This,RHS) ) 

#define ISpinner_get_Index(This,RHS)	\
    ( (This)->lpVtbl -> get_Index(This,RHS) ) 

#define ISpinner_get_Left(This,RHS)	\
    ( (This)->lpVtbl -> get_Left(This,RHS) ) 

#define ISpinner_put_Left(This,RHS)	\
    ( (This)->lpVtbl -> put_Left(This,RHS) ) 

#define ISpinner_get_Locked(This,RHS)	\
    ( (This)->lpVtbl -> get_Locked(This,RHS) ) 

#define ISpinner_put_Locked(This,RHS)	\
    ( (This)->lpVtbl -> put_Locked(This,RHS) ) 

#define ISpinner_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define ISpinner_put_Name(This,RHS)	\
    ( (This)->lpVtbl -> put_Name(This,RHS) ) 

#define ISpinner_get_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> get_OnAction(This,RHS) ) 

#define ISpinner_put_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> put_OnAction(This,RHS) ) 

#define ISpinner_get_Placement(This,RHS)	\
    ( (This)->lpVtbl -> get_Placement(This,RHS) ) 

#define ISpinner_put_Placement(This,RHS)	\
    ( (This)->lpVtbl -> put_Placement(This,RHS) ) 

#define ISpinner_get_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> get_PrintObject(This,RHS) ) 

#define ISpinner_put_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> put_PrintObject(This,RHS) ) 

#define ISpinner_Select(This,Replace,RHS)	\
    ( (This)->lpVtbl -> Select(This,Replace,RHS) ) 

#define ISpinner_SendToBack(This,RHS)	\
    ( (This)->lpVtbl -> SendToBack(This,RHS) ) 

#define ISpinner_get_Top(This,RHS)	\
    ( (This)->lpVtbl -> get_Top(This,RHS) ) 

#define ISpinner_put_Top(This,RHS)	\
    ( (This)->lpVtbl -> put_Top(This,RHS) ) 

#define ISpinner_get_TopLeftCell(This,RHS)	\
    ( (This)->lpVtbl -> get_TopLeftCell(This,RHS) ) 

#define ISpinner_get_Visible(This,RHS)	\
    ( (This)->lpVtbl -> get_Visible(This,RHS) ) 

#define ISpinner_put_Visible(This,RHS)	\
    ( (This)->lpVtbl -> put_Visible(This,RHS) ) 

#define ISpinner_get_Width(This,RHS)	\
    ( (This)->lpVtbl -> get_Width(This,RHS) ) 

#define ISpinner_put_Width(This,RHS)	\
    ( (This)->lpVtbl -> put_Width(This,RHS) ) 

#define ISpinner_get_ZOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_ZOrder(This,RHS) ) 

#define ISpinner_get_ShapeRange(This,RHS)	\
    ( (This)->lpVtbl -> get_ShapeRange(This,RHS) ) 

#define ISpinner_get__Default(This,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,RHS) ) 

#define ISpinner_put__Default(This,RHS)	\
    ( (This)->lpVtbl -> put__Default(This,RHS) ) 

#define ISpinner_get_Display3DShading(This,RHS)	\
    ( (This)->lpVtbl -> get_Display3DShading(This,RHS) ) 

#define ISpinner_put_Display3DShading(This,RHS)	\
    ( (This)->lpVtbl -> put_Display3DShading(This,RHS) ) 

#define ISpinner_get_LinkedCell(This,RHS)	\
    ( (This)->lpVtbl -> get_LinkedCell(This,RHS) ) 

#define ISpinner_put_LinkedCell(This,RHS)	\
    ( (This)->lpVtbl -> put_LinkedCell(This,RHS) ) 

#define ISpinner_get_Max(This,RHS)	\
    ( (This)->lpVtbl -> get_Max(This,RHS) ) 

#define ISpinner_put_Max(This,RHS)	\
    ( (This)->lpVtbl -> put_Max(This,RHS) ) 

#define ISpinner_get_Min(This,RHS)	\
    ( (This)->lpVtbl -> get_Min(This,RHS) ) 

#define ISpinner_put_Min(This,RHS)	\
    ( (This)->lpVtbl -> put_Min(This,RHS) ) 

#define ISpinner_get_SmallChange(This,RHS)	\
    ( (This)->lpVtbl -> get_SmallChange(This,RHS) ) 

#define ISpinner_put_SmallChange(This,RHS)	\
    ( (This)->lpVtbl -> put_SmallChange(This,RHS) ) 

#define ISpinner_get_Value(This,RHS)	\
    ( (This)->lpVtbl -> get_Value(This,RHS) ) 

#define ISpinner_put_Value(This,RHS)	\
    ( (This)->lpVtbl -> put_Value(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ISpinner_INTERFACE_DEFINED__ */


#ifndef __ISpinners_INTERFACE_DEFINED__
#define __ISpinners_INTERFACE_DEFINED__

/* interface ISpinners */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ISpinners;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002088E-0001-0000-C000-000000000046")
    ISpinners : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy3( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall BringToFront( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Copy( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CopyPicture( 
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Cut( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Duplicate( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Enabled( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Enabled( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Height( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Height( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy12( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Left( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Left( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Locked( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Locked( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy15( void) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_OnAction( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_OnAction( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Placement( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Placement( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PrintObject( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PrintObject( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SendToBack( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Top( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Top( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy22( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Visible( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Visible( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Width( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Width( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ZOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShapeRange( 
            /* [retval][out] */ ShapeRange	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put__Default( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Display3DShading( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Display3DShading( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LinkedCell( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_LinkedCell( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Max( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Max( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Min( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Min( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SmallChange( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_SmallChange( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Value( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Value( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add( 
            /* [in] */ double Left,
            /* [in] */ double Top,
            /* [in] */ double Width,
            /* [in] */ double Height,
            /* [retval][out] */ Spinner	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Group( 
            /* [retval][out] */ GroupObject	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall _NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ISpinnersVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ISpinners * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ISpinners * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ISpinners * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ISpinners * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ISpinners * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ISpinners * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ISpinners * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ISpinners * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ISpinners * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ISpinners * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy3 )( 
            ISpinners * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *BringToFront )( 
            ISpinners * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Copy )( 
            ISpinners * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CopyPicture )( 
            ISpinners * This,
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Cut )( 
            ISpinners * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            ISpinners * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Duplicate )( 
            ISpinners * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Enabled )( 
            ISpinners * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Enabled )( 
            ISpinners * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Height )( 
            ISpinners * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Height )( 
            ISpinners * This,
            /* [in] */ double RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy12 )( 
            ISpinners * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Left )( 
            ISpinners * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Left )( 
            ISpinners * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Locked )( 
            ISpinners * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Locked )( 
            ISpinners * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy15 )( 
            ISpinners * This);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_OnAction )( 
            ISpinners * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_OnAction )( 
            ISpinners * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Placement )( 
            ISpinners * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Placement )( 
            ISpinners * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PrintObject )( 
            ISpinners * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PrintObject )( 
            ISpinners * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            ISpinners * This,
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SendToBack )( 
            ISpinners * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Top )( 
            ISpinners * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Top )( 
            ISpinners * This,
            /* [in] */ double RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy22 )( 
            ISpinners * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Visible )( 
            ISpinners * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Visible )( 
            ISpinners * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Width )( 
            ISpinners * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Width )( 
            ISpinners * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ZOrder )( 
            ISpinners * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShapeRange )( 
            ISpinners * This,
            /* [retval][out] */ ShapeRange	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            ISpinners * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put__Default )( 
            ISpinners * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Display3DShading )( 
            ISpinners * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Display3DShading )( 
            ISpinners * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LinkedCell )( 
            ISpinners * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_LinkedCell )( 
            ISpinners * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Max )( 
            ISpinners * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Max )( 
            ISpinners * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Min )( 
            ISpinners * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Min )( 
            ISpinners * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SmallChange )( 
            ISpinners * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_SmallChange )( 
            ISpinners * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Value )( 
            ISpinners * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Value )( 
            ISpinners * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add )( 
            ISpinners * This,
            /* [in] */ double Left,
            /* [in] */ double Top,
            /* [in] */ double Width,
            /* [in] */ double Height,
            /* [retval][out] */ Spinner	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            ISpinners * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Group )( 
            ISpinners * This,
            /* [retval][out] */ GroupObject	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Item )( 
            ISpinners * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *_NewEnum )( 
            ISpinners * This,
            /* [retval][out] */ IUnknown **RHS);
        
        END_INTERFACE
    } ISpinnersVtbl;

    interface ISpinners
    {
        CONST_VTBL struct ISpinnersVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ISpinners_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ISpinners_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ISpinners_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ISpinners_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ISpinners_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ISpinners_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ISpinners_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ISpinners_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ISpinners_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ISpinners_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ISpinners__Dummy3(This)	\
    ( (This)->lpVtbl -> _Dummy3(This) ) 

#define ISpinners_BringToFront(This,RHS)	\
    ( (This)->lpVtbl -> BringToFront(This,RHS) ) 

#define ISpinners_Copy(This,RHS)	\
    ( (This)->lpVtbl -> Copy(This,RHS) ) 

#define ISpinners_CopyPicture(This,Appearance,Format,RHS)	\
    ( (This)->lpVtbl -> CopyPicture(This,Appearance,Format,RHS) ) 

#define ISpinners_Cut(This,RHS)	\
    ( (This)->lpVtbl -> Cut(This,RHS) ) 

#define ISpinners_Delete(This,RHS)	\
    ( (This)->lpVtbl -> Delete(This,RHS) ) 

#define ISpinners_Duplicate(This,RHS)	\
    ( (This)->lpVtbl -> Duplicate(This,RHS) ) 

#define ISpinners_get_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> get_Enabled(This,RHS) ) 

#define ISpinners_put_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> put_Enabled(This,RHS) ) 

#define ISpinners_get_Height(This,RHS)	\
    ( (This)->lpVtbl -> get_Height(This,RHS) ) 

#define ISpinners_put_Height(This,RHS)	\
    ( (This)->lpVtbl -> put_Height(This,RHS) ) 

#define ISpinners__Dummy12(This)	\
    ( (This)->lpVtbl -> _Dummy12(This) ) 

#define ISpinners_get_Left(This,RHS)	\
    ( (This)->lpVtbl -> get_Left(This,RHS) ) 

#define ISpinners_put_Left(This,RHS)	\
    ( (This)->lpVtbl -> put_Left(This,RHS) ) 

#define ISpinners_get_Locked(This,RHS)	\
    ( (This)->lpVtbl -> get_Locked(This,RHS) ) 

#define ISpinners_put_Locked(This,RHS)	\
    ( (This)->lpVtbl -> put_Locked(This,RHS) ) 

#define ISpinners__Dummy15(This)	\
    ( (This)->lpVtbl -> _Dummy15(This) ) 

#define ISpinners_get_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> get_OnAction(This,RHS) ) 

#define ISpinners_put_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> put_OnAction(This,RHS) ) 

#define ISpinners_get_Placement(This,RHS)	\
    ( (This)->lpVtbl -> get_Placement(This,RHS) ) 

#define ISpinners_put_Placement(This,RHS)	\
    ( (This)->lpVtbl -> put_Placement(This,RHS) ) 

#define ISpinners_get_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> get_PrintObject(This,RHS) ) 

#define ISpinners_put_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> put_PrintObject(This,RHS) ) 

#define ISpinners_Select(This,Replace,RHS)	\
    ( (This)->lpVtbl -> Select(This,Replace,RHS) ) 

#define ISpinners_SendToBack(This,RHS)	\
    ( (This)->lpVtbl -> SendToBack(This,RHS) ) 

#define ISpinners_get_Top(This,RHS)	\
    ( (This)->lpVtbl -> get_Top(This,RHS) ) 

#define ISpinners_put_Top(This,RHS)	\
    ( (This)->lpVtbl -> put_Top(This,RHS) ) 

#define ISpinners__Dummy22(This)	\
    ( (This)->lpVtbl -> _Dummy22(This) ) 

#define ISpinners_get_Visible(This,RHS)	\
    ( (This)->lpVtbl -> get_Visible(This,RHS) ) 

#define ISpinners_put_Visible(This,RHS)	\
    ( (This)->lpVtbl -> put_Visible(This,RHS) ) 

#define ISpinners_get_Width(This,RHS)	\
    ( (This)->lpVtbl -> get_Width(This,RHS) ) 

#define ISpinners_put_Width(This,RHS)	\
    ( (This)->lpVtbl -> put_Width(This,RHS) ) 

#define ISpinners_get_ZOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_ZOrder(This,RHS) ) 

#define ISpinners_get_ShapeRange(This,RHS)	\
    ( (This)->lpVtbl -> get_ShapeRange(This,RHS) ) 

#define ISpinners_get__Default(This,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,RHS) ) 

#define ISpinners_put__Default(This,RHS)	\
    ( (This)->lpVtbl -> put__Default(This,RHS) ) 

#define ISpinners_get_Display3DShading(This,RHS)	\
    ( (This)->lpVtbl -> get_Display3DShading(This,RHS) ) 

#define ISpinners_put_Display3DShading(This,RHS)	\
    ( (This)->lpVtbl -> put_Display3DShading(This,RHS) ) 

#define ISpinners_get_LinkedCell(This,RHS)	\
    ( (This)->lpVtbl -> get_LinkedCell(This,RHS) ) 

#define ISpinners_put_LinkedCell(This,RHS)	\
    ( (This)->lpVtbl -> put_LinkedCell(This,RHS) ) 

#define ISpinners_get_Max(This,RHS)	\
    ( (This)->lpVtbl -> get_Max(This,RHS) ) 

#define ISpinners_put_Max(This,RHS)	\
    ( (This)->lpVtbl -> put_Max(This,RHS) ) 

#define ISpinners_get_Min(This,RHS)	\
    ( (This)->lpVtbl -> get_Min(This,RHS) ) 

#define ISpinners_put_Min(This,RHS)	\
    ( (This)->lpVtbl -> put_Min(This,RHS) ) 

#define ISpinners_get_SmallChange(This,RHS)	\
    ( (This)->lpVtbl -> get_SmallChange(This,RHS) ) 

#define ISpinners_put_SmallChange(This,RHS)	\
    ( (This)->lpVtbl -> put_SmallChange(This,RHS) ) 

#define ISpinners_get_Value(This,RHS)	\
    ( (This)->lpVtbl -> get_Value(This,RHS) ) 

#define ISpinners_put_Value(This,RHS)	\
    ( (This)->lpVtbl -> put_Value(This,RHS) ) 

#define ISpinners_Add(This,Left,Top,Width,Height,RHS)	\
    ( (This)->lpVtbl -> Add(This,Left,Top,Width,Height,RHS) ) 

#define ISpinners_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define ISpinners_Group(This,RHS)	\
    ( (This)->lpVtbl -> Group(This,RHS) ) 

#define ISpinners_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> Item(This,Index,RHS) ) 

#define ISpinners__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> _NewEnum(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ISpinners_INTERFACE_DEFINED__ */


#ifndef __IDialogFrame_INTERFACE_DEFINED__
#define __IDialogFrame_INTERFACE_DEFINED__

/* interface IDialogFrame */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IDialogFrame;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002088F-0001-0000-C000-000000000046")
    IDialogFrame : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy3( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy4( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy5( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CopyPicture( 
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy7( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy8( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy9( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy10( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Height( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Height( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy12( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Left( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Left( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Locked( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Locked( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Name( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_OnAction( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_OnAction( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy17( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy18( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy20( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Top( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Top( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy22( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy23( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Width( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Width( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy25( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShapeRange( 
            /* [retval][out] */ ShapeRange	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Caption( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Caption( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Characters( 
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Length,
            /* [retval][out] */ Characters	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CheckSpelling( 
            /* [optional][in] */ VARIANT CustomDictionary,
            /* [optional][in] */ VARIANT IgnoreUppercase,
            /* [optional][in] */ VARIANT AlwaysSuggest,
            /* [optional][in] */ VARIANT SpellLang,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LockedText( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_LockedText( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Text( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Text( 
            /* [in] */ BSTR RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IDialogFrameVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IDialogFrame * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IDialogFrame * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IDialogFrame * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IDialogFrame * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IDialogFrame * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IDialogFrame * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IDialogFrame * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IDialogFrame * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IDialogFrame * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IDialogFrame * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy3 )( 
            IDialogFrame * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy4 )( 
            IDialogFrame * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy5 )( 
            IDialogFrame * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CopyPicture )( 
            IDialogFrame * This,
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy7 )( 
            IDialogFrame * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy8 )( 
            IDialogFrame * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy9 )( 
            IDialogFrame * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy10 )( 
            IDialogFrame * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Height )( 
            IDialogFrame * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Height )( 
            IDialogFrame * This,
            /* [in] */ double RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy12 )( 
            IDialogFrame * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Left )( 
            IDialogFrame * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Left )( 
            IDialogFrame * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Locked )( 
            IDialogFrame * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Locked )( 
            IDialogFrame * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            IDialogFrame * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Name )( 
            IDialogFrame * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_OnAction )( 
            IDialogFrame * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_OnAction )( 
            IDialogFrame * This,
            /* [in] */ BSTR RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy17 )( 
            IDialogFrame * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy18 )( 
            IDialogFrame * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            IDialogFrame * This,
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy20 )( 
            IDialogFrame * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Top )( 
            IDialogFrame * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Top )( 
            IDialogFrame * This,
            /* [in] */ double RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy22 )( 
            IDialogFrame * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy23 )( 
            IDialogFrame * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Width )( 
            IDialogFrame * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Width )( 
            IDialogFrame * This,
            /* [in] */ double RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy25 )( 
            IDialogFrame * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShapeRange )( 
            IDialogFrame * This,
            /* [retval][out] */ ShapeRange	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Caption )( 
            IDialogFrame * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Caption )( 
            IDialogFrame * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Characters )( 
            IDialogFrame * This,
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Length,
            /* [retval][out] */ Characters	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CheckSpelling )( 
            IDialogFrame * This,
            /* [optional][in] */ VARIANT CustomDictionary,
            /* [optional][in] */ VARIANT IgnoreUppercase,
            /* [optional][in] */ VARIANT AlwaysSuggest,
            /* [optional][in] */ VARIANT SpellLang,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LockedText )( 
            IDialogFrame * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_LockedText )( 
            IDialogFrame * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Text )( 
            IDialogFrame * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Text )( 
            IDialogFrame * This,
            /* [in] */ BSTR RHS);
        
        END_INTERFACE
    } IDialogFrameVtbl;

    interface IDialogFrame
    {
        CONST_VTBL struct IDialogFrameVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IDialogFrame_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IDialogFrame_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IDialogFrame_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IDialogFrame_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IDialogFrame_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IDialogFrame_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IDialogFrame_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IDialogFrame_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IDialogFrame_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IDialogFrame_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IDialogFrame__Dummy3(This)	\
    ( (This)->lpVtbl -> _Dummy3(This) ) 

#define IDialogFrame__Dummy4(This)	\
    ( (This)->lpVtbl -> _Dummy4(This) ) 

#define IDialogFrame__Dummy5(This)	\
    ( (This)->lpVtbl -> _Dummy5(This) ) 

#define IDialogFrame_CopyPicture(This,Appearance,Format,RHS)	\
    ( (This)->lpVtbl -> CopyPicture(This,Appearance,Format,RHS) ) 

#define IDialogFrame__Dummy7(This)	\
    ( (This)->lpVtbl -> _Dummy7(This) ) 

#define IDialogFrame__Dummy8(This)	\
    ( (This)->lpVtbl -> _Dummy8(This) ) 

#define IDialogFrame__Dummy9(This)	\
    ( (This)->lpVtbl -> _Dummy9(This) ) 

#define IDialogFrame__Dummy10(This)	\
    ( (This)->lpVtbl -> _Dummy10(This) ) 

#define IDialogFrame_get_Height(This,RHS)	\
    ( (This)->lpVtbl -> get_Height(This,RHS) ) 

#define IDialogFrame_put_Height(This,RHS)	\
    ( (This)->lpVtbl -> put_Height(This,RHS) ) 

#define IDialogFrame__Dummy12(This)	\
    ( (This)->lpVtbl -> _Dummy12(This) ) 

#define IDialogFrame_get_Left(This,RHS)	\
    ( (This)->lpVtbl -> get_Left(This,RHS) ) 

#define IDialogFrame_put_Left(This,RHS)	\
    ( (This)->lpVtbl -> put_Left(This,RHS) ) 

#define IDialogFrame_get_Locked(This,RHS)	\
    ( (This)->lpVtbl -> get_Locked(This,RHS) ) 

#define IDialogFrame_put_Locked(This,RHS)	\
    ( (This)->lpVtbl -> put_Locked(This,RHS) ) 

#define IDialogFrame_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define IDialogFrame_put_Name(This,RHS)	\
    ( (This)->lpVtbl -> put_Name(This,RHS) ) 

#define IDialogFrame_get_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> get_OnAction(This,RHS) ) 

#define IDialogFrame_put_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> put_OnAction(This,RHS) ) 

#define IDialogFrame__Dummy17(This)	\
    ( (This)->lpVtbl -> _Dummy17(This) ) 

#define IDialogFrame__Dummy18(This)	\
    ( (This)->lpVtbl -> _Dummy18(This) ) 

#define IDialogFrame_Select(This,Replace,RHS)	\
    ( (This)->lpVtbl -> Select(This,Replace,RHS) ) 

#define IDialogFrame__Dummy20(This)	\
    ( (This)->lpVtbl -> _Dummy20(This) ) 

#define IDialogFrame_get_Top(This,RHS)	\
    ( (This)->lpVtbl -> get_Top(This,RHS) ) 

#define IDialogFrame_put_Top(This,RHS)	\
    ( (This)->lpVtbl -> put_Top(This,RHS) ) 

#define IDialogFrame__Dummy22(This)	\
    ( (This)->lpVtbl -> _Dummy22(This) ) 

#define IDialogFrame__Dummy23(This)	\
    ( (This)->lpVtbl -> _Dummy23(This) ) 

#define IDialogFrame_get_Width(This,RHS)	\
    ( (This)->lpVtbl -> get_Width(This,RHS) ) 

#define IDialogFrame_put_Width(This,RHS)	\
    ( (This)->lpVtbl -> put_Width(This,RHS) ) 

#define IDialogFrame__Dummy25(This)	\
    ( (This)->lpVtbl -> _Dummy25(This) ) 

#define IDialogFrame_get_ShapeRange(This,RHS)	\
    ( (This)->lpVtbl -> get_ShapeRange(This,RHS) ) 

#define IDialogFrame_get_Caption(This,RHS)	\
    ( (This)->lpVtbl -> get_Caption(This,RHS) ) 

#define IDialogFrame_put_Caption(This,RHS)	\
    ( (This)->lpVtbl -> put_Caption(This,RHS) ) 

#define IDialogFrame_get_Characters(This,Start,Length,RHS)	\
    ( (This)->lpVtbl -> get_Characters(This,Start,Length,RHS) ) 

#define IDialogFrame_CheckSpelling(This,CustomDictionary,IgnoreUppercase,AlwaysSuggest,SpellLang,RHS)	\
    ( (This)->lpVtbl -> CheckSpelling(This,CustomDictionary,IgnoreUppercase,AlwaysSuggest,SpellLang,RHS) ) 

#define IDialogFrame_get_LockedText(This,RHS)	\
    ( (This)->lpVtbl -> get_LockedText(This,RHS) ) 

#define IDialogFrame_put_LockedText(This,RHS)	\
    ( (This)->lpVtbl -> put_LockedText(This,RHS) ) 

#define IDialogFrame_get_Text(This,RHS)	\
    ( (This)->lpVtbl -> get_Text(This,RHS) ) 

#define IDialogFrame_put_Text(This,RHS)	\
    ( (This)->lpVtbl -> put_Text(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IDialogFrame_INTERFACE_DEFINED__ */


#ifndef __ILabel_INTERFACE_DEFINED__
#define __ILabel_INTERFACE_DEFINED__

/* interface ILabel */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ILabel;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00020890-0001-0000-C000-000000000046")
    ILabel : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_BottomRightCell( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall BringToFront( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Copy( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CopyPicture( 
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Cut( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Duplicate( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Enabled( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Enabled( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Height( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Height( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Index( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Left( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Left( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Locked( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Locked( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Name( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_OnAction( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_OnAction( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Placement( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Placement( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PrintObject( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PrintObject( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SendToBack( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Top( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Top( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TopLeftCell( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Visible( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Visible( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Width( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Width( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ZOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShapeRange( 
            /* [retval][out] */ ShapeRange	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Caption( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Caption( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Characters( 
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Length,
            /* [retval][out] */ Characters	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CheckSpelling( 
            /* [optional][in] */ VARIANT CustomDictionary,
            /* [optional][in] */ VARIANT IgnoreUppercase,
            /* [optional][in] */ VARIANT AlwaysSuggest,
            /* [optional][in] */ VARIANT SpellLang,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LockedText( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_LockedText( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Text( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Text( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Accelerator( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Accelerator( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy33( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PhoneticAccelerator( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PhoneticAccelerator( 
            /* [in] */ VARIANT RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ILabelVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ILabel * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ILabel * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ILabel * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ILabel * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ILabel * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ILabel * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ILabel * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ILabel * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ILabel * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ILabel * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_BottomRightCell )( 
            ILabel * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *BringToFront )( 
            ILabel * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Copy )( 
            ILabel * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CopyPicture )( 
            ILabel * This,
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Cut )( 
            ILabel * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            ILabel * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Duplicate )( 
            ILabel * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Enabled )( 
            ILabel * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Enabled )( 
            ILabel * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Height )( 
            ILabel * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Height )( 
            ILabel * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Index )( 
            ILabel * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Left )( 
            ILabel * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Left )( 
            ILabel * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Locked )( 
            ILabel * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Locked )( 
            ILabel * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            ILabel * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Name )( 
            ILabel * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_OnAction )( 
            ILabel * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_OnAction )( 
            ILabel * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Placement )( 
            ILabel * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Placement )( 
            ILabel * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PrintObject )( 
            ILabel * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PrintObject )( 
            ILabel * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            ILabel * This,
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SendToBack )( 
            ILabel * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Top )( 
            ILabel * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Top )( 
            ILabel * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TopLeftCell )( 
            ILabel * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Visible )( 
            ILabel * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Visible )( 
            ILabel * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Width )( 
            ILabel * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Width )( 
            ILabel * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ZOrder )( 
            ILabel * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShapeRange )( 
            ILabel * This,
            /* [retval][out] */ ShapeRange	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Caption )( 
            ILabel * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Caption )( 
            ILabel * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Characters )( 
            ILabel * This,
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Length,
            /* [retval][out] */ Characters	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CheckSpelling )( 
            ILabel * This,
            /* [optional][in] */ VARIANT CustomDictionary,
            /* [optional][in] */ VARIANT IgnoreUppercase,
            /* [optional][in] */ VARIANT AlwaysSuggest,
            /* [optional][in] */ VARIANT SpellLang,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LockedText )( 
            ILabel * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_LockedText )( 
            ILabel * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Text )( 
            ILabel * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Text )( 
            ILabel * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Accelerator )( 
            ILabel * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Accelerator )( 
            ILabel * This,
            /* [in] */ VARIANT RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy33 )( 
            ILabel * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PhoneticAccelerator )( 
            ILabel * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PhoneticAccelerator )( 
            ILabel * This,
            /* [in] */ VARIANT RHS);
        
        END_INTERFACE
    } ILabelVtbl;

    interface ILabel
    {
        CONST_VTBL struct ILabelVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ILabel_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ILabel_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ILabel_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ILabel_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ILabel_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ILabel_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ILabel_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ILabel_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ILabel_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ILabel_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ILabel_get_BottomRightCell(This,RHS)	\
    ( (This)->lpVtbl -> get_BottomRightCell(This,RHS) ) 

#define ILabel_BringToFront(This,RHS)	\
    ( (This)->lpVtbl -> BringToFront(This,RHS) ) 

#define ILabel_Copy(This,RHS)	\
    ( (This)->lpVtbl -> Copy(This,RHS) ) 

#define ILabel_CopyPicture(This,Appearance,Format,RHS)	\
    ( (This)->lpVtbl -> CopyPicture(This,Appearance,Format,RHS) ) 

#define ILabel_Cut(This,RHS)	\
    ( (This)->lpVtbl -> Cut(This,RHS) ) 

#define ILabel_Delete(This,RHS)	\
    ( (This)->lpVtbl -> Delete(This,RHS) ) 

#define ILabel_Duplicate(This,RHS)	\
    ( (This)->lpVtbl -> Duplicate(This,RHS) ) 

#define ILabel_get_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> get_Enabled(This,RHS) ) 

#define ILabel_put_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> put_Enabled(This,RHS) ) 

#define ILabel_get_Height(This,RHS)	\
    ( (This)->lpVtbl -> get_Height(This,RHS) ) 

#define ILabel_put_Height(This,RHS)	\
    ( (This)->lpVtbl -> put_Height(This,RHS) ) 

#define ILabel_get_Index(This,RHS)	\
    ( (This)->lpVtbl -> get_Index(This,RHS) ) 

#define ILabel_get_Left(This,RHS)	\
    ( (This)->lpVtbl -> get_Left(This,RHS) ) 

#define ILabel_put_Left(This,RHS)	\
    ( (This)->lpVtbl -> put_Left(This,RHS) ) 

#define ILabel_get_Locked(This,RHS)	\
    ( (This)->lpVtbl -> get_Locked(This,RHS) ) 

#define ILabel_put_Locked(This,RHS)	\
    ( (This)->lpVtbl -> put_Locked(This,RHS) ) 

#define ILabel_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define ILabel_put_Name(This,RHS)	\
    ( (This)->lpVtbl -> put_Name(This,RHS) ) 

#define ILabel_get_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> get_OnAction(This,RHS) ) 

#define ILabel_put_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> put_OnAction(This,RHS) ) 

#define ILabel_get_Placement(This,RHS)	\
    ( (This)->lpVtbl -> get_Placement(This,RHS) ) 

#define ILabel_put_Placement(This,RHS)	\
    ( (This)->lpVtbl -> put_Placement(This,RHS) ) 

#define ILabel_get_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> get_PrintObject(This,RHS) ) 

#define ILabel_put_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> put_PrintObject(This,RHS) ) 

#define ILabel_Select(This,Replace,RHS)	\
    ( (This)->lpVtbl -> Select(This,Replace,RHS) ) 

#define ILabel_SendToBack(This,RHS)	\
    ( (This)->lpVtbl -> SendToBack(This,RHS) ) 

#define ILabel_get_Top(This,RHS)	\
    ( (This)->lpVtbl -> get_Top(This,RHS) ) 

#define ILabel_put_Top(This,RHS)	\
    ( (This)->lpVtbl -> put_Top(This,RHS) ) 

#define ILabel_get_TopLeftCell(This,RHS)	\
    ( (This)->lpVtbl -> get_TopLeftCell(This,RHS) ) 

#define ILabel_get_Visible(This,RHS)	\
    ( (This)->lpVtbl -> get_Visible(This,RHS) ) 

#define ILabel_put_Visible(This,RHS)	\
    ( (This)->lpVtbl -> put_Visible(This,RHS) ) 

#define ILabel_get_Width(This,RHS)	\
    ( (This)->lpVtbl -> get_Width(This,RHS) ) 

#define ILabel_put_Width(This,RHS)	\
    ( (This)->lpVtbl -> put_Width(This,RHS) ) 

#define ILabel_get_ZOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_ZOrder(This,RHS) ) 

#define ILabel_get_ShapeRange(This,RHS)	\
    ( (This)->lpVtbl -> get_ShapeRange(This,RHS) ) 

#define ILabel_get_Caption(This,RHS)	\
    ( (This)->lpVtbl -> get_Caption(This,RHS) ) 

#define ILabel_put_Caption(This,RHS)	\
    ( (This)->lpVtbl -> put_Caption(This,RHS) ) 

#define ILabel_get_Characters(This,Start,Length,RHS)	\
    ( (This)->lpVtbl -> get_Characters(This,Start,Length,RHS) ) 

#define ILabel_CheckSpelling(This,CustomDictionary,IgnoreUppercase,AlwaysSuggest,SpellLang,RHS)	\
    ( (This)->lpVtbl -> CheckSpelling(This,CustomDictionary,IgnoreUppercase,AlwaysSuggest,SpellLang,RHS) ) 

#define ILabel_get_LockedText(This,RHS)	\
    ( (This)->lpVtbl -> get_LockedText(This,RHS) ) 

#define ILabel_put_LockedText(This,RHS)	\
    ( (This)->lpVtbl -> put_LockedText(This,RHS) ) 

#define ILabel_get_Text(This,RHS)	\
    ( (This)->lpVtbl -> get_Text(This,RHS) ) 

#define ILabel_put_Text(This,RHS)	\
    ( (This)->lpVtbl -> put_Text(This,RHS) ) 

#define ILabel_get_Accelerator(This,RHS)	\
    ( (This)->lpVtbl -> get_Accelerator(This,RHS) ) 

#define ILabel_put_Accelerator(This,RHS)	\
    ( (This)->lpVtbl -> put_Accelerator(This,RHS) ) 

#define ILabel__Dummy33(This)	\
    ( (This)->lpVtbl -> _Dummy33(This) ) 

#define ILabel_get_PhoneticAccelerator(This,RHS)	\
    ( (This)->lpVtbl -> get_PhoneticAccelerator(This,RHS) ) 

#define ILabel_put_PhoneticAccelerator(This,RHS)	\
    ( (This)->lpVtbl -> put_PhoneticAccelerator(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ILabel_INTERFACE_DEFINED__ */


#ifndef __ILabels_INTERFACE_DEFINED__
#define __ILabels_INTERFACE_DEFINED__

/* interface ILabels */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ILabels;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00020891-0001-0000-C000-000000000046")
    ILabels : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy3( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall BringToFront( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Copy( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CopyPicture( 
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Cut( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Duplicate( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Enabled( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Enabled( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Height( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Height( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy12( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Left( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Left( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Locked( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Locked( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy15( void) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_OnAction( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_OnAction( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Placement( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Placement( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PrintObject( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PrintObject( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SendToBack( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Top( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Top( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy22( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Visible( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Visible( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Width( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Width( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ZOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShapeRange( 
            /* [retval][out] */ ShapeRange	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Caption( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Caption( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Characters( 
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Length,
            /* [retval][out] */ Characters	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CheckSpelling( 
            /* [optional][in] */ VARIANT CustomDictionary,
            /* [optional][in] */ VARIANT IgnoreUppercase,
            /* [optional][in] */ VARIANT AlwaysSuggest,
            /* [optional][in] */ VARIANT SpellLang,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LockedText( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_LockedText( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Text( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Text( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Accelerator( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Accelerator( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy33( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PhoneticAccelerator( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PhoneticAccelerator( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add( 
            /* [in] */ double Left,
            /* [in] */ double Top,
            /* [in] */ double Width,
            /* [in] */ double Height,
            /* [retval][out] */ Label	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Group( 
            /* [retval][out] */ GroupObject	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall _NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ILabelsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ILabels * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ILabels * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ILabels * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ILabels * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ILabels * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ILabels * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ILabels * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ILabels * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ILabels * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ILabels * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy3 )( 
            ILabels * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *BringToFront )( 
            ILabels * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Copy )( 
            ILabels * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CopyPicture )( 
            ILabels * This,
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Cut )( 
            ILabels * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            ILabels * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Duplicate )( 
            ILabels * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Enabled )( 
            ILabels * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Enabled )( 
            ILabels * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Height )( 
            ILabels * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Height )( 
            ILabels * This,
            /* [in] */ double RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy12 )( 
            ILabels * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Left )( 
            ILabels * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Left )( 
            ILabels * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Locked )( 
            ILabels * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Locked )( 
            ILabels * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy15 )( 
            ILabels * This);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_OnAction )( 
            ILabels * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_OnAction )( 
            ILabels * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Placement )( 
            ILabels * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Placement )( 
            ILabels * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PrintObject )( 
            ILabels * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PrintObject )( 
            ILabels * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            ILabels * This,
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SendToBack )( 
            ILabels * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Top )( 
            ILabels * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Top )( 
            ILabels * This,
            /* [in] */ double RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy22 )( 
            ILabels * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Visible )( 
            ILabels * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Visible )( 
            ILabels * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Width )( 
            ILabels * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Width )( 
            ILabels * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ZOrder )( 
            ILabels * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShapeRange )( 
            ILabels * This,
            /* [retval][out] */ ShapeRange	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Caption )( 
            ILabels * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Caption )( 
            ILabels * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Characters )( 
            ILabels * This,
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Length,
            /* [retval][out] */ Characters	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CheckSpelling )( 
            ILabels * This,
            /* [optional][in] */ VARIANT CustomDictionary,
            /* [optional][in] */ VARIANT IgnoreUppercase,
            /* [optional][in] */ VARIANT AlwaysSuggest,
            /* [optional][in] */ VARIANT SpellLang,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LockedText )( 
            ILabels * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_LockedText )( 
            ILabels * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Text )( 
            ILabels * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Text )( 
            ILabels * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Accelerator )( 
            ILabels * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Accelerator )( 
            ILabels * This,
            /* [in] */ VARIANT RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy33 )( 
            ILabels * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PhoneticAccelerator )( 
            ILabels * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PhoneticAccelerator )( 
            ILabels * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add )( 
            ILabels * This,
            /* [in] */ double Left,
            /* [in] */ double Top,
            /* [in] */ double Width,
            /* [in] */ double Height,
            /* [retval][out] */ Label	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            ILabels * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Group )( 
            ILabels * This,
            /* [retval][out] */ GroupObject	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Item )( 
            ILabels * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *_NewEnum )( 
            ILabels * This,
            /* [retval][out] */ IUnknown **RHS);
        
        END_INTERFACE
    } ILabelsVtbl;

    interface ILabels
    {
        CONST_VTBL struct ILabelsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ILabels_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ILabels_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ILabels_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ILabels_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ILabels_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ILabels_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ILabels_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ILabels_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ILabels_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ILabels_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ILabels__Dummy3(This)	\
    ( (This)->lpVtbl -> _Dummy3(This) ) 

#define ILabels_BringToFront(This,RHS)	\
    ( (This)->lpVtbl -> BringToFront(This,RHS) ) 

#define ILabels_Copy(This,RHS)	\
    ( (This)->lpVtbl -> Copy(This,RHS) ) 

#define ILabels_CopyPicture(This,Appearance,Format,RHS)	\
    ( (This)->lpVtbl -> CopyPicture(This,Appearance,Format,RHS) ) 

#define ILabels_Cut(This,RHS)	\
    ( (This)->lpVtbl -> Cut(This,RHS) ) 

#define ILabels_Delete(This,RHS)	\
    ( (This)->lpVtbl -> Delete(This,RHS) ) 

#define ILabels_Duplicate(This,RHS)	\
    ( (This)->lpVtbl -> Duplicate(This,RHS) ) 

#define ILabels_get_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> get_Enabled(This,RHS) ) 

#define ILabels_put_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> put_Enabled(This,RHS) ) 

#define ILabels_get_Height(This,RHS)	\
    ( (This)->lpVtbl -> get_Height(This,RHS) ) 

#define ILabels_put_Height(This,RHS)	\
    ( (This)->lpVtbl -> put_Height(This,RHS) ) 

#define ILabels__Dummy12(This)	\
    ( (This)->lpVtbl -> _Dummy12(This) ) 

#define ILabels_get_Left(This,RHS)	\
    ( (This)->lpVtbl -> get_Left(This,RHS) ) 

#define ILabels_put_Left(This,RHS)	\
    ( (This)->lpVtbl -> put_Left(This,RHS) ) 

#define ILabels_get_Locked(This,RHS)	\
    ( (This)->lpVtbl -> get_Locked(This,RHS) ) 

#define ILabels_put_Locked(This,RHS)	\
    ( (This)->lpVtbl -> put_Locked(This,RHS) ) 

#define ILabels__Dummy15(This)	\
    ( (This)->lpVtbl -> _Dummy15(This) ) 

#define ILabels_get_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> get_OnAction(This,RHS) ) 

#define ILabels_put_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> put_OnAction(This,RHS) ) 

#define ILabels_get_Placement(This,RHS)	\
    ( (This)->lpVtbl -> get_Placement(This,RHS) ) 

#define ILabels_put_Placement(This,RHS)	\
    ( (This)->lpVtbl -> put_Placement(This,RHS) ) 

#define ILabels_get_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> get_PrintObject(This,RHS) ) 

#define ILabels_put_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> put_PrintObject(This,RHS) ) 

#define ILabels_Select(This,Replace,RHS)	\
    ( (This)->lpVtbl -> Select(This,Replace,RHS) ) 

#define ILabels_SendToBack(This,RHS)	\
    ( (This)->lpVtbl -> SendToBack(This,RHS) ) 

#define ILabels_get_Top(This,RHS)	\
    ( (This)->lpVtbl -> get_Top(This,RHS) ) 

#define ILabels_put_Top(This,RHS)	\
    ( (This)->lpVtbl -> put_Top(This,RHS) ) 

#define ILabels__Dummy22(This)	\
    ( (This)->lpVtbl -> _Dummy22(This) ) 

#define ILabels_get_Visible(This,RHS)	\
    ( (This)->lpVtbl -> get_Visible(This,RHS) ) 

#define ILabels_put_Visible(This,RHS)	\
    ( (This)->lpVtbl -> put_Visible(This,RHS) ) 

#define ILabels_get_Width(This,RHS)	\
    ( (This)->lpVtbl -> get_Width(This,RHS) ) 

#define ILabels_put_Width(This,RHS)	\
    ( (This)->lpVtbl -> put_Width(This,RHS) ) 

#define ILabels_get_ZOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_ZOrder(This,RHS) ) 

#define ILabels_get_ShapeRange(This,RHS)	\
    ( (This)->lpVtbl -> get_ShapeRange(This,RHS) ) 

#define ILabels_get_Caption(This,RHS)	\
    ( (This)->lpVtbl -> get_Caption(This,RHS) ) 

#define ILabels_put_Caption(This,RHS)	\
    ( (This)->lpVtbl -> put_Caption(This,RHS) ) 

#define ILabels_get_Characters(This,Start,Length,RHS)	\
    ( (This)->lpVtbl -> get_Characters(This,Start,Length,RHS) ) 

#define ILabels_CheckSpelling(This,CustomDictionary,IgnoreUppercase,AlwaysSuggest,SpellLang,RHS)	\
    ( (This)->lpVtbl -> CheckSpelling(This,CustomDictionary,IgnoreUppercase,AlwaysSuggest,SpellLang,RHS) ) 

#define ILabels_get_LockedText(This,RHS)	\
    ( (This)->lpVtbl -> get_LockedText(This,RHS) ) 

#define ILabels_put_LockedText(This,RHS)	\
    ( (This)->lpVtbl -> put_LockedText(This,RHS) ) 

#define ILabels_get_Text(This,RHS)	\
    ( (This)->lpVtbl -> get_Text(This,RHS) ) 

#define ILabels_put_Text(This,RHS)	\
    ( (This)->lpVtbl -> put_Text(This,RHS) ) 

#define ILabels_get_Accelerator(This,RHS)	\
    ( (This)->lpVtbl -> get_Accelerator(This,RHS) ) 

#define ILabels_put_Accelerator(This,RHS)	\
    ( (This)->lpVtbl -> put_Accelerator(This,RHS) ) 

#define ILabels__Dummy33(This)	\
    ( (This)->lpVtbl -> _Dummy33(This) ) 

#define ILabels_get_PhoneticAccelerator(This,RHS)	\
    ( (This)->lpVtbl -> get_PhoneticAccelerator(This,RHS) ) 

#define ILabels_put_PhoneticAccelerator(This,RHS)	\
    ( (This)->lpVtbl -> put_PhoneticAccelerator(This,RHS) ) 

#define ILabels_Add(This,Left,Top,Width,Height,RHS)	\
    ( (This)->lpVtbl -> Add(This,Left,Top,Width,Height,RHS) ) 

#define ILabels_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define ILabels_Group(This,RHS)	\
    ( (This)->lpVtbl -> Group(This,RHS) ) 

#define ILabels_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> Item(This,Index,RHS) ) 

#define ILabels__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> _NewEnum(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ILabels_INTERFACE_DEFINED__ */


#ifndef __IPanes_INTERFACE_DEFINED__
#define __IPanes_INTERFACE_DEFINED__

/* interface IPanes */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IPanes;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00020894-0001-0000-C000-000000000046")
    IPanes : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Item( 
            /* [in] */ long Index,
            /* [retval][out] */ Pane	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ long Index,
            /* [retval][out] */ Pane	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IPanesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IPanes * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IPanes * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IPanes * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IPanes * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IPanes * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IPanes * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IPanes * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IPanes * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IPanes * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IPanes * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IPanes * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Item )( 
            IPanes * This,
            /* [in] */ long Index,
            /* [retval][out] */ Pane	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IPanes * This,
            /* [in] */ long Index,
            /* [retval][out] */ Pane	**RHS);
        
        END_INTERFACE
    } IPanesVtbl;

    interface IPanes
    {
        CONST_VTBL struct IPanesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IPanes_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IPanes_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IPanes_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IPanes_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IPanes_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IPanes_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IPanes_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IPanes_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IPanes_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IPanes_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IPanes_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IPanes_get_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Item(This,Index,RHS) ) 

#define IPanes_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IPanes_INTERFACE_DEFINED__ */


#ifndef __IPane_INTERFACE_DEFINED__
#define __IPane_INTERFACE_DEFINED__

/* interface IPane */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IPane;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00020895-0001-0000-C000-000000000046")
    IPane : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Activate( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Index( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall LargeScroll( 
            /* [optional][in] */ VARIANT Down,
            /* [optional][in] */ VARIANT Up,
            /* [optional][in] */ VARIANT ToRight,
            /* [optional][in] */ VARIANT ToLeft,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ScrollColumn( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ScrollColumn( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ScrollRow( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ScrollRow( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SmallScroll( 
            /* [optional][in] */ VARIANT Down,
            /* [optional][in] */ VARIANT Up,
            /* [optional][in] */ VARIANT ToRight,
            /* [optional][in] */ VARIANT ToLeft,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_VisibleRange( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ScrollIntoView( 
            /* [in] */ long Left,
            /* [in] */ long Top,
            /* [in] */ long Width,
            /* [in] */ long Height,
            /* [optional][in] */ VARIANT Start) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall PointsToScreenPixelsX( 
            /* [in] */ long Points,
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall PointsToScreenPixelsY( 
            /* [in] */ long Points,
            /* [retval][out] */ long *RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IPaneVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IPane * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IPane * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IPane * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IPane * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IPane * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IPane * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IPane * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IPane * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IPane * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IPane * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Activate )( 
            IPane * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Index )( 
            IPane * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *LargeScroll )( 
            IPane * This,
            /* [optional][in] */ VARIANT Down,
            /* [optional][in] */ VARIANT Up,
            /* [optional][in] */ VARIANT ToRight,
            /* [optional][in] */ VARIANT ToLeft,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ScrollColumn )( 
            IPane * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ScrollColumn )( 
            IPane * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ScrollRow )( 
            IPane * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ScrollRow )( 
            IPane * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SmallScroll )( 
            IPane * This,
            /* [optional][in] */ VARIANT Down,
            /* [optional][in] */ VARIANT Up,
            /* [optional][in] */ VARIANT ToRight,
            /* [optional][in] */ VARIANT ToLeft,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_VisibleRange )( 
            IPane * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ScrollIntoView )( 
            IPane * This,
            /* [in] */ long Left,
            /* [in] */ long Top,
            /* [in] */ long Width,
            /* [in] */ long Height,
            /* [optional][in] */ VARIANT Start);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *PointsToScreenPixelsX )( 
            IPane * This,
            /* [in] */ long Points,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *PointsToScreenPixelsY )( 
            IPane * This,
            /* [in] */ long Points,
            /* [retval][out] */ long *RHS);
        
        END_INTERFACE
    } IPaneVtbl;

    interface IPane
    {
        CONST_VTBL struct IPaneVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IPane_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IPane_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IPane_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IPane_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IPane_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IPane_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IPane_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IPane_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IPane_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IPane_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IPane_Activate(This,RHS)	\
    ( (This)->lpVtbl -> Activate(This,RHS) ) 

#define IPane_get_Index(This,RHS)	\
    ( (This)->lpVtbl -> get_Index(This,RHS) ) 

#define IPane_LargeScroll(This,Down,Up,ToRight,ToLeft,RHS)	\
    ( (This)->lpVtbl -> LargeScroll(This,Down,Up,ToRight,ToLeft,RHS) ) 

#define IPane_get_ScrollColumn(This,RHS)	\
    ( (This)->lpVtbl -> get_ScrollColumn(This,RHS) ) 

#define IPane_put_ScrollColumn(This,RHS)	\
    ( (This)->lpVtbl -> put_ScrollColumn(This,RHS) ) 

#define IPane_get_ScrollRow(This,RHS)	\
    ( (This)->lpVtbl -> get_ScrollRow(This,RHS) ) 

#define IPane_put_ScrollRow(This,RHS)	\
    ( (This)->lpVtbl -> put_ScrollRow(This,RHS) ) 

#define IPane_SmallScroll(This,Down,Up,ToRight,ToLeft,RHS)	\
    ( (This)->lpVtbl -> SmallScroll(This,Down,Up,ToRight,ToLeft,RHS) ) 

#define IPane_get_VisibleRange(This,RHS)	\
    ( (This)->lpVtbl -> get_VisibleRange(This,RHS) ) 

#define IPane_ScrollIntoView(This,Left,Top,Width,Height,Start)	\
    ( (This)->lpVtbl -> ScrollIntoView(This,Left,Top,Width,Height,Start) ) 

#define IPane_PointsToScreenPixelsX(This,Points,RHS)	\
    ( (This)->lpVtbl -> PointsToScreenPixelsX(This,Points,RHS) ) 

#define IPane_PointsToScreenPixelsY(This,Points,RHS)	\
    ( (This)->lpVtbl -> PointsToScreenPixelsY(This,Points,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IPane_INTERFACE_DEFINED__ */


#ifndef __IScenarios_INTERFACE_DEFINED__
#define __IScenarios_INTERFACE_DEFINED__

/* interface IScenarios */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IScenarios;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00020896-0001-0000-C000-000000000046")
    IScenarios : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add( 
            /* [in] */ BSTR Name,
            /* [in] */ VARIANT ChangingCells,
            /* [optional][in] */ VARIANT Values,
            /* [optional][in] */ VARIANT Comment,
            /* [optional][in] */ VARIANT Locked,
            /* [optional][in] */ VARIANT Hidden,
            /* [retval][out] */ Scenario	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CreateSummary( 
            /* [defaultvalue][optional][in] */ XlSummaryReportType ReportType,
            /* [optional][in] */ VARIANT ResultCells,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Scenario	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Merge( 
            /* [in] */ VARIANT Source,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall _NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IScenariosVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IScenarios * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IScenarios * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IScenarios * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IScenarios * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IScenarios * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IScenarios * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IScenarios * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IScenarios * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IScenarios * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IScenarios * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add )( 
            IScenarios * This,
            /* [in] */ BSTR Name,
            /* [in] */ VARIANT ChangingCells,
            /* [optional][in] */ VARIANT Values,
            /* [optional][in] */ VARIANT Comment,
            /* [optional][in] */ VARIANT Locked,
            /* [optional][in] */ VARIANT Hidden,
            /* [retval][out] */ Scenario	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IScenarios * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CreateSummary )( 
            IScenarios * This,
            /* [defaultvalue][optional][in] */ XlSummaryReportType ReportType,
            /* [optional][in] */ VARIANT ResultCells,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Item )( 
            IScenarios * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Scenario	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Merge )( 
            IScenarios * This,
            /* [in] */ VARIANT Source,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *_NewEnum )( 
            IScenarios * This,
            /* [retval][out] */ IUnknown **RHS);
        
        END_INTERFACE
    } IScenariosVtbl;

    interface IScenarios
    {
        CONST_VTBL struct IScenariosVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IScenarios_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IScenarios_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IScenarios_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IScenarios_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IScenarios_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IScenarios_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IScenarios_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IScenarios_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IScenarios_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IScenarios_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IScenarios_Add(This,Name,ChangingCells,Values,Comment,Locked,Hidden,RHS)	\
    ( (This)->lpVtbl -> Add(This,Name,ChangingCells,Values,Comment,Locked,Hidden,RHS) ) 

#define IScenarios_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IScenarios_CreateSummary(This,ReportType,ResultCells,RHS)	\
    ( (This)->lpVtbl -> CreateSummary(This,ReportType,ResultCells,RHS) ) 

#define IScenarios_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> Item(This,Index,RHS) ) 

#define IScenarios_Merge(This,Source,RHS)	\
    ( (This)->lpVtbl -> Merge(This,Source,RHS) ) 

#define IScenarios__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> _NewEnum(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IScenarios_INTERFACE_DEFINED__ */


#ifndef __IScenario_INTERFACE_DEFINED__
#define __IScenario_INTERFACE_DEFINED__

/* interface IScenario */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IScenario;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00020897-0001-0000-C000-000000000046")
    IScenario : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ChangeScenario( 
            /* [in] */ VARIANT ChangingCells,
            /* [optional][in] */ VARIANT Values,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ChangingCells( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Comment( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Comment( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Hidden( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Hidden( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Index( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Locked( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Locked( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Name( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Show( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Values( 
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IScenarioVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IScenario * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IScenario * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IScenario * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IScenario * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IScenario * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IScenario * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IScenario * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IScenario * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IScenario * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IScenario * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ChangeScenario )( 
            IScenario * This,
            /* [in] */ VARIANT ChangingCells,
            /* [optional][in] */ VARIANT Values,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ChangingCells )( 
            IScenario * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Comment )( 
            IScenario * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Comment )( 
            IScenario * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IScenario * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Hidden )( 
            IScenario * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Hidden )( 
            IScenario * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Index )( 
            IScenario * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Locked )( 
            IScenario * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Locked )( 
            IScenario * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            IScenario * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Name )( 
            IScenario * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Show )( 
            IScenario * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Values )( 
            IScenario * This,
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ VARIANT *RHS);
        
        END_INTERFACE
    } IScenarioVtbl;

    interface IScenario
    {
        CONST_VTBL struct IScenarioVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IScenario_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IScenario_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IScenario_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IScenario_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IScenario_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IScenario_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IScenario_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IScenario_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IScenario_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IScenario_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IScenario_ChangeScenario(This,ChangingCells,Values,RHS)	\
    ( (This)->lpVtbl -> ChangeScenario(This,ChangingCells,Values,RHS) ) 

#define IScenario_get_ChangingCells(This,RHS)	\
    ( (This)->lpVtbl -> get_ChangingCells(This,RHS) ) 

#define IScenario_get_Comment(This,RHS)	\
    ( (This)->lpVtbl -> get_Comment(This,RHS) ) 

#define IScenario_put_Comment(This,RHS)	\
    ( (This)->lpVtbl -> put_Comment(This,RHS) ) 

#define IScenario_Delete(This,RHS)	\
    ( (This)->lpVtbl -> Delete(This,RHS) ) 

#define IScenario_get_Hidden(This,RHS)	\
    ( (This)->lpVtbl -> get_Hidden(This,RHS) ) 

#define IScenario_put_Hidden(This,RHS)	\
    ( (This)->lpVtbl -> put_Hidden(This,RHS) ) 

#define IScenario_get_Index(This,RHS)	\
    ( (This)->lpVtbl -> get_Index(This,RHS) ) 

#define IScenario_get_Locked(This,RHS)	\
    ( (This)->lpVtbl -> get_Locked(This,RHS) ) 

#define IScenario_put_Locked(This,RHS)	\
    ( (This)->lpVtbl -> put_Locked(This,RHS) ) 

#define IScenario_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define IScenario_put_Name(This,RHS)	\
    ( (This)->lpVtbl -> put_Name(This,RHS) ) 

#define IScenario_Show(This,RHS)	\
    ( (This)->lpVtbl -> Show(This,RHS) ) 

#define IScenario_get_Values(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Values(This,Index,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IScenario_INTERFACE_DEFINED__ */


#ifndef __IGroupObject_INTERFACE_DEFINED__
#define __IGroupObject_INTERFACE_DEFINED__

/* interface IGroupObject */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IGroupObject;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00020898-0001-0000-C000-000000000046")
    IGroupObject : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_BottomRightCell( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall BringToFront( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Copy( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CopyPicture( 
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Cut( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Duplicate( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Enabled( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Enabled( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Height( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Height( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Index( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Left( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Left( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Locked( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Locked( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Name( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_OnAction( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_OnAction( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Placement( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Placement( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PrintObject( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PrintObject( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SendToBack( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Top( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Top( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TopLeftCell( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Visible( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Visible( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Width( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Width( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ZOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShapeRange( 
            /* [retval][out] */ ShapeRange	**RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy27( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy28( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AddIndent( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AddIndent( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy30( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ArrowHeadLength( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ArrowHeadLength( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ArrowHeadStyle( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ArrowHeadStyle( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ArrowHeadWidth( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ArrowHeadWidth( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AutoSize( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AutoSize( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Border( 
            /* [retval][out] */ Border	**RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy36( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy37( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy38( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CheckSpelling( 
            /* [optional][in] */ VARIANT CustomDictionary,
            /* [optional][in] */ VARIANT IgnoreUppercase,
            /* [optional][in] */ VARIANT AlwaysSuggest,
            /* [optional][in] */ VARIANT SpellLang,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put__Default( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy41( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy42( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy43( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy44( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy45( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Font( 
            /* [retval][out] */ Font	**RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy47( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy48( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HorizontalAlignment( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_HorizontalAlignment( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy50( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Interior( 
            /* [retval][out] */ Interior	**RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy52( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy53( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy54( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy55( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy56( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy57( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy58( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy59( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy60( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy61( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy62( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy63( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Orientation( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Orientation( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy65( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy66( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy67( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy68( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RoundedCorners( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_RoundedCorners( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy70( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Shadow( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Shadow( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy72( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy73( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Ungroup( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy75( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_VerticalAlignment( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_VerticalAlignment( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy77( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ReadingOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ReadingOrder( 
            /* [in] */ long RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IGroupObjectVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IGroupObject * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IGroupObject * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IGroupObject * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IGroupObject * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IGroupObject * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IGroupObject * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IGroupObject * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IGroupObject * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IGroupObject * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IGroupObject * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_BottomRightCell )( 
            IGroupObject * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *BringToFront )( 
            IGroupObject * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Copy )( 
            IGroupObject * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CopyPicture )( 
            IGroupObject * This,
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Cut )( 
            IGroupObject * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IGroupObject * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Duplicate )( 
            IGroupObject * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Enabled )( 
            IGroupObject * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Enabled )( 
            IGroupObject * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Height )( 
            IGroupObject * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Height )( 
            IGroupObject * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Index )( 
            IGroupObject * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Left )( 
            IGroupObject * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Left )( 
            IGroupObject * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Locked )( 
            IGroupObject * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Locked )( 
            IGroupObject * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            IGroupObject * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Name )( 
            IGroupObject * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_OnAction )( 
            IGroupObject * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_OnAction )( 
            IGroupObject * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Placement )( 
            IGroupObject * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Placement )( 
            IGroupObject * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PrintObject )( 
            IGroupObject * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PrintObject )( 
            IGroupObject * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            IGroupObject * This,
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SendToBack )( 
            IGroupObject * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Top )( 
            IGroupObject * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Top )( 
            IGroupObject * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TopLeftCell )( 
            IGroupObject * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Visible )( 
            IGroupObject * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Visible )( 
            IGroupObject * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Width )( 
            IGroupObject * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Width )( 
            IGroupObject * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ZOrder )( 
            IGroupObject * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShapeRange )( 
            IGroupObject * This,
            /* [retval][out] */ ShapeRange	**RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy27 )( 
            IGroupObject * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy28 )( 
            IGroupObject * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AddIndent )( 
            IGroupObject * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AddIndent )( 
            IGroupObject * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy30 )( 
            IGroupObject * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ArrowHeadLength )( 
            IGroupObject * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ArrowHeadLength )( 
            IGroupObject * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ArrowHeadStyle )( 
            IGroupObject * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ArrowHeadStyle )( 
            IGroupObject * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ArrowHeadWidth )( 
            IGroupObject * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ArrowHeadWidth )( 
            IGroupObject * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AutoSize )( 
            IGroupObject * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AutoSize )( 
            IGroupObject * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Border )( 
            IGroupObject * This,
            /* [retval][out] */ Border	**RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy36 )( 
            IGroupObject * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy37 )( 
            IGroupObject * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy38 )( 
            IGroupObject * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CheckSpelling )( 
            IGroupObject * This,
            /* [optional][in] */ VARIANT CustomDictionary,
            /* [optional][in] */ VARIANT IgnoreUppercase,
            /* [optional][in] */ VARIANT AlwaysSuggest,
            /* [optional][in] */ VARIANT SpellLang,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IGroupObject * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put__Default )( 
            IGroupObject * This,
            /* [in] */ long RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy41 )( 
            IGroupObject * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy42 )( 
            IGroupObject * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy43 )( 
            IGroupObject * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy44 )( 
            IGroupObject * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy45 )( 
            IGroupObject * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Font )( 
            IGroupObject * This,
            /* [retval][out] */ Font	**RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy47 )( 
            IGroupObject * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy48 )( 
            IGroupObject * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HorizontalAlignment )( 
            IGroupObject * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_HorizontalAlignment )( 
            IGroupObject * This,
            /* [in] */ VARIANT RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy50 )( 
            IGroupObject * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Interior )( 
            IGroupObject * This,
            /* [retval][out] */ Interior	**RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy52 )( 
            IGroupObject * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy53 )( 
            IGroupObject * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy54 )( 
            IGroupObject * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy55 )( 
            IGroupObject * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy56 )( 
            IGroupObject * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy57 )( 
            IGroupObject * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy58 )( 
            IGroupObject * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy59 )( 
            IGroupObject * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy60 )( 
            IGroupObject * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy61 )( 
            IGroupObject * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy62 )( 
            IGroupObject * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy63 )( 
            IGroupObject * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Orientation )( 
            IGroupObject * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Orientation )( 
            IGroupObject * This,
            /* [in] */ VARIANT RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy65 )( 
            IGroupObject * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy66 )( 
            IGroupObject * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy67 )( 
            IGroupObject * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy68 )( 
            IGroupObject * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RoundedCorners )( 
            IGroupObject * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_RoundedCorners )( 
            IGroupObject * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy70 )( 
            IGroupObject * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Shadow )( 
            IGroupObject * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Shadow )( 
            IGroupObject * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy72 )( 
            IGroupObject * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy73 )( 
            IGroupObject * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Ungroup )( 
            IGroupObject * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy75 )( 
            IGroupObject * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_VerticalAlignment )( 
            IGroupObject * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_VerticalAlignment )( 
            IGroupObject * This,
            /* [in] */ VARIANT RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy77 )( 
            IGroupObject * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ReadingOrder )( 
            IGroupObject * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ReadingOrder )( 
            IGroupObject * This,
            /* [in] */ long RHS);
        
        END_INTERFACE
    } IGroupObjectVtbl;

    interface IGroupObject
    {
        CONST_VTBL struct IGroupObjectVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IGroupObject_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IGroupObject_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IGroupObject_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IGroupObject_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IGroupObject_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IGroupObject_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IGroupObject_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IGroupObject_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IGroupObject_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IGroupObject_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IGroupObject_get_BottomRightCell(This,RHS)	\
    ( (This)->lpVtbl -> get_BottomRightCell(This,RHS) ) 

#define IGroupObject_BringToFront(This,RHS)	\
    ( (This)->lpVtbl -> BringToFront(This,RHS) ) 

#define IGroupObject_Copy(This,RHS)	\
    ( (This)->lpVtbl -> Copy(This,RHS) ) 

#define IGroupObject_CopyPicture(This,Appearance,Format,RHS)	\
    ( (This)->lpVtbl -> CopyPicture(This,Appearance,Format,RHS) ) 

#define IGroupObject_Cut(This,RHS)	\
    ( (This)->lpVtbl -> Cut(This,RHS) ) 

#define IGroupObject_Delete(This,RHS)	\
    ( (This)->lpVtbl -> Delete(This,RHS) ) 

#define IGroupObject_Duplicate(This,RHS)	\
    ( (This)->lpVtbl -> Duplicate(This,RHS) ) 

#define IGroupObject_get_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> get_Enabled(This,RHS) ) 

#define IGroupObject_put_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> put_Enabled(This,RHS) ) 

#define IGroupObject_get_Height(This,RHS)	\
    ( (This)->lpVtbl -> get_Height(This,RHS) ) 

#define IGroupObject_put_Height(This,RHS)	\
    ( (This)->lpVtbl -> put_Height(This,RHS) ) 

#define IGroupObject_get_Index(This,RHS)	\
    ( (This)->lpVtbl -> get_Index(This,RHS) ) 

#define IGroupObject_get_Left(This,RHS)	\
    ( (This)->lpVtbl -> get_Left(This,RHS) ) 

#define IGroupObject_put_Left(This,RHS)	\
    ( (This)->lpVtbl -> put_Left(This,RHS) ) 

#define IGroupObject_get_Locked(This,RHS)	\
    ( (This)->lpVtbl -> get_Locked(This,RHS) ) 

#define IGroupObject_put_Locked(This,RHS)	\
    ( (This)->lpVtbl -> put_Locked(This,RHS) ) 

#define IGroupObject_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define IGroupObject_put_Name(This,RHS)	\
    ( (This)->lpVtbl -> put_Name(This,RHS) ) 

#define IGroupObject_get_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> get_OnAction(This,RHS) ) 

#define IGroupObject_put_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> put_OnAction(This,RHS) ) 

#define IGroupObject_get_Placement(This,RHS)	\
    ( (This)->lpVtbl -> get_Placement(This,RHS) ) 

#define IGroupObject_put_Placement(This,RHS)	\
    ( (This)->lpVtbl -> put_Placement(This,RHS) ) 

#define IGroupObject_get_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> get_PrintObject(This,RHS) ) 

#define IGroupObject_put_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> put_PrintObject(This,RHS) ) 

#define IGroupObject_Select(This,Replace,RHS)	\
    ( (This)->lpVtbl -> Select(This,Replace,RHS) ) 

#define IGroupObject_SendToBack(This,RHS)	\
    ( (This)->lpVtbl -> SendToBack(This,RHS) ) 

#define IGroupObject_get_Top(This,RHS)	\
    ( (This)->lpVtbl -> get_Top(This,RHS) ) 

#define IGroupObject_put_Top(This,RHS)	\
    ( (This)->lpVtbl -> put_Top(This,RHS) ) 

#define IGroupObject_get_TopLeftCell(This,RHS)	\
    ( (This)->lpVtbl -> get_TopLeftCell(This,RHS) ) 

#define IGroupObject_get_Visible(This,RHS)	\
    ( (This)->lpVtbl -> get_Visible(This,RHS) ) 

#define IGroupObject_put_Visible(This,RHS)	\
    ( (This)->lpVtbl -> put_Visible(This,RHS) ) 

#define IGroupObject_get_Width(This,RHS)	\
    ( (This)->lpVtbl -> get_Width(This,RHS) ) 

#define IGroupObject_put_Width(This,RHS)	\
    ( (This)->lpVtbl -> put_Width(This,RHS) ) 

#define IGroupObject_get_ZOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_ZOrder(This,RHS) ) 

#define IGroupObject_get_ShapeRange(This,RHS)	\
    ( (This)->lpVtbl -> get_ShapeRange(This,RHS) ) 

#define IGroupObject__Dummy27(This)	\
    ( (This)->lpVtbl -> _Dummy27(This) ) 

#define IGroupObject__Dummy28(This)	\
    ( (This)->lpVtbl -> _Dummy28(This) ) 

#define IGroupObject_get_AddIndent(This,RHS)	\
    ( (This)->lpVtbl -> get_AddIndent(This,RHS) ) 

#define IGroupObject_put_AddIndent(This,RHS)	\
    ( (This)->lpVtbl -> put_AddIndent(This,RHS) ) 

#define IGroupObject__Dummy30(This)	\
    ( (This)->lpVtbl -> _Dummy30(This) ) 

#define IGroupObject_get_ArrowHeadLength(This,RHS)	\
    ( (This)->lpVtbl -> get_ArrowHeadLength(This,RHS) ) 

#define IGroupObject_put_ArrowHeadLength(This,RHS)	\
    ( (This)->lpVtbl -> put_ArrowHeadLength(This,RHS) ) 

#define IGroupObject_get_ArrowHeadStyle(This,RHS)	\
    ( (This)->lpVtbl -> get_ArrowHeadStyle(This,RHS) ) 

#define IGroupObject_put_ArrowHeadStyle(This,RHS)	\
    ( (This)->lpVtbl -> put_ArrowHeadStyle(This,RHS) ) 

#define IGroupObject_get_ArrowHeadWidth(This,RHS)	\
    ( (This)->lpVtbl -> get_ArrowHeadWidth(This,RHS) ) 

#define IGroupObject_put_ArrowHeadWidth(This,RHS)	\
    ( (This)->lpVtbl -> put_ArrowHeadWidth(This,RHS) ) 

#define IGroupObject_get_AutoSize(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoSize(This,RHS) ) 

#define IGroupObject_put_AutoSize(This,RHS)	\
    ( (This)->lpVtbl -> put_AutoSize(This,RHS) ) 

#define IGroupObject_get_Border(This,RHS)	\
    ( (This)->lpVtbl -> get_Border(This,RHS) ) 

#define IGroupObject__Dummy36(This)	\
    ( (This)->lpVtbl -> _Dummy36(This) ) 

#define IGroupObject__Dummy37(This)	\
    ( (This)->lpVtbl -> _Dummy37(This) ) 

#define IGroupObject__Dummy38(This)	\
    ( (This)->lpVtbl -> _Dummy38(This) ) 

#define IGroupObject_CheckSpelling(This,CustomDictionary,IgnoreUppercase,AlwaysSuggest,SpellLang,RHS)	\
    ( (This)->lpVtbl -> CheckSpelling(This,CustomDictionary,IgnoreUppercase,AlwaysSuggest,SpellLang,RHS) ) 

#define IGroupObject_get__Default(This,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,RHS) ) 

#define IGroupObject_put__Default(This,RHS)	\
    ( (This)->lpVtbl -> put__Default(This,RHS) ) 

#define IGroupObject__Dummy41(This)	\
    ( (This)->lpVtbl -> _Dummy41(This) ) 

#define IGroupObject__Dummy42(This)	\
    ( (This)->lpVtbl -> _Dummy42(This) ) 

#define IGroupObject__Dummy43(This)	\
    ( (This)->lpVtbl -> _Dummy43(This) ) 

#define IGroupObject__Dummy44(This)	\
    ( (This)->lpVtbl -> _Dummy44(This) ) 

#define IGroupObject__Dummy45(This)	\
    ( (This)->lpVtbl -> _Dummy45(This) ) 

#define IGroupObject_get_Font(This,RHS)	\
    ( (This)->lpVtbl -> get_Font(This,RHS) ) 

#define IGroupObject__Dummy47(This)	\
    ( (This)->lpVtbl -> _Dummy47(This) ) 

#define IGroupObject__Dummy48(This)	\
    ( (This)->lpVtbl -> _Dummy48(This) ) 

#define IGroupObject_get_HorizontalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> get_HorizontalAlignment(This,RHS) ) 

#define IGroupObject_put_HorizontalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> put_HorizontalAlignment(This,RHS) ) 

#define IGroupObject__Dummy50(This)	\
    ( (This)->lpVtbl -> _Dummy50(This) ) 

#define IGroupObject_get_Interior(This,RHS)	\
    ( (This)->lpVtbl -> get_Interior(This,RHS) ) 

#define IGroupObject__Dummy52(This)	\
    ( (This)->lpVtbl -> _Dummy52(This) ) 

#define IGroupObject__Dummy53(This)	\
    ( (This)->lpVtbl -> _Dummy53(This) ) 

#define IGroupObject__Dummy54(This)	\
    ( (This)->lpVtbl -> _Dummy54(This) ) 

#define IGroupObject__Dummy55(This)	\
    ( (This)->lpVtbl -> _Dummy55(This) ) 

#define IGroupObject__Dummy56(This)	\
    ( (This)->lpVtbl -> _Dummy56(This) ) 

#define IGroupObject__Dummy57(This)	\
    ( (This)->lpVtbl -> _Dummy57(This) ) 

#define IGroupObject__Dummy58(This)	\
    ( (This)->lpVtbl -> _Dummy58(This) ) 

#define IGroupObject__Dummy59(This)	\
    ( (This)->lpVtbl -> _Dummy59(This) ) 

#define IGroupObject__Dummy60(This)	\
    ( (This)->lpVtbl -> _Dummy60(This) ) 

#define IGroupObject__Dummy61(This)	\
    ( (This)->lpVtbl -> _Dummy61(This) ) 

#define IGroupObject__Dummy62(This)	\
    ( (This)->lpVtbl -> _Dummy62(This) ) 

#define IGroupObject__Dummy63(This)	\
    ( (This)->lpVtbl -> _Dummy63(This) ) 

#define IGroupObject_get_Orientation(This,RHS)	\
    ( (This)->lpVtbl -> get_Orientation(This,RHS) ) 

#define IGroupObject_put_Orientation(This,RHS)	\
    ( (This)->lpVtbl -> put_Orientation(This,RHS) ) 

#define IGroupObject__Dummy65(This)	\
    ( (This)->lpVtbl -> _Dummy65(This) ) 

#define IGroupObject__Dummy66(This)	\
    ( (This)->lpVtbl -> _Dummy66(This) ) 

#define IGroupObject__Dummy67(This)	\
    ( (This)->lpVtbl -> _Dummy67(This) ) 

#define IGroupObject__Dummy68(This)	\
    ( (This)->lpVtbl -> _Dummy68(This) ) 

#define IGroupObject_get_RoundedCorners(This,RHS)	\
    ( (This)->lpVtbl -> get_RoundedCorners(This,RHS) ) 

#define IGroupObject_put_RoundedCorners(This,RHS)	\
    ( (This)->lpVtbl -> put_RoundedCorners(This,RHS) ) 

#define IGroupObject__Dummy70(This)	\
    ( (This)->lpVtbl -> _Dummy70(This) ) 

#define IGroupObject_get_Shadow(This,RHS)	\
    ( (This)->lpVtbl -> get_Shadow(This,RHS) ) 

#define IGroupObject_put_Shadow(This,RHS)	\
    ( (This)->lpVtbl -> put_Shadow(This,RHS) ) 

#define IGroupObject__Dummy72(This)	\
    ( (This)->lpVtbl -> _Dummy72(This) ) 

#define IGroupObject__Dummy73(This)	\
    ( (This)->lpVtbl -> _Dummy73(This) ) 

#define IGroupObject_Ungroup(This,RHS)	\
    ( (This)->lpVtbl -> Ungroup(This,RHS) ) 

#define IGroupObject__Dummy75(This)	\
    ( (This)->lpVtbl -> _Dummy75(This) ) 

#define IGroupObject_get_VerticalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> get_VerticalAlignment(This,RHS) ) 

#define IGroupObject_put_VerticalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> put_VerticalAlignment(This,RHS) ) 

#define IGroupObject__Dummy77(This)	\
    ( (This)->lpVtbl -> _Dummy77(This) ) 

#define IGroupObject_get_ReadingOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_ReadingOrder(This,RHS) ) 

#define IGroupObject_put_ReadingOrder(This,RHS)	\
    ( (This)->lpVtbl -> put_ReadingOrder(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IGroupObject_INTERFACE_DEFINED__ */


#ifndef __IGroupObjects_INTERFACE_DEFINED__
#define __IGroupObjects_INTERFACE_DEFINED__

/* interface IGroupObjects */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IGroupObjects;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00020899-0001-0000-C000-000000000046")
    IGroupObjects : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy3( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall BringToFront( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Copy( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CopyPicture( 
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Cut( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Duplicate( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Enabled( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Enabled( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Height( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Height( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy12( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Left( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Left( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Locked( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Locked( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy15( void) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_OnAction( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_OnAction( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Placement( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Placement( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PrintObject( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PrintObject( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SendToBack( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Top( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Top( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy22( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Visible( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Visible( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Width( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Width( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ZOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShapeRange( 
            /* [retval][out] */ ShapeRange	**RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy27( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy28( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AddIndent( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AddIndent( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy30( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ArrowHeadLength( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ArrowHeadLength( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ArrowHeadStyle( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ArrowHeadStyle( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ArrowHeadWidth( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ArrowHeadWidth( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AutoSize( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AutoSize( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Border( 
            /* [retval][out] */ Border	**RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy36( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy37( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy38( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CheckSpelling( 
            /* [optional][in] */ VARIANT CustomDictionary,
            /* [optional][in] */ VARIANT IgnoreUppercase,
            /* [optional][in] */ VARIANT AlwaysSuggest,
            /* [optional][in] */ VARIANT SpellLang,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put__Default( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy41( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy42( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy43( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy44( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy45( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Font( 
            /* [retval][out] */ Font	**RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy47( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy48( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HorizontalAlignment( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_HorizontalAlignment( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy50( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Interior( 
            /* [retval][out] */ Interior	**RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy52( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy53( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy54( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy55( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy56( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy57( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy58( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy59( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy60( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy61( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy62( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy63( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Orientation( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Orientation( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy65( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy66( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy67( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy68( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RoundedCorners( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_RoundedCorners( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy70( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Shadow( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Shadow( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy72( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy73( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Ungroup( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy75( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_VerticalAlignment( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_VerticalAlignment( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy77( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ReadingOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ReadingOrder( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Group( 
            /* [retval][out] */ GroupObject	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall _NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IGroupObjectsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IGroupObjects * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IGroupObjects * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IGroupObjects * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IGroupObjects * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IGroupObjects * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IGroupObjects * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IGroupObjects * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IGroupObjects * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IGroupObjects * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IGroupObjects * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy3 )( 
            IGroupObjects * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *BringToFront )( 
            IGroupObjects * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Copy )( 
            IGroupObjects * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CopyPicture )( 
            IGroupObjects * This,
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Cut )( 
            IGroupObjects * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IGroupObjects * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Duplicate )( 
            IGroupObjects * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Enabled )( 
            IGroupObjects * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Enabled )( 
            IGroupObjects * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Height )( 
            IGroupObjects * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Height )( 
            IGroupObjects * This,
            /* [in] */ double RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy12 )( 
            IGroupObjects * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Left )( 
            IGroupObjects * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Left )( 
            IGroupObjects * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Locked )( 
            IGroupObjects * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Locked )( 
            IGroupObjects * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy15 )( 
            IGroupObjects * This);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_OnAction )( 
            IGroupObjects * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_OnAction )( 
            IGroupObjects * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Placement )( 
            IGroupObjects * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Placement )( 
            IGroupObjects * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PrintObject )( 
            IGroupObjects * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PrintObject )( 
            IGroupObjects * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            IGroupObjects * This,
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SendToBack )( 
            IGroupObjects * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Top )( 
            IGroupObjects * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Top )( 
            IGroupObjects * This,
            /* [in] */ double RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy22 )( 
            IGroupObjects * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Visible )( 
            IGroupObjects * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Visible )( 
            IGroupObjects * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Width )( 
            IGroupObjects * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Width )( 
            IGroupObjects * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ZOrder )( 
            IGroupObjects * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShapeRange )( 
            IGroupObjects * This,
            /* [retval][out] */ ShapeRange	**RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy27 )( 
            IGroupObjects * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy28 )( 
            IGroupObjects * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AddIndent )( 
            IGroupObjects * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AddIndent )( 
            IGroupObjects * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy30 )( 
            IGroupObjects * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ArrowHeadLength )( 
            IGroupObjects * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ArrowHeadLength )( 
            IGroupObjects * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ArrowHeadStyle )( 
            IGroupObjects * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ArrowHeadStyle )( 
            IGroupObjects * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ArrowHeadWidth )( 
            IGroupObjects * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ArrowHeadWidth )( 
            IGroupObjects * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AutoSize )( 
            IGroupObjects * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AutoSize )( 
            IGroupObjects * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Border )( 
            IGroupObjects * This,
            /* [retval][out] */ Border	**RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy36 )( 
            IGroupObjects * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy37 )( 
            IGroupObjects * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy38 )( 
            IGroupObjects * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CheckSpelling )( 
            IGroupObjects * This,
            /* [optional][in] */ VARIANT CustomDictionary,
            /* [optional][in] */ VARIANT IgnoreUppercase,
            /* [optional][in] */ VARIANT AlwaysSuggest,
            /* [optional][in] */ VARIANT SpellLang,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IGroupObjects * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put__Default )( 
            IGroupObjects * This,
            /* [in] */ long RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy41 )( 
            IGroupObjects * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy42 )( 
            IGroupObjects * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy43 )( 
            IGroupObjects * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy44 )( 
            IGroupObjects * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy45 )( 
            IGroupObjects * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Font )( 
            IGroupObjects * This,
            /* [retval][out] */ Font	**RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy47 )( 
            IGroupObjects * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy48 )( 
            IGroupObjects * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HorizontalAlignment )( 
            IGroupObjects * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_HorizontalAlignment )( 
            IGroupObjects * This,
            /* [in] */ VARIANT RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy50 )( 
            IGroupObjects * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Interior )( 
            IGroupObjects * This,
            /* [retval][out] */ Interior	**RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy52 )( 
            IGroupObjects * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy53 )( 
            IGroupObjects * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy54 )( 
            IGroupObjects * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy55 )( 
            IGroupObjects * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy56 )( 
            IGroupObjects * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy57 )( 
            IGroupObjects * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy58 )( 
            IGroupObjects * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy59 )( 
            IGroupObjects * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy60 )( 
            IGroupObjects * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy61 )( 
            IGroupObjects * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy62 )( 
            IGroupObjects * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy63 )( 
            IGroupObjects * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Orientation )( 
            IGroupObjects * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Orientation )( 
            IGroupObjects * This,
            /* [in] */ VARIANT RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy65 )( 
            IGroupObjects * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy66 )( 
            IGroupObjects * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy67 )( 
            IGroupObjects * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy68 )( 
            IGroupObjects * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RoundedCorners )( 
            IGroupObjects * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_RoundedCorners )( 
            IGroupObjects * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy70 )( 
            IGroupObjects * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Shadow )( 
            IGroupObjects * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Shadow )( 
            IGroupObjects * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy72 )( 
            IGroupObjects * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy73 )( 
            IGroupObjects * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Ungroup )( 
            IGroupObjects * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy75 )( 
            IGroupObjects * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_VerticalAlignment )( 
            IGroupObjects * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_VerticalAlignment )( 
            IGroupObjects * This,
            /* [in] */ VARIANT RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy77 )( 
            IGroupObjects * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ReadingOrder )( 
            IGroupObjects * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ReadingOrder )( 
            IGroupObjects * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IGroupObjects * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Group )( 
            IGroupObjects * This,
            /* [retval][out] */ GroupObject	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Item )( 
            IGroupObjects * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *_NewEnum )( 
            IGroupObjects * This,
            /* [retval][out] */ IUnknown **RHS);
        
        END_INTERFACE
    } IGroupObjectsVtbl;

    interface IGroupObjects
    {
        CONST_VTBL struct IGroupObjectsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IGroupObjects_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IGroupObjects_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IGroupObjects_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IGroupObjects_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IGroupObjects_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IGroupObjects_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IGroupObjects_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IGroupObjects_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IGroupObjects_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IGroupObjects_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IGroupObjects__Dummy3(This)	\
    ( (This)->lpVtbl -> _Dummy3(This) ) 

#define IGroupObjects_BringToFront(This,RHS)	\
    ( (This)->lpVtbl -> BringToFront(This,RHS) ) 

#define IGroupObjects_Copy(This,RHS)	\
    ( (This)->lpVtbl -> Copy(This,RHS) ) 

#define IGroupObjects_CopyPicture(This,Appearance,Format,RHS)	\
    ( (This)->lpVtbl -> CopyPicture(This,Appearance,Format,RHS) ) 

#define IGroupObjects_Cut(This,RHS)	\
    ( (This)->lpVtbl -> Cut(This,RHS) ) 

#define IGroupObjects_Delete(This,RHS)	\
    ( (This)->lpVtbl -> Delete(This,RHS) ) 

#define IGroupObjects_Duplicate(This,RHS)	\
    ( (This)->lpVtbl -> Duplicate(This,RHS) ) 

#define IGroupObjects_get_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> get_Enabled(This,RHS) ) 

#define IGroupObjects_put_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> put_Enabled(This,RHS) ) 

#define IGroupObjects_get_Height(This,RHS)	\
    ( (This)->lpVtbl -> get_Height(This,RHS) ) 

#define IGroupObjects_put_Height(This,RHS)	\
    ( (This)->lpVtbl -> put_Height(This,RHS) ) 

#define IGroupObjects__Dummy12(This)	\
    ( (This)->lpVtbl -> _Dummy12(This) ) 

#define IGroupObjects_get_Left(This,RHS)	\
    ( (This)->lpVtbl -> get_Left(This,RHS) ) 

#define IGroupObjects_put_Left(This,RHS)	\
    ( (This)->lpVtbl -> put_Left(This,RHS) ) 

#define IGroupObjects_get_Locked(This,RHS)	\
    ( (This)->lpVtbl -> get_Locked(This,RHS) ) 

#define IGroupObjects_put_Locked(This,RHS)	\
    ( (This)->lpVtbl -> put_Locked(This,RHS) ) 

#define IGroupObjects__Dummy15(This)	\
    ( (This)->lpVtbl -> _Dummy15(This) ) 

#define IGroupObjects_get_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> get_OnAction(This,RHS) ) 

#define IGroupObjects_put_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> put_OnAction(This,RHS) ) 

#define IGroupObjects_get_Placement(This,RHS)	\
    ( (This)->lpVtbl -> get_Placement(This,RHS) ) 

#define IGroupObjects_put_Placement(This,RHS)	\
    ( (This)->lpVtbl -> put_Placement(This,RHS) ) 

#define IGroupObjects_get_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> get_PrintObject(This,RHS) ) 

#define IGroupObjects_put_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> put_PrintObject(This,RHS) ) 

#define IGroupObjects_Select(This,Replace,RHS)	\
    ( (This)->lpVtbl -> Select(This,Replace,RHS) ) 

#define IGroupObjects_SendToBack(This,RHS)	\
    ( (This)->lpVtbl -> SendToBack(This,RHS) ) 

#define IGroupObjects_get_Top(This,RHS)	\
    ( (This)->lpVtbl -> get_Top(This,RHS) ) 

#define IGroupObjects_put_Top(This,RHS)	\
    ( (This)->lpVtbl -> put_Top(This,RHS) ) 

#define IGroupObjects__Dummy22(This)	\
    ( (This)->lpVtbl -> _Dummy22(This) ) 

#define IGroupObjects_get_Visible(This,RHS)	\
    ( (This)->lpVtbl -> get_Visible(This,RHS) ) 

#define IGroupObjects_put_Visible(This,RHS)	\
    ( (This)->lpVtbl -> put_Visible(This,RHS) ) 

#define IGroupObjects_get_Width(This,RHS)	\
    ( (This)->lpVtbl -> get_Width(This,RHS) ) 

#define IGroupObjects_put_Width(This,RHS)	\
    ( (This)->lpVtbl -> put_Width(This,RHS) ) 

#define IGroupObjects_get_ZOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_ZOrder(This,RHS) ) 

#define IGroupObjects_get_ShapeRange(This,RHS)	\
    ( (This)->lpVtbl -> get_ShapeRange(This,RHS) ) 

#define IGroupObjects__Dummy27(This)	\
    ( (This)->lpVtbl -> _Dummy27(This) ) 

#define IGroupObjects__Dummy28(This)	\
    ( (This)->lpVtbl -> _Dummy28(This) ) 

#define IGroupObjects_get_AddIndent(This,RHS)	\
    ( (This)->lpVtbl -> get_AddIndent(This,RHS) ) 

#define IGroupObjects_put_AddIndent(This,RHS)	\
    ( (This)->lpVtbl -> put_AddIndent(This,RHS) ) 

#define IGroupObjects__Dummy30(This)	\
    ( (This)->lpVtbl -> _Dummy30(This) ) 

#define IGroupObjects_get_ArrowHeadLength(This,RHS)	\
    ( (This)->lpVtbl -> get_ArrowHeadLength(This,RHS) ) 

#define IGroupObjects_put_ArrowHeadLength(This,RHS)	\
    ( (This)->lpVtbl -> put_ArrowHeadLength(This,RHS) ) 

#define IGroupObjects_get_ArrowHeadStyle(This,RHS)	\
    ( (This)->lpVtbl -> get_ArrowHeadStyle(This,RHS) ) 

#define IGroupObjects_put_ArrowHeadStyle(This,RHS)	\
    ( (This)->lpVtbl -> put_ArrowHeadStyle(This,RHS) ) 

#define IGroupObjects_get_ArrowHeadWidth(This,RHS)	\
    ( (This)->lpVtbl -> get_ArrowHeadWidth(This,RHS) ) 

#define IGroupObjects_put_ArrowHeadWidth(This,RHS)	\
    ( (This)->lpVtbl -> put_ArrowHeadWidth(This,RHS) ) 

#define IGroupObjects_get_AutoSize(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoSize(This,RHS) ) 

#define IGroupObjects_put_AutoSize(This,RHS)	\
    ( (This)->lpVtbl -> put_AutoSize(This,RHS) ) 

#define IGroupObjects_get_Border(This,RHS)	\
    ( (This)->lpVtbl -> get_Border(This,RHS) ) 

#define IGroupObjects__Dummy36(This)	\
    ( (This)->lpVtbl -> _Dummy36(This) ) 

#define IGroupObjects__Dummy37(This)	\
    ( (This)->lpVtbl -> _Dummy37(This) ) 

#define IGroupObjects__Dummy38(This)	\
    ( (This)->lpVtbl -> _Dummy38(This) ) 

#define IGroupObjects_CheckSpelling(This,CustomDictionary,IgnoreUppercase,AlwaysSuggest,SpellLang,RHS)	\
    ( (This)->lpVtbl -> CheckSpelling(This,CustomDictionary,IgnoreUppercase,AlwaysSuggest,SpellLang,RHS) ) 

#define IGroupObjects_get__Default(This,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,RHS) ) 

#define IGroupObjects_put__Default(This,RHS)	\
    ( (This)->lpVtbl -> put__Default(This,RHS) ) 

#define IGroupObjects__Dummy41(This)	\
    ( (This)->lpVtbl -> _Dummy41(This) ) 

#define IGroupObjects__Dummy42(This)	\
    ( (This)->lpVtbl -> _Dummy42(This) ) 

#define IGroupObjects__Dummy43(This)	\
    ( (This)->lpVtbl -> _Dummy43(This) ) 

#define IGroupObjects__Dummy44(This)	\
    ( (This)->lpVtbl -> _Dummy44(This) ) 

#define IGroupObjects__Dummy45(This)	\
    ( (This)->lpVtbl -> _Dummy45(This) ) 

#define IGroupObjects_get_Font(This,RHS)	\
    ( (This)->lpVtbl -> get_Font(This,RHS) ) 

#define IGroupObjects__Dummy47(This)	\
    ( (This)->lpVtbl -> _Dummy47(This) ) 

#define IGroupObjects__Dummy48(This)	\
    ( (This)->lpVtbl -> _Dummy48(This) ) 

#define IGroupObjects_get_HorizontalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> get_HorizontalAlignment(This,RHS) ) 

#define IGroupObjects_put_HorizontalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> put_HorizontalAlignment(This,RHS) ) 

#define IGroupObjects__Dummy50(This)	\
    ( (This)->lpVtbl -> _Dummy50(This) ) 

#define IGroupObjects_get_Interior(This,RHS)	\
    ( (This)->lpVtbl -> get_Interior(This,RHS) ) 

#define IGroupObjects__Dummy52(This)	\
    ( (This)->lpVtbl -> _Dummy52(This) ) 

#define IGroupObjects__Dummy53(This)	\
    ( (This)->lpVtbl -> _Dummy53(This) ) 

#define IGroupObjects__Dummy54(This)	\
    ( (This)->lpVtbl -> _Dummy54(This) ) 

#define IGroupObjects__Dummy55(This)	\
    ( (This)->lpVtbl -> _Dummy55(This) ) 

#define IGroupObjects__Dummy56(This)	\
    ( (This)->lpVtbl -> _Dummy56(This) ) 

#define IGroupObjects__Dummy57(This)	\
    ( (This)->lpVtbl -> _Dummy57(This) ) 

#define IGroupObjects__Dummy58(This)	\
    ( (This)->lpVtbl -> _Dummy58(This) ) 

#define IGroupObjects__Dummy59(This)	\
    ( (This)->lpVtbl -> _Dummy59(This) ) 

#define IGroupObjects__Dummy60(This)	\
    ( (This)->lpVtbl -> _Dummy60(This) ) 

#define IGroupObjects__Dummy61(This)	\
    ( (This)->lpVtbl -> _Dummy61(This) ) 

#define IGroupObjects__Dummy62(This)	\
    ( (This)->lpVtbl -> _Dummy62(This) ) 

#define IGroupObjects__Dummy63(This)	\
    ( (This)->lpVtbl -> _Dummy63(This) ) 

#define IGroupObjects_get_Orientation(This,RHS)	\
    ( (This)->lpVtbl -> get_Orientation(This,RHS) ) 

#define IGroupObjects_put_Orientation(This,RHS)	\
    ( (This)->lpVtbl -> put_Orientation(This,RHS) ) 

#define IGroupObjects__Dummy65(This)	\
    ( (This)->lpVtbl -> _Dummy65(This) ) 

#define IGroupObjects__Dummy66(This)	\
    ( (This)->lpVtbl -> _Dummy66(This) ) 

#define IGroupObjects__Dummy67(This)	\
    ( (This)->lpVtbl -> _Dummy67(This) ) 

#define IGroupObjects__Dummy68(This)	\
    ( (This)->lpVtbl -> _Dummy68(This) ) 

#define IGroupObjects_get_RoundedCorners(This,RHS)	\
    ( (This)->lpVtbl -> get_RoundedCorners(This,RHS) ) 

#define IGroupObjects_put_RoundedCorners(This,RHS)	\
    ( (This)->lpVtbl -> put_RoundedCorners(This,RHS) ) 

#define IGroupObjects__Dummy70(This)	\
    ( (This)->lpVtbl -> _Dummy70(This) ) 

#define IGroupObjects_get_Shadow(This,RHS)	\
    ( (This)->lpVtbl -> get_Shadow(This,RHS) ) 

#define IGroupObjects_put_Shadow(This,RHS)	\
    ( (This)->lpVtbl -> put_Shadow(This,RHS) ) 

#define IGroupObjects__Dummy72(This)	\
    ( (This)->lpVtbl -> _Dummy72(This) ) 

#define IGroupObjects__Dummy73(This)	\
    ( (This)->lpVtbl -> _Dummy73(This) ) 

#define IGroupObjects_Ungroup(This,RHS)	\
    ( (This)->lpVtbl -> Ungroup(This,RHS) ) 

#define IGroupObjects__Dummy75(This)	\
    ( (This)->lpVtbl -> _Dummy75(This) ) 

#define IGroupObjects_get_VerticalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> get_VerticalAlignment(This,RHS) ) 

#define IGroupObjects_put_VerticalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> put_VerticalAlignment(This,RHS) ) 

#define IGroupObjects__Dummy77(This)	\
    ( (This)->lpVtbl -> _Dummy77(This) ) 

#define IGroupObjects_get_ReadingOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_ReadingOrder(This,RHS) ) 

#define IGroupObjects_put_ReadingOrder(This,RHS)	\
    ( (This)->lpVtbl -> put_ReadingOrder(This,RHS) ) 

#define IGroupObjects_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IGroupObjects_Group(This,RHS)	\
    ( (This)->lpVtbl -> Group(This,RHS) ) 

#define IGroupObjects_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> Item(This,Index,RHS) ) 

#define IGroupObjects__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> _NewEnum(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IGroupObjects_INTERFACE_DEFINED__ */


#ifndef __ILine_INTERFACE_DEFINED__
#define __ILine_INTERFACE_DEFINED__

/* interface ILine */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ILine;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002089A-0001-0000-C000-000000000046")
    ILine : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_BottomRightCell( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall BringToFront( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Copy( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CopyPicture( 
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Cut( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Duplicate( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Enabled( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Enabled( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Height( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Height( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Index( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Left( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Left( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Locked( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Locked( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Name( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_OnAction( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_OnAction( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Placement( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Placement( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PrintObject( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PrintObject( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SendToBack( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Top( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Top( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TopLeftCell( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Visible( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Visible( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Width( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Width( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ZOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShapeRange( 
            /* [retval][out] */ ShapeRange	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ArrowHeadLength( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ArrowHeadLength( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ArrowHeadStyle( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ArrowHeadStyle( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ArrowHeadWidth( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ArrowHeadWidth( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Border( 
            /* [retval][out] */ Border	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ILineVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ILine * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ILine * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ILine * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ILine * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ILine * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ILine * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ILine * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ILine * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ILine * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ILine * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_BottomRightCell )( 
            ILine * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *BringToFront )( 
            ILine * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Copy )( 
            ILine * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CopyPicture )( 
            ILine * This,
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Cut )( 
            ILine * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            ILine * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Duplicate )( 
            ILine * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Enabled )( 
            ILine * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Enabled )( 
            ILine * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Height )( 
            ILine * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Height )( 
            ILine * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Index )( 
            ILine * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Left )( 
            ILine * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Left )( 
            ILine * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Locked )( 
            ILine * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Locked )( 
            ILine * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            ILine * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Name )( 
            ILine * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_OnAction )( 
            ILine * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_OnAction )( 
            ILine * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Placement )( 
            ILine * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Placement )( 
            ILine * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PrintObject )( 
            ILine * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PrintObject )( 
            ILine * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            ILine * This,
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SendToBack )( 
            ILine * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Top )( 
            ILine * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Top )( 
            ILine * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TopLeftCell )( 
            ILine * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Visible )( 
            ILine * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Visible )( 
            ILine * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Width )( 
            ILine * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Width )( 
            ILine * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ZOrder )( 
            ILine * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShapeRange )( 
            ILine * This,
            /* [retval][out] */ ShapeRange	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ArrowHeadLength )( 
            ILine * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ArrowHeadLength )( 
            ILine * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ArrowHeadStyle )( 
            ILine * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ArrowHeadStyle )( 
            ILine * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ArrowHeadWidth )( 
            ILine * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ArrowHeadWidth )( 
            ILine * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Border )( 
            ILine * This,
            /* [retval][out] */ Border	**RHS);
        
        END_INTERFACE
    } ILineVtbl;

    interface ILine
    {
        CONST_VTBL struct ILineVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ILine_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ILine_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ILine_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ILine_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ILine_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ILine_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ILine_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ILine_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ILine_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ILine_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ILine_get_BottomRightCell(This,RHS)	\
    ( (This)->lpVtbl -> get_BottomRightCell(This,RHS) ) 

#define ILine_BringToFront(This,RHS)	\
    ( (This)->lpVtbl -> BringToFront(This,RHS) ) 

#define ILine_Copy(This,RHS)	\
    ( (This)->lpVtbl -> Copy(This,RHS) ) 

#define ILine_CopyPicture(This,Appearance,Format,RHS)	\
    ( (This)->lpVtbl -> CopyPicture(This,Appearance,Format,RHS) ) 

#define ILine_Cut(This,RHS)	\
    ( (This)->lpVtbl -> Cut(This,RHS) ) 

#define ILine_Delete(This,RHS)	\
    ( (This)->lpVtbl -> Delete(This,RHS) ) 

#define ILine_Duplicate(This,RHS)	\
    ( (This)->lpVtbl -> Duplicate(This,RHS) ) 

#define ILine_get_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> get_Enabled(This,RHS) ) 

#define ILine_put_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> put_Enabled(This,RHS) ) 

#define ILine_get_Height(This,RHS)	\
    ( (This)->lpVtbl -> get_Height(This,RHS) ) 

#define ILine_put_Height(This,RHS)	\
    ( (This)->lpVtbl -> put_Height(This,RHS) ) 

#define ILine_get_Index(This,RHS)	\
    ( (This)->lpVtbl -> get_Index(This,RHS) ) 

#define ILine_get_Left(This,RHS)	\
    ( (This)->lpVtbl -> get_Left(This,RHS) ) 

#define ILine_put_Left(This,RHS)	\
    ( (This)->lpVtbl -> put_Left(This,RHS) ) 

#define ILine_get_Locked(This,RHS)	\
    ( (This)->lpVtbl -> get_Locked(This,RHS) ) 

#define ILine_put_Locked(This,RHS)	\
    ( (This)->lpVtbl -> put_Locked(This,RHS) ) 

#define ILine_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define ILine_put_Name(This,RHS)	\
    ( (This)->lpVtbl -> put_Name(This,RHS) ) 

#define ILine_get_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> get_OnAction(This,RHS) ) 

#define ILine_put_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> put_OnAction(This,RHS) ) 

#define ILine_get_Placement(This,RHS)	\
    ( (This)->lpVtbl -> get_Placement(This,RHS) ) 

#define ILine_put_Placement(This,RHS)	\
    ( (This)->lpVtbl -> put_Placement(This,RHS) ) 

#define ILine_get_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> get_PrintObject(This,RHS) ) 

#define ILine_put_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> put_PrintObject(This,RHS) ) 

#define ILine_Select(This,Replace,RHS)	\
    ( (This)->lpVtbl -> Select(This,Replace,RHS) ) 

#define ILine_SendToBack(This,RHS)	\
    ( (This)->lpVtbl -> SendToBack(This,RHS) ) 

#define ILine_get_Top(This,RHS)	\
    ( (This)->lpVtbl -> get_Top(This,RHS) ) 

#define ILine_put_Top(This,RHS)	\
    ( (This)->lpVtbl -> put_Top(This,RHS) ) 

#define ILine_get_TopLeftCell(This,RHS)	\
    ( (This)->lpVtbl -> get_TopLeftCell(This,RHS) ) 

#define ILine_get_Visible(This,RHS)	\
    ( (This)->lpVtbl -> get_Visible(This,RHS) ) 

#define ILine_put_Visible(This,RHS)	\
    ( (This)->lpVtbl -> put_Visible(This,RHS) ) 

#define ILine_get_Width(This,RHS)	\
    ( (This)->lpVtbl -> get_Width(This,RHS) ) 

#define ILine_put_Width(This,RHS)	\
    ( (This)->lpVtbl -> put_Width(This,RHS) ) 

#define ILine_get_ZOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_ZOrder(This,RHS) ) 

#define ILine_get_ShapeRange(This,RHS)	\
    ( (This)->lpVtbl -> get_ShapeRange(This,RHS) ) 

#define ILine_get_ArrowHeadLength(This,RHS)	\
    ( (This)->lpVtbl -> get_ArrowHeadLength(This,RHS) ) 

#define ILine_put_ArrowHeadLength(This,RHS)	\
    ( (This)->lpVtbl -> put_ArrowHeadLength(This,RHS) ) 

#define ILine_get_ArrowHeadStyle(This,RHS)	\
    ( (This)->lpVtbl -> get_ArrowHeadStyle(This,RHS) ) 

#define ILine_put_ArrowHeadStyle(This,RHS)	\
    ( (This)->lpVtbl -> put_ArrowHeadStyle(This,RHS) ) 

#define ILine_get_ArrowHeadWidth(This,RHS)	\
    ( (This)->lpVtbl -> get_ArrowHeadWidth(This,RHS) ) 

#define ILine_put_ArrowHeadWidth(This,RHS)	\
    ( (This)->lpVtbl -> put_ArrowHeadWidth(This,RHS) ) 

#define ILine_get_Border(This,RHS)	\
    ( (This)->lpVtbl -> get_Border(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ILine_INTERFACE_DEFINED__ */


#ifndef __ILines_INTERFACE_DEFINED__
#define __ILines_INTERFACE_DEFINED__

/* interface ILines */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ILines;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002089B-0001-0000-C000-000000000046")
    ILines : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy3( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall BringToFront( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Copy( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CopyPicture( 
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Cut( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Duplicate( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Enabled( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Enabled( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Height( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Height( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy12( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Left( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Left( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Locked( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Locked( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy15( void) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_OnAction( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_OnAction( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Placement( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Placement( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PrintObject( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PrintObject( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SendToBack( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Top( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Top( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy22( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Visible( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Visible( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Width( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Width( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ZOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShapeRange( 
            /* [retval][out] */ ShapeRange	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ArrowHeadLength( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ArrowHeadLength( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ArrowHeadStyle( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ArrowHeadStyle( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ArrowHeadWidth( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ArrowHeadWidth( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Border( 
            /* [retval][out] */ Border	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add( 
            /* [in] */ double X1,
            /* [in] */ double Y1,
            /* [in] */ double X2,
            /* [in] */ double Y2,
            /* [retval][out] */ Line	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Group( 
            /* [retval][out] */ GroupObject	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall _NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ILinesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ILines * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ILines * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ILines * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ILines * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ILines * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ILines * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ILines * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ILines * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ILines * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ILines * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy3 )( 
            ILines * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *BringToFront )( 
            ILines * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Copy )( 
            ILines * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CopyPicture )( 
            ILines * This,
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Cut )( 
            ILines * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            ILines * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Duplicate )( 
            ILines * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Enabled )( 
            ILines * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Enabled )( 
            ILines * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Height )( 
            ILines * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Height )( 
            ILines * This,
            /* [in] */ double RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy12 )( 
            ILines * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Left )( 
            ILines * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Left )( 
            ILines * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Locked )( 
            ILines * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Locked )( 
            ILines * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy15 )( 
            ILines * This);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_OnAction )( 
            ILines * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_OnAction )( 
            ILines * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Placement )( 
            ILines * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Placement )( 
            ILines * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PrintObject )( 
            ILines * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PrintObject )( 
            ILines * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            ILines * This,
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SendToBack )( 
            ILines * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Top )( 
            ILines * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Top )( 
            ILines * This,
            /* [in] */ double RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy22 )( 
            ILines * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Visible )( 
            ILines * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Visible )( 
            ILines * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Width )( 
            ILines * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Width )( 
            ILines * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ZOrder )( 
            ILines * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShapeRange )( 
            ILines * This,
            /* [retval][out] */ ShapeRange	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ArrowHeadLength )( 
            ILines * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ArrowHeadLength )( 
            ILines * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ArrowHeadStyle )( 
            ILines * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ArrowHeadStyle )( 
            ILines * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ArrowHeadWidth )( 
            ILines * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ArrowHeadWidth )( 
            ILines * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Border )( 
            ILines * This,
            /* [retval][out] */ Border	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add )( 
            ILines * This,
            /* [in] */ double X1,
            /* [in] */ double Y1,
            /* [in] */ double X2,
            /* [in] */ double Y2,
            /* [retval][out] */ Line	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            ILines * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Group )( 
            ILines * This,
            /* [retval][out] */ GroupObject	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Item )( 
            ILines * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *_NewEnum )( 
            ILines * This,
            /* [retval][out] */ IUnknown **RHS);
        
        END_INTERFACE
    } ILinesVtbl;

    interface ILines
    {
        CONST_VTBL struct ILinesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ILines_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ILines_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ILines_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ILines_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ILines_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ILines_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ILines_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ILines_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ILines_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ILines_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ILines__Dummy3(This)	\
    ( (This)->lpVtbl -> _Dummy3(This) ) 

#define ILines_BringToFront(This,RHS)	\
    ( (This)->lpVtbl -> BringToFront(This,RHS) ) 

#define ILines_Copy(This,RHS)	\
    ( (This)->lpVtbl -> Copy(This,RHS) ) 

#define ILines_CopyPicture(This,Appearance,Format,RHS)	\
    ( (This)->lpVtbl -> CopyPicture(This,Appearance,Format,RHS) ) 

#define ILines_Cut(This,RHS)	\
    ( (This)->lpVtbl -> Cut(This,RHS) ) 

#define ILines_Delete(This,RHS)	\
    ( (This)->lpVtbl -> Delete(This,RHS) ) 

#define ILines_Duplicate(This,RHS)	\
    ( (This)->lpVtbl -> Duplicate(This,RHS) ) 

#define ILines_get_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> get_Enabled(This,RHS) ) 

#define ILines_put_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> put_Enabled(This,RHS) ) 

#define ILines_get_Height(This,RHS)	\
    ( (This)->lpVtbl -> get_Height(This,RHS) ) 

#define ILines_put_Height(This,RHS)	\
    ( (This)->lpVtbl -> put_Height(This,RHS) ) 

#define ILines__Dummy12(This)	\
    ( (This)->lpVtbl -> _Dummy12(This) ) 

#define ILines_get_Left(This,RHS)	\
    ( (This)->lpVtbl -> get_Left(This,RHS) ) 

#define ILines_put_Left(This,RHS)	\
    ( (This)->lpVtbl -> put_Left(This,RHS) ) 

#define ILines_get_Locked(This,RHS)	\
    ( (This)->lpVtbl -> get_Locked(This,RHS) ) 

#define ILines_put_Locked(This,RHS)	\
    ( (This)->lpVtbl -> put_Locked(This,RHS) ) 

#define ILines__Dummy15(This)	\
    ( (This)->lpVtbl -> _Dummy15(This) ) 

#define ILines_get_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> get_OnAction(This,RHS) ) 

#define ILines_put_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> put_OnAction(This,RHS) ) 

#define ILines_get_Placement(This,RHS)	\
    ( (This)->lpVtbl -> get_Placement(This,RHS) ) 

#define ILines_put_Placement(This,RHS)	\
    ( (This)->lpVtbl -> put_Placement(This,RHS) ) 

#define ILines_get_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> get_PrintObject(This,RHS) ) 

#define ILines_put_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> put_PrintObject(This,RHS) ) 

#define ILines_Select(This,Replace,RHS)	\
    ( (This)->lpVtbl -> Select(This,Replace,RHS) ) 

#define ILines_SendToBack(This,RHS)	\
    ( (This)->lpVtbl -> SendToBack(This,RHS) ) 

#define ILines_get_Top(This,RHS)	\
    ( (This)->lpVtbl -> get_Top(This,RHS) ) 

#define ILines_put_Top(This,RHS)	\
    ( (This)->lpVtbl -> put_Top(This,RHS) ) 

#define ILines__Dummy22(This)	\
    ( (This)->lpVtbl -> _Dummy22(This) ) 

#define ILines_get_Visible(This,RHS)	\
    ( (This)->lpVtbl -> get_Visible(This,RHS) ) 

#define ILines_put_Visible(This,RHS)	\
    ( (This)->lpVtbl -> put_Visible(This,RHS) ) 

#define ILines_get_Width(This,RHS)	\
    ( (This)->lpVtbl -> get_Width(This,RHS) ) 

#define ILines_put_Width(This,RHS)	\
    ( (This)->lpVtbl -> put_Width(This,RHS) ) 

#define ILines_get_ZOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_ZOrder(This,RHS) ) 

#define ILines_get_ShapeRange(This,RHS)	\
    ( (This)->lpVtbl -> get_ShapeRange(This,RHS) ) 

#define ILines_get_ArrowHeadLength(This,RHS)	\
    ( (This)->lpVtbl -> get_ArrowHeadLength(This,RHS) ) 

#define ILines_put_ArrowHeadLength(This,RHS)	\
    ( (This)->lpVtbl -> put_ArrowHeadLength(This,RHS) ) 

#define ILines_get_ArrowHeadStyle(This,RHS)	\
    ( (This)->lpVtbl -> get_ArrowHeadStyle(This,RHS) ) 

#define ILines_put_ArrowHeadStyle(This,RHS)	\
    ( (This)->lpVtbl -> put_ArrowHeadStyle(This,RHS) ) 

#define ILines_get_ArrowHeadWidth(This,RHS)	\
    ( (This)->lpVtbl -> get_ArrowHeadWidth(This,RHS) ) 

#define ILines_put_ArrowHeadWidth(This,RHS)	\
    ( (This)->lpVtbl -> put_ArrowHeadWidth(This,RHS) ) 

#define ILines_get_Border(This,RHS)	\
    ( (This)->lpVtbl -> get_Border(This,RHS) ) 

#define ILines_Add(This,X1,Y1,X2,Y2,RHS)	\
    ( (This)->lpVtbl -> Add(This,X1,Y1,X2,Y2,RHS) ) 

#define ILines_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define ILines_Group(This,RHS)	\
    ( (This)->lpVtbl -> Group(This,RHS) ) 

#define ILines_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> Item(This,Index,RHS) ) 

#define ILines__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> _NewEnum(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ILines_INTERFACE_DEFINED__ */


#ifndef __IRectangle_INTERFACE_DEFINED__
#define __IRectangle_INTERFACE_DEFINED__

/* interface IRectangle */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IRectangle;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002089C-0001-0000-C000-000000000046")
    IRectangle : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_BottomRightCell( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall BringToFront( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Copy( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CopyPicture( 
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Cut( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Duplicate( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Enabled( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Enabled( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Height( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Height( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Index( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Left( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Left( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Locked( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Locked( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Name( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_OnAction( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_OnAction( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Placement( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Placement( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PrintObject( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PrintObject( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SendToBack( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Top( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Top( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TopLeftCell( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Visible( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Visible( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Width( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Width( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ZOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShapeRange( 
            /* [retval][out] */ ShapeRange	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AddIndent( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AddIndent( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AutoScaleFont( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AutoScaleFont( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AutoSize( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AutoSize( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Caption( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Caption( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Characters( 
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Length,
            /* [retval][out] */ Characters	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CheckSpelling( 
            /* [optional][in] */ VARIANT CustomDictionary,
            /* [optional][in] */ VARIANT IgnoreUppercase,
            /* [optional][in] */ VARIANT AlwaysSuggest,
            /* [optional][in] */ VARIANT SpellLang,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Font( 
            /* [retval][out] */ Font	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Formula( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Formula( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HorizontalAlignment( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_HorizontalAlignment( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LockedText( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_LockedText( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Orientation( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Orientation( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Text( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Text( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_VerticalAlignment( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_VerticalAlignment( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ReadingOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ReadingOrder( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Border( 
            /* [retval][out] */ Border	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Interior( 
            /* [retval][out] */ Interior	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Shadow( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Shadow( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RoundedCorners( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_RoundedCorners( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IRectangleVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IRectangle * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IRectangle * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IRectangle * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IRectangle * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IRectangle * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IRectangle * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IRectangle * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IRectangle * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IRectangle * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IRectangle * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_BottomRightCell )( 
            IRectangle * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *BringToFront )( 
            IRectangle * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Copy )( 
            IRectangle * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CopyPicture )( 
            IRectangle * This,
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Cut )( 
            IRectangle * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IRectangle * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Duplicate )( 
            IRectangle * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Enabled )( 
            IRectangle * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Enabled )( 
            IRectangle * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Height )( 
            IRectangle * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Height )( 
            IRectangle * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Index )( 
            IRectangle * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Left )( 
            IRectangle * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Left )( 
            IRectangle * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Locked )( 
            IRectangle * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Locked )( 
            IRectangle * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            IRectangle * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Name )( 
            IRectangle * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_OnAction )( 
            IRectangle * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_OnAction )( 
            IRectangle * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Placement )( 
            IRectangle * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Placement )( 
            IRectangle * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PrintObject )( 
            IRectangle * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PrintObject )( 
            IRectangle * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            IRectangle * This,
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SendToBack )( 
            IRectangle * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Top )( 
            IRectangle * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Top )( 
            IRectangle * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TopLeftCell )( 
            IRectangle * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Visible )( 
            IRectangle * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Visible )( 
            IRectangle * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Width )( 
            IRectangle * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Width )( 
            IRectangle * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ZOrder )( 
            IRectangle * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShapeRange )( 
            IRectangle * This,
            /* [retval][out] */ ShapeRange	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AddIndent )( 
            IRectangle * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AddIndent )( 
            IRectangle * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AutoScaleFont )( 
            IRectangle * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AutoScaleFont )( 
            IRectangle * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AutoSize )( 
            IRectangle * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AutoSize )( 
            IRectangle * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Caption )( 
            IRectangle * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Caption )( 
            IRectangle * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Characters )( 
            IRectangle * This,
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Length,
            /* [retval][out] */ Characters	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CheckSpelling )( 
            IRectangle * This,
            /* [optional][in] */ VARIANT CustomDictionary,
            /* [optional][in] */ VARIANT IgnoreUppercase,
            /* [optional][in] */ VARIANT AlwaysSuggest,
            /* [optional][in] */ VARIANT SpellLang,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Font )( 
            IRectangle * This,
            /* [retval][out] */ Font	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Formula )( 
            IRectangle * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Formula )( 
            IRectangle * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HorizontalAlignment )( 
            IRectangle * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_HorizontalAlignment )( 
            IRectangle * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LockedText )( 
            IRectangle * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_LockedText )( 
            IRectangle * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Orientation )( 
            IRectangle * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Orientation )( 
            IRectangle * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Text )( 
            IRectangle * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Text )( 
            IRectangle * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_VerticalAlignment )( 
            IRectangle * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_VerticalAlignment )( 
            IRectangle * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ReadingOrder )( 
            IRectangle * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ReadingOrder )( 
            IRectangle * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Border )( 
            IRectangle * This,
            /* [retval][out] */ Border	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Interior )( 
            IRectangle * This,
            /* [retval][out] */ Interior	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Shadow )( 
            IRectangle * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Shadow )( 
            IRectangle * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RoundedCorners )( 
            IRectangle * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_RoundedCorners )( 
            IRectangle * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        END_INTERFACE
    } IRectangleVtbl;

    interface IRectangle
    {
        CONST_VTBL struct IRectangleVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IRectangle_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IRectangle_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IRectangle_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IRectangle_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IRectangle_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IRectangle_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IRectangle_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IRectangle_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IRectangle_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IRectangle_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IRectangle_get_BottomRightCell(This,RHS)	\
    ( (This)->lpVtbl -> get_BottomRightCell(This,RHS) ) 

#define IRectangle_BringToFront(This,RHS)	\
    ( (This)->lpVtbl -> BringToFront(This,RHS) ) 

#define IRectangle_Copy(This,RHS)	\
    ( (This)->lpVtbl -> Copy(This,RHS) ) 

#define IRectangle_CopyPicture(This,Appearance,Format,RHS)	\
    ( (This)->lpVtbl -> CopyPicture(This,Appearance,Format,RHS) ) 

#define IRectangle_Cut(This,RHS)	\
    ( (This)->lpVtbl -> Cut(This,RHS) ) 

#define IRectangle_Delete(This,RHS)	\
    ( (This)->lpVtbl -> Delete(This,RHS) ) 

#define IRectangle_Duplicate(This,RHS)	\
    ( (This)->lpVtbl -> Duplicate(This,RHS) ) 

#define IRectangle_get_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> get_Enabled(This,RHS) ) 

#define IRectangle_put_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> put_Enabled(This,RHS) ) 

#define IRectangle_get_Height(This,RHS)	\
    ( (This)->lpVtbl -> get_Height(This,RHS) ) 

#define IRectangle_put_Height(This,RHS)	\
    ( (This)->lpVtbl -> put_Height(This,RHS) ) 

#define IRectangle_get_Index(This,RHS)	\
    ( (This)->lpVtbl -> get_Index(This,RHS) ) 

#define IRectangle_get_Left(This,RHS)	\
    ( (This)->lpVtbl -> get_Left(This,RHS) ) 

#define IRectangle_put_Left(This,RHS)	\
    ( (This)->lpVtbl -> put_Left(This,RHS) ) 

#define IRectangle_get_Locked(This,RHS)	\
    ( (This)->lpVtbl -> get_Locked(This,RHS) ) 

#define IRectangle_put_Locked(This,RHS)	\
    ( (This)->lpVtbl -> put_Locked(This,RHS) ) 

#define IRectangle_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define IRectangle_put_Name(This,RHS)	\
    ( (This)->lpVtbl -> put_Name(This,RHS) ) 

#define IRectangle_get_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> get_OnAction(This,RHS) ) 

#define IRectangle_put_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> put_OnAction(This,RHS) ) 

#define IRectangle_get_Placement(This,RHS)	\
    ( (This)->lpVtbl -> get_Placement(This,RHS) ) 

#define IRectangle_put_Placement(This,RHS)	\
    ( (This)->lpVtbl -> put_Placement(This,RHS) ) 

#define IRectangle_get_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> get_PrintObject(This,RHS) ) 

#define IRectangle_put_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> put_PrintObject(This,RHS) ) 

#define IRectangle_Select(This,Replace,RHS)	\
    ( (This)->lpVtbl -> Select(This,Replace,RHS) ) 

#define IRectangle_SendToBack(This,RHS)	\
    ( (This)->lpVtbl -> SendToBack(This,RHS) ) 

#define IRectangle_get_Top(This,RHS)	\
    ( (This)->lpVtbl -> get_Top(This,RHS) ) 

#define IRectangle_put_Top(This,RHS)	\
    ( (This)->lpVtbl -> put_Top(This,RHS) ) 

#define IRectangle_get_TopLeftCell(This,RHS)	\
    ( (This)->lpVtbl -> get_TopLeftCell(This,RHS) ) 

#define IRectangle_get_Visible(This,RHS)	\
    ( (This)->lpVtbl -> get_Visible(This,RHS) ) 

#define IRectangle_put_Visible(This,RHS)	\
    ( (This)->lpVtbl -> put_Visible(This,RHS) ) 

#define IRectangle_get_Width(This,RHS)	\
    ( (This)->lpVtbl -> get_Width(This,RHS) ) 

#define IRectangle_put_Width(This,RHS)	\
    ( (This)->lpVtbl -> put_Width(This,RHS) ) 

#define IRectangle_get_ZOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_ZOrder(This,RHS) ) 

#define IRectangle_get_ShapeRange(This,RHS)	\
    ( (This)->lpVtbl -> get_ShapeRange(This,RHS) ) 

#define IRectangle_get_AddIndent(This,RHS)	\
    ( (This)->lpVtbl -> get_AddIndent(This,RHS) ) 

#define IRectangle_put_AddIndent(This,RHS)	\
    ( (This)->lpVtbl -> put_AddIndent(This,RHS) ) 

#define IRectangle_get_AutoScaleFont(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoScaleFont(This,RHS) ) 

#define IRectangle_put_AutoScaleFont(This,RHS)	\
    ( (This)->lpVtbl -> put_AutoScaleFont(This,RHS) ) 

#define IRectangle_get_AutoSize(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoSize(This,RHS) ) 

#define IRectangle_put_AutoSize(This,RHS)	\
    ( (This)->lpVtbl -> put_AutoSize(This,RHS) ) 

#define IRectangle_get_Caption(This,RHS)	\
    ( (This)->lpVtbl -> get_Caption(This,RHS) ) 

#define IRectangle_put_Caption(This,RHS)	\
    ( (This)->lpVtbl -> put_Caption(This,RHS) ) 

#define IRectangle_get_Characters(This,Start,Length,RHS)	\
    ( (This)->lpVtbl -> get_Characters(This,Start,Length,RHS) ) 

#define IRectangle_CheckSpelling(This,CustomDictionary,IgnoreUppercase,AlwaysSuggest,SpellLang,RHS)	\
    ( (This)->lpVtbl -> CheckSpelling(This,CustomDictionary,IgnoreUppercase,AlwaysSuggest,SpellLang,RHS) ) 

#define IRectangle_get_Font(This,RHS)	\
    ( (This)->lpVtbl -> get_Font(This,RHS) ) 

#define IRectangle_get_Formula(This,RHS)	\
    ( (This)->lpVtbl -> get_Formula(This,RHS) ) 

#define IRectangle_put_Formula(This,RHS)	\
    ( (This)->lpVtbl -> put_Formula(This,RHS) ) 

#define IRectangle_get_HorizontalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> get_HorizontalAlignment(This,RHS) ) 

#define IRectangle_put_HorizontalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> put_HorizontalAlignment(This,RHS) ) 

#define IRectangle_get_LockedText(This,RHS)	\
    ( (This)->lpVtbl -> get_LockedText(This,RHS) ) 

#define IRectangle_put_LockedText(This,RHS)	\
    ( (This)->lpVtbl -> put_LockedText(This,RHS) ) 

#define IRectangle_get_Orientation(This,RHS)	\
    ( (This)->lpVtbl -> get_Orientation(This,RHS) ) 

#define IRectangle_put_Orientation(This,RHS)	\
    ( (This)->lpVtbl -> put_Orientation(This,RHS) ) 

#define IRectangle_get_Text(This,RHS)	\
    ( (This)->lpVtbl -> get_Text(This,RHS) ) 

#define IRectangle_put_Text(This,RHS)	\
    ( (This)->lpVtbl -> put_Text(This,RHS) ) 

#define IRectangle_get_VerticalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> get_VerticalAlignment(This,RHS) ) 

#define IRectangle_put_VerticalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> put_VerticalAlignment(This,RHS) ) 

#define IRectangle_get_ReadingOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_ReadingOrder(This,RHS) ) 

#define IRectangle_put_ReadingOrder(This,RHS)	\
    ( (This)->lpVtbl -> put_ReadingOrder(This,RHS) ) 

#define IRectangle_get_Border(This,RHS)	\
    ( (This)->lpVtbl -> get_Border(This,RHS) ) 

#define IRectangle_get_Interior(This,RHS)	\
    ( (This)->lpVtbl -> get_Interior(This,RHS) ) 

#define IRectangle_get_Shadow(This,RHS)	\
    ( (This)->lpVtbl -> get_Shadow(This,RHS) ) 

#define IRectangle_put_Shadow(This,RHS)	\
    ( (This)->lpVtbl -> put_Shadow(This,RHS) ) 

#define IRectangle_get_RoundedCorners(This,RHS)	\
    ( (This)->lpVtbl -> get_RoundedCorners(This,RHS) ) 

#define IRectangle_put_RoundedCorners(This,RHS)	\
    ( (This)->lpVtbl -> put_RoundedCorners(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IRectangle_INTERFACE_DEFINED__ */


#ifndef __IRectangles_INTERFACE_DEFINED__
#define __IRectangles_INTERFACE_DEFINED__

/* interface IRectangles */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IRectangles;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002089D-0001-0000-C000-000000000046")
    IRectangles : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy3( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall BringToFront( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Copy( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CopyPicture( 
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Cut( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Duplicate( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Enabled( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Enabled( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Height( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Height( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy12( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Left( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Left( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Locked( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Locked( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy15( void) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_OnAction( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_OnAction( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Placement( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Placement( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PrintObject( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PrintObject( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SendToBack( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Top( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Top( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy22( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Visible( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Visible( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Width( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Width( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ZOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShapeRange( 
            /* [retval][out] */ ShapeRange	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AddIndent( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AddIndent( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AutoScaleFont( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AutoScaleFont( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AutoSize( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AutoSize( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Caption( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Caption( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Characters( 
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Length,
            /* [retval][out] */ Characters	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CheckSpelling( 
            /* [optional][in] */ VARIANT CustomDictionary,
            /* [optional][in] */ VARIANT IgnoreUppercase,
            /* [optional][in] */ VARIANT AlwaysSuggest,
            /* [optional][in] */ VARIANT SpellLang,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Font( 
            /* [retval][out] */ Font	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Formula( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Formula( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HorizontalAlignment( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_HorizontalAlignment( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LockedText( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_LockedText( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Orientation( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Orientation( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Text( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Text( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_VerticalAlignment( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_VerticalAlignment( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ReadingOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ReadingOrder( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Border( 
            /* [retval][out] */ Border	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Interior( 
            /* [retval][out] */ Interior	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Shadow( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Shadow( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RoundedCorners( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_RoundedCorners( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add( 
            /* [in] */ double Left,
            /* [in] */ double Top,
            /* [in] */ double Width,
            /* [in] */ double Height,
            /* [retval][out] */ Rectangle	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Group( 
            /* [retval][out] */ GroupObject	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall _NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IRectanglesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IRectangles * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IRectangles * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IRectangles * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IRectangles * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IRectangles * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IRectangles * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IRectangles * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IRectangles * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IRectangles * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IRectangles * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy3 )( 
            IRectangles * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *BringToFront )( 
            IRectangles * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Copy )( 
            IRectangles * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CopyPicture )( 
            IRectangles * This,
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Cut )( 
            IRectangles * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IRectangles * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Duplicate )( 
            IRectangles * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Enabled )( 
            IRectangles * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Enabled )( 
            IRectangles * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Height )( 
            IRectangles * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Height )( 
            IRectangles * This,
            /* [in] */ double RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy12 )( 
            IRectangles * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Left )( 
            IRectangles * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Left )( 
            IRectangles * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Locked )( 
            IRectangles * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Locked )( 
            IRectangles * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy15 )( 
            IRectangles * This);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_OnAction )( 
            IRectangles * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_OnAction )( 
            IRectangles * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Placement )( 
            IRectangles * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Placement )( 
            IRectangles * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PrintObject )( 
            IRectangles * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PrintObject )( 
            IRectangles * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            IRectangles * This,
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SendToBack )( 
            IRectangles * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Top )( 
            IRectangles * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Top )( 
            IRectangles * This,
            /* [in] */ double RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy22 )( 
            IRectangles * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Visible )( 
            IRectangles * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Visible )( 
            IRectangles * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Width )( 
            IRectangles * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Width )( 
            IRectangles * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ZOrder )( 
            IRectangles * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShapeRange )( 
            IRectangles * This,
            /* [retval][out] */ ShapeRange	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AddIndent )( 
            IRectangles * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AddIndent )( 
            IRectangles * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AutoScaleFont )( 
            IRectangles * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AutoScaleFont )( 
            IRectangles * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AutoSize )( 
            IRectangles * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AutoSize )( 
            IRectangles * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Caption )( 
            IRectangles * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Caption )( 
            IRectangles * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Characters )( 
            IRectangles * This,
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Length,
            /* [retval][out] */ Characters	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CheckSpelling )( 
            IRectangles * This,
            /* [optional][in] */ VARIANT CustomDictionary,
            /* [optional][in] */ VARIANT IgnoreUppercase,
            /* [optional][in] */ VARIANT AlwaysSuggest,
            /* [optional][in] */ VARIANT SpellLang,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Font )( 
            IRectangles * This,
            /* [retval][out] */ Font	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Formula )( 
            IRectangles * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Formula )( 
            IRectangles * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HorizontalAlignment )( 
            IRectangles * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_HorizontalAlignment )( 
            IRectangles * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LockedText )( 
            IRectangles * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_LockedText )( 
            IRectangles * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Orientation )( 
            IRectangles * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Orientation )( 
            IRectangles * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Text )( 
            IRectangles * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Text )( 
            IRectangles * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_VerticalAlignment )( 
            IRectangles * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_VerticalAlignment )( 
            IRectangles * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ReadingOrder )( 
            IRectangles * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ReadingOrder )( 
            IRectangles * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Border )( 
            IRectangles * This,
            /* [retval][out] */ Border	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Interior )( 
            IRectangles * This,
            /* [retval][out] */ Interior	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Shadow )( 
            IRectangles * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Shadow )( 
            IRectangles * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RoundedCorners )( 
            IRectangles * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_RoundedCorners )( 
            IRectangles * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add )( 
            IRectangles * This,
            /* [in] */ double Left,
            /* [in] */ double Top,
            /* [in] */ double Width,
            /* [in] */ double Height,
            /* [retval][out] */ Rectangle	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IRectangles * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Group )( 
            IRectangles * This,
            /* [retval][out] */ GroupObject	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Item )( 
            IRectangles * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *_NewEnum )( 
            IRectangles * This,
            /* [retval][out] */ IUnknown **RHS);
        
        END_INTERFACE
    } IRectanglesVtbl;

    interface IRectangles
    {
        CONST_VTBL struct IRectanglesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IRectangles_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IRectangles_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IRectangles_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IRectangles_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IRectangles_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IRectangles_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IRectangles_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IRectangles_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IRectangles_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IRectangles_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IRectangles__Dummy3(This)	\
    ( (This)->lpVtbl -> _Dummy3(This) ) 

#define IRectangles_BringToFront(This,RHS)	\
    ( (This)->lpVtbl -> BringToFront(This,RHS) ) 

#define IRectangles_Copy(This,RHS)	\
    ( (This)->lpVtbl -> Copy(This,RHS) ) 

#define IRectangles_CopyPicture(This,Appearance,Format,RHS)	\
    ( (This)->lpVtbl -> CopyPicture(This,Appearance,Format,RHS) ) 

#define IRectangles_Cut(This,RHS)	\
    ( (This)->lpVtbl -> Cut(This,RHS) ) 

#define IRectangles_Delete(This,RHS)	\
    ( (This)->lpVtbl -> Delete(This,RHS) ) 

#define IRectangles_Duplicate(This,RHS)	\
    ( (This)->lpVtbl -> Duplicate(This,RHS) ) 

#define IRectangles_get_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> get_Enabled(This,RHS) ) 

#define IRectangles_put_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> put_Enabled(This,RHS) ) 

#define IRectangles_get_Height(This,RHS)	\
    ( (This)->lpVtbl -> get_Height(This,RHS) ) 

#define IRectangles_put_Height(This,RHS)	\
    ( (This)->lpVtbl -> put_Height(This,RHS) ) 

#define IRectangles__Dummy12(This)	\
    ( (This)->lpVtbl -> _Dummy12(This) ) 

#define IRectangles_get_Left(This,RHS)	\
    ( (This)->lpVtbl -> get_Left(This,RHS) ) 

#define IRectangles_put_Left(This,RHS)	\
    ( (This)->lpVtbl -> put_Left(This,RHS) ) 

#define IRectangles_get_Locked(This,RHS)	\
    ( (This)->lpVtbl -> get_Locked(This,RHS) ) 

#define IRectangles_put_Locked(This,RHS)	\
    ( (This)->lpVtbl -> put_Locked(This,RHS) ) 

#define IRectangles__Dummy15(This)	\
    ( (This)->lpVtbl -> _Dummy15(This) ) 

#define IRectangles_get_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> get_OnAction(This,RHS) ) 

#define IRectangles_put_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> put_OnAction(This,RHS) ) 

#define IRectangles_get_Placement(This,RHS)	\
    ( (This)->lpVtbl -> get_Placement(This,RHS) ) 

#define IRectangles_put_Placement(This,RHS)	\
    ( (This)->lpVtbl -> put_Placement(This,RHS) ) 

#define IRectangles_get_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> get_PrintObject(This,RHS) ) 

#define IRectangles_put_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> put_PrintObject(This,RHS) ) 

#define IRectangles_Select(This,Replace,RHS)	\
    ( (This)->lpVtbl -> Select(This,Replace,RHS) ) 

#define IRectangles_SendToBack(This,RHS)	\
    ( (This)->lpVtbl -> SendToBack(This,RHS) ) 

#define IRectangles_get_Top(This,RHS)	\
    ( (This)->lpVtbl -> get_Top(This,RHS) ) 

#define IRectangles_put_Top(This,RHS)	\
    ( (This)->lpVtbl -> put_Top(This,RHS) ) 

#define IRectangles__Dummy22(This)	\
    ( (This)->lpVtbl -> _Dummy22(This) ) 

#define IRectangles_get_Visible(This,RHS)	\
    ( (This)->lpVtbl -> get_Visible(This,RHS) ) 

#define IRectangles_put_Visible(This,RHS)	\
    ( (This)->lpVtbl -> put_Visible(This,RHS) ) 

#define IRectangles_get_Width(This,RHS)	\
    ( (This)->lpVtbl -> get_Width(This,RHS) ) 

#define IRectangles_put_Width(This,RHS)	\
    ( (This)->lpVtbl -> put_Width(This,RHS) ) 

#define IRectangles_get_ZOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_ZOrder(This,RHS) ) 

#define IRectangles_get_ShapeRange(This,RHS)	\
    ( (This)->lpVtbl -> get_ShapeRange(This,RHS) ) 

#define IRectangles_get_AddIndent(This,RHS)	\
    ( (This)->lpVtbl -> get_AddIndent(This,RHS) ) 

#define IRectangles_put_AddIndent(This,RHS)	\
    ( (This)->lpVtbl -> put_AddIndent(This,RHS) ) 

#define IRectangles_get_AutoScaleFont(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoScaleFont(This,RHS) ) 

#define IRectangles_put_AutoScaleFont(This,RHS)	\
    ( (This)->lpVtbl -> put_AutoScaleFont(This,RHS) ) 

#define IRectangles_get_AutoSize(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoSize(This,RHS) ) 

#define IRectangles_put_AutoSize(This,RHS)	\
    ( (This)->lpVtbl -> put_AutoSize(This,RHS) ) 

#define IRectangles_get_Caption(This,RHS)	\
    ( (This)->lpVtbl -> get_Caption(This,RHS) ) 

#define IRectangles_put_Caption(This,RHS)	\
    ( (This)->lpVtbl -> put_Caption(This,RHS) ) 

#define IRectangles_get_Characters(This,Start,Length,RHS)	\
    ( (This)->lpVtbl -> get_Characters(This,Start,Length,RHS) ) 

#define IRectangles_CheckSpelling(This,CustomDictionary,IgnoreUppercase,AlwaysSuggest,SpellLang,RHS)	\
    ( (This)->lpVtbl -> CheckSpelling(This,CustomDictionary,IgnoreUppercase,AlwaysSuggest,SpellLang,RHS) ) 

#define IRectangles_get_Font(This,RHS)	\
    ( (This)->lpVtbl -> get_Font(This,RHS) ) 

#define IRectangles_get_Formula(This,RHS)	\
    ( (This)->lpVtbl -> get_Formula(This,RHS) ) 

#define IRectangles_put_Formula(This,RHS)	\
    ( (This)->lpVtbl -> put_Formula(This,RHS) ) 

#define IRectangles_get_HorizontalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> get_HorizontalAlignment(This,RHS) ) 

#define IRectangles_put_HorizontalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> put_HorizontalAlignment(This,RHS) ) 

#define IRectangles_get_LockedText(This,RHS)	\
    ( (This)->lpVtbl -> get_LockedText(This,RHS) ) 

#define IRectangles_put_LockedText(This,RHS)	\
    ( (This)->lpVtbl -> put_LockedText(This,RHS) ) 

#define IRectangles_get_Orientation(This,RHS)	\
    ( (This)->lpVtbl -> get_Orientation(This,RHS) ) 

#define IRectangles_put_Orientation(This,RHS)	\
    ( (This)->lpVtbl -> put_Orientation(This,RHS) ) 

#define IRectangles_get_Text(This,RHS)	\
    ( (This)->lpVtbl -> get_Text(This,RHS) ) 

#define IRectangles_put_Text(This,RHS)	\
    ( (This)->lpVtbl -> put_Text(This,RHS) ) 

#define IRectangles_get_VerticalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> get_VerticalAlignment(This,RHS) ) 

#define IRectangles_put_VerticalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> put_VerticalAlignment(This,RHS) ) 

#define IRectangles_get_ReadingOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_ReadingOrder(This,RHS) ) 

#define IRectangles_put_ReadingOrder(This,RHS)	\
    ( (This)->lpVtbl -> put_ReadingOrder(This,RHS) ) 

#define IRectangles_get_Border(This,RHS)	\
    ( (This)->lpVtbl -> get_Border(This,RHS) ) 

#define IRectangles_get_Interior(This,RHS)	\
    ( (This)->lpVtbl -> get_Interior(This,RHS) ) 

#define IRectangles_get_Shadow(This,RHS)	\
    ( (This)->lpVtbl -> get_Shadow(This,RHS) ) 

#define IRectangles_put_Shadow(This,RHS)	\
    ( (This)->lpVtbl -> put_Shadow(This,RHS) ) 

#define IRectangles_get_RoundedCorners(This,RHS)	\
    ( (This)->lpVtbl -> get_RoundedCorners(This,RHS) ) 

#define IRectangles_put_RoundedCorners(This,RHS)	\
    ( (This)->lpVtbl -> put_RoundedCorners(This,RHS) ) 

#define IRectangles_Add(This,Left,Top,Width,Height,RHS)	\
    ( (This)->lpVtbl -> Add(This,Left,Top,Width,Height,RHS) ) 

#define IRectangles_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IRectangles_Group(This,RHS)	\
    ( (This)->lpVtbl -> Group(This,RHS) ) 

#define IRectangles_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> Item(This,Index,RHS) ) 

#define IRectangles__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> _NewEnum(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IRectangles_INTERFACE_DEFINED__ */


#ifndef __IOval_INTERFACE_DEFINED__
#define __IOval_INTERFACE_DEFINED__

/* interface IOval */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IOval;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002089E-0001-0000-C000-000000000046")
    IOval : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_BottomRightCell( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall BringToFront( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Copy( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CopyPicture( 
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Cut( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Duplicate( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Enabled( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Enabled( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Height( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Height( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Index( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Left( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Left( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Locked( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Locked( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Name( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_OnAction( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_OnAction( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Placement( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Placement( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PrintObject( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PrintObject( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SendToBack( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Top( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Top( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TopLeftCell( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Visible( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Visible( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Width( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Width( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ZOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShapeRange( 
            /* [retval][out] */ ShapeRange	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AddIndent( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AddIndent( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AutoScaleFont( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AutoScaleFont( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AutoSize( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AutoSize( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Caption( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Caption( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Characters( 
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Length,
            /* [retval][out] */ Characters	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CheckSpelling( 
            /* [optional][in] */ VARIANT CustomDictionary,
            /* [optional][in] */ VARIANT IgnoreUppercase,
            /* [optional][in] */ VARIANT AlwaysSuggest,
            /* [optional][in] */ VARIANT SpellLang,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Font( 
            /* [retval][out] */ Font	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Formula( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Formula( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HorizontalAlignment( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_HorizontalAlignment( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LockedText( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_LockedText( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Orientation( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Orientation( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Text( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Text( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_VerticalAlignment( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_VerticalAlignment( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ReadingOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ReadingOrder( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Border( 
            /* [retval][out] */ Border	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Interior( 
            /* [retval][out] */ Interior	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Shadow( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Shadow( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IOvalVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IOval * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IOval * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IOval * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IOval * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IOval * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IOval * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IOval * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IOval * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IOval * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IOval * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_BottomRightCell )( 
            IOval * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *BringToFront )( 
            IOval * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Copy )( 
            IOval * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CopyPicture )( 
            IOval * This,
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Cut )( 
            IOval * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IOval * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Duplicate )( 
            IOval * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Enabled )( 
            IOval * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Enabled )( 
            IOval * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Height )( 
            IOval * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Height )( 
            IOval * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Index )( 
            IOval * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Left )( 
            IOval * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Left )( 
            IOval * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Locked )( 
            IOval * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Locked )( 
            IOval * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            IOval * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Name )( 
            IOval * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_OnAction )( 
            IOval * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_OnAction )( 
            IOval * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Placement )( 
            IOval * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Placement )( 
            IOval * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PrintObject )( 
            IOval * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PrintObject )( 
            IOval * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            IOval * This,
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SendToBack )( 
            IOval * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Top )( 
            IOval * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Top )( 
            IOval * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TopLeftCell )( 
            IOval * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Visible )( 
            IOval * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Visible )( 
            IOval * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Width )( 
            IOval * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Width )( 
            IOval * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ZOrder )( 
            IOval * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShapeRange )( 
            IOval * This,
            /* [retval][out] */ ShapeRange	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AddIndent )( 
            IOval * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AddIndent )( 
            IOval * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AutoScaleFont )( 
            IOval * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AutoScaleFont )( 
            IOval * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AutoSize )( 
            IOval * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AutoSize )( 
            IOval * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Caption )( 
            IOval * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Caption )( 
            IOval * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Characters )( 
            IOval * This,
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Length,
            /* [retval][out] */ Characters	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CheckSpelling )( 
            IOval * This,
            /* [optional][in] */ VARIANT CustomDictionary,
            /* [optional][in] */ VARIANT IgnoreUppercase,
            /* [optional][in] */ VARIANT AlwaysSuggest,
            /* [optional][in] */ VARIANT SpellLang,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Font )( 
            IOval * This,
            /* [retval][out] */ Font	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Formula )( 
            IOval * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Formula )( 
            IOval * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HorizontalAlignment )( 
            IOval * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_HorizontalAlignment )( 
            IOval * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LockedText )( 
            IOval * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_LockedText )( 
            IOval * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Orientation )( 
            IOval * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Orientation )( 
            IOval * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Text )( 
            IOval * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Text )( 
            IOval * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_VerticalAlignment )( 
            IOval * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_VerticalAlignment )( 
            IOval * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ReadingOrder )( 
            IOval * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ReadingOrder )( 
            IOval * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Border )( 
            IOval * This,
            /* [retval][out] */ Border	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Interior )( 
            IOval * This,
            /* [retval][out] */ Interior	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Shadow )( 
            IOval * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Shadow )( 
            IOval * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        END_INTERFACE
    } IOvalVtbl;

    interface IOval
    {
        CONST_VTBL struct IOvalVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IOval_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IOval_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IOval_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IOval_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IOval_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IOval_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IOval_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IOval_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IOval_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IOval_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IOval_get_BottomRightCell(This,RHS)	\
    ( (This)->lpVtbl -> get_BottomRightCell(This,RHS) ) 

#define IOval_BringToFront(This,RHS)	\
    ( (This)->lpVtbl -> BringToFront(This,RHS) ) 

#define IOval_Copy(This,RHS)	\
    ( (This)->lpVtbl -> Copy(This,RHS) ) 

#define IOval_CopyPicture(This,Appearance,Format,RHS)	\
    ( (This)->lpVtbl -> CopyPicture(This,Appearance,Format,RHS) ) 

#define IOval_Cut(This,RHS)	\
    ( (This)->lpVtbl -> Cut(This,RHS) ) 

#define IOval_Delete(This,RHS)	\
    ( (This)->lpVtbl -> Delete(This,RHS) ) 

#define IOval_Duplicate(This,RHS)	\
    ( (This)->lpVtbl -> Duplicate(This,RHS) ) 

#define IOval_get_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> get_Enabled(This,RHS) ) 

#define IOval_put_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> put_Enabled(This,RHS) ) 

#define IOval_get_Height(This,RHS)	\
    ( (This)->lpVtbl -> get_Height(This,RHS) ) 

#define IOval_put_Height(This,RHS)	\
    ( (This)->lpVtbl -> put_Height(This,RHS) ) 

#define IOval_get_Index(This,RHS)	\
    ( (This)->lpVtbl -> get_Index(This,RHS) ) 

#define IOval_get_Left(This,RHS)	\
    ( (This)->lpVtbl -> get_Left(This,RHS) ) 

#define IOval_put_Left(This,RHS)	\
    ( (This)->lpVtbl -> put_Left(This,RHS) ) 

#define IOval_get_Locked(This,RHS)	\
    ( (This)->lpVtbl -> get_Locked(This,RHS) ) 

#define IOval_put_Locked(This,RHS)	\
    ( (This)->lpVtbl -> put_Locked(This,RHS) ) 

#define IOval_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define IOval_put_Name(This,RHS)	\
    ( (This)->lpVtbl -> put_Name(This,RHS) ) 

#define IOval_get_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> get_OnAction(This,RHS) ) 

#define IOval_put_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> put_OnAction(This,RHS) ) 

#define IOval_get_Placement(This,RHS)	\
    ( (This)->lpVtbl -> get_Placement(This,RHS) ) 

#define IOval_put_Placement(This,RHS)	\
    ( (This)->lpVtbl -> put_Placement(This,RHS) ) 

#define IOval_get_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> get_PrintObject(This,RHS) ) 

#define IOval_put_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> put_PrintObject(This,RHS) ) 

#define IOval_Select(This,Replace,RHS)	\
    ( (This)->lpVtbl -> Select(This,Replace,RHS) ) 

#define IOval_SendToBack(This,RHS)	\
    ( (This)->lpVtbl -> SendToBack(This,RHS) ) 

#define IOval_get_Top(This,RHS)	\
    ( (This)->lpVtbl -> get_Top(This,RHS) ) 

#define IOval_put_Top(This,RHS)	\
    ( (This)->lpVtbl -> put_Top(This,RHS) ) 

#define IOval_get_TopLeftCell(This,RHS)	\
    ( (This)->lpVtbl -> get_TopLeftCell(This,RHS) ) 

#define IOval_get_Visible(This,RHS)	\
    ( (This)->lpVtbl -> get_Visible(This,RHS) ) 

#define IOval_put_Visible(This,RHS)	\
    ( (This)->lpVtbl -> put_Visible(This,RHS) ) 

#define IOval_get_Width(This,RHS)	\
    ( (This)->lpVtbl -> get_Width(This,RHS) ) 

#define IOval_put_Width(This,RHS)	\
    ( (This)->lpVtbl -> put_Width(This,RHS) ) 

#define IOval_get_ZOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_ZOrder(This,RHS) ) 

#define IOval_get_ShapeRange(This,RHS)	\
    ( (This)->lpVtbl -> get_ShapeRange(This,RHS) ) 

#define IOval_get_AddIndent(This,RHS)	\
    ( (This)->lpVtbl -> get_AddIndent(This,RHS) ) 

#define IOval_put_AddIndent(This,RHS)	\
    ( (This)->lpVtbl -> put_AddIndent(This,RHS) ) 

#define IOval_get_AutoScaleFont(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoScaleFont(This,RHS) ) 

#define IOval_put_AutoScaleFont(This,RHS)	\
    ( (This)->lpVtbl -> put_AutoScaleFont(This,RHS) ) 

#define IOval_get_AutoSize(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoSize(This,RHS) ) 

#define IOval_put_AutoSize(This,RHS)	\
    ( (This)->lpVtbl -> put_AutoSize(This,RHS) ) 

#define IOval_get_Caption(This,RHS)	\
    ( (This)->lpVtbl -> get_Caption(This,RHS) ) 

#define IOval_put_Caption(This,RHS)	\
    ( (This)->lpVtbl -> put_Caption(This,RHS) ) 

#define IOval_get_Characters(This,Start,Length,RHS)	\
    ( (This)->lpVtbl -> get_Characters(This,Start,Length,RHS) ) 

#define IOval_CheckSpelling(This,CustomDictionary,IgnoreUppercase,AlwaysSuggest,SpellLang,RHS)	\
    ( (This)->lpVtbl -> CheckSpelling(This,CustomDictionary,IgnoreUppercase,AlwaysSuggest,SpellLang,RHS) ) 

#define IOval_get_Font(This,RHS)	\
    ( (This)->lpVtbl -> get_Font(This,RHS) ) 

#define IOval_get_Formula(This,RHS)	\
    ( (This)->lpVtbl -> get_Formula(This,RHS) ) 

#define IOval_put_Formula(This,RHS)	\
    ( (This)->lpVtbl -> put_Formula(This,RHS) ) 

#define IOval_get_HorizontalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> get_HorizontalAlignment(This,RHS) ) 

#define IOval_put_HorizontalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> put_HorizontalAlignment(This,RHS) ) 

#define IOval_get_LockedText(This,RHS)	\
    ( (This)->lpVtbl -> get_LockedText(This,RHS) ) 

#define IOval_put_LockedText(This,RHS)	\
    ( (This)->lpVtbl -> put_LockedText(This,RHS) ) 

#define IOval_get_Orientation(This,RHS)	\
    ( (This)->lpVtbl -> get_Orientation(This,RHS) ) 

#define IOval_put_Orientation(This,RHS)	\
    ( (This)->lpVtbl -> put_Orientation(This,RHS) ) 

#define IOval_get_Text(This,RHS)	\
    ( (This)->lpVtbl -> get_Text(This,RHS) ) 

#define IOval_put_Text(This,RHS)	\
    ( (This)->lpVtbl -> put_Text(This,RHS) ) 

#define IOval_get_VerticalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> get_VerticalAlignment(This,RHS) ) 

#define IOval_put_VerticalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> put_VerticalAlignment(This,RHS) ) 

#define IOval_get_ReadingOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_ReadingOrder(This,RHS) ) 

#define IOval_put_ReadingOrder(This,RHS)	\
    ( (This)->lpVtbl -> put_ReadingOrder(This,RHS) ) 

#define IOval_get_Border(This,RHS)	\
    ( (This)->lpVtbl -> get_Border(This,RHS) ) 

#define IOval_get_Interior(This,RHS)	\
    ( (This)->lpVtbl -> get_Interior(This,RHS) ) 

#define IOval_get_Shadow(This,RHS)	\
    ( (This)->lpVtbl -> get_Shadow(This,RHS) ) 

#define IOval_put_Shadow(This,RHS)	\
    ( (This)->lpVtbl -> put_Shadow(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IOval_INTERFACE_DEFINED__ */


#ifndef __IOvals_INTERFACE_DEFINED__
#define __IOvals_INTERFACE_DEFINED__

/* interface IOvals */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IOvals;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002089F-0001-0000-C000-000000000046")
    IOvals : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy3( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall BringToFront( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Copy( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CopyPicture( 
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Cut( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Duplicate( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Enabled( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Enabled( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Height( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Height( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy12( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Left( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Left( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Locked( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Locked( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy15( void) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_OnAction( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_OnAction( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Placement( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Placement( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PrintObject( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PrintObject( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SendToBack( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Top( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Top( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy22( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Visible( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Visible( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Width( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Width( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ZOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShapeRange( 
            /* [retval][out] */ ShapeRange	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AddIndent( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AddIndent( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AutoScaleFont( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AutoScaleFont( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AutoSize( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AutoSize( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Caption( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Caption( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Characters( 
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Length,
            /* [retval][out] */ Characters	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CheckSpelling( 
            /* [optional][in] */ VARIANT CustomDictionary,
            /* [optional][in] */ VARIANT IgnoreUppercase,
            /* [optional][in] */ VARIANT AlwaysSuggest,
            /* [optional][in] */ VARIANT SpellLang,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Font( 
            /* [retval][out] */ Font	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Formula( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Formula( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HorizontalAlignment( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_HorizontalAlignment( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LockedText( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_LockedText( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Orientation( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Orientation( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Text( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Text( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_VerticalAlignment( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_VerticalAlignment( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ReadingOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ReadingOrder( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Border( 
            /* [retval][out] */ Border	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Interior( 
            /* [retval][out] */ Interior	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Shadow( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Shadow( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add( 
            /* [in] */ double Left,
            /* [in] */ double Top,
            /* [in] */ double Width,
            /* [in] */ double Height,
            /* [retval][out] */ Oval	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Group( 
            /* [retval][out] */ GroupObject	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall _NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IOvalsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IOvals * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IOvals * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IOvals * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IOvals * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IOvals * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IOvals * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IOvals * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IOvals * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IOvals * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IOvals * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy3 )( 
            IOvals * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *BringToFront )( 
            IOvals * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Copy )( 
            IOvals * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CopyPicture )( 
            IOvals * This,
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Cut )( 
            IOvals * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IOvals * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Duplicate )( 
            IOvals * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Enabled )( 
            IOvals * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Enabled )( 
            IOvals * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Height )( 
            IOvals * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Height )( 
            IOvals * This,
            /* [in] */ double RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy12 )( 
            IOvals * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Left )( 
            IOvals * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Left )( 
            IOvals * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Locked )( 
            IOvals * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Locked )( 
            IOvals * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy15 )( 
            IOvals * This);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_OnAction )( 
            IOvals * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_OnAction )( 
            IOvals * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Placement )( 
            IOvals * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Placement )( 
            IOvals * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PrintObject )( 
            IOvals * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PrintObject )( 
            IOvals * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            IOvals * This,
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SendToBack )( 
            IOvals * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Top )( 
            IOvals * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Top )( 
            IOvals * This,
            /* [in] */ double RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy22 )( 
            IOvals * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Visible )( 
            IOvals * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Visible )( 
            IOvals * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Width )( 
            IOvals * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Width )( 
            IOvals * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ZOrder )( 
            IOvals * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShapeRange )( 
            IOvals * This,
            /* [retval][out] */ ShapeRange	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AddIndent )( 
            IOvals * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AddIndent )( 
            IOvals * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AutoScaleFont )( 
            IOvals * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AutoScaleFont )( 
            IOvals * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AutoSize )( 
            IOvals * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AutoSize )( 
            IOvals * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Caption )( 
            IOvals * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Caption )( 
            IOvals * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Characters )( 
            IOvals * This,
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Length,
            /* [retval][out] */ Characters	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CheckSpelling )( 
            IOvals * This,
            /* [optional][in] */ VARIANT CustomDictionary,
            /* [optional][in] */ VARIANT IgnoreUppercase,
            /* [optional][in] */ VARIANT AlwaysSuggest,
            /* [optional][in] */ VARIANT SpellLang,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Font )( 
            IOvals * This,
            /* [retval][out] */ Font	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Formula )( 
            IOvals * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Formula )( 
            IOvals * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HorizontalAlignment )( 
            IOvals * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_HorizontalAlignment )( 
            IOvals * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LockedText )( 
            IOvals * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_LockedText )( 
            IOvals * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Orientation )( 
            IOvals * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Orientation )( 
            IOvals * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Text )( 
            IOvals * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Text )( 
            IOvals * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_VerticalAlignment )( 
            IOvals * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_VerticalAlignment )( 
            IOvals * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ReadingOrder )( 
            IOvals * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ReadingOrder )( 
            IOvals * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Border )( 
            IOvals * This,
            /* [retval][out] */ Border	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Interior )( 
            IOvals * This,
            /* [retval][out] */ Interior	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Shadow )( 
            IOvals * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Shadow )( 
            IOvals * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add )( 
            IOvals * This,
            /* [in] */ double Left,
            /* [in] */ double Top,
            /* [in] */ double Width,
            /* [in] */ double Height,
            /* [retval][out] */ Oval	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IOvals * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Group )( 
            IOvals * This,
            /* [retval][out] */ GroupObject	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Item )( 
            IOvals * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *_NewEnum )( 
            IOvals * This,
            /* [retval][out] */ IUnknown **RHS);
        
        END_INTERFACE
    } IOvalsVtbl;

    interface IOvals
    {
        CONST_VTBL struct IOvalsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IOvals_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IOvals_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IOvals_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IOvals_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IOvals_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IOvals_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IOvals_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IOvals_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IOvals_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IOvals_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IOvals__Dummy3(This)	\
    ( (This)->lpVtbl -> _Dummy3(This) ) 

#define IOvals_BringToFront(This,RHS)	\
    ( (This)->lpVtbl -> BringToFront(This,RHS) ) 

#define IOvals_Copy(This,RHS)	\
    ( (This)->lpVtbl -> Copy(This,RHS) ) 

#define IOvals_CopyPicture(This,Appearance,Format,RHS)	\
    ( (This)->lpVtbl -> CopyPicture(This,Appearance,Format,RHS) ) 

#define IOvals_Cut(This,RHS)	\
    ( (This)->lpVtbl -> Cut(This,RHS) ) 

#define IOvals_Delete(This,RHS)	\
    ( (This)->lpVtbl -> Delete(This,RHS) ) 

#define IOvals_Duplicate(This,RHS)	\
    ( (This)->lpVtbl -> Duplicate(This,RHS) ) 

#define IOvals_get_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> get_Enabled(This,RHS) ) 

#define IOvals_put_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> put_Enabled(This,RHS) ) 

#define IOvals_get_Height(This,RHS)	\
    ( (This)->lpVtbl -> get_Height(This,RHS) ) 

#define IOvals_put_Height(This,RHS)	\
    ( (This)->lpVtbl -> put_Height(This,RHS) ) 

#define IOvals__Dummy12(This)	\
    ( (This)->lpVtbl -> _Dummy12(This) ) 

#define IOvals_get_Left(This,RHS)	\
    ( (This)->lpVtbl -> get_Left(This,RHS) ) 

#define IOvals_put_Left(This,RHS)	\
    ( (This)->lpVtbl -> put_Left(This,RHS) ) 

#define IOvals_get_Locked(This,RHS)	\
    ( (This)->lpVtbl -> get_Locked(This,RHS) ) 

#define IOvals_put_Locked(This,RHS)	\
    ( (This)->lpVtbl -> put_Locked(This,RHS) ) 

#define IOvals__Dummy15(This)	\
    ( (This)->lpVtbl -> _Dummy15(This) ) 

#define IOvals_get_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> get_OnAction(This,RHS) ) 

#define IOvals_put_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> put_OnAction(This,RHS) ) 

#define IOvals_get_Placement(This,RHS)	\
    ( (This)->lpVtbl -> get_Placement(This,RHS) ) 

#define IOvals_put_Placement(This,RHS)	\
    ( (This)->lpVtbl -> put_Placement(This,RHS) ) 

#define IOvals_get_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> get_PrintObject(This,RHS) ) 

#define IOvals_put_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> put_PrintObject(This,RHS) ) 

#define IOvals_Select(This,Replace,RHS)	\
    ( (This)->lpVtbl -> Select(This,Replace,RHS) ) 

#define IOvals_SendToBack(This,RHS)	\
    ( (This)->lpVtbl -> SendToBack(This,RHS) ) 

#define IOvals_get_Top(This,RHS)	\
    ( (This)->lpVtbl -> get_Top(This,RHS) ) 

#define IOvals_put_Top(This,RHS)	\
    ( (This)->lpVtbl -> put_Top(This,RHS) ) 

#define IOvals__Dummy22(This)	\
    ( (This)->lpVtbl -> _Dummy22(This) ) 

#define IOvals_get_Visible(This,RHS)	\
    ( (This)->lpVtbl -> get_Visible(This,RHS) ) 

#define IOvals_put_Visible(This,RHS)	\
    ( (This)->lpVtbl -> put_Visible(This,RHS) ) 

#define IOvals_get_Width(This,RHS)	\
    ( (This)->lpVtbl -> get_Width(This,RHS) ) 

#define IOvals_put_Width(This,RHS)	\
    ( (This)->lpVtbl -> put_Width(This,RHS) ) 

#define IOvals_get_ZOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_ZOrder(This,RHS) ) 

#define IOvals_get_ShapeRange(This,RHS)	\
    ( (This)->lpVtbl -> get_ShapeRange(This,RHS) ) 

#define IOvals_get_AddIndent(This,RHS)	\
    ( (This)->lpVtbl -> get_AddIndent(This,RHS) ) 

#define IOvals_put_AddIndent(This,RHS)	\
    ( (This)->lpVtbl -> put_AddIndent(This,RHS) ) 

#define IOvals_get_AutoScaleFont(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoScaleFont(This,RHS) ) 

#define IOvals_put_AutoScaleFont(This,RHS)	\
    ( (This)->lpVtbl -> put_AutoScaleFont(This,RHS) ) 

#define IOvals_get_AutoSize(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoSize(This,RHS) ) 

#define IOvals_put_AutoSize(This,RHS)	\
    ( (This)->lpVtbl -> put_AutoSize(This,RHS) ) 

#define IOvals_get_Caption(This,RHS)	\
    ( (This)->lpVtbl -> get_Caption(This,RHS) ) 

#define IOvals_put_Caption(This,RHS)	\
    ( (This)->lpVtbl -> put_Caption(This,RHS) ) 

#define IOvals_get_Characters(This,Start,Length,RHS)	\
    ( (This)->lpVtbl -> get_Characters(This,Start,Length,RHS) ) 

#define IOvals_CheckSpelling(This,CustomDictionary,IgnoreUppercase,AlwaysSuggest,SpellLang,RHS)	\
    ( (This)->lpVtbl -> CheckSpelling(This,CustomDictionary,IgnoreUppercase,AlwaysSuggest,SpellLang,RHS) ) 

#define IOvals_get_Font(This,RHS)	\
    ( (This)->lpVtbl -> get_Font(This,RHS) ) 

#define IOvals_get_Formula(This,RHS)	\
    ( (This)->lpVtbl -> get_Formula(This,RHS) ) 

#define IOvals_put_Formula(This,RHS)	\
    ( (This)->lpVtbl -> put_Formula(This,RHS) ) 

#define IOvals_get_HorizontalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> get_HorizontalAlignment(This,RHS) ) 

#define IOvals_put_HorizontalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> put_HorizontalAlignment(This,RHS) ) 

#define IOvals_get_LockedText(This,RHS)	\
    ( (This)->lpVtbl -> get_LockedText(This,RHS) ) 

#define IOvals_put_LockedText(This,RHS)	\
    ( (This)->lpVtbl -> put_LockedText(This,RHS) ) 

#define IOvals_get_Orientation(This,RHS)	\
    ( (This)->lpVtbl -> get_Orientation(This,RHS) ) 

#define IOvals_put_Orientation(This,RHS)	\
    ( (This)->lpVtbl -> put_Orientation(This,RHS) ) 

#define IOvals_get_Text(This,RHS)	\
    ( (This)->lpVtbl -> get_Text(This,RHS) ) 

#define IOvals_put_Text(This,RHS)	\
    ( (This)->lpVtbl -> put_Text(This,RHS) ) 

#define IOvals_get_VerticalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> get_VerticalAlignment(This,RHS) ) 

#define IOvals_put_VerticalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> put_VerticalAlignment(This,RHS) ) 

#define IOvals_get_ReadingOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_ReadingOrder(This,RHS) ) 

#define IOvals_put_ReadingOrder(This,RHS)	\
    ( (This)->lpVtbl -> put_ReadingOrder(This,RHS) ) 

#define IOvals_get_Border(This,RHS)	\
    ( (This)->lpVtbl -> get_Border(This,RHS) ) 

#define IOvals_get_Interior(This,RHS)	\
    ( (This)->lpVtbl -> get_Interior(This,RHS) ) 

#define IOvals_get_Shadow(This,RHS)	\
    ( (This)->lpVtbl -> get_Shadow(This,RHS) ) 

#define IOvals_put_Shadow(This,RHS)	\
    ( (This)->lpVtbl -> put_Shadow(This,RHS) ) 

#define IOvals_Add(This,Left,Top,Width,Height,RHS)	\
    ( (This)->lpVtbl -> Add(This,Left,Top,Width,Height,RHS) ) 

#define IOvals_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IOvals_Group(This,RHS)	\
    ( (This)->lpVtbl -> Group(This,RHS) ) 

#define IOvals_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> Item(This,Index,RHS) ) 

#define IOvals__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> _NewEnum(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IOvals_INTERFACE_DEFINED__ */


#ifndef __IArc_INTERFACE_DEFINED__
#define __IArc_INTERFACE_DEFINED__

/* interface IArc */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IArc;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000208A0-0001-0000-C000-000000000046")
    IArc : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_BottomRightCell( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall BringToFront( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Copy( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CopyPicture( 
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Cut( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Duplicate( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Enabled( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Enabled( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Height( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Height( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Index( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Left( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Left( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Locked( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Locked( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Name( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_OnAction( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_OnAction( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Placement( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Placement( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PrintObject( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PrintObject( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SendToBack( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Top( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Top( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TopLeftCell( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Visible( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Visible( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Width( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Width( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ZOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShapeRange( 
            /* [retval][out] */ ShapeRange	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AddIndent( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AddIndent( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AutoScaleFont( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AutoScaleFont( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AutoSize( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AutoSize( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Caption( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Caption( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Characters( 
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Length,
            /* [retval][out] */ Characters	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CheckSpelling( 
            /* [optional][in] */ VARIANT CustomDictionary,
            /* [optional][in] */ VARIANT IgnoreUppercase,
            /* [optional][in] */ VARIANT AlwaysSuggest,
            /* [optional][in] */ VARIANT SpellLang,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Font( 
            /* [retval][out] */ Font	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Formula( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Formula( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HorizontalAlignment( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_HorizontalAlignment( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LockedText( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_LockedText( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Orientation( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Orientation( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Text( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Text( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_VerticalAlignment( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_VerticalAlignment( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ReadingOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ReadingOrder( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Border( 
            /* [retval][out] */ Border	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Interior( 
            /* [retval][out] */ Interior	**RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy43( void) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IArcVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IArc * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IArc * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IArc * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IArc * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IArc * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IArc * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IArc * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IArc * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IArc * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IArc * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_BottomRightCell )( 
            IArc * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *BringToFront )( 
            IArc * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Copy )( 
            IArc * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CopyPicture )( 
            IArc * This,
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Cut )( 
            IArc * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IArc * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Duplicate )( 
            IArc * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Enabled )( 
            IArc * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Enabled )( 
            IArc * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Height )( 
            IArc * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Height )( 
            IArc * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Index )( 
            IArc * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Left )( 
            IArc * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Left )( 
            IArc * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Locked )( 
            IArc * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Locked )( 
            IArc * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            IArc * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Name )( 
            IArc * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_OnAction )( 
            IArc * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_OnAction )( 
            IArc * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Placement )( 
            IArc * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Placement )( 
            IArc * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PrintObject )( 
            IArc * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PrintObject )( 
            IArc * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            IArc * This,
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SendToBack )( 
            IArc * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Top )( 
            IArc * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Top )( 
            IArc * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TopLeftCell )( 
            IArc * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Visible )( 
            IArc * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Visible )( 
            IArc * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Width )( 
            IArc * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Width )( 
            IArc * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ZOrder )( 
            IArc * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShapeRange )( 
            IArc * This,
            /* [retval][out] */ ShapeRange	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AddIndent )( 
            IArc * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AddIndent )( 
            IArc * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AutoScaleFont )( 
            IArc * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AutoScaleFont )( 
            IArc * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AutoSize )( 
            IArc * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AutoSize )( 
            IArc * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Caption )( 
            IArc * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Caption )( 
            IArc * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Characters )( 
            IArc * This,
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Length,
            /* [retval][out] */ Characters	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CheckSpelling )( 
            IArc * This,
            /* [optional][in] */ VARIANT CustomDictionary,
            /* [optional][in] */ VARIANT IgnoreUppercase,
            /* [optional][in] */ VARIANT AlwaysSuggest,
            /* [optional][in] */ VARIANT SpellLang,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Font )( 
            IArc * This,
            /* [retval][out] */ Font	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Formula )( 
            IArc * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Formula )( 
            IArc * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HorizontalAlignment )( 
            IArc * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_HorizontalAlignment )( 
            IArc * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LockedText )( 
            IArc * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_LockedText )( 
            IArc * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Orientation )( 
            IArc * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Orientation )( 
            IArc * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Text )( 
            IArc * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Text )( 
            IArc * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_VerticalAlignment )( 
            IArc * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_VerticalAlignment )( 
            IArc * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ReadingOrder )( 
            IArc * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ReadingOrder )( 
            IArc * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Border )( 
            IArc * This,
            /* [retval][out] */ Border	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Interior )( 
            IArc * This,
            /* [retval][out] */ Interior	**RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy43 )( 
            IArc * This);
        
        END_INTERFACE
    } IArcVtbl;

    interface IArc
    {
        CONST_VTBL struct IArcVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IArc_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IArc_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IArc_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IArc_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IArc_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IArc_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IArc_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IArc_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IArc_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IArc_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IArc_get_BottomRightCell(This,RHS)	\
    ( (This)->lpVtbl -> get_BottomRightCell(This,RHS) ) 

#define IArc_BringToFront(This,RHS)	\
    ( (This)->lpVtbl -> BringToFront(This,RHS) ) 

#define IArc_Copy(This,RHS)	\
    ( (This)->lpVtbl -> Copy(This,RHS) ) 

#define IArc_CopyPicture(This,Appearance,Format,RHS)	\
    ( (This)->lpVtbl -> CopyPicture(This,Appearance,Format,RHS) ) 

#define IArc_Cut(This,RHS)	\
    ( (This)->lpVtbl -> Cut(This,RHS) ) 

#define IArc_Delete(This,RHS)	\
    ( (This)->lpVtbl -> Delete(This,RHS) ) 

#define IArc_Duplicate(This,RHS)	\
    ( (This)->lpVtbl -> Duplicate(This,RHS) ) 

#define IArc_get_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> get_Enabled(This,RHS) ) 

#define IArc_put_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> put_Enabled(This,RHS) ) 

#define IArc_get_Height(This,RHS)	\
    ( (This)->lpVtbl -> get_Height(This,RHS) ) 

#define IArc_put_Height(This,RHS)	\
    ( (This)->lpVtbl -> put_Height(This,RHS) ) 

#define IArc_get_Index(This,RHS)	\
    ( (This)->lpVtbl -> get_Index(This,RHS) ) 

#define IArc_get_Left(This,RHS)	\
    ( (This)->lpVtbl -> get_Left(This,RHS) ) 

#define IArc_put_Left(This,RHS)	\
    ( (This)->lpVtbl -> put_Left(This,RHS) ) 

#define IArc_get_Locked(This,RHS)	\
    ( (This)->lpVtbl -> get_Locked(This,RHS) ) 

#define IArc_put_Locked(This,RHS)	\
    ( (This)->lpVtbl -> put_Locked(This,RHS) ) 

#define IArc_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define IArc_put_Name(This,RHS)	\
    ( (This)->lpVtbl -> put_Name(This,RHS) ) 

#define IArc_get_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> get_OnAction(This,RHS) ) 

#define IArc_put_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> put_OnAction(This,RHS) ) 

#define IArc_get_Placement(This,RHS)	\
    ( (This)->lpVtbl -> get_Placement(This,RHS) ) 

#define IArc_put_Placement(This,RHS)	\
    ( (This)->lpVtbl -> put_Placement(This,RHS) ) 

#define IArc_get_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> get_PrintObject(This,RHS) ) 

#define IArc_put_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> put_PrintObject(This,RHS) ) 

#define IArc_Select(This,Replace,RHS)	\
    ( (This)->lpVtbl -> Select(This,Replace,RHS) ) 

#define IArc_SendToBack(This,RHS)	\
    ( (This)->lpVtbl -> SendToBack(This,RHS) ) 

#define IArc_get_Top(This,RHS)	\
    ( (This)->lpVtbl -> get_Top(This,RHS) ) 

#define IArc_put_Top(This,RHS)	\
    ( (This)->lpVtbl -> put_Top(This,RHS) ) 

#define IArc_get_TopLeftCell(This,RHS)	\
    ( (This)->lpVtbl -> get_TopLeftCell(This,RHS) ) 

#define IArc_get_Visible(This,RHS)	\
    ( (This)->lpVtbl -> get_Visible(This,RHS) ) 

#define IArc_put_Visible(This,RHS)	\
    ( (This)->lpVtbl -> put_Visible(This,RHS) ) 

#define IArc_get_Width(This,RHS)	\
    ( (This)->lpVtbl -> get_Width(This,RHS) ) 

#define IArc_put_Width(This,RHS)	\
    ( (This)->lpVtbl -> put_Width(This,RHS) ) 

#define IArc_get_ZOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_ZOrder(This,RHS) ) 

#define IArc_get_ShapeRange(This,RHS)	\
    ( (This)->lpVtbl -> get_ShapeRange(This,RHS) ) 

#define IArc_get_AddIndent(This,RHS)	\
    ( (This)->lpVtbl -> get_AddIndent(This,RHS) ) 

#define IArc_put_AddIndent(This,RHS)	\
    ( (This)->lpVtbl -> put_AddIndent(This,RHS) ) 

#define IArc_get_AutoScaleFont(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoScaleFont(This,RHS) ) 

#define IArc_put_AutoScaleFont(This,RHS)	\
    ( (This)->lpVtbl -> put_AutoScaleFont(This,RHS) ) 

#define IArc_get_AutoSize(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoSize(This,RHS) ) 

#define IArc_put_AutoSize(This,RHS)	\
    ( (This)->lpVtbl -> put_AutoSize(This,RHS) ) 

#define IArc_get_Caption(This,RHS)	\
    ( (This)->lpVtbl -> get_Caption(This,RHS) ) 

#define IArc_put_Caption(This,RHS)	\
    ( (This)->lpVtbl -> put_Caption(This,RHS) ) 

#define IArc_get_Characters(This,Start,Length,RHS)	\
    ( (This)->lpVtbl -> get_Characters(This,Start,Length,RHS) ) 

#define IArc_CheckSpelling(This,CustomDictionary,IgnoreUppercase,AlwaysSuggest,SpellLang,RHS)	\
    ( (This)->lpVtbl -> CheckSpelling(This,CustomDictionary,IgnoreUppercase,AlwaysSuggest,SpellLang,RHS) ) 

#define IArc_get_Font(This,RHS)	\
    ( (This)->lpVtbl -> get_Font(This,RHS) ) 

#define IArc_get_Formula(This,RHS)	\
    ( (This)->lpVtbl -> get_Formula(This,RHS) ) 

#define IArc_put_Formula(This,RHS)	\
    ( (This)->lpVtbl -> put_Formula(This,RHS) ) 

#define IArc_get_HorizontalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> get_HorizontalAlignment(This,RHS) ) 

#define IArc_put_HorizontalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> put_HorizontalAlignment(This,RHS) ) 

#define IArc_get_LockedText(This,RHS)	\
    ( (This)->lpVtbl -> get_LockedText(This,RHS) ) 

#define IArc_put_LockedText(This,RHS)	\
    ( (This)->lpVtbl -> put_LockedText(This,RHS) ) 

#define IArc_get_Orientation(This,RHS)	\
    ( (This)->lpVtbl -> get_Orientation(This,RHS) ) 

#define IArc_put_Orientation(This,RHS)	\
    ( (This)->lpVtbl -> put_Orientation(This,RHS) ) 

#define IArc_get_Text(This,RHS)	\
    ( (This)->lpVtbl -> get_Text(This,RHS) ) 

#define IArc_put_Text(This,RHS)	\
    ( (This)->lpVtbl -> put_Text(This,RHS) ) 

#define IArc_get_VerticalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> get_VerticalAlignment(This,RHS) ) 

#define IArc_put_VerticalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> put_VerticalAlignment(This,RHS) ) 

#define IArc_get_ReadingOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_ReadingOrder(This,RHS) ) 

#define IArc_put_ReadingOrder(This,RHS)	\
    ( (This)->lpVtbl -> put_ReadingOrder(This,RHS) ) 

#define IArc_get_Border(This,RHS)	\
    ( (This)->lpVtbl -> get_Border(This,RHS) ) 

#define IArc_get_Interior(This,RHS)	\
    ( (This)->lpVtbl -> get_Interior(This,RHS) ) 

#define IArc__Dummy43(This)	\
    ( (This)->lpVtbl -> _Dummy43(This) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IArc_INTERFACE_DEFINED__ */


#ifndef __IArcs_INTERFACE_DEFINED__
#define __IArcs_INTERFACE_DEFINED__

/* interface IArcs */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IArcs;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000208A1-0001-0000-C000-000000000046")
    IArcs : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy3( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall BringToFront( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Copy( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CopyPicture( 
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Cut( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Duplicate( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Enabled( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Enabled( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Height( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Height( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy12( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Left( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Left( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Locked( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Locked( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy15( void) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_OnAction( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_OnAction( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Placement( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Placement( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PrintObject( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PrintObject( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SendToBack( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Top( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Top( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy22( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Visible( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Visible( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Width( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Width( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ZOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShapeRange( 
            /* [retval][out] */ ShapeRange	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AddIndent( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AddIndent( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AutoScaleFont( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AutoScaleFont( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AutoSize( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AutoSize( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Caption( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Caption( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Characters( 
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Length,
            /* [retval][out] */ Characters	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CheckSpelling( 
            /* [optional][in] */ VARIANT CustomDictionary,
            /* [optional][in] */ VARIANT IgnoreUppercase,
            /* [optional][in] */ VARIANT AlwaysSuggest,
            /* [optional][in] */ VARIANT SpellLang,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Font( 
            /* [retval][out] */ Font	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Formula( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Formula( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HorizontalAlignment( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_HorizontalAlignment( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LockedText( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_LockedText( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Orientation( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Orientation( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Text( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Text( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_VerticalAlignment( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_VerticalAlignment( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ReadingOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ReadingOrder( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Border( 
            /* [retval][out] */ Border	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Interior( 
            /* [retval][out] */ Interior	**RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy43( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add( 
            /* [in] */ double X1,
            /* [in] */ double Y1,
            /* [in] */ double X2,
            /* [in] */ double Y2,
            /* [retval][out] */ Arc	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Group( 
            /* [retval][out] */ GroupObject	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall _NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IArcsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IArcs * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IArcs * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IArcs * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IArcs * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IArcs * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IArcs * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IArcs * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IArcs * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IArcs * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IArcs * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy3 )( 
            IArcs * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *BringToFront )( 
            IArcs * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Copy )( 
            IArcs * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CopyPicture )( 
            IArcs * This,
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Cut )( 
            IArcs * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IArcs * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Duplicate )( 
            IArcs * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Enabled )( 
            IArcs * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Enabled )( 
            IArcs * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Height )( 
            IArcs * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Height )( 
            IArcs * This,
            /* [in] */ double RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy12 )( 
            IArcs * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Left )( 
            IArcs * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Left )( 
            IArcs * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Locked )( 
            IArcs * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Locked )( 
            IArcs * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy15 )( 
            IArcs * This);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_OnAction )( 
            IArcs * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_OnAction )( 
            IArcs * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Placement )( 
            IArcs * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Placement )( 
            IArcs * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PrintObject )( 
            IArcs * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PrintObject )( 
            IArcs * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            IArcs * This,
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SendToBack )( 
            IArcs * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Top )( 
            IArcs * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Top )( 
            IArcs * This,
            /* [in] */ double RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy22 )( 
            IArcs * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Visible )( 
            IArcs * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Visible )( 
            IArcs * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Width )( 
            IArcs * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Width )( 
            IArcs * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ZOrder )( 
            IArcs * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShapeRange )( 
            IArcs * This,
            /* [retval][out] */ ShapeRange	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AddIndent )( 
            IArcs * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AddIndent )( 
            IArcs * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AutoScaleFont )( 
            IArcs * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AutoScaleFont )( 
            IArcs * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AutoSize )( 
            IArcs * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AutoSize )( 
            IArcs * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Caption )( 
            IArcs * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Caption )( 
            IArcs * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Characters )( 
            IArcs * This,
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Length,
            /* [retval][out] */ Characters	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CheckSpelling )( 
            IArcs * This,
            /* [optional][in] */ VARIANT CustomDictionary,
            /* [optional][in] */ VARIANT IgnoreUppercase,
            /* [optional][in] */ VARIANT AlwaysSuggest,
            /* [optional][in] */ VARIANT SpellLang,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Font )( 
            IArcs * This,
            /* [retval][out] */ Font	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Formula )( 
            IArcs * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Formula )( 
            IArcs * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HorizontalAlignment )( 
            IArcs * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_HorizontalAlignment )( 
            IArcs * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LockedText )( 
            IArcs * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_LockedText )( 
            IArcs * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Orientation )( 
            IArcs * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Orientation )( 
            IArcs * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Text )( 
            IArcs * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Text )( 
            IArcs * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_VerticalAlignment )( 
            IArcs * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_VerticalAlignment )( 
            IArcs * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ReadingOrder )( 
            IArcs * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ReadingOrder )( 
            IArcs * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Border )( 
            IArcs * This,
            /* [retval][out] */ Border	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Interior )( 
            IArcs * This,
            /* [retval][out] */ Interior	**RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy43 )( 
            IArcs * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add )( 
            IArcs * This,
            /* [in] */ double X1,
            /* [in] */ double Y1,
            /* [in] */ double X2,
            /* [in] */ double Y2,
            /* [retval][out] */ Arc	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IArcs * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Group )( 
            IArcs * This,
            /* [retval][out] */ GroupObject	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Item )( 
            IArcs * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *_NewEnum )( 
            IArcs * This,
            /* [retval][out] */ IUnknown **RHS);
        
        END_INTERFACE
    } IArcsVtbl;

    interface IArcs
    {
        CONST_VTBL struct IArcsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IArcs_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IArcs_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IArcs_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IArcs_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IArcs_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IArcs_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IArcs_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IArcs_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IArcs_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IArcs_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IArcs__Dummy3(This)	\
    ( (This)->lpVtbl -> _Dummy3(This) ) 

#define IArcs_BringToFront(This,RHS)	\
    ( (This)->lpVtbl -> BringToFront(This,RHS) ) 

#define IArcs_Copy(This,RHS)	\
    ( (This)->lpVtbl -> Copy(This,RHS) ) 

#define IArcs_CopyPicture(This,Appearance,Format,RHS)	\
    ( (This)->lpVtbl -> CopyPicture(This,Appearance,Format,RHS) ) 

#define IArcs_Cut(This,RHS)	\
    ( (This)->lpVtbl -> Cut(This,RHS) ) 

#define IArcs_Delete(This,RHS)	\
    ( (This)->lpVtbl -> Delete(This,RHS) ) 

#define IArcs_Duplicate(This,RHS)	\
    ( (This)->lpVtbl -> Duplicate(This,RHS) ) 

#define IArcs_get_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> get_Enabled(This,RHS) ) 

#define IArcs_put_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> put_Enabled(This,RHS) ) 

#define IArcs_get_Height(This,RHS)	\
    ( (This)->lpVtbl -> get_Height(This,RHS) ) 

#define IArcs_put_Height(This,RHS)	\
    ( (This)->lpVtbl -> put_Height(This,RHS) ) 

#define IArcs__Dummy12(This)	\
    ( (This)->lpVtbl -> _Dummy12(This) ) 

#define IArcs_get_Left(This,RHS)	\
    ( (This)->lpVtbl -> get_Left(This,RHS) ) 

#define IArcs_put_Left(This,RHS)	\
    ( (This)->lpVtbl -> put_Left(This,RHS) ) 

#define IArcs_get_Locked(This,RHS)	\
    ( (This)->lpVtbl -> get_Locked(This,RHS) ) 

#define IArcs_put_Locked(This,RHS)	\
    ( (This)->lpVtbl -> put_Locked(This,RHS) ) 

#define IArcs__Dummy15(This)	\
    ( (This)->lpVtbl -> _Dummy15(This) ) 

#define IArcs_get_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> get_OnAction(This,RHS) ) 

#define IArcs_put_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> put_OnAction(This,RHS) ) 

#define IArcs_get_Placement(This,RHS)	\
    ( (This)->lpVtbl -> get_Placement(This,RHS) ) 

#define IArcs_put_Placement(This,RHS)	\
    ( (This)->lpVtbl -> put_Placement(This,RHS) ) 

#define IArcs_get_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> get_PrintObject(This,RHS) ) 

#define IArcs_put_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> put_PrintObject(This,RHS) ) 

#define IArcs_Select(This,Replace,RHS)	\
    ( (This)->lpVtbl -> Select(This,Replace,RHS) ) 

#define IArcs_SendToBack(This,RHS)	\
    ( (This)->lpVtbl -> SendToBack(This,RHS) ) 

#define IArcs_get_Top(This,RHS)	\
    ( (This)->lpVtbl -> get_Top(This,RHS) ) 

#define IArcs_put_Top(This,RHS)	\
    ( (This)->lpVtbl -> put_Top(This,RHS) ) 

#define IArcs__Dummy22(This)	\
    ( (This)->lpVtbl -> _Dummy22(This) ) 

#define IArcs_get_Visible(This,RHS)	\
    ( (This)->lpVtbl -> get_Visible(This,RHS) ) 

#define IArcs_put_Visible(This,RHS)	\
    ( (This)->lpVtbl -> put_Visible(This,RHS) ) 

#define IArcs_get_Width(This,RHS)	\
    ( (This)->lpVtbl -> get_Width(This,RHS) ) 

#define IArcs_put_Width(This,RHS)	\
    ( (This)->lpVtbl -> put_Width(This,RHS) ) 

#define IArcs_get_ZOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_ZOrder(This,RHS) ) 

#define IArcs_get_ShapeRange(This,RHS)	\
    ( (This)->lpVtbl -> get_ShapeRange(This,RHS) ) 

#define IArcs_get_AddIndent(This,RHS)	\
    ( (This)->lpVtbl -> get_AddIndent(This,RHS) ) 

#define IArcs_put_AddIndent(This,RHS)	\
    ( (This)->lpVtbl -> put_AddIndent(This,RHS) ) 

#define IArcs_get_AutoScaleFont(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoScaleFont(This,RHS) ) 

#define IArcs_put_AutoScaleFont(This,RHS)	\
    ( (This)->lpVtbl -> put_AutoScaleFont(This,RHS) ) 

#define IArcs_get_AutoSize(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoSize(This,RHS) ) 

#define IArcs_put_AutoSize(This,RHS)	\
    ( (This)->lpVtbl -> put_AutoSize(This,RHS) ) 

#define IArcs_get_Caption(This,RHS)	\
    ( (This)->lpVtbl -> get_Caption(This,RHS) ) 

#define IArcs_put_Caption(This,RHS)	\
    ( (This)->lpVtbl -> put_Caption(This,RHS) ) 

#define IArcs_get_Characters(This,Start,Length,RHS)	\
    ( (This)->lpVtbl -> get_Characters(This,Start,Length,RHS) ) 

#define IArcs_CheckSpelling(This,CustomDictionary,IgnoreUppercase,AlwaysSuggest,SpellLang,RHS)	\
    ( (This)->lpVtbl -> CheckSpelling(This,CustomDictionary,IgnoreUppercase,AlwaysSuggest,SpellLang,RHS) ) 

#define IArcs_get_Font(This,RHS)	\
    ( (This)->lpVtbl -> get_Font(This,RHS) ) 

#define IArcs_get_Formula(This,RHS)	\
    ( (This)->lpVtbl -> get_Formula(This,RHS) ) 

#define IArcs_put_Formula(This,RHS)	\
    ( (This)->lpVtbl -> put_Formula(This,RHS) ) 

#define IArcs_get_HorizontalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> get_HorizontalAlignment(This,RHS) ) 

#define IArcs_put_HorizontalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> put_HorizontalAlignment(This,RHS) ) 

#define IArcs_get_LockedText(This,RHS)	\
    ( (This)->lpVtbl -> get_LockedText(This,RHS) ) 

#define IArcs_put_LockedText(This,RHS)	\
    ( (This)->lpVtbl -> put_LockedText(This,RHS) ) 

#define IArcs_get_Orientation(This,RHS)	\
    ( (This)->lpVtbl -> get_Orientation(This,RHS) ) 

#define IArcs_put_Orientation(This,RHS)	\
    ( (This)->lpVtbl -> put_Orientation(This,RHS) ) 

#define IArcs_get_Text(This,RHS)	\
    ( (This)->lpVtbl -> get_Text(This,RHS) ) 

#define IArcs_put_Text(This,RHS)	\
    ( (This)->lpVtbl -> put_Text(This,RHS) ) 

#define IArcs_get_VerticalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> get_VerticalAlignment(This,RHS) ) 

#define IArcs_put_VerticalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> put_VerticalAlignment(This,RHS) ) 

#define IArcs_get_ReadingOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_ReadingOrder(This,RHS) ) 

#define IArcs_put_ReadingOrder(This,RHS)	\
    ( (This)->lpVtbl -> put_ReadingOrder(This,RHS) ) 

#define IArcs_get_Border(This,RHS)	\
    ( (This)->lpVtbl -> get_Border(This,RHS) ) 

#define IArcs_get_Interior(This,RHS)	\
    ( (This)->lpVtbl -> get_Interior(This,RHS) ) 

#define IArcs__Dummy43(This)	\
    ( (This)->lpVtbl -> _Dummy43(This) ) 

#define IArcs_Add(This,X1,Y1,X2,Y2,RHS)	\
    ( (This)->lpVtbl -> Add(This,X1,Y1,X2,Y2,RHS) ) 

#define IArcs_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IArcs_Group(This,RHS)	\
    ( (This)->lpVtbl -> Group(This,RHS) ) 

#define IArcs_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> Item(This,Index,RHS) ) 

#define IArcs__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> _NewEnum(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IArcs_INTERFACE_DEFINED__ */


#ifndef __IOLEObjectEvents_INTERFACE_DEFINED__
#define __IOLEObjectEvents_INTERFACE_DEFINED__

/* interface IOLEObjectEvents */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IOLEObjectEvents;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024410-0001-0000-C000-000000000046")
    IOLEObjectEvents : public IDispatch
    {
    public:
        virtual /* [helpcontext][id] */ HRESULT __stdcall GotFocus( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall LostFocus( void) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IOLEObjectEventsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IOLEObjectEvents * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IOLEObjectEvents * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IOLEObjectEvents * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IOLEObjectEvents * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IOLEObjectEvents * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IOLEObjectEvents * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IOLEObjectEvents * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *GotFocus )( 
            IOLEObjectEvents * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *LostFocus )( 
            IOLEObjectEvents * This);
        
        END_INTERFACE
    } IOLEObjectEventsVtbl;

    interface IOLEObjectEvents
    {
        CONST_VTBL struct IOLEObjectEventsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IOLEObjectEvents_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IOLEObjectEvents_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IOLEObjectEvents_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IOLEObjectEvents_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IOLEObjectEvents_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IOLEObjectEvents_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IOLEObjectEvents_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IOLEObjectEvents_GotFocus(This)	\
    ( (This)->lpVtbl -> GotFocus(This) ) 

#define IOLEObjectEvents_LostFocus(This)	\
    ( (This)->lpVtbl -> LostFocus(This) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IOLEObjectEvents_INTERFACE_DEFINED__ */


#ifndef ___IOLEObject_INTERFACE_DEFINED__
#define ___IOLEObject_INTERFACE_DEFINED__

/* interface _IOLEObject */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID__IOLEObject;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000208A2-0001-0000-C000-000000000046")
    _IOLEObject : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_BottomRightCell( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall BringToFront( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Copy( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CopyPicture( 
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Cut( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Duplicate( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Enabled( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Enabled( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Height( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Height( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Index( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Left( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Left( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Locked( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Locked( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Name( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_OnAction( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_OnAction( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Placement( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Placement( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PrintObject( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PrintObject( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SendToBack( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Top( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Top( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TopLeftCell( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Visible( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Visible( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Width( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Width( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ZOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShapeRange( 
            /* [retval][out] */ ShapeRange	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Border( 
            /* [retval][out] */ Border	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Interior( 
            /* [retval][out] */ Interior	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Shadow( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Shadow( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Activate( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AutoLoad( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AutoLoad( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AutoUpdate( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AutoUpdate( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Object( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_OLEType( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SourceName( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_SourceName( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Update( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Verb( 
            /* [defaultvalue][optional][in] */ XlOLEVerb Verb,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LinkedCell( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_LinkedCell( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ListFillRange( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ListFillRange( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_progID( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_AltHTML( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_AltHTML( 
            /* [in] */ BSTR RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct _IOLEObjectVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            _IOLEObject * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            _IOLEObject * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            _IOLEObject * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            _IOLEObject * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            _IOLEObject * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            _IOLEObject * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            _IOLEObject * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            _IOLEObject * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            _IOLEObject * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            _IOLEObject * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_BottomRightCell )( 
            _IOLEObject * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *BringToFront )( 
            _IOLEObject * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Copy )( 
            _IOLEObject * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CopyPicture )( 
            _IOLEObject * This,
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Cut )( 
            _IOLEObject * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            _IOLEObject * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Duplicate )( 
            _IOLEObject * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Enabled )( 
            _IOLEObject * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Enabled )( 
            _IOLEObject * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Height )( 
            _IOLEObject * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Height )( 
            _IOLEObject * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Index )( 
            _IOLEObject * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Left )( 
            _IOLEObject * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Left )( 
            _IOLEObject * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Locked )( 
            _IOLEObject * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Locked )( 
            _IOLEObject * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            _IOLEObject * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Name )( 
            _IOLEObject * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_OnAction )( 
            _IOLEObject * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_OnAction )( 
            _IOLEObject * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Placement )( 
            _IOLEObject * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Placement )( 
            _IOLEObject * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PrintObject )( 
            _IOLEObject * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PrintObject )( 
            _IOLEObject * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            _IOLEObject * This,
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SendToBack )( 
            _IOLEObject * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Top )( 
            _IOLEObject * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Top )( 
            _IOLEObject * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TopLeftCell )( 
            _IOLEObject * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Visible )( 
            _IOLEObject * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Visible )( 
            _IOLEObject * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Width )( 
            _IOLEObject * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Width )( 
            _IOLEObject * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ZOrder )( 
            _IOLEObject * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShapeRange )( 
            _IOLEObject * This,
            /* [retval][out] */ ShapeRange	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Border )( 
            _IOLEObject * This,
            /* [retval][out] */ Border	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Interior )( 
            _IOLEObject * This,
            /* [retval][out] */ Interior	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Shadow )( 
            _IOLEObject * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Shadow )( 
            _IOLEObject * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Activate )( 
            _IOLEObject * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AutoLoad )( 
            _IOLEObject * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AutoLoad )( 
            _IOLEObject * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AutoUpdate )( 
            _IOLEObject * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AutoUpdate )( 
            _IOLEObject * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Object )( 
            _IOLEObject * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_OLEType )( 
            _IOLEObject * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SourceName )( 
            _IOLEObject * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_SourceName )( 
            _IOLEObject * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Update )( 
            _IOLEObject * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Verb )( 
            _IOLEObject * This,
            /* [defaultvalue][optional][in] */ XlOLEVerb Verb,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LinkedCell )( 
            _IOLEObject * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_LinkedCell )( 
            _IOLEObject * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ListFillRange )( 
            _IOLEObject * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ListFillRange )( 
            _IOLEObject * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_progID )( 
            _IOLEObject * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_AltHTML )( 
            _IOLEObject * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_AltHTML )( 
            _IOLEObject * This,
            /* [in] */ BSTR RHS);
        
        END_INTERFACE
    } _IOLEObjectVtbl;

    interface _IOLEObject
    {
        CONST_VTBL struct _IOLEObjectVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define _IOLEObject_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define _IOLEObject_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define _IOLEObject_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define _IOLEObject_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define _IOLEObject_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define _IOLEObject_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define _IOLEObject_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define _IOLEObject_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define _IOLEObject_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define _IOLEObject_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define _IOLEObject_get_BottomRightCell(This,RHS)	\
    ( (This)->lpVtbl -> get_BottomRightCell(This,RHS) ) 

#define _IOLEObject_BringToFront(This,RHS)	\
    ( (This)->lpVtbl -> BringToFront(This,RHS) ) 

#define _IOLEObject_Copy(This,RHS)	\
    ( (This)->lpVtbl -> Copy(This,RHS) ) 

#define _IOLEObject_CopyPicture(This,Appearance,Format,RHS)	\
    ( (This)->lpVtbl -> CopyPicture(This,Appearance,Format,RHS) ) 

#define _IOLEObject_Cut(This,RHS)	\
    ( (This)->lpVtbl -> Cut(This,RHS) ) 

#define _IOLEObject_Delete(This,RHS)	\
    ( (This)->lpVtbl -> Delete(This,RHS) ) 

#define _IOLEObject_Duplicate(This,RHS)	\
    ( (This)->lpVtbl -> Duplicate(This,RHS) ) 

#define _IOLEObject_get_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> get_Enabled(This,RHS) ) 

#define _IOLEObject_put_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> put_Enabled(This,RHS) ) 

#define _IOLEObject_get_Height(This,RHS)	\
    ( (This)->lpVtbl -> get_Height(This,RHS) ) 

#define _IOLEObject_put_Height(This,RHS)	\
    ( (This)->lpVtbl -> put_Height(This,RHS) ) 

#define _IOLEObject_get_Index(This,RHS)	\
    ( (This)->lpVtbl -> get_Index(This,RHS) ) 

#define _IOLEObject_get_Left(This,RHS)	\
    ( (This)->lpVtbl -> get_Left(This,RHS) ) 

#define _IOLEObject_put_Left(This,RHS)	\
    ( (This)->lpVtbl -> put_Left(This,RHS) ) 

#define _IOLEObject_get_Locked(This,RHS)	\
    ( (This)->lpVtbl -> get_Locked(This,RHS) ) 

#define _IOLEObject_put_Locked(This,RHS)	\
    ( (This)->lpVtbl -> put_Locked(This,RHS) ) 

#define _IOLEObject_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define _IOLEObject_put_Name(This,RHS)	\
    ( (This)->lpVtbl -> put_Name(This,RHS) ) 

#define _IOLEObject_get_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> get_OnAction(This,RHS) ) 

#define _IOLEObject_put_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> put_OnAction(This,RHS) ) 

#define _IOLEObject_get_Placement(This,RHS)	\
    ( (This)->lpVtbl -> get_Placement(This,RHS) ) 

#define _IOLEObject_put_Placement(This,RHS)	\
    ( (This)->lpVtbl -> put_Placement(This,RHS) ) 

#define _IOLEObject_get_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> get_PrintObject(This,RHS) ) 

#define _IOLEObject_put_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> put_PrintObject(This,RHS) ) 

#define _IOLEObject_Select(This,Replace,RHS)	\
    ( (This)->lpVtbl -> Select(This,Replace,RHS) ) 

#define _IOLEObject_SendToBack(This,RHS)	\
    ( (This)->lpVtbl -> SendToBack(This,RHS) ) 

#define _IOLEObject_get_Top(This,RHS)	\
    ( (This)->lpVtbl -> get_Top(This,RHS) ) 

#define _IOLEObject_put_Top(This,RHS)	\
    ( (This)->lpVtbl -> put_Top(This,RHS) ) 

#define _IOLEObject_get_TopLeftCell(This,RHS)	\
    ( (This)->lpVtbl -> get_TopLeftCell(This,RHS) ) 

#define _IOLEObject_get_Visible(This,RHS)	\
    ( (This)->lpVtbl -> get_Visible(This,RHS) ) 

#define _IOLEObject_put_Visible(This,RHS)	\
    ( (This)->lpVtbl -> put_Visible(This,RHS) ) 

#define _IOLEObject_get_Width(This,RHS)	\
    ( (This)->lpVtbl -> get_Width(This,RHS) ) 

#define _IOLEObject_put_Width(This,RHS)	\
    ( (This)->lpVtbl -> put_Width(This,RHS) ) 

#define _IOLEObject_get_ZOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_ZOrder(This,RHS) ) 

#define _IOLEObject_get_ShapeRange(This,RHS)	\
    ( (This)->lpVtbl -> get_ShapeRange(This,RHS) ) 

#define _IOLEObject_get_Border(This,RHS)	\
    ( (This)->lpVtbl -> get_Border(This,RHS) ) 

#define _IOLEObject_get_Interior(This,RHS)	\
    ( (This)->lpVtbl -> get_Interior(This,RHS) ) 

#define _IOLEObject_get_Shadow(This,RHS)	\
    ( (This)->lpVtbl -> get_Shadow(This,RHS) ) 

#define _IOLEObject_put_Shadow(This,RHS)	\
    ( (This)->lpVtbl -> put_Shadow(This,RHS) ) 

#define _IOLEObject_Activate(This,RHS)	\
    ( (This)->lpVtbl -> Activate(This,RHS) ) 

#define _IOLEObject_get_AutoLoad(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoLoad(This,RHS) ) 

#define _IOLEObject_put_AutoLoad(This,RHS)	\
    ( (This)->lpVtbl -> put_AutoLoad(This,RHS) ) 

#define _IOLEObject_get_AutoUpdate(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoUpdate(This,RHS) ) 

#define _IOLEObject_put_AutoUpdate(This,RHS)	\
    ( (This)->lpVtbl -> put_AutoUpdate(This,RHS) ) 

#define _IOLEObject_get_Object(This,RHS)	\
    ( (This)->lpVtbl -> get_Object(This,RHS) ) 

#define _IOLEObject_get_OLEType(This,RHS)	\
    ( (This)->lpVtbl -> get_OLEType(This,RHS) ) 

#define _IOLEObject_get_SourceName(This,RHS)	\
    ( (This)->lpVtbl -> get_SourceName(This,RHS) ) 

#define _IOLEObject_put_SourceName(This,RHS)	\
    ( (This)->lpVtbl -> put_SourceName(This,RHS) ) 

#define _IOLEObject_Update(This,RHS)	\
    ( (This)->lpVtbl -> Update(This,RHS) ) 

#define _IOLEObject_Verb(This,Verb,RHS)	\
    ( (This)->lpVtbl -> Verb(This,Verb,RHS) ) 

#define _IOLEObject_get_LinkedCell(This,RHS)	\
    ( (This)->lpVtbl -> get_LinkedCell(This,RHS) ) 

#define _IOLEObject_put_LinkedCell(This,RHS)	\
    ( (This)->lpVtbl -> put_LinkedCell(This,RHS) ) 

#define _IOLEObject_get_ListFillRange(This,RHS)	\
    ( (This)->lpVtbl -> get_ListFillRange(This,RHS) ) 

#define _IOLEObject_put_ListFillRange(This,RHS)	\
    ( (This)->lpVtbl -> put_ListFillRange(This,RHS) ) 

#define _IOLEObject_get_progID(This,RHS)	\
    ( (This)->lpVtbl -> get_progID(This,RHS) ) 

#define _IOLEObject_get_AltHTML(This,RHS)	\
    ( (This)->lpVtbl -> get_AltHTML(This,RHS) ) 

#define _IOLEObject_put_AltHTML(This,RHS)	\
    ( (This)->lpVtbl -> put_AltHTML(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* ___IOLEObject_INTERFACE_DEFINED__ */


#ifndef __IOLEObjects_INTERFACE_DEFINED__
#define __IOLEObjects_INTERFACE_DEFINED__

/* interface IOLEObjects */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IOLEObjects;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000208A3-0001-0000-C000-000000000046")
    IOLEObjects : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy3( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall BringToFront( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Copy( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CopyPicture( 
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Cut( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Duplicate( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Enabled( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Enabled( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Height( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Height( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy12( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Left( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Left( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Locked( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Locked( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy15( void) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_OnAction( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_OnAction( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Placement( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Placement( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PrintObject( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PrintObject( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SendToBack( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Top( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Top( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy22( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Visible( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Visible( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Width( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Width( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ZOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShapeRange( 
            /* [retval][out] */ ShapeRange	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Border( 
            /* [retval][out] */ Border	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Interior( 
            /* [retval][out] */ Interior	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Shadow( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Shadow( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy30( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AutoLoad( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AutoLoad( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy32( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy33( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy34( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SourceName( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_SourceName( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy36( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy37( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy38( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy39( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy40( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy41( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add( 
            /* [optional][in] */ VARIANT ClassType,
            /* [optional][in] */ VARIANT Filename,
            /* [optional][in] */ VARIANT Link,
            /* [optional][in] */ VARIANT DisplayAsIcon,
            /* [optional][in] */ VARIANT IconFileName,
            /* [optional][in] */ VARIANT IconIndex,
            /* [optional][in] */ VARIANT IconLabel,
            /* [optional][in] */ VARIANT Left,
            /* [optional][in] */ VARIANT Top,
            /* [optional][in] */ VARIANT Width,
            /* [optional][in] */ VARIANT Height,
            /* [retval][out] */ OLEObject	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall Group( 
            /* [retval][out] */ GroupObject	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall _NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IOLEObjectsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IOLEObjects * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IOLEObjects * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IOLEObjects * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IOLEObjects * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IOLEObjects * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IOLEObjects * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IOLEObjects * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IOLEObjects * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IOLEObjects * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IOLEObjects * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy3 )( 
            IOLEObjects * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *BringToFront )( 
            IOLEObjects * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Copy )( 
            IOLEObjects * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CopyPicture )( 
            IOLEObjects * This,
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Cut )( 
            IOLEObjects * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IOLEObjects * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Duplicate )( 
            IOLEObjects * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Enabled )( 
            IOLEObjects * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Enabled )( 
            IOLEObjects * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Height )( 
            IOLEObjects * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Height )( 
            IOLEObjects * This,
            /* [in] */ double RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy12 )( 
            IOLEObjects * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Left )( 
            IOLEObjects * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Left )( 
            IOLEObjects * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Locked )( 
            IOLEObjects * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Locked )( 
            IOLEObjects * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy15 )( 
            IOLEObjects * This);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_OnAction )( 
            IOLEObjects * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_OnAction )( 
            IOLEObjects * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Placement )( 
            IOLEObjects * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Placement )( 
            IOLEObjects * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PrintObject )( 
            IOLEObjects * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PrintObject )( 
            IOLEObjects * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            IOLEObjects * This,
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SendToBack )( 
            IOLEObjects * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Top )( 
            IOLEObjects * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Top )( 
            IOLEObjects * This,
            /* [in] */ double RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy22 )( 
            IOLEObjects * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Visible )( 
            IOLEObjects * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Visible )( 
            IOLEObjects * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Width )( 
            IOLEObjects * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Width )( 
            IOLEObjects * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ZOrder )( 
            IOLEObjects * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShapeRange )( 
            IOLEObjects * This,
            /* [retval][out] */ ShapeRange	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Border )( 
            IOLEObjects * This,
            /* [retval][out] */ Border	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Interior )( 
            IOLEObjects * This,
            /* [retval][out] */ Interior	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Shadow )( 
            IOLEObjects * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Shadow )( 
            IOLEObjects * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy30 )( 
            IOLEObjects * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AutoLoad )( 
            IOLEObjects * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AutoLoad )( 
            IOLEObjects * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy32 )( 
            IOLEObjects * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy33 )( 
            IOLEObjects * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy34 )( 
            IOLEObjects * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SourceName )( 
            IOLEObjects * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_SourceName )( 
            IOLEObjects * This,
            /* [in] */ BSTR RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy36 )( 
            IOLEObjects * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy37 )( 
            IOLEObjects * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy38 )( 
            IOLEObjects * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy39 )( 
            IOLEObjects * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy40 )( 
            IOLEObjects * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy41 )( 
            IOLEObjects * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add )( 
            IOLEObjects * This,
            /* [optional][in] */ VARIANT ClassType,
            /* [optional][in] */ VARIANT Filename,
            /* [optional][in] */ VARIANT Link,
            /* [optional][in] */ VARIANT DisplayAsIcon,
            /* [optional][in] */ VARIANT IconFileName,
            /* [optional][in] */ VARIANT IconIndex,
            /* [optional][in] */ VARIANT IconLabel,
            /* [optional][in] */ VARIANT Left,
            /* [optional][in] */ VARIANT Top,
            /* [optional][in] */ VARIANT Width,
            /* [optional][in] */ VARIANT Height,
            /* [retval][out] */ OLEObject	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IOLEObjects * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *Group )( 
            IOLEObjects * This,
            /* [retval][out] */ GroupObject	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Item )( 
            IOLEObjects * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *_NewEnum )( 
            IOLEObjects * This,
            /* [retval][out] */ IUnknown **RHS);
        
        END_INTERFACE
    } IOLEObjectsVtbl;

    interface IOLEObjects
    {
        CONST_VTBL struct IOLEObjectsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IOLEObjects_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IOLEObjects_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IOLEObjects_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IOLEObjects_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IOLEObjects_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IOLEObjects_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IOLEObjects_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IOLEObjects_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IOLEObjects_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IOLEObjects_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IOLEObjects__Dummy3(This)	\
    ( (This)->lpVtbl -> _Dummy3(This) ) 

#define IOLEObjects_BringToFront(This,RHS)	\
    ( (This)->lpVtbl -> BringToFront(This,RHS) ) 

#define IOLEObjects_Copy(This,RHS)	\
    ( (This)->lpVtbl -> Copy(This,RHS) ) 

#define IOLEObjects_CopyPicture(This,Appearance,Format,RHS)	\
    ( (This)->lpVtbl -> CopyPicture(This,Appearance,Format,RHS) ) 

#define IOLEObjects_Cut(This,RHS)	\
    ( (This)->lpVtbl -> Cut(This,RHS) ) 

#define IOLEObjects_Delete(This,RHS)	\
    ( (This)->lpVtbl -> Delete(This,RHS) ) 

#define IOLEObjects_Duplicate(This,RHS)	\
    ( (This)->lpVtbl -> Duplicate(This,RHS) ) 

#define IOLEObjects_get_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> get_Enabled(This,RHS) ) 

#define IOLEObjects_put_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> put_Enabled(This,RHS) ) 

#define IOLEObjects_get_Height(This,RHS)	\
    ( (This)->lpVtbl -> get_Height(This,RHS) ) 

#define IOLEObjects_put_Height(This,RHS)	\
    ( (This)->lpVtbl -> put_Height(This,RHS) ) 

#define IOLEObjects__Dummy12(This)	\
    ( (This)->lpVtbl -> _Dummy12(This) ) 

#define IOLEObjects_get_Left(This,RHS)	\
    ( (This)->lpVtbl -> get_Left(This,RHS) ) 

#define IOLEObjects_put_Left(This,RHS)	\
    ( (This)->lpVtbl -> put_Left(This,RHS) ) 

#define IOLEObjects_get_Locked(This,RHS)	\
    ( (This)->lpVtbl -> get_Locked(This,RHS) ) 

#define IOLEObjects_put_Locked(This,RHS)	\
    ( (This)->lpVtbl -> put_Locked(This,RHS) ) 

#define IOLEObjects__Dummy15(This)	\
    ( (This)->lpVtbl -> _Dummy15(This) ) 

#define IOLEObjects_get_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> get_OnAction(This,RHS) ) 

#define IOLEObjects_put_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> put_OnAction(This,RHS) ) 

#define IOLEObjects_get_Placement(This,RHS)	\
    ( (This)->lpVtbl -> get_Placement(This,RHS) ) 

#define IOLEObjects_put_Placement(This,RHS)	\
    ( (This)->lpVtbl -> put_Placement(This,RHS) ) 

#define IOLEObjects_get_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> get_PrintObject(This,RHS) ) 

#define IOLEObjects_put_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> put_PrintObject(This,RHS) ) 

#define IOLEObjects_Select(This,Replace,RHS)	\
    ( (This)->lpVtbl -> Select(This,Replace,RHS) ) 

#define IOLEObjects_SendToBack(This,RHS)	\
    ( (This)->lpVtbl -> SendToBack(This,RHS) ) 

#define IOLEObjects_get_Top(This,RHS)	\
    ( (This)->lpVtbl -> get_Top(This,RHS) ) 

#define IOLEObjects_put_Top(This,RHS)	\
    ( (This)->lpVtbl -> put_Top(This,RHS) ) 

#define IOLEObjects__Dummy22(This)	\
    ( (This)->lpVtbl -> _Dummy22(This) ) 

#define IOLEObjects_get_Visible(This,RHS)	\
    ( (This)->lpVtbl -> get_Visible(This,RHS) ) 

#define IOLEObjects_put_Visible(This,RHS)	\
    ( (This)->lpVtbl -> put_Visible(This,RHS) ) 

#define IOLEObjects_get_Width(This,RHS)	\
    ( (This)->lpVtbl -> get_Width(This,RHS) ) 

#define IOLEObjects_put_Width(This,RHS)	\
    ( (This)->lpVtbl -> put_Width(This,RHS) ) 

#define IOLEObjects_get_ZOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_ZOrder(This,RHS) ) 

#define IOLEObjects_get_ShapeRange(This,RHS)	\
    ( (This)->lpVtbl -> get_ShapeRange(This,RHS) ) 

#define IOLEObjects_get_Border(This,RHS)	\
    ( (This)->lpVtbl -> get_Border(This,RHS) ) 

#define IOLEObjects_get_Interior(This,RHS)	\
    ( (This)->lpVtbl -> get_Interior(This,RHS) ) 

#define IOLEObjects_get_Shadow(This,RHS)	\
    ( (This)->lpVtbl -> get_Shadow(This,RHS) ) 

#define IOLEObjects_put_Shadow(This,RHS)	\
    ( (This)->lpVtbl -> put_Shadow(This,RHS) ) 

#define IOLEObjects__Dummy30(This)	\
    ( (This)->lpVtbl -> _Dummy30(This) ) 

#define IOLEObjects_get_AutoLoad(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoLoad(This,RHS) ) 

#define IOLEObjects_put_AutoLoad(This,RHS)	\
    ( (This)->lpVtbl -> put_AutoLoad(This,RHS) ) 

#define IOLEObjects__Dummy32(This)	\
    ( (This)->lpVtbl -> _Dummy32(This) ) 

#define IOLEObjects__Dummy33(This)	\
    ( (This)->lpVtbl -> _Dummy33(This) ) 

#define IOLEObjects__Dummy34(This)	\
    ( (This)->lpVtbl -> _Dummy34(This) ) 

#define IOLEObjects_get_SourceName(This,RHS)	\
    ( (This)->lpVtbl -> get_SourceName(This,RHS) ) 

#define IOLEObjects_put_SourceName(This,RHS)	\
    ( (This)->lpVtbl -> put_SourceName(This,RHS) ) 

#define IOLEObjects__Dummy36(This)	\
    ( (This)->lpVtbl -> _Dummy36(This) ) 

#define IOLEObjects__Dummy37(This)	\
    ( (This)->lpVtbl -> _Dummy37(This) ) 

#define IOLEObjects__Dummy38(This)	\
    ( (This)->lpVtbl -> _Dummy38(This) ) 

#define IOLEObjects__Dummy39(This)	\
    ( (This)->lpVtbl -> _Dummy39(This) ) 

#define IOLEObjects__Dummy40(This)	\
    ( (This)->lpVtbl -> _Dummy40(This) ) 

#define IOLEObjects__Dummy41(This)	\
    ( (This)->lpVtbl -> _Dummy41(This) ) 

#define IOLEObjects_Add(This,ClassType,Filename,Link,DisplayAsIcon,IconFileName,IconIndex,IconLabel,Left,Top,Width,Height,RHS)	\
    ( (This)->lpVtbl -> Add(This,ClassType,Filename,Link,DisplayAsIcon,IconFileName,IconIndex,IconLabel,Left,Top,Width,Height,RHS) ) 

#define IOLEObjects_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IOLEObjects_Group(This,RHS)	\
    ( (This)->lpVtbl -> Group(This,RHS) ) 

#define IOLEObjects_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> Item(This,Index,RHS) ) 

#define IOLEObjects__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> _NewEnum(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IOLEObjects_INTERFACE_DEFINED__ */


#ifndef __ITextBox_INTERFACE_DEFINED__
#define __ITextBox_INTERFACE_DEFINED__

/* interface ITextBox */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ITextBox;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000208A4-0001-0000-C000-000000000046")
    ITextBox : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_BottomRightCell( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall BringToFront( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Copy( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CopyPicture( 
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Cut( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Duplicate( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Enabled( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Enabled( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Height( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Height( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Index( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Left( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Left( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Locked( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Locked( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Name( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_OnAction( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_OnAction( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Placement( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Placement( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PrintObject( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PrintObject( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SendToBack( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Top( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Top( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TopLeftCell( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Visible( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Visible( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Width( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Width( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ZOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShapeRange( 
            /* [retval][out] */ ShapeRange	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AddIndent( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AddIndent( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AutoScaleFont( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AutoScaleFont( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AutoSize( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AutoSize( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Caption( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Caption( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Characters( 
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Length,
            /* [retval][out] */ Characters	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CheckSpelling( 
            /* [optional][in] */ VARIANT CustomDictionary,
            /* [optional][in] */ VARIANT IgnoreUppercase,
            /* [optional][in] */ VARIANT AlwaysSuggest,
            /* [optional][in] */ VARIANT SpellLang,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Font( 
            /* [retval][out] */ Font	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Formula( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Formula( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HorizontalAlignment( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_HorizontalAlignment( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LockedText( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_LockedText( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Orientation( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Orientation( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Text( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Text( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_VerticalAlignment( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_VerticalAlignment( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ReadingOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ReadingOrder( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Border( 
            /* [retval][out] */ Border	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Interior( 
            /* [retval][out] */ Interior	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RoundedCorners( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_RoundedCorners( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Shadow( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Shadow( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ITextBoxVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ITextBox * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ITextBox * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ITextBox * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ITextBox * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ITextBox * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ITextBox * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ITextBox * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ITextBox * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ITextBox * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ITextBox * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_BottomRightCell )( 
            ITextBox * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *BringToFront )( 
            ITextBox * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Copy )( 
            ITextBox * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CopyPicture )( 
            ITextBox * This,
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Cut )( 
            ITextBox * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            ITextBox * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Duplicate )( 
            ITextBox * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Enabled )( 
            ITextBox * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Enabled )( 
            ITextBox * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Height )( 
            ITextBox * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Height )( 
            ITextBox * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Index )( 
            ITextBox * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Left )( 
            ITextBox * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Left )( 
            ITextBox * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Locked )( 
            ITextBox * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Locked )( 
            ITextBox * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            ITextBox * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Name )( 
            ITextBox * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_OnAction )( 
            ITextBox * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_OnAction )( 
            ITextBox * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Placement )( 
            ITextBox * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Placement )( 
            ITextBox * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PrintObject )( 
            ITextBox * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PrintObject )( 
            ITextBox * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            ITextBox * This,
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SendToBack )( 
            ITextBox * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Top )( 
            ITextBox * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Top )( 
            ITextBox * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TopLeftCell )( 
            ITextBox * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Visible )( 
            ITextBox * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Visible )( 
            ITextBox * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Width )( 
            ITextBox * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Width )( 
            ITextBox * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ZOrder )( 
            ITextBox * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShapeRange )( 
            ITextBox * This,
            /* [retval][out] */ ShapeRange	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AddIndent )( 
            ITextBox * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AddIndent )( 
            ITextBox * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AutoScaleFont )( 
            ITextBox * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AutoScaleFont )( 
            ITextBox * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AutoSize )( 
            ITextBox * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AutoSize )( 
            ITextBox * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Caption )( 
            ITextBox * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Caption )( 
            ITextBox * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Characters )( 
            ITextBox * This,
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Length,
            /* [retval][out] */ Characters	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CheckSpelling )( 
            ITextBox * This,
            /* [optional][in] */ VARIANT CustomDictionary,
            /* [optional][in] */ VARIANT IgnoreUppercase,
            /* [optional][in] */ VARIANT AlwaysSuggest,
            /* [optional][in] */ VARIANT SpellLang,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Font )( 
            ITextBox * This,
            /* [retval][out] */ Font	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Formula )( 
            ITextBox * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Formula )( 
            ITextBox * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HorizontalAlignment )( 
            ITextBox * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_HorizontalAlignment )( 
            ITextBox * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LockedText )( 
            ITextBox * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_LockedText )( 
            ITextBox * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Orientation )( 
            ITextBox * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Orientation )( 
            ITextBox * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Text )( 
            ITextBox * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Text )( 
            ITextBox * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_VerticalAlignment )( 
            ITextBox * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_VerticalAlignment )( 
            ITextBox * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ReadingOrder )( 
            ITextBox * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ReadingOrder )( 
            ITextBox * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Border )( 
            ITextBox * This,
            /* [retval][out] */ Border	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Interior )( 
            ITextBox * This,
            /* [retval][out] */ Interior	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RoundedCorners )( 
            ITextBox * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_RoundedCorners )( 
            ITextBox * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Shadow )( 
            ITextBox * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Shadow )( 
            ITextBox * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        END_INTERFACE
    } ITextBoxVtbl;

    interface ITextBox
    {
        CONST_VTBL struct ITextBoxVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ITextBox_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ITextBox_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ITextBox_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ITextBox_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ITextBox_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ITextBox_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ITextBox_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ITextBox_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ITextBox_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ITextBox_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ITextBox_get_BottomRightCell(This,RHS)	\
    ( (This)->lpVtbl -> get_BottomRightCell(This,RHS) ) 

#define ITextBox_BringToFront(This,RHS)	\
    ( (This)->lpVtbl -> BringToFront(This,RHS) ) 

#define ITextBox_Copy(This,RHS)	\
    ( (This)->lpVtbl -> Copy(This,RHS) ) 

#define ITextBox_CopyPicture(This,Appearance,Format,RHS)	\
    ( (This)->lpVtbl -> CopyPicture(This,Appearance,Format,RHS) ) 

#define ITextBox_Cut(This,RHS)	\
    ( (This)->lpVtbl -> Cut(This,RHS) ) 

#define ITextBox_Delete(This,RHS)	\
    ( (This)->lpVtbl -> Delete(This,RHS) ) 

#define ITextBox_Duplicate(This,RHS)	\
    ( (This)->lpVtbl -> Duplicate(This,RHS) ) 

#define ITextBox_get_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> get_Enabled(This,RHS) ) 

#define ITextBox_put_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> put_Enabled(This,RHS) ) 

#define ITextBox_get_Height(This,RHS)	\
    ( (This)->lpVtbl -> get_Height(This,RHS) ) 

#define ITextBox_put_Height(This,RHS)	\
    ( (This)->lpVtbl -> put_Height(This,RHS) ) 

#define ITextBox_get_Index(This,RHS)	\
    ( (This)->lpVtbl -> get_Index(This,RHS) ) 

#define ITextBox_get_Left(This,RHS)	\
    ( (This)->lpVtbl -> get_Left(This,RHS) ) 

#define ITextBox_put_Left(This,RHS)	\
    ( (This)->lpVtbl -> put_Left(This,RHS) ) 

#define ITextBox_get_Locked(This,RHS)	\
    ( (This)->lpVtbl -> get_Locked(This,RHS) ) 

#define ITextBox_put_Locked(This,RHS)	\
    ( (This)->lpVtbl -> put_Locked(This,RHS) ) 

#define ITextBox_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define ITextBox_put_Name(This,RHS)	\
    ( (This)->lpVtbl -> put_Name(This,RHS) ) 

#define ITextBox_get_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> get_OnAction(This,RHS) ) 

#define ITextBox_put_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> put_OnAction(This,RHS) ) 

#define ITextBox_get_Placement(This,RHS)	\
    ( (This)->lpVtbl -> get_Placement(This,RHS) ) 

#define ITextBox_put_Placement(This,RHS)	\
    ( (This)->lpVtbl -> put_Placement(This,RHS) ) 

#define ITextBox_get_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> get_PrintObject(This,RHS) ) 

#define ITextBox_put_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> put_PrintObject(This,RHS) ) 

#define ITextBox_Select(This,Replace,RHS)	\
    ( (This)->lpVtbl -> Select(This,Replace,RHS) ) 

#define ITextBox_SendToBack(This,RHS)	\
    ( (This)->lpVtbl -> SendToBack(This,RHS) ) 

#define ITextBox_get_Top(This,RHS)	\
    ( (This)->lpVtbl -> get_Top(This,RHS) ) 

#define ITextBox_put_Top(This,RHS)	\
    ( (This)->lpVtbl -> put_Top(This,RHS) ) 

#define ITextBox_get_TopLeftCell(This,RHS)	\
    ( (This)->lpVtbl -> get_TopLeftCell(This,RHS) ) 

#define ITextBox_get_Visible(This,RHS)	\
    ( (This)->lpVtbl -> get_Visible(This,RHS) ) 

#define ITextBox_put_Visible(This,RHS)	\
    ( (This)->lpVtbl -> put_Visible(This,RHS) ) 

#define ITextBox_get_Width(This,RHS)	\
    ( (This)->lpVtbl -> get_Width(This,RHS) ) 

#define ITextBox_put_Width(This,RHS)	\
    ( (This)->lpVtbl -> put_Width(This,RHS) ) 

#define ITextBox_get_ZOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_ZOrder(This,RHS) ) 

#define ITextBox_get_ShapeRange(This,RHS)	\
    ( (This)->lpVtbl -> get_ShapeRange(This,RHS) ) 

#define ITextBox_get_AddIndent(This,RHS)	\
    ( (This)->lpVtbl -> get_AddIndent(This,RHS) ) 

#define ITextBox_put_AddIndent(This,RHS)	\
    ( (This)->lpVtbl -> put_AddIndent(This,RHS) ) 

#define ITextBox_get_AutoScaleFont(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoScaleFont(This,RHS) ) 

#define ITextBox_put_AutoScaleFont(This,RHS)	\
    ( (This)->lpVtbl -> put_AutoScaleFont(This,RHS) ) 

#define ITextBox_get_AutoSize(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoSize(This,RHS) ) 

#define ITextBox_put_AutoSize(This,RHS)	\
    ( (This)->lpVtbl -> put_AutoSize(This,RHS) ) 

#define ITextBox_get_Caption(This,RHS)	\
    ( (This)->lpVtbl -> get_Caption(This,RHS) ) 

#define ITextBox_put_Caption(This,RHS)	\
    ( (This)->lpVtbl -> put_Caption(This,RHS) ) 

#define ITextBox_get_Characters(This,Start,Length,RHS)	\
    ( (This)->lpVtbl -> get_Characters(This,Start,Length,RHS) ) 

#define ITextBox_CheckSpelling(This,CustomDictionary,IgnoreUppercase,AlwaysSuggest,SpellLang,RHS)	\
    ( (This)->lpVtbl -> CheckSpelling(This,CustomDictionary,IgnoreUppercase,AlwaysSuggest,SpellLang,RHS) ) 

#define ITextBox_get_Font(This,RHS)	\
    ( (This)->lpVtbl -> get_Font(This,RHS) ) 

#define ITextBox_get_Formula(This,RHS)	\
    ( (This)->lpVtbl -> get_Formula(This,RHS) ) 

#define ITextBox_put_Formula(This,RHS)	\
    ( (This)->lpVtbl -> put_Formula(This,RHS) ) 

#define ITextBox_get_HorizontalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> get_HorizontalAlignment(This,RHS) ) 

#define ITextBox_put_HorizontalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> put_HorizontalAlignment(This,RHS) ) 

#define ITextBox_get_LockedText(This,RHS)	\
    ( (This)->lpVtbl -> get_LockedText(This,RHS) ) 

#define ITextBox_put_LockedText(This,RHS)	\
    ( (This)->lpVtbl -> put_LockedText(This,RHS) ) 

#define ITextBox_get_Orientation(This,RHS)	\
    ( (This)->lpVtbl -> get_Orientation(This,RHS) ) 

#define ITextBox_put_Orientation(This,RHS)	\
    ( (This)->lpVtbl -> put_Orientation(This,RHS) ) 

#define ITextBox_get_Text(This,RHS)	\
    ( (This)->lpVtbl -> get_Text(This,RHS) ) 

#define ITextBox_put_Text(This,RHS)	\
    ( (This)->lpVtbl -> put_Text(This,RHS) ) 

#define ITextBox_get_VerticalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> get_VerticalAlignment(This,RHS) ) 

#define ITextBox_put_VerticalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> put_VerticalAlignment(This,RHS) ) 

#define ITextBox_get_ReadingOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_ReadingOrder(This,RHS) ) 

#define ITextBox_put_ReadingOrder(This,RHS)	\
    ( (This)->lpVtbl -> put_ReadingOrder(This,RHS) ) 

#define ITextBox_get_Border(This,RHS)	\
    ( (This)->lpVtbl -> get_Border(This,RHS) ) 

#define ITextBox_get_Interior(This,RHS)	\
    ( (This)->lpVtbl -> get_Interior(This,RHS) ) 

#define ITextBox_get_RoundedCorners(This,RHS)	\
    ( (This)->lpVtbl -> get_RoundedCorners(This,RHS) ) 

#define ITextBox_put_RoundedCorners(This,RHS)	\
    ( (This)->lpVtbl -> put_RoundedCorners(This,RHS) ) 

#define ITextBox_get_Shadow(This,RHS)	\
    ( (This)->lpVtbl -> get_Shadow(This,RHS) ) 

#define ITextBox_put_Shadow(This,RHS)	\
    ( (This)->lpVtbl -> put_Shadow(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ITextBox_INTERFACE_DEFINED__ */


#ifndef __ITextBoxes_INTERFACE_DEFINED__
#define __ITextBoxes_INTERFACE_DEFINED__

/* interface ITextBoxes */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ITextBoxes;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000208A5-0001-0000-C000-000000000046")
    ITextBoxes : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy3( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall BringToFront( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Copy( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CopyPicture( 
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Cut( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Duplicate( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Enabled( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Enabled( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Height( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Height( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy12( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Left( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Left( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Locked( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Locked( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy15( void) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_OnAction( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_OnAction( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Placement( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Placement( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PrintObject( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PrintObject( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SendToBack( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Top( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Top( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy22( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Visible( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Visible( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Width( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Width( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ZOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShapeRange( 
            /* [retval][out] */ ShapeRange	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AddIndent( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AddIndent( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AutoScaleFont( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AutoScaleFont( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AutoSize( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AutoSize( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Caption( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Caption( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Characters( 
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Length,
            /* [retval][out] */ Characters	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CheckSpelling( 
            /* [optional][in] */ VARIANT CustomDictionary,
            /* [optional][in] */ VARIANT IgnoreUppercase,
            /* [optional][in] */ VARIANT AlwaysSuggest,
            /* [optional][in] */ VARIANT SpellLang,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Font( 
            /* [retval][out] */ Font	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Formula( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Formula( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HorizontalAlignment( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_HorizontalAlignment( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LockedText( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_LockedText( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Orientation( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Orientation( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Text( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Text( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_VerticalAlignment( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_VerticalAlignment( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ReadingOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ReadingOrder( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Border( 
            /* [retval][out] */ Border	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Interior( 
            /* [retval][out] */ Interior	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RoundedCorners( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_RoundedCorners( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Shadow( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Shadow( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add( 
            /* [in] */ double Left,
            /* [in] */ double Top,
            /* [in] */ double Width,
            /* [in] */ double Height,
            /* [retval][out] */ TextBox	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Group( 
            /* [retval][out] */ GroupObject	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall _NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ITextBoxesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ITextBoxes * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ITextBoxes * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ITextBoxes * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ITextBoxes * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ITextBoxes * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ITextBoxes * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ITextBoxes * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ITextBoxes * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ITextBoxes * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ITextBoxes * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy3 )( 
            ITextBoxes * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *BringToFront )( 
            ITextBoxes * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Copy )( 
            ITextBoxes * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CopyPicture )( 
            ITextBoxes * This,
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Cut )( 
            ITextBoxes * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            ITextBoxes * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Duplicate )( 
            ITextBoxes * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Enabled )( 
            ITextBoxes * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Enabled )( 
            ITextBoxes * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Height )( 
            ITextBoxes * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Height )( 
            ITextBoxes * This,
            /* [in] */ double RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy12 )( 
            ITextBoxes * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Left )( 
            ITextBoxes * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Left )( 
            ITextBoxes * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Locked )( 
            ITextBoxes * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Locked )( 
            ITextBoxes * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy15 )( 
            ITextBoxes * This);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_OnAction )( 
            ITextBoxes * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_OnAction )( 
            ITextBoxes * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Placement )( 
            ITextBoxes * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Placement )( 
            ITextBoxes * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PrintObject )( 
            ITextBoxes * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PrintObject )( 
            ITextBoxes * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            ITextBoxes * This,
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SendToBack )( 
            ITextBoxes * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Top )( 
            ITextBoxes * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Top )( 
            ITextBoxes * This,
            /* [in] */ double RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy22 )( 
            ITextBoxes * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Visible )( 
            ITextBoxes * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Visible )( 
            ITextBoxes * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Width )( 
            ITextBoxes * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Width )( 
            ITextBoxes * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ZOrder )( 
            ITextBoxes * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShapeRange )( 
            ITextBoxes * This,
            /* [retval][out] */ ShapeRange	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AddIndent )( 
            ITextBoxes * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AddIndent )( 
            ITextBoxes * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AutoScaleFont )( 
            ITextBoxes * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AutoScaleFont )( 
            ITextBoxes * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AutoSize )( 
            ITextBoxes * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AutoSize )( 
            ITextBoxes * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Caption )( 
            ITextBoxes * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Caption )( 
            ITextBoxes * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Characters )( 
            ITextBoxes * This,
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Length,
            /* [retval][out] */ Characters	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CheckSpelling )( 
            ITextBoxes * This,
            /* [optional][in] */ VARIANT CustomDictionary,
            /* [optional][in] */ VARIANT IgnoreUppercase,
            /* [optional][in] */ VARIANT AlwaysSuggest,
            /* [optional][in] */ VARIANT SpellLang,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Font )( 
            ITextBoxes * This,
            /* [retval][out] */ Font	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Formula )( 
            ITextBoxes * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Formula )( 
            ITextBoxes * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HorizontalAlignment )( 
            ITextBoxes * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_HorizontalAlignment )( 
            ITextBoxes * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LockedText )( 
            ITextBoxes * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_LockedText )( 
            ITextBoxes * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Orientation )( 
            ITextBoxes * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Orientation )( 
            ITextBoxes * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Text )( 
            ITextBoxes * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Text )( 
            ITextBoxes * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_VerticalAlignment )( 
            ITextBoxes * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_VerticalAlignment )( 
            ITextBoxes * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ReadingOrder )( 
            ITextBoxes * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ReadingOrder )( 
            ITextBoxes * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Border )( 
            ITextBoxes * This,
            /* [retval][out] */ Border	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Interior )( 
            ITextBoxes * This,
            /* [retval][out] */ Interior	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RoundedCorners )( 
            ITextBoxes * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_RoundedCorners )( 
            ITextBoxes * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Shadow )( 
            ITextBoxes * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Shadow )( 
            ITextBoxes * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add )( 
            ITextBoxes * This,
            /* [in] */ double Left,
            /* [in] */ double Top,
            /* [in] */ double Width,
            /* [in] */ double Height,
            /* [retval][out] */ TextBox	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            ITextBoxes * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Group )( 
            ITextBoxes * This,
            /* [retval][out] */ GroupObject	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Item )( 
            ITextBoxes * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *_NewEnum )( 
            ITextBoxes * This,
            /* [retval][out] */ IUnknown **RHS);
        
        END_INTERFACE
    } ITextBoxesVtbl;

    interface ITextBoxes
    {
        CONST_VTBL struct ITextBoxesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ITextBoxes_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ITextBoxes_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ITextBoxes_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ITextBoxes_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ITextBoxes_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ITextBoxes_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ITextBoxes_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ITextBoxes_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ITextBoxes_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ITextBoxes_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ITextBoxes__Dummy3(This)	\
    ( (This)->lpVtbl -> _Dummy3(This) ) 

#define ITextBoxes_BringToFront(This,RHS)	\
    ( (This)->lpVtbl -> BringToFront(This,RHS) ) 

#define ITextBoxes_Copy(This,RHS)	\
    ( (This)->lpVtbl -> Copy(This,RHS) ) 

#define ITextBoxes_CopyPicture(This,Appearance,Format,RHS)	\
    ( (This)->lpVtbl -> CopyPicture(This,Appearance,Format,RHS) ) 

#define ITextBoxes_Cut(This,RHS)	\
    ( (This)->lpVtbl -> Cut(This,RHS) ) 

#define ITextBoxes_Delete(This,RHS)	\
    ( (This)->lpVtbl -> Delete(This,RHS) ) 

#define ITextBoxes_Duplicate(This,RHS)	\
    ( (This)->lpVtbl -> Duplicate(This,RHS) ) 

#define ITextBoxes_get_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> get_Enabled(This,RHS) ) 

#define ITextBoxes_put_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> put_Enabled(This,RHS) ) 

#define ITextBoxes_get_Height(This,RHS)	\
    ( (This)->lpVtbl -> get_Height(This,RHS) ) 

#define ITextBoxes_put_Height(This,RHS)	\
    ( (This)->lpVtbl -> put_Height(This,RHS) ) 

#define ITextBoxes__Dummy12(This)	\
    ( (This)->lpVtbl -> _Dummy12(This) ) 

#define ITextBoxes_get_Left(This,RHS)	\
    ( (This)->lpVtbl -> get_Left(This,RHS) ) 

#define ITextBoxes_put_Left(This,RHS)	\
    ( (This)->lpVtbl -> put_Left(This,RHS) ) 

#define ITextBoxes_get_Locked(This,RHS)	\
    ( (This)->lpVtbl -> get_Locked(This,RHS) ) 

#define ITextBoxes_put_Locked(This,RHS)	\
    ( (This)->lpVtbl -> put_Locked(This,RHS) ) 

#define ITextBoxes__Dummy15(This)	\
    ( (This)->lpVtbl -> _Dummy15(This) ) 

#define ITextBoxes_get_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> get_OnAction(This,RHS) ) 

#define ITextBoxes_put_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> put_OnAction(This,RHS) ) 

#define ITextBoxes_get_Placement(This,RHS)	\
    ( (This)->lpVtbl -> get_Placement(This,RHS) ) 

#define ITextBoxes_put_Placement(This,RHS)	\
    ( (This)->lpVtbl -> put_Placement(This,RHS) ) 

#define ITextBoxes_get_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> get_PrintObject(This,RHS) ) 

#define ITextBoxes_put_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> put_PrintObject(This,RHS) ) 

#define ITextBoxes_Select(This,Replace,RHS)	\
    ( (This)->lpVtbl -> Select(This,Replace,RHS) ) 

#define ITextBoxes_SendToBack(This,RHS)	\
    ( (This)->lpVtbl -> SendToBack(This,RHS) ) 

#define ITextBoxes_get_Top(This,RHS)	\
    ( (This)->lpVtbl -> get_Top(This,RHS) ) 

#define ITextBoxes_put_Top(This,RHS)	\
    ( (This)->lpVtbl -> put_Top(This,RHS) ) 

#define ITextBoxes__Dummy22(This)	\
    ( (This)->lpVtbl -> _Dummy22(This) ) 

#define ITextBoxes_get_Visible(This,RHS)	\
    ( (This)->lpVtbl -> get_Visible(This,RHS) ) 

#define ITextBoxes_put_Visible(This,RHS)	\
    ( (This)->lpVtbl -> put_Visible(This,RHS) ) 

#define ITextBoxes_get_Width(This,RHS)	\
    ( (This)->lpVtbl -> get_Width(This,RHS) ) 

#define ITextBoxes_put_Width(This,RHS)	\
    ( (This)->lpVtbl -> put_Width(This,RHS) ) 

#define ITextBoxes_get_ZOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_ZOrder(This,RHS) ) 

#define ITextBoxes_get_ShapeRange(This,RHS)	\
    ( (This)->lpVtbl -> get_ShapeRange(This,RHS) ) 

#define ITextBoxes_get_AddIndent(This,RHS)	\
    ( (This)->lpVtbl -> get_AddIndent(This,RHS) ) 

#define ITextBoxes_put_AddIndent(This,RHS)	\
    ( (This)->lpVtbl -> put_AddIndent(This,RHS) ) 

#define ITextBoxes_get_AutoScaleFont(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoScaleFont(This,RHS) ) 

#define ITextBoxes_put_AutoScaleFont(This,RHS)	\
    ( (This)->lpVtbl -> put_AutoScaleFont(This,RHS) ) 

#define ITextBoxes_get_AutoSize(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoSize(This,RHS) ) 

#define ITextBoxes_put_AutoSize(This,RHS)	\
    ( (This)->lpVtbl -> put_AutoSize(This,RHS) ) 

#define ITextBoxes_get_Caption(This,RHS)	\
    ( (This)->lpVtbl -> get_Caption(This,RHS) ) 

#define ITextBoxes_put_Caption(This,RHS)	\
    ( (This)->lpVtbl -> put_Caption(This,RHS) ) 

#define ITextBoxes_get_Characters(This,Start,Length,RHS)	\
    ( (This)->lpVtbl -> get_Characters(This,Start,Length,RHS) ) 

#define ITextBoxes_CheckSpelling(This,CustomDictionary,IgnoreUppercase,AlwaysSuggest,SpellLang,RHS)	\
    ( (This)->lpVtbl -> CheckSpelling(This,CustomDictionary,IgnoreUppercase,AlwaysSuggest,SpellLang,RHS) ) 

#define ITextBoxes_get_Font(This,RHS)	\
    ( (This)->lpVtbl -> get_Font(This,RHS) ) 

#define ITextBoxes_get_Formula(This,RHS)	\
    ( (This)->lpVtbl -> get_Formula(This,RHS) ) 

#define ITextBoxes_put_Formula(This,RHS)	\
    ( (This)->lpVtbl -> put_Formula(This,RHS) ) 

#define ITextBoxes_get_HorizontalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> get_HorizontalAlignment(This,RHS) ) 

#define ITextBoxes_put_HorizontalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> put_HorizontalAlignment(This,RHS) ) 

#define ITextBoxes_get_LockedText(This,RHS)	\
    ( (This)->lpVtbl -> get_LockedText(This,RHS) ) 

#define ITextBoxes_put_LockedText(This,RHS)	\
    ( (This)->lpVtbl -> put_LockedText(This,RHS) ) 

#define ITextBoxes_get_Orientation(This,RHS)	\
    ( (This)->lpVtbl -> get_Orientation(This,RHS) ) 

#define ITextBoxes_put_Orientation(This,RHS)	\
    ( (This)->lpVtbl -> put_Orientation(This,RHS) ) 

#define ITextBoxes_get_Text(This,RHS)	\
    ( (This)->lpVtbl -> get_Text(This,RHS) ) 

#define ITextBoxes_put_Text(This,RHS)	\
    ( (This)->lpVtbl -> put_Text(This,RHS) ) 

#define ITextBoxes_get_VerticalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> get_VerticalAlignment(This,RHS) ) 

#define ITextBoxes_put_VerticalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> put_VerticalAlignment(This,RHS) ) 

#define ITextBoxes_get_ReadingOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_ReadingOrder(This,RHS) ) 

#define ITextBoxes_put_ReadingOrder(This,RHS)	\
    ( (This)->lpVtbl -> put_ReadingOrder(This,RHS) ) 

#define ITextBoxes_get_Border(This,RHS)	\
    ( (This)->lpVtbl -> get_Border(This,RHS) ) 

#define ITextBoxes_get_Interior(This,RHS)	\
    ( (This)->lpVtbl -> get_Interior(This,RHS) ) 

#define ITextBoxes_get_RoundedCorners(This,RHS)	\
    ( (This)->lpVtbl -> get_RoundedCorners(This,RHS) ) 

#define ITextBoxes_put_RoundedCorners(This,RHS)	\
    ( (This)->lpVtbl -> put_RoundedCorners(This,RHS) ) 

#define ITextBoxes_get_Shadow(This,RHS)	\
    ( (This)->lpVtbl -> get_Shadow(This,RHS) ) 

#define ITextBoxes_put_Shadow(This,RHS)	\
    ( (This)->lpVtbl -> put_Shadow(This,RHS) ) 

#define ITextBoxes_Add(This,Left,Top,Width,Height,RHS)	\
    ( (This)->lpVtbl -> Add(This,Left,Top,Width,Height,RHS) ) 

#define ITextBoxes_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define ITextBoxes_Group(This,RHS)	\
    ( (This)->lpVtbl -> Group(This,RHS) ) 

#define ITextBoxes_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> Item(This,Index,RHS) ) 

#define ITextBoxes__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> _NewEnum(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ITextBoxes_INTERFACE_DEFINED__ */


#ifndef __IPicture_INTERFACE_DEFINED__
#define __IPicture_INTERFACE_DEFINED__

/* interface IPicture */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IPicture;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000208A6-0001-0000-C000-000000000046")
    IPicture : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_BottomRightCell( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall BringToFront( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Copy( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CopyPicture( 
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Cut( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Duplicate( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Enabled( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Enabled( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Height( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Height( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Index( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Left( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Left( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Locked( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Locked( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Name( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_OnAction( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_OnAction( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Placement( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Placement( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PrintObject( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PrintObject( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SendToBack( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Top( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Top( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TopLeftCell( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Visible( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Visible( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Width( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Width( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ZOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShapeRange( 
            /* [retval][out] */ ShapeRange	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Border( 
            /* [retval][out] */ Border	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Interior( 
            /* [retval][out] */ Interior	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Shadow( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Shadow( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Formula( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Formula( 
            /* [in] */ BSTR RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IPictureVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IPicture * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IPicture * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IPicture * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IPicture * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IPicture * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IPicture * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IPicture * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IPicture * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IPicture * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IPicture * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_BottomRightCell )( 
            IPicture * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *BringToFront )( 
            IPicture * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Copy )( 
            IPicture * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CopyPicture )( 
            IPicture * This,
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Cut )( 
            IPicture * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IPicture * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Duplicate )( 
            IPicture * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Enabled )( 
            IPicture * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Enabled )( 
            IPicture * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Height )( 
            IPicture * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Height )( 
            IPicture * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Index )( 
            IPicture * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Left )( 
            IPicture * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Left )( 
            IPicture * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Locked )( 
            IPicture * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Locked )( 
            IPicture * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            IPicture * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Name )( 
            IPicture * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_OnAction )( 
            IPicture * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_OnAction )( 
            IPicture * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Placement )( 
            IPicture * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Placement )( 
            IPicture * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PrintObject )( 
            IPicture * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PrintObject )( 
            IPicture * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            IPicture * This,
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SendToBack )( 
            IPicture * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Top )( 
            IPicture * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Top )( 
            IPicture * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TopLeftCell )( 
            IPicture * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Visible )( 
            IPicture * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Visible )( 
            IPicture * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Width )( 
            IPicture * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Width )( 
            IPicture * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ZOrder )( 
            IPicture * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShapeRange )( 
            IPicture * This,
            /* [retval][out] */ ShapeRange	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Border )( 
            IPicture * This,
            /* [retval][out] */ Border	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Interior )( 
            IPicture * This,
            /* [retval][out] */ Interior	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Shadow )( 
            IPicture * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Shadow )( 
            IPicture * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Formula )( 
            IPicture * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Formula )( 
            IPicture * This,
            /* [in] */ BSTR RHS);
        
        END_INTERFACE
    } IPictureVtbl;

    interface IPicture
    {
        CONST_VTBL struct IPictureVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IPicture_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IPicture_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IPicture_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IPicture_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IPicture_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IPicture_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IPicture_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IPicture_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IPicture_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IPicture_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IPicture_get_BottomRightCell(This,RHS)	\
    ( (This)->lpVtbl -> get_BottomRightCell(This,RHS) ) 

#define IPicture_BringToFront(This,RHS)	\
    ( (This)->lpVtbl -> BringToFront(This,RHS) ) 

#define IPicture_Copy(This,RHS)	\
    ( (This)->lpVtbl -> Copy(This,RHS) ) 

#define IPicture_CopyPicture(This,Appearance,Format,RHS)	\
    ( (This)->lpVtbl -> CopyPicture(This,Appearance,Format,RHS) ) 

#define IPicture_Cut(This,RHS)	\
    ( (This)->lpVtbl -> Cut(This,RHS) ) 

#define IPicture_Delete(This,RHS)	\
    ( (This)->lpVtbl -> Delete(This,RHS) ) 

#define IPicture_Duplicate(This,RHS)	\
    ( (This)->lpVtbl -> Duplicate(This,RHS) ) 

#define IPicture_get_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> get_Enabled(This,RHS) ) 

#define IPicture_put_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> put_Enabled(This,RHS) ) 

#define IPicture_get_Height(This,RHS)	\
    ( (This)->lpVtbl -> get_Height(This,RHS) ) 

#define IPicture_put_Height(This,RHS)	\
    ( (This)->lpVtbl -> put_Height(This,RHS) ) 

#define IPicture_get_Index(This,RHS)	\
    ( (This)->lpVtbl -> get_Index(This,RHS) ) 

#define IPicture_get_Left(This,RHS)	\
    ( (This)->lpVtbl -> get_Left(This,RHS) ) 

#define IPicture_put_Left(This,RHS)	\
    ( (This)->lpVtbl -> put_Left(This,RHS) ) 

#define IPicture_get_Locked(This,RHS)	\
    ( (This)->lpVtbl -> get_Locked(This,RHS) ) 

#define IPicture_put_Locked(This,RHS)	\
    ( (This)->lpVtbl -> put_Locked(This,RHS) ) 

#define IPicture_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define IPicture_put_Name(This,RHS)	\
    ( (This)->lpVtbl -> put_Name(This,RHS) ) 

#define IPicture_get_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> get_OnAction(This,RHS) ) 

#define IPicture_put_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> put_OnAction(This,RHS) ) 

#define IPicture_get_Placement(This,RHS)	\
    ( (This)->lpVtbl -> get_Placement(This,RHS) ) 

#define IPicture_put_Placement(This,RHS)	\
    ( (This)->lpVtbl -> put_Placement(This,RHS) ) 

#define IPicture_get_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> get_PrintObject(This,RHS) ) 

#define IPicture_put_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> put_PrintObject(This,RHS) ) 

#define IPicture_Select(This,Replace,RHS)	\
    ( (This)->lpVtbl -> Select(This,Replace,RHS) ) 

#define IPicture_SendToBack(This,RHS)	\
    ( (This)->lpVtbl -> SendToBack(This,RHS) ) 

#define IPicture_get_Top(This,RHS)	\
    ( (This)->lpVtbl -> get_Top(This,RHS) ) 

#define IPicture_put_Top(This,RHS)	\
    ( (This)->lpVtbl -> put_Top(This,RHS) ) 

#define IPicture_get_TopLeftCell(This,RHS)	\
    ( (This)->lpVtbl -> get_TopLeftCell(This,RHS) ) 

#define IPicture_get_Visible(This,RHS)	\
    ( (This)->lpVtbl -> get_Visible(This,RHS) ) 

#define IPicture_put_Visible(This,RHS)	\
    ( (This)->lpVtbl -> put_Visible(This,RHS) ) 

#define IPicture_get_Width(This,RHS)	\
    ( (This)->lpVtbl -> get_Width(This,RHS) ) 

#define IPicture_put_Width(This,RHS)	\
    ( (This)->lpVtbl -> put_Width(This,RHS) ) 

#define IPicture_get_ZOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_ZOrder(This,RHS) ) 

#define IPicture_get_ShapeRange(This,RHS)	\
    ( (This)->lpVtbl -> get_ShapeRange(This,RHS) ) 

#define IPicture_get_Border(This,RHS)	\
    ( (This)->lpVtbl -> get_Border(This,RHS) ) 

#define IPicture_get_Interior(This,RHS)	\
    ( (This)->lpVtbl -> get_Interior(This,RHS) ) 

#define IPicture_get_Shadow(This,RHS)	\
    ( (This)->lpVtbl -> get_Shadow(This,RHS) ) 

#define IPicture_put_Shadow(This,RHS)	\
    ( (This)->lpVtbl -> put_Shadow(This,RHS) ) 

#define IPicture_get_Formula(This,RHS)	\
    ( (This)->lpVtbl -> get_Formula(This,RHS) ) 

#define IPicture_put_Formula(This,RHS)	\
    ( (This)->lpVtbl -> put_Formula(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IPicture_INTERFACE_DEFINED__ */


#ifndef __IPictures_INTERFACE_DEFINED__
#define __IPictures_INTERFACE_DEFINED__

/* interface IPictures */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IPictures;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000208A7-0001-0000-C000-000000000046")
    IPictures : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy3( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall BringToFront( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Copy( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CopyPicture( 
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Cut( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Duplicate( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Enabled( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Enabled( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Height( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Height( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy12( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Left( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Left( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Locked( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Locked( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy15( void) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_OnAction( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_OnAction( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Placement( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Placement( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PrintObject( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PrintObject( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SendToBack( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Top( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Top( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy22( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Visible( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Visible( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Width( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Width( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ZOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShapeRange( 
            /* [retval][out] */ ShapeRange	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Border( 
            /* [retval][out] */ Border	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Interior( 
            /* [retval][out] */ Interior	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Shadow( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Shadow( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Formula( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Formula( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add( 
            /* [in] */ double Left,
            /* [in] */ double Top,
            /* [in] */ double Width,
            /* [in] */ double Height,
            /* [retval][out] */ Picture	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Group( 
            /* [retval][out] */ GroupObject	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Insert( 
            /* [in] */ BSTR Filename,
            /* [optional][in] */ VARIANT Converter,
            /* [retval][out] */ Picture	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall _NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Paste( 
            /* [optional][in] */ VARIANT Link,
            /* [retval][out] */ Picture	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IPicturesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IPictures * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IPictures * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IPictures * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IPictures * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IPictures * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IPictures * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IPictures * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IPictures * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IPictures * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IPictures * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy3 )( 
            IPictures * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *BringToFront )( 
            IPictures * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Copy )( 
            IPictures * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CopyPicture )( 
            IPictures * This,
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Cut )( 
            IPictures * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IPictures * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Duplicate )( 
            IPictures * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Enabled )( 
            IPictures * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Enabled )( 
            IPictures * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Height )( 
            IPictures * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Height )( 
            IPictures * This,
            /* [in] */ double RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy12 )( 
            IPictures * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Left )( 
            IPictures * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Left )( 
            IPictures * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Locked )( 
            IPictures * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Locked )( 
            IPictures * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy15 )( 
            IPictures * This);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_OnAction )( 
            IPictures * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_OnAction )( 
            IPictures * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Placement )( 
            IPictures * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Placement )( 
            IPictures * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PrintObject )( 
            IPictures * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PrintObject )( 
            IPictures * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            IPictures * This,
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SendToBack )( 
            IPictures * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Top )( 
            IPictures * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Top )( 
            IPictures * This,
            /* [in] */ double RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy22 )( 
            IPictures * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Visible )( 
            IPictures * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Visible )( 
            IPictures * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Width )( 
            IPictures * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Width )( 
            IPictures * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ZOrder )( 
            IPictures * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShapeRange )( 
            IPictures * This,
            /* [retval][out] */ ShapeRange	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Border )( 
            IPictures * This,
            /* [retval][out] */ Border	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Interior )( 
            IPictures * This,
            /* [retval][out] */ Interior	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Shadow )( 
            IPictures * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Shadow )( 
            IPictures * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Formula )( 
            IPictures * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Formula )( 
            IPictures * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add )( 
            IPictures * This,
            /* [in] */ double Left,
            /* [in] */ double Top,
            /* [in] */ double Width,
            /* [in] */ double Height,
            /* [retval][out] */ Picture	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IPictures * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Group )( 
            IPictures * This,
            /* [retval][out] */ GroupObject	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Insert )( 
            IPictures * This,
            /* [in] */ BSTR Filename,
            /* [optional][in] */ VARIANT Converter,
            /* [retval][out] */ Picture	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Item )( 
            IPictures * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *_NewEnum )( 
            IPictures * This,
            /* [retval][out] */ IUnknown **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Paste )( 
            IPictures * This,
            /* [optional][in] */ VARIANT Link,
            /* [retval][out] */ Picture	**RHS);
        
        END_INTERFACE
    } IPicturesVtbl;

    interface IPictures
    {
        CONST_VTBL struct IPicturesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IPictures_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IPictures_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IPictures_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IPictures_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IPictures_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IPictures_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IPictures_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IPictures_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IPictures_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IPictures_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IPictures__Dummy3(This)	\
    ( (This)->lpVtbl -> _Dummy3(This) ) 

#define IPictures_BringToFront(This,RHS)	\
    ( (This)->lpVtbl -> BringToFront(This,RHS) ) 

#define IPictures_Copy(This,RHS)	\
    ( (This)->lpVtbl -> Copy(This,RHS) ) 

#define IPictures_CopyPicture(This,Appearance,Format,RHS)	\
    ( (This)->lpVtbl -> CopyPicture(This,Appearance,Format,RHS) ) 

#define IPictures_Cut(This,RHS)	\
    ( (This)->lpVtbl -> Cut(This,RHS) ) 

#define IPictures_Delete(This,RHS)	\
    ( (This)->lpVtbl -> Delete(This,RHS) ) 

#define IPictures_Duplicate(This,RHS)	\
    ( (This)->lpVtbl -> Duplicate(This,RHS) ) 

#define IPictures_get_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> get_Enabled(This,RHS) ) 

#define IPictures_put_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> put_Enabled(This,RHS) ) 

#define IPictures_get_Height(This,RHS)	\
    ( (This)->lpVtbl -> get_Height(This,RHS) ) 

#define IPictures_put_Height(This,RHS)	\
    ( (This)->lpVtbl -> put_Height(This,RHS) ) 

#define IPictures__Dummy12(This)	\
    ( (This)->lpVtbl -> _Dummy12(This) ) 

#define IPictures_get_Left(This,RHS)	\
    ( (This)->lpVtbl -> get_Left(This,RHS) ) 

#define IPictures_put_Left(This,RHS)	\
    ( (This)->lpVtbl -> put_Left(This,RHS) ) 

#define IPictures_get_Locked(This,RHS)	\
    ( (This)->lpVtbl -> get_Locked(This,RHS) ) 

#define IPictures_put_Locked(This,RHS)	\
    ( (This)->lpVtbl -> put_Locked(This,RHS) ) 

#define IPictures__Dummy15(This)	\
    ( (This)->lpVtbl -> _Dummy15(This) ) 

#define IPictures_get_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> get_OnAction(This,RHS) ) 

#define IPictures_put_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> put_OnAction(This,RHS) ) 

#define IPictures_get_Placement(This,RHS)	\
    ( (This)->lpVtbl -> get_Placement(This,RHS) ) 

#define IPictures_put_Placement(This,RHS)	\
    ( (This)->lpVtbl -> put_Placement(This,RHS) ) 

#define IPictures_get_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> get_PrintObject(This,RHS) ) 

#define IPictures_put_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> put_PrintObject(This,RHS) ) 

#define IPictures_Select(This,Replace,RHS)	\
    ( (This)->lpVtbl -> Select(This,Replace,RHS) ) 

#define IPictures_SendToBack(This,RHS)	\
    ( (This)->lpVtbl -> SendToBack(This,RHS) ) 

#define IPictures_get_Top(This,RHS)	\
    ( (This)->lpVtbl -> get_Top(This,RHS) ) 

#define IPictures_put_Top(This,RHS)	\
    ( (This)->lpVtbl -> put_Top(This,RHS) ) 

#define IPictures__Dummy22(This)	\
    ( (This)->lpVtbl -> _Dummy22(This) ) 

#define IPictures_get_Visible(This,RHS)	\
    ( (This)->lpVtbl -> get_Visible(This,RHS) ) 

#define IPictures_put_Visible(This,RHS)	\
    ( (This)->lpVtbl -> put_Visible(This,RHS) ) 

#define IPictures_get_Width(This,RHS)	\
    ( (This)->lpVtbl -> get_Width(This,RHS) ) 

#define IPictures_put_Width(This,RHS)	\
    ( (This)->lpVtbl -> put_Width(This,RHS) ) 

#define IPictures_get_ZOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_ZOrder(This,RHS) ) 

#define IPictures_get_ShapeRange(This,RHS)	\
    ( (This)->lpVtbl -> get_ShapeRange(This,RHS) ) 

#define IPictures_get_Border(This,RHS)	\
    ( (This)->lpVtbl -> get_Border(This,RHS) ) 

#define IPictures_get_Interior(This,RHS)	\
    ( (This)->lpVtbl -> get_Interior(This,RHS) ) 

#define IPictures_get_Shadow(This,RHS)	\
    ( (This)->lpVtbl -> get_Shadow(This,RHS) ) 

#define IPictures_put_Shadow(This,RHS)	\
    ( (This)->lpVtbl -> put_Shadow(This,RHS) ) 

#define IPictures_get_Formula(This,RHS)	\
    ( (This)->lpVtbl -> get_Formula(This,RHS) ) 

#define IPictures_put_Formula(This,RHS)	\
    ( (This)->lpVtbl -> put_Formula(This,RHS) ) 

#define IPictures_Add(This,Left,Top,Width,Height,RHS)	\
    ( (This)->lpVtbl -> Add(This,Left,Top,Width,Height,RHS) ) 

#define IPictures_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IPictures_Group(This,RHS)	\
    ( (This)->lpVtbl -> Group(This,RHS) ) 

#define IPictures_Insert(This,Filename,Converter,RHS)	\
    ( (This)->lpVtbl -> Insert(This,Filename,Converter,RHS) ) 

#define IPictures_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> Item(This,Index,RHS) ) 

#define IPictures__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> _NewEnum(This,RHS) ) 

#define IPictures_Paste(This,Link,RHS)	\
    ( (This)->lpVtbl -> Paste(This,Link,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IPictures_INTERFACE_DEFINED__ */


#ifndef __IDrawing_INTERFACE_DEFINED__
#define __IDrawing_INTERFACE_DEFINED__

/* interface IDrawing */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IDrawing;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000208A8-0001-0000-C000-000000000046")
    IDrawing : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_BottomRightCell( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall BringToFront( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Copy( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CopyPicture( 
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Cut( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Duplicate( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Enabled( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Enabled( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Height( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Height( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Index( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Left( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Left( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Locked( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Locked( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Name( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_OnAction( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_OnAction( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Placement( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Placement( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PrintObject( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PrintObject( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SendToBack( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Top( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Top( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TopLeftCell( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Visible( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Visible( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Width( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Width( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ZOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShapeRange( 
            /* [retval][out] */ ShapeRange	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AddIndent( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AddIndent( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AutoScaleFont( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AutoScaleFont( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AutoSize( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AutoSize( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Caption( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Caption( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Characters( 
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Length,
            /* [retval][out] */ Characters	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CheckSpelling( 
            /* [optional][in] */ VARIANT CustomDictionary,
            /* [optional][in] */ VARIANT IgnoreUppercase,
            /* [optional][in] */ VARIANT AlwaysSuggest,
            /* [optional][in] */ VARIANT SpellLang,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Font( 
            /* [retval][out] */ Font	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Formula( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Formula( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HorizontalAlignment( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_HorizontalAlignment( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LockedText( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_LockedText( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Orientation( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Orientation( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Text( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Text( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_VerticalAlignment( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_VerticalAlignment( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ReadingOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ReadingOrder( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Border( 
            /* [retval][out] */ Border	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Interior( 
            /* [retval][out] */ Interior	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Shadow( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Shadow( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall AddVertex( 
            /* [in] */ double Left,
            /* [in] */ double Top,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Reshape( 
            /* [in] */ long Vertex,
            /* [in] */ VARIANT_BOOL Insert,
            /* [optional][in] */ VARIANT Left,
            /* [optional][in] */ VARIANT Top,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Vertices( 
            /* [optional][in] */ VARIANT Index1,
            /* [optional][in] */ VARIANT Index2,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IDrawingVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IDrawing * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IDrawing * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IDrawing * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IDrawing * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IDrawing * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IDrawing * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IDrawing * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IDrawing * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IDrawing * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IDrawing * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_BottomRightCell )( 
            IDrawing * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *BringToFront )( 
            IDrawing * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Copy )( 
            IDrawing * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CopyPicture )( 
            IDrawing * This,
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Cut )( 
            IDrawing * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IDrawing * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Duplicate )( 
            IDrawing * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Enabled )( 
            IDrawing * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Enabled )( 
            IDrawing * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Height )( 
            IDrawing * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Height )( 
            IDrawing * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Index )( 
            IDrawing * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Left )( 
            IDrawing * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Left )( 
            IDrawing * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Locked )( 
            IDrawing * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Locked )( 
            IDrawing * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            IDrawing * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Name )( 
            IDrawing * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_OnAction )( 
            IDrawing * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_OnAction )( 
            IDrawing * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Placement )( 
            IDrawing * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Placement )( 
            IDrawing * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PrintObject )( 
            IDrawing * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PrintObject )( 
            IDrawing * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            IDrawing * This,
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SendToBack )( 
            IDrawing * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Top )( 
            IDrawing * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Top )( 
            IDrawing * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TopLeftCell )( 
            IDrawing * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Visible )( 
            IDrawing * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Visible )( 
            IDrawing * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Width )( 
            IDrawing * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Width )( 
            IDrawing * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ZOrder )( 
            IDrawing * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShapeRange )( 
            IDrawing * This,
            /* [retval][out] */ ShapeRange	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AddIndent )( 
            IDrawing * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AddIndent )( 
            IDrawing * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AutoScaleFont )( 
            IDrawing * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AutoScaleFont )( 
            IDrawing * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AutoSize )( 
            IDrawing * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AutoSize )( 
            IDrawing * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Caption )( 
            IDrawing * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Caption )( 
            IDrawing * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Characters )( 
            IDrawing * This,
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Length,
            /* [retval][out] */ Characters	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CheckSpelling )( 
            IDrawing * This,
            /* [optional][in] */ VARIANT CustomDictionary,
            /* [optional][in] */ VARIANT IgnoreUppercase,
            /* [optional][in] */ VARIANT AlwaysSuggest,
            /* [optional][in] */ VARIANT SpellLang,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Font )( 
            IDrawing * This,
            /* [retval][out] */ Font	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Formula )( 
            IDrawing * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Formula )( 
            IDrawing * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HorizontalAlignment )( 
            IDrawing * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_HorizontalAlignment )( 
            IDrawing * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LockedText )( 
            IDrawing * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_LockedText )( 
            IDrawing * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Orientation )( 
            IDrawing * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Orientation )( 
            IDrawing * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Text )( 
            IDrawing * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Text )( 
            IDrawing * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_VerticalAlignment )( 
            IDrawing * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_VerticalAlignment )( 
            IDrawing * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ReadingOrder )( 
            IDrawing * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ReadingOrder )( 
            IDrawing * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Border )( 
            IDrawing * This,
            /* [retval][out] */ Border	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Interior )( 
            IDrawing * This,
            /* [retval][out] */ Interior	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Shadow )( 
            IDrawing * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Shadow )( 
            IDrawing * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *AddVertex )( 
            IDrawing * This,
            /* [in] */ double Left,
            /* [in] */ double Top,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Reshape )( 
            IDrawing * This,
            /* [in] */ long Vertex,
            /* [in] */ VARIANT_BOOL Insert,
            /* [optional][in] */ VARIANT Left,
            /* [optional][in] */ VARIANT Top,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Vertices )( 
            IDrawing * This,
            /* [optional][in] */ VARIANT Index1,
            /* [optional][in] */ VARIANT Index2,
            /* [retval][out] */ VARIANT *RHS);
        
        END_INTERFACE
    } IDrawingVtbl;

    interface IDrawing
    {
        CONST_VTBL struct IDrawingVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IDrawing_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IDrawing_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IDrawing_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IDrawing_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IDrawing_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IDrawing_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IDrawing_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IDrawing_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IDrawing_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IDrawing_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IDrawing_get_BottomRightCell(This,RHS)	\
    ( (This)->lpVtbl -> get_BottomRightCell(This,RHS) ) 

#define IDrawing_BringToFront(This,RHS)	\
    ( (This)->lpVtbl -> BringToFront(This,RHS) ) 

#define IDrawing_Copy(This,RHS)	\
    ( (This)->lpVtbl -> Copy(This,RHS) ) 

#define IDrawing_CopyPicture(This,Appearance,Format,RHS)	\
    ( (This)->lpVtbl -> CopyPicture(This,Appearance,Format,RHS) ) 

#define IDrawing_Cut(This,RHS)	\
    ( (This)->lpVtbl -> Cut(This,RHS) ) 

#define IDrawing_Delete(This,RHS)	\
    ( (This)->lpVtbl -> Delete(This,RHS) ) 

#define IDrawing_Duplicate(This,RHS)	\
    ( (This)->lpVtbl -> Duplicate(This,RHS) ) 

#define IDrawing_get_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> get_Enabled(This,RHS) ) 

#define IDrawing_put_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> put_Enabled(This,RHS) ) 

#define IDrawing_get_Height(This,RHS)	\
    ( (This)->lpVtbl -> get_Height(This,RHS) ) 

#define IDrawing_put_Height(This,RHS)	\
    ( (This)->lpVtbl -> put_Height(This,RHS) ) 

#define IDrawing_get_Index(This,RHS)	\
    ( (This)->lpVtbl -> get_Index(This,RHS) ) 

#define IDrawing_get_Left(This,RHS)	\
    ( (This)->lpVtbl -> get_Left(This,RHS) ) 

#define IDrawing_put_Left(This,RHS)	\
    ( (This)->lpVtbl -> put_Left(This,RHS) ) 

#define IDrawing_get_Locked(This,RHS)	\
    ( (This)->lpVtbl -> get_Locked(This,RHS) ) 

#define IDrawing_put_Locked(This,RHS)	\
    ( (This)->lpVtbl -> put_Locked(This,RHS) ) 

#define IDrawing_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define IDrawing_put_Name(This,RHS)	\
    ( (This)->lpVtbl -> put_Name(This,RHS) ) 

#define IDrawing_get_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> get_OnAction(This,RHS) ) 

#define IDrawing_put_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> put_OnAction(This,RHS) ) 

#define IDrawing_get_Placement(This,RHS)	\
    ( (This)->lpVtbl -> get_Placement(This,RHS) ) 

#define IDrawing_put_Placement(This,RHS)	\
    ( (This)->lpVtbl -> put_Placement(This,RHS) ) 

#define IDrawing_get_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> get_PrintObject(This,RHS) ) 

#define IDrawing_put_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> put_PrintObject(This,RHS) ) 

#define IDrawing_Select(This,Replace,RHS)	\
    ( (This)->lpVtbl -> Select(This,Replace,RHS) ) 

#define IDrawing_SendToBack(This,RHS)	\
    ( (This)->lpVtbl -> SendToBack(This,RHS) ) 

#define IDrawing_get_Top(This,RHS)	\
    ( (This)->lpVtbl -> get_Top(This,RHS) ) 

#define IDrawing_put_Top(This,RHS)	\
    ( (This)->lpVtbl -> put_Top(This,RHS) ) 

#define IDrawing_get_TopLeftCell(This,RHS)	\
    ( (This)->lpVtbl -> get_TopLeftCell(This,RHS) ) 

#define IDrawing_get_Visible(This,RHS)	\
    ( (This)->lpVtbl -> get_Visible(This,RHS) ) 

#define IDrawing_put_Visible(This,RHS)	\
    ( (This)->lpVtbl -> put_Visible(This,RHS) ) 

#define IDrawing_get_Width(This,RHS)	\
    ( (This)->lpVtbl -> get_Width(This,RHS) ) 

#define IDrawing_put_Width(This,RHS)	\
    ( (This)->lpVtbl -> put_Width(This,RHS) ) 

#define IDrawing_get_ZOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_ZOrder(This,RHS) ) 

#define IDrawing_get_ShapeRange(This,RHS)	\
    ( (This)->lpVtbl -> get_ShapeRange(This,RHS) ) 

#define IDrawing_get_AddIndent(This,RHS)	\
    ( (This)->lpVtbl -> get_AddIndent(This,RHS) ) 

#define IDrawing_put_AddIndent(This,RHS)	\
    ( (This)->lpVtbl -> put_AddIndent(This,RHS) ) 

#define IDrawing_get_AutoScaleFont(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoScaleFont(This,RHS) ) 

#define IDrawing_put_AutoScaleFont(This,RHS)	\
    ( (This)->lpVtbl -> put_AutoScaleFont(This,RHS) ) 

#define IDrawing_get_AutoSize(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoSize(This,RHS) ) 

#define IDrawing_put_AutoSize(This,RHS)	\
    ( (This)->lpVtbl -> put_AutoSize(This,RHS) ) 

#define IDrawing_get_Caption(This,RHS)	\
    ( (This)->lpVtbl -> get_Caption(This,RHS) ) 

#define IDrawing_put_Caption(This,RHS)	\
    ( (This)->lpVtbl -> put_Caption(This,RHS) ) 

#define IDrawing_get_Characters(This,Start,Length,RHS)	\
    ( (This)->lpVtbl -> get_Characters(This,Start,Length,RHS) ) 

#define IDrawing_CheckSpelling(This,CustomDictionary,IgnoreUppercase,AlwaysSuggest,SpellLang,RHS)	\
    ( (This)->lpVtbl -> CheckSpelling(This,CustomDictionary,IgnoreUppercase,AlwaysSuggest,SpellLang,RHS) ) 

#define IDrawing_get_Font(This,RHS)	\
    ( (This)->lpVtbl -> get_Font(This,RHS) ) 

#define IDrawing_get_Formula(This,RHS)	\
    ( (This)->lpVtbl -> get_Formula(This,RHS) ) 

#define IDrawing_put_Formula(This,RHS)	\
    ( (This)->lpVtbl -> put_Formula(This,RHS) ) 

#define IDrawing_get_HorizontalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> get_HorizontalAlignment(This,RHS) ) 

#define IDrawing_put_HorizontalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> put_HorizontalAlignment(This,RHS) ) 

#define IDrawing_get_LockedText(This,RHS)	\
    ( (This)->lpVtbl -> get_LockedText(This,RHS) ) 

#define IDrawing_put_LockedText(This,RHS)	\
    ( (This)->lpVtbl -> put_LockedText(This,RHS) ) 

#define IDrawing_get_Orientation(This,RHS)	\
    ( (This)->lpVtbl -> get_Orientation(This,RHS) ) 

#define IDrawing_put_Orientation(This,RHS)	\
    ( (This)->lpVtbl -> put_Orientation(This,RHS) ) 

#define IDrawing_get_Text(This,RHS)	\
    ( (This)->lpVtbl -> get_Text(This,RHS) ) 

#define IDrawing_put_Text(This,RHS)	\
    ( (This)->lpVtbl -> put_Text(This,RHS) ) 

#define IDrawing_get_VerticalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> get_VerticalAlignment(This,RHS) ) 

#define IDrawing_put_VerticalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> put_VerticalAlignment(This,RHS) ) 

#define IDrawing_get_ReadingOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_ReadingOrder(This,RHS) ) 

#define IDrawing_put_ReadingOrder(This,RHS)	\
    ( (This)->lpVtbl -> put_ReadingOrder(This,RHS) ) 

#define IDrawing_get_Border(This,RHS)	\
    ( (This)->lpVtbl -> get_Border(This,RHS) ) 

#define IDrawing_get_Interior(This,RHS)	\
    ( (This)->lpVtbl -> get_Interior(This,RHS) ) 

#define IDrawing_get_Shadow(This,RHS)	\
    ( (This)->lpVtbl -> get_Shadow(This,RHS) ) 

#define IDrawing_put_Shadow(This,RHS)	\
    ( (This)->lpVtbl -> put_Shadow(This,RHS) ) 

#define IDrawing_AddVertex(This,Left,Top,RHS)	\
    ( (This)->lpVtbl -> AddVertex(This,Left,Top,RHS) ) 

#define IDrawing_Reshape(This,Vertex,Insert,Left,Top,RHS)	\
    ( (This)->lpVtbl -> Reshape(This,Vertex,Insert,Left,Top,RHS) ) 

#define IDrawing_get_Vertices(This,Index1,Index2,RHS)	\
    ( (This)->lpVtbl -> get_Vertices(This,Index1,Index2,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IDrawing_INTERFACE_DEFINED__ */


#ifndef __IDrawings_INTERFACE_DEFINED__
#define __IDrawings_INTERFACE_DEFINED__

/* interface IDrawings */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IDrawings;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000208A9-0001-0000-C000-000000000046")
    IDrawings : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy3( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall BringToFront( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Copy( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CopyPicture( 
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Cut( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Duplicate( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Enabled( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Enabled( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Height( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Height( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy12( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Left( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Left( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Locked( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Locked( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy15( void) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_OnAction( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_OnAction( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Placement( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Placement( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PrintObject( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PrintObject( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SendToBack( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Top( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Top( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy22( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Visible( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Visible( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Width( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Width( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ZOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShapeRange( 
            /* [retval][out] */ ShapeRange	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AddIndent( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AddIndent( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AutoScaleFont( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AutoScaleFont( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AutoSize( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AutoSize( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Caption( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Caption( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Characters( 
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Length,
            /* [retval][out] */ Characters	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CheckSpelling( 
            /* [optional][in] */ VARIANT CustomDictionary,
            /* [optional][in] */ VARIANT IgnoreUppercase,
            /* [optional][in] */ VARIANT AlwaysSuggest,
            /* [optional][in] */ VARIANT SpellLang,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Font( 
            /* [retval][out] */ Font	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Formula( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Formula( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HorizontalAlignment( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_HorizontalAlignment( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LockedText( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_LockedText( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Orientation( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Orientation( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Text( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Text( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_VerticalAlignment( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_VerticalAlignment( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ReadingOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ReadingOrder( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Border( 
            /* [retval][out] */ Border	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Interior( 
            /* [retval][out] */ Interior	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Shadow( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Shadow( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy44( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Reshape( 
            /* [in] */ long Vertex,
            /* [in] */ VARIANT_BOOL Insert,
            /* [optional][in] */ VARIANT Left,
            /* [optional][in] */ VARIANT Top,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy46( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add( 
            /* [in] */ double X1,
            /* [in] */ double Y1,
            /* [in] */ double X2,
            /* [in] */ double Y2,
            /* [in] */ VARIANT_BOOL Closed,
            /* [retval][out] */ Drawing	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Group( 
            /* [retval][out] */ GroupObject	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall _NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IDrawingsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IDrawings * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IDrawings * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IDrawings * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IDrawings * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IDrawings * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IDrawings * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IDrawings * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IDrawings * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IDrawings * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IDrawings * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy3 )( 
            IDrawings * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *BringToFront )( 
            IDrawings * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Copy )( 
            IDrawings * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CopyPicture )( 
            IDrawings * This,
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Cut )( 
            IDrawings * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IDrawings * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Duplicate )( 
            IDrawings * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Enabled )( 
            IDrawings * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Enabled )( 
            IDrawings * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Height )( 
            IDrawings * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Height )( 
            IDrawings * This,
            /* [in] */ double RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy12 )( 
            IDrawings * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Left )( 
            IDrawings * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Left )( 
            IDrawings * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Locked )( 
            IDrawings * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Locked )( 
            IDrawings * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy15 )( 
            IDrawings * This);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_OnAction )( 
            IDrawings * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_OnAction )( 
            IDrawings * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Placement )( 
            IDrawings * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Placement )( 
            IDrawings * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PrintObject )( 
            IDrawings * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PrintObject )( 
            IDrawings * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            IDrawings * This,
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SendToBack )( 
            IDrawings * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Top )( 
            IDrawings * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Top )( 
            IDrawings * This,
            /* [in] */ double RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy22 )( 
            IDrawings * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Visible )( 
            IDrawings * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Visible )( 
            IDrawings * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Width )( 
            IDrawings * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Width )( 
            IDrawings * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ZOrder )( 
            IDrawings * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShapeRange )( 
            IDrawings * This,
            /* [retval][out] */ ShapeRange	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AddIndent )( 
            IDrawings * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AddIndent )( 
            IDrawings * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AutoScaleFont )( 
            IDrawings * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AutoScaleFont )( 
            IDrawings * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AutoSize )( 
            IDrawings * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AutoSize )( 
            IDrawings * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Caption )( 
            IDrawings * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Caption )( 
            IDrawings * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Characters )( 
            IDrawings * This,
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Length,
            /* [retval][out] */ Characters	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CheckSpelling )( 
            IDrawings * This,
            /* [optional][in] */ VARIANT CustomDictionary,
            /* [optional][in] */ VARIANT IgnoreUppercase,
            /* [optional][in] */ VARIANT AlwaysSuggest,
            /* [optional][in] */ VARIANT SpellLang,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Font )( 
            IDrawings * This,
            /* [retval][out] */ Font	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Formula )( 
            IDrawings * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Formula )( 
            IDrawings * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HorizontalAlignment )( 
            IDrawings * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_HorizontalAlignment )( 
            IDrawings * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LockedText )( 
            IDrawings * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_LockedText )( 
            IDrawings * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Orientation )( 
            IDrawings * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Orientation )( 
            IDrawings * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Text )( 
            IDrawings * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Text )( 
            IDrawings * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_VerticalAlignment )( 
            IDrawings * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_VerticalAlignment )( 
            IDrawings * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ReadingOrder )( 
            IDrawings * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ReadingOrder )( 
            IDrawings * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Border )( 
            IDrawings * This,
            /* [retval][out] */ Border	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Interior )( 
            IDrawings * This,
            /* [retval][out] */ Interior	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Shadow )( 
            IDrawings * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Shadow )( 
            IDrawings * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy44 )( 
            IDrawings * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Reshape )( 
            IDrawings * This,
            /* [in] */ long Vertex,
            /* [in] */ VARIANT_BOOL Insert,
            /* [optional][in] */ VARIANT Left,
            /* [optional][in] */ VARIANT Top,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy46 )( 
            IDrawings * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add )( 
            IDrawings * This,
            /* [in] */ double X1,
            /* [in] */ double Y1,
            /* [in] */ double X2,
            /* [in] */ double Y2,
            /* [in] */ VARIANT_BOOL Closed,
            /* [retval][out] */ Drawing	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IDrawings * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Group )( 
            IDrawings * This,
            /* [retval][out] */ GroupObject	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Item )( 
            IDrawings * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *_NewEnum )( 
            IDrawings * This,
            /* [retval][out] */ IUnknown **RHS);
        
        END_INTERFACE
    } IDrawingsVtbl;

    interface IDrawings
    {
        CONST_VTBL struct IDrawingsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IDrawings_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IDrawings_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IDrawings_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IDrawings_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IDrawings_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IDrawings_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IDrawings_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IDrawings_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IDrawings_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IDrawings_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IDrawings__Dummy3(This)	\
    ( (This)->lpVtbl -> _Dummy3(This) ) 

#define IDrawings_BringToFront(This,RHS)	\
    ( (This)->lpVtbl -> BringToFront(This,RHS) ) 

#define IDrawings_Copy(This,RHS)	\
    ( (This)->lpVtbl -> Copy(This,RHS) ) 

#define IDrawings_CopyPicture(This,Appearance,Format,RHS)	\
    ( (This)->lpVtbl -> CopyPicture(This,Appearance,Format,RHS) ) 

#define IDrawings_Cut(This,RHS)	\
    ( (This)->lpVtbl -> Cut(This,RHS) ) 

#define IDrawings_Delete(This,RHS)	\
    ( (This)->lpVtbl -> Delete(This,RHS) ) 

#define IDrawings_Duplicate(This,RHS)	\
    ( (This)->lpVtbl -> Duplicate(This,RHS) ) 

#define IDrawings_get_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> get_Enabled(This,RHS) ) 

#define IDrawings_put_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> put_Enabled(This,RHS) ) 

#define IDrawings_get_Height(This,RHS)	\
    ( (This)->lpVtbl -> get_Height(This,RHS) ) 

#define IDrawings_put_Height(This,RHS)	\
    ( (This)->lpVtbl -> put_Height(This,RHS) ) 

#define IDrawings__Dummy12(This)	\
    ( (This)->lpVtbl -> _Dummy12(This) ) 

#define IDrawings_get_Left(This,RHS)	\
    ( (This)->lpVtbl -> get_Left(This,RHS) ) 

#define IDrawings_put_Left(This,RHS)	\
    ( (This)->lpVtbl -> put_Left(This,RHS) ) 

#define IDrawings_get_Locked(This,RHS)	\
    ( (This)->lpVtbl -> get_Locked(This,RHS) ) 

#define IDrawings_put_Locked(This,RHS)	\
    ( (This)->lpVtbl -> put_Locked(This,RHS) ) 

#define IDrawings__Dummy15(This)	\
    ( (This)->lpVtbl -> _Dummy15(This) ) 

#define IDrawings_get_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> get_OnAction(This,RHS) ) 

#define IDrawings_put_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> put_OnAction(This,RHS) ) 

#define IDrawings_get_Placement(This,RHS)	\
    ( (This)->lpVtbl -> get_Placement(This,RHS) ) 

#define IDrawings_put_Placement(This,RHS)	\
    ( (This)->lpVtbl -> put_Placement(This,RHS) ) 

#define IDrawings_get_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> get_PrintObject(This,RHS) ) 

#define IDrawings_put_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> put_PrintObject(This,RHS) ) 

#define IDrawings_Select(This,Replace,RHS)	\
    ( (This)->lpVtbl -> Select(This,Replace,RHS) ) 

#define IDrawings_SendToBack(This,RHS)	\
    ( (This)->lpVtbl -> SendToBack(This,RHS) ) 

#define IDrawings_get_Top(This,RHS)	\
    ( (This)->lpVtbl -> get_Top(This,RHS) ) 

#define IDrawings_put_Top(This,RHS)	\
    ( (This)->lpVtbl -> put_Top(This,RHS) ) 

#define IDrawings__Dummy22(This)	\
    ( (This)->lpVtbl -> _Dummy22(This) ) 

#define IDrawings_get_Visible(This,RHS)	\
    ( (This)->lpVtbl -> get_Visible(This,RHS) ) 

#define IDrawings_put_Visible(This,RHS)	\
    ( (This)->lpVtbl -> put_Visible(This,RHS) ) 

#define IDrawings_get_Width(This,RHS)	\
    ( (This)->lpVtbl -> get_Width(This,RHS) ) 

#define IDrawings_put_Width(This,RHS)	\
    ( (This)->lpVtbl -> put_Width(This,RHS) ) 

#define IDrawings_get_ZOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_ZOrder(This,RHS) ) 

#define IDrawings_get_ShapeRange(This,RHS)	\
    ( (This)->lpVtbl -> get_ShapeRange(This,RHS) ) 

#define IDrawings_get_AddIndent(This,RHS)	\
    ( (This)->lpVtbl -> get_AddIndent(This,RHS) ) 

#define IDrawings_put_AddIndent(This,RHS)	\
    ( (This)->lpVtbl -> put_AddIndent(This,RHS) ) 

#define IDrawings_get_AutoScaleFont(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoScaleFont(This,RHS) ) 

#define IDrawings_put_AutoScaleFont(This,RHS)	\
    ( (This)->lpVtbl -> put_AutoScaleFont(This,RHS) ) 

#define IDrawings_get_AutoSize(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoSize(This,RHS) ) 

#define IDrawings_put_AutoSize(This,RHS)	\
    ( (This)->lpVtbl -> put_AutoSize(This,RHS) ) 

#define IDrawings_get_Caption(This,RHS)	\
    ( (This)->lpVtbl -> get_Caption(This,RHS) ) 

#define IDrawings_put_Caption(This,RHS)	\
    ( (This)->lpVtbl -> put_Caption(This,RHS) ) 

#define IDrawings_get_Characters(This,Start,Length,RHS)	\
    ( (This)->lpVtbl -> get_Characters(This,Start,Length,RHS) ) 

#define IDrawings_CheckSpelling(This,CustomDictionary,IgnoreUppercase,AlwaysSuggest,SpellLang,RHS)	\
    ( (This)->lpVtbl -> CheckSpelling(This,CustomDictionary,IgnoreUppercase,AlwaysSuggest,SpellLang,RHS) ) 

#define IDrawings_get_Font(This,RHS)	\
    ( (This)->lpVtbl -> get_Font(This,RHS) ) 

#define IDrawings_get_Formula(This,RHS)	\
    ( (This)->lpVtbl -> get_Formula(This,RHS) ) 

#define IDrawings_put_Formula(This,RHS)	\
    ( (This)->lpVtbl -> put_Formula(This,RHS) ) 

#define IDrawings_get_HorizontalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> get_HorizontalAlignment(This,RHS) ) 

#define IDrawings_put_HorizontalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> put_HorizontalAlignment(This,RHS) ) 

#define IDrawings_get_LockedText(This,RHS)	\
    ( (This)->lpVtbl -> get_LockedText(This,RHS) ) 

#define IDrawings_put_LockedText(This,RHS)	\
    ( (This)->lpVtbl -> put_LockedText(This,RHS) ) 

#define IDrawings_get_Orientation(This,RHS)	\
    ( (This)->lpVtbl -> get_Orientation(This,RHS) ) 

#define IDrawings_put_Orientation(This,RHS)	\
    ( (This)->lpVtbl -> put_Orientation(This,RHS) ) 

#define IDrawings_get_Text(This,RHS)	\
    ( (This)->lpVtbl -> get_Text(This,RHS) ) 

#define IDrawings_put_Text(This,RHS)	\
    ( (This)->lpVtbl -> put_Text(This,RHS) ) 

#define IDrawings_get_VerticalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> get_VerticalAlignment(This,RHS) ) 

#define IDrawings_put_VerticalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> put_VerticalAlignment(This,RHS) ) 

#define IDrawings_get_ReadingOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_ReadingOrder(This,RHS) ) 

#define IDrawings_put_ReadingOrder(This,RHS)	\
    ( (This)->lpVtbl -> put_ReadingOrder(This,RHS) ) 

#define IDrawings_get_Border(This,RHS)	\
    ( (This)->lpVtbl -> get_Border(This,RHS) ) 

#define IDrawings_get_Interior(This,RHS)	\
    ( (This)->lpVtbl -> get_Interior(This,RHS) ) 

#define IDrawings_get_Shadow(This,RHS)	\
    ( (This)->lpVtbl -> get_Shadow(This,RHS) ) 

#define IDrawings_put_Shadow(This,RHS)	\
    ( (This)->lpVtbl -> put_Shadow(This,RHS) ) 

#define IDrawings__Dummy44(This)	\
    ( (This)->lpVtbl -> _Dummy44(This) ) 

#define IDrawings_Reshape(This,Vertex,Insert,Left,Top,RHS)	\
    ( (This)->lpVtbl -> Reshape(This,Vertex,Insert,Left,Top,RHS) ) 

#define IDrawings__Dummy46(This)	\
    ( (This)->lpVtbl -> _Dummy46(This) ) 

#define IDrawings_Add(This,X1,Y1,X2,Y2,Closed,RHS)	\
    ( (This)->lpVtbl -> Add(This,X1,Y1,X2,Y2,Closed,RHS) ) 

#define IDrawings_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IDrawings_Group(This,RHS)	\
    ( (This)->lpVtbl -> Group(This,RHS) ) 

#define IDrawings_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> Item(This,Index,RHS) ) 

#define IDrawings__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> _NewEnum(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IDrawings_INTERFACE_DEFINED__ */


#ifndef __IRoutingSlip_INTERFACE_DEFINED__
#define __IRoutingSlip_INTERFACE_DEFINED__

/* interface IRoutingSlip */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IRoutingSlip;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000208AA-0001-0000-C000-000000000046")
    IRoutingSlip : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Delivery( 
            /* [retval][out] */ XlRoutingSlipDelivery *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Delivery( 
            /* [in] */ XlRoutingSlipDelivery RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Message( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Message( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Recipients( 
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Recipients( 
            /* [optional][in] */ VARIANT Index,
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Reset( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ReturnWhenDone( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ReturnWhenDone( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Status( 
            /* [retval][out] */ XlRoutingSlipStatus *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Subject( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Subject( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TrackStatus( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_TrackStatus( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IRoutingSlipVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IRoutingSlip * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IRoutingSlip * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IRoutingSlip * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IRoutingSlip * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IRoutingSlip * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IRoutingSlip * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IRoutingSlip * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IRoutingSlip * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IRoutingSlip * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IRoutingSlip * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Delivery )( 
            IRoutingSlip * This,
            /* [retval][out] */ XlRoutingSlipDelivery *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Delivery )( 
            IRoutingSlip * This,
            /* [in] */ XlRoutingSlipDelivery RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Message )( 
            IRoutingSlip * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Message )( 
            IRoutingSlip * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Recipients )( 
            IRoutingSlip * This,
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Recipients )( 
            IRoutingSlip * This,
            /* [optional][in] */ VARIANT Index,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Reset )( 
            IRoutingSlip * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ReturnWhenDone )( 
            IRoutingSlip * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ReturnWhenDone )( 
            IRoutingSlip * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Status )( 
            IRoutingSlip * This,
            /* [retval][out] */ XlRoutingSlipStatus *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Subject )( 
            IRoutingSlip * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Subject )( 
            IRoutingSlip * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TrackStatus )( 
            IRoutingSlip * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_TrackStatus )( 
            IRoutingSlip * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        END_INTERFACE
    } IRoutingSlipVtbl;

    interface IRoutingSlip
    {
        CONST_VTBL struct IRoutingSlipVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IRoutingSlip_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IRoutingSlip_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IRoutingSlip_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IRoutingSlip_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IRoutingSlip_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IRoutingSlip_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IRoutingSlip_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IRoutingSlip_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IRoutingSlip_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IRoutingSlip_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IRoutingSlip_get_Delivery(This,RHS)	\
    ( (This)->lpVtbl -> get_Delivery(This,RHS) ) 

#define IRoutingSlip_put_Delivery(This,RHS)	\
    ( (This)->lpVtbl -> put_Delivery(This,RHS) ) 

#define IRoutingSlip_get_Message(This,RHS)	\
    ( (This)->lpVtbl -> get_Message(This,RHS) ) 

#define IRoutingSlip_put_Message(This,RHS)	\
    ( (This)->lpVtbl -> put_Message(This,RHS) ) 

#define IRoutingSlip_get_Recipients(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Recipients(This,Index,RHS) ) 

#define IRoutingSlip_put_Recipients(This,Index,RHS)	\
    ( (This)->lpVtbl -> put_Recipients(This,Index,RHS) ) 

#define IRoutingSlip_Reset(This,RHS)	\
    ( (This)->lpVtbl -> Reset(This,RHS) ) 

#define IRoutingSlip_get_ReturnWhenDone(This,RHS)	\
    ( (This)->lpVtbl -> get_ReturnWhenDone(This,RHS) ) 

#define IRoutingSlip_put_ReturnWhenDone(This,RHS)	\
    ( (This)->lpVtbl -> put_ReturnWhenDone(This,RHS) ) 

#define IRoutingSlip_get_Status(This,RHS)	\
    ( (This)->lpVtbl -> get_Status(This,RHS) ) 

#define IRoutingSlip_get_Subject(This,RHS)	\
    ( (This)->lpVtbl -> get_Subject(This,RHS) ) 

#define IRoutingSlip_put_Subject(This,RHS)	\
    ( (This)->lpVtbl -> put_Subject(This,RHS) ) 

#define IRoutingSlip_get_TrackStatus(This,RHS)	\
    ( (This)->lpVtbl -> get_TrackStatus(This,RHS) ) 

#define IRoutingSlip_put_TrackStatus(This,RHS)	\
    ( (This)->lpVtbl -> put_TrackStatus(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IRoutingSlip_INTERFACE_DEFINED__ */


#ifndef __IOutline_INTERFACE_DEFINED__
#define __IOutline_INTERFACE_DEFINED__

/* interface IOutline */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IOutline;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000208AB-0001-0000-C000-000000000046")
    IOutline : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AutomaticStyles( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AutomaticStyles( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ShowLevels( 
            /* [optional][in] */ VARIANT RowLevels,
            /* [optional][in] */ VARIANT ColumnLevels,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SummaryColumn( 
            /* [retval][out] */ XlSummaryColumn *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_SummaryColumn( 
            /* [in] */ XlSummaryColumn RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SummaryRow( 
            /* [retval][out] */ XlSummaryRow *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_SummaryRow( 
            /* [in] */ XlSummaryRow RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IOutlineVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IOutline * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IOutline * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IOutline * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IOutline * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IOutline * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IOutline * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IOutline * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IOutline * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IOutline * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IOutline * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AutomaticStyles )( 
            IOutline * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AutomaticStyles )( 
            IOutline * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ShowLevels )( 
            IOutline * This,
            /* [optional][in] */ VARIANT RowLevels,
            /* [optional][in] */ VARIANT ColumnLevels,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SummaryColumn )( 
            IOutline * This,
            /* [retval][out] */ XlSummaryColumn *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_SummaryColumn )( 
            IOutline * This,
            /* [in] */ XlSummaryColumn RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SummaryRow )( 
            IOutline * This,
            /* [retval][out] */ XlSummaryRow *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_SummaryRow )( 
            IOutline * This,
            /* [in] */ XlSummaryRow RHS);
        
        END_INTERFACE
    } IOutlineVtbl;

    interface IOutline
    {
        CONST_VTBL struct IOutlineVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IOutline_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IOutline_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IOutline_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IOutline_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IOutline_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IOutline_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IOutline_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IOutline_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IOutline_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IOutline_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IOutline_get_AutomaticStyles(This,RHS)	\
    ( (This)->lpVtbl -> get_AutomaticStyles(This,RHS) ) 

#define IOutline_put_AutomaticStyles(This,RHS)	\
    ( (This)->lpVtbl -> put_AutomaticStyles(This,RHS) ) 

#define IOutline_ShowLevels(This,RowLevels,ColumnLevels,RHS)	\
    ( (This)->lpVtbl -> ShowLevels(This,RowLevels,ColumnLevels,RHS) ) 

#define IOutline_get_SummaryColumn(This,RHS)	\
    ( (This)->lpVtbl -> get_SummaryColumn(This,RHS) ) 

#define IOutline_put_SummaryColumn(This,RHS)	\
    ( (This)->lpVtbl -> put_SummaryColumn(This,RHS) ) 

#define IOutline_get_SummaryRow(This,RHS)	\
    ( (This)->lpVtbl -> get_SummaryRow(This,RHS) ) 

#define IOutline_put_SummaryRow(This,RHS)	\
    ( (This)->lpVtbl -> put_SummaryRow(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IOutline_INTERFACE_DEFINED__ */


#ifndef __IModule_INTERFACE_DEFINED__
#define __IModule_INTERFACE_DEFINED__

/* interface IModule */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IModule;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000208AD-0001-0000-C000-000000000046")
    IModule : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Activate( 
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Copy( 
            /* [optional][in] */ VARIANT Before,
            /* [optional][in] */ VARIANT After,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CodeName( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__CodeName( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put__CodeName( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Index( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Move( 
            /* [optional][in] */ VARIANT Before,
            /* [optional][in] */ VARIANT After,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Name( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Next( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_OnDoubleClick( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_OnDoubleClick( 
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_OnSheetActivate( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_OnSheetActivate( 
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_OnSheetDeactivate( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_OnSheetDeactivate( 
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PageSetup( 
            /* [retval][out] */ PageSetup	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Previous( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [custom][helpcontext][hidden][id] */ HRESULT __stdcall __PrintOut( 
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy18( void) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall _Protect( 
            /* [optional][in] */ VARIANT Password,
            /* [optional][in] */ VARIANT DrawingObjects,
            /* [optional][in] */ VARIANT Contents,
            /* [optional][in] */ VARIANT Scenarios,
            /* [optional][in] */ VARIANT UserInterfaceOnly,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ProtectContents( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy21( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ProtectionMode( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy23( void) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall _SaveAs( 
            /* [in] */ BSTR Filename,
            /* [optional][in] */ VARIANT FileFormat,
            /* [optional][in] */ VARIANT Password,
            /* [optional][in] */ VARIANT WriteResPassword,
            /* [optional][in] */ VARIANT ReadOnlyRecommended,
            /* [optional][in] */ VARIANT CreateBackup,
            /* [optional][in] */ VARIANT AddToMru,
            /* [optional][in] */ VARIANT TextCodepage,
            /* [optional][in] */ VARIANT TextVisualLayout,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [optional][in] */ VARIANT Replace,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Unprotect( 
            /* [optional][in] */ VARIANT Password,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Visible( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ XlSheetVisibility *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Visible( 
            /* [lcid][in] */ long lcid,
            /* [in] */ XlSheetVisibility RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Shapes( 
            /* [retval][out] */ Shapes	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall InsertFile( 
            /* [in] */ VARIANT Filename,
            /* [optional][in] */ VARIANT Merge,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SaveAs( 
            /* [in] */ BSTR Filename,
            /* [optional][in] */ VARIANT FileFormat,
            /* [optional][in] */ VARIANT Password,
            /* [optional][in] */ VARIANT WriteResPassword,
            /* [optional][in] */ VARIANT ReadOnlyRecommended,
            /* [optional][in] */ VARIANT CreateBackup,
            /* [optional][in] */ VARIANT AddToMru,
            /* [optional][in] */ VARIANT TextCodepage,
            /* [optional][in] */ VARIANT TextVisualLayout) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Protect( 
            /* [optional][in] */ VARIANT Password,
            /* [optional][in] */ VARIANT DrawingObjects,
            /* [optional][in] */ VARIANT Contents,
            /* [optional][in] */ VARIANT Scenarios,
            /* [optional][in] */ VARIANT UserInterfaceOnly) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall _PrintOut( 
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall PrintOut( 
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IModuleVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IModule * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IModule * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IModule * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IModule * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IModule * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IModule * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IModule * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IModule * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IModule * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IModule * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Activate )( 
            IModule * This,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Copy )( 
            IModule * This,
            /* [optional][in] */ VARIANT Before,
            /* [optional][in] */ VARIANT After,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IModule * This,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CodeName )( 
            IModule * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__CodeName )( 
            IModule * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put__CodeName )( 
            IModule * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Index )( 
            IModule * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Move )( 
            IModule * This,
            /* [optional][in] */ VARIANT Before,
            /* [optional][in] */ VARIANT After,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            IModule * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Name )( 
            IModule * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Next )( 
            IModule * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_OnDoubleClick )( 
            IModule * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_OnDoubleClick )( 
            IModule * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_OnSheetActivate )( 
            IModule * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_OnSheetActivate )( 
            IModule * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_OnSheetDeactivate )( 
            IModule * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_OnSheetDeactivate )( 
            IModule * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PageSetup )( 
            IModule * This,
            /* [retval][out] */ PageSetup	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Previous )( 
            IModule * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [custom][helpcontext][hidden][id] */ HRESULT ( __stdcall *__PrintOut )( 
            IModule * This,
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate,
            /* [lcid][in] */ long lcid);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy18 )( 
            IModule * This);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *_Protect )( 
            IModule * This,
            /* [optional][in] */ VARIANT Password,
            /* [optional][in] */ VARIANT DrawingObjects,
            /* [optional][in] */ VARIANT Contents,
            /* [optional][in] */ VARIANT Scenarios,
            /* [optional][in] */ VARIANT UserInterfaceOnly,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ProtectContents )( 
            IModule * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy21 )( 
            IModule * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ProtectionMode )( 
            IModule * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy23 )( 
            IModule * This);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *_SaveAs )( 
            IModule * This,
            /* [in] */ BSTR Filename,
            /* [optional][in] */ VARIANT FileFormat,
            /* [optional][in] */ VARIANT Password,
            /* [optional][in] */ VARIANT WriteResPassword,
            /* [optional][in] */ VARIANT ReadOnlyRecommended,
            /* [optional][in] */ VARIANT CreateBackup,
            /* [optional][in] */ VARIANT AddToMru,
            /* [optional][in] */ VARIANT TextCodepage,
            /* [optional][in] */ VARIANT TextVisualLayout,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            IModule * This,
            /* [optional][in] */ VARIANT Replace,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Unprotect )( 
            IModule * This,
            /* [optional][in] */ VARIANT Password,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Visible )( 
            IModule * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ XlSheetVisibility *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Visible )( 
            IModule * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ XlSheetVisibility RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Shapes )( 
            IModule * This,
            /* [retval][out] */ Shapes	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *InsertFile )( 
            IModule * This,
            /* [in] */ VARIANT Filename,
            /* [optional][in] */ VARIANT Merge,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SaveAs )( 
            IModule * This,
            /* [in] */ BSTR Filename,
            /* [optional][in] */ VARIANT FileFormat,
            /* [optional][in] */ VARIANT Password,
            /* [optional][in] */ VARIANT WriteResPassword,
            /* [optional][in] */ VARIANT ReadOnlyRecommended,
            /* [optional][in] */ VARIANT CreateBackup,
            /* [optional][in] */ VARIANT AddToMru,
            /* [optional][in] */ VARIANT TextCodepage,
            /* [optional][in] */ VARIANT TextVisualLayout);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Protect )( 
            IModule * This,
            /* [optional][in] */ VARIANT Password,
            /* [optional][in] */ VARIANT DrawingObjects,
            /* [optional][in] */ VARIANT Contents,
            /* [optional][in] */ VARIANT Scenarios,
            /* [optional][in] */ VARIANT UserInterfaceOnly);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *_PrintOut )( 
            IModule * This,
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *PrintOut )( 
            IModule * This,
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate);
        
        END_INTERFACE
    } IModuleVtbl;

    interface IModule
    {
        CONST_VTBL struct IModuleVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IModule_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IModule_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IModule_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IModule_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IModule_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IModule_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IModule_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IModule_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IModule_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IModule_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IModule_Activate(This,lcid)	\
    ( (This)->lpVtbl -> Activate(This,lcid) ) 

#define IModule_Copy(This,Before,After,lcid)	\
    ( (This)->lpVtbl -> Copy(This,Before,After,lcid) ) 

#define IModule_Delete(This,lcid)	\
    ( (This)->lpVtbl -> Delete(This,lcid) ) 

#define IModule_get_CodeName(This,RHS)	\
    ( (This)->lpVtbl -> get_CodeName(This,RHS) ) 

#define IModule_get__CodeName(This,RHS)	\
    ( (This)->lpVtbl -> get__CodeName(This,RHS) ) 

#define IModule_put__CodeName(This,RHS)	\
    ( (This)->lpVtbl -> put__CodeName(This,RHS) ) 

#define IModule_get_Index(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_Index(This,lcid,RHS) ) 

#define IModule_Move(This,Before,After,lcid)	\
    ( (This)->lpVtbl -> Move(This,Before,After,lcid) ) 

#define IModule_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define IModule_put_Name(This,RHS)	\
    ( (This)->lpVtbl -> put_Name(This,RHS) ) 

#define IModule_get_Next(This,RHS)	\
    ( (This)->lpVtbl -> get_Next(This,RHS) ) 

#define IModule_get_OnDoubleClick(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_OnDoubleClick(This,lcid,RHS) ) 

#define IModule_put_OnDoubleClick(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_OnDoubleClick(This,lcid,RHS) ) 

#define IModule_get_OnSheetActivate(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_OnSheetActivate(This,lcid,RHS) ) 

#define IModule_put_OnSheetActivate(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_OnSheetActivate(This,lcid,RHS) ) 

#define IModule_get_OnSheetDeactivate(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_OnSheetDeactivate(This,lcid,RHS) ) 

#define IModule_put_OnSheetDeactivate(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_OnSheetDeactivate(This,lcid,RHS) ) 

#define IModule_get_PageSetup(This,RHS)	\
    ( (This)->lpVtbl -> get_PageSetup(This,RHS) ) 

#define IModule_get_Previous(This,RHS)	\
    ( (This)->lpVtbl -> get_Previous(This,RHS) ) 

#define IModule___PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate,lcid)	\
    ( (This)->lpVtbl -> __PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate,lcid) ) 

#define IModule__Dummy18(This)	\
    ( (This)->lpVtbl -> _Dummy18(This) ) 

#define IModule__Protect(This,Password,DrawingObjects,Contents,Scenarios,UserInterfaceOnly,lcid)	\
    ( (This)->lpVtbl -> _Protect(This,Password,DrawingObjects,Contents,Scenarios,UserInterfaceOnly,lcid) ) 

#define IModule_get_ProtectContents(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_ProtectContents(This,lcid,RHS) ) 

#define IModule__Dummy21(This)	\
    ( (This)->lpVtbl -> _Dummy21(This) ) 

#define IModule_get_ProtectionMode(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_ProtectionMode(This,lcid,RHS) ) 

#define IModule__Dummy23(This)	\
    ( (This)->lpVtbl -> _Dummy23(This) ) 

#define IModule__SaveAs(This,Filename,FileFormat,Password,WriteResPassword,ReadOnlyRecommended,CreateBackup,AddToMru,TextCodepage,TextVisualLayout,lcid)	\
    ( (This)->lpVtbl -> _SaveAs(This,Filename,FileFormat,Password,WriteResPassword,ReadOnlyRecommended,CreateBackup,AddToMru,TextCodepage,TextVisualLayout,lcid) ) 

#define IModule_Select(This,Replace,lcid)	\
    ( (This)->lpVtbl -> Select(This,Replace,lcid) ) 

#define IModule_Unprotect(This,Password,lcid)	\
    ( (This)->lpVtbl -> Unprotect(This,Password,lcid) ) 

#define IModule_get_Visible(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_Visible(This,lcid,RHS) ) 

#define IModule_put_Visible(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_Visible(This,lcid,RHS) ) 

#define IModule_get_Shapes(This,RHS)	\
    ( (This)->lpVtbl -> get_Shapes(This,RHS) ) 

#define IModule_InsertFile(This,Filename,Merge,RHS)	\
    ( (This)->lpVtbl -> InsertFile(This,Filename,Merge,RHS) ) 

#define IModule_SaveAs(This,Filename,FileFormat,Password,WriteResPassword,ReadOnlyRecommended,CreateBackup,AddToMru,TextCodepage,TextVisualLayout)	\
    ( (This)->lpVtbl -> SaveAs(This,Filename,FileFormat,Password,WriteResPassword,ReadOnlyRecommended,CreateBackup,AddToMru,TextCodepage,TextVisualLayout) ) 

#define IModule_Protect(This,Password,DrawingObjects,Contents,Scenarios,UserInterfaceOnly)	\
    ( (This)->lpVtbl -> Protect(This,Password,DrawingObjects,Contents,Scenarios,UserInterfaceOnly) ) 

#define IModule__PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate)	\
    ( (This)->lpVtbl -> _PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate) ) 

#define IModule_PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate)	\
    ( (This)->lpVtbl -> PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IModule_INTERFACE_DEFINED__ */


#ifndef __IModules_INTERFACE_DEFINED__
#define __IModules_INTERFACE_DEFINED__

/* interface IModules */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IModules;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000208AE-0001-0000-C000-000000000046")
    IModules : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add( 
            /* [optional][in] */ VARIANT Before,
            /* [optional][in] */ VARIANT After,
            /* [optional][in] */ VARIANT Count,
            /* [retval][out] */ Module	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Copy( 
            /* [optional][in] */ VARIANT Before,
            /* [optional][in] */ VARIANT After,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy7( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Move( 
            /* [optional][in] */ VARIANT Before,
            /* [optional][in] */ VARIANT After,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
        virtual /* [custom][helpcontext][hidden][id] */ HRESULT __stdcall __PrintOut( 
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy12( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [optional][in] */ VARIANT Replace,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HPageBreaks( 
            /* [retval][out] */ HPageBreaks	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_VPageBreaks( 
            /* [retval][out] */ VPageBreaks	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Visible( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Visible( 
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [custom][helpcontext][hidden][id] */ HRESULT __stdcall _PrintOut( 
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate,
            /* [optional][in] */ VARIANT PrToFileName,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [custom][helpcontext][id] */ HRESULT __stdcall PrintOut( 
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate,
            /* [optional][in] */ VARIANT PrToFileName,
            /* [optional][in] */ VARIANT IgnorePrintAreas,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add2( 
            /* [optional][in] */ VARIANT Before,
            /* [optional][in] */ VARIANT After,
            /* [optional][in] */ VARIANT Count,
            /* [optional][in] */ VARIANT NewLayout,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IModulesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IModules * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IModules * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IModules * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IModules * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IModules * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IModules * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IModules * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IModules * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IModules * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IModules * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add )( 
            IModules * This,
            /* [optional][in] */ VARIANT Before,
            /* [optional][in] */ VARIANT After,
            /* [optional][in] */ VARIANT Count,
            /* [retval][out] */ Module	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Copy )( 
            IModules * This,
            /* [optional][in] */ VARIANT Before,
            /* [optional][in] */ VARIANT After,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IModules * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IModules * This,
            /* [lcid][in] */ long lcid);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy7 )( 
            IModules * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Item )( 
            IModules * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Move )( 
            IModules * This,
            /* [optional][in] */ VARIANT Before,
            /* [optional][in] */ VARIANT After,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            IModules * This,
            /* [retval][out] */ IUnknown **RHS);
        
        /* [custom][helpcontext][hidden][id] */ HRESULT ( __stdcall *__PrintOut )( 
            IModules * This,
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate,
            /* [lcid][in] */ long lcid);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy12 )( 
            IModules * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            IModules * This,
            /* [optional][in] */ VARIANT Replace,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HPageBreaks )( 
            IModules * This,
            /* [retval][out] */ HPageBreaks	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_VPageBreaks )( 
            IModules * This,
            /* [retval][out] */ VPageBreaks	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Visible )( 
            IModules * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Visible )( 
            IModules * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IModules * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [custom][helpcontext][hidden][id] */ HRESULT ( __stdcall *_PrintOut )( 
            IModules * This,
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate,
            /* [optional][in] */ VARIANT PrToFileName,
            /* [lcid][in] */ long lcid);
        
        /* [custom][helpcontext][id] */ HRESULT ( __stdcall *PrintOut )( 
            IModules * This,
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate,
            /* [optional][in] */ VARIANT PrToFileName,
            /* [optional][in] */ VARIANT IgnorePrintAreas,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add2 )( 
            IModules * This,
            /* [optional][in] */ VARIANT Before,
            /* [optional][in] */ VARIANT After,
            /* [optional][in] */ VARIANT Count,
            /* [optional][in] */ VARIANT NewLayout,
            /* [retval][out] */ IDispatch **RHS);
        
        END_INTERFACE
    } IModulesVtbl;

    interface IModules
    {
        CONST_VTBL struct IModulesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IModules_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IModules_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IModules_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IModules_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IModules_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IModules_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IModules_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IModules_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IModules_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IModules_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IModules_Add(This,Before,After,Count,RHS)	\
    ( (This)->lpVtbl -> Add(This,Before,After,Count,RHS) ) 

#define IModules_Copy(This,Before,After,lcid)	\
    ( (This)->lpVtbl -> Copy(This,Before,After,lcid) ) 

#define IModules_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IModules_Delete(This,lcid)	\
    ( (This)->lpVtbl -> Delete(This,lcid) ) 

#define IModules__Dummy7(This)	\
    ( (This)->lpVtbl -> _Dummy7(This) ) 

#define IModules_get_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Item(This,Index,RHS) ) 

#define IModules_Move(This,Before,After,lcid)	\
    ( (This)->lpVtbl -> Move(This,Before,After,lcid) ) 

#define IModules_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#define IModules___PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate,lcid)	\
    ( (This)->lpVtbl -> __PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate,lcid) ) 

#define IModules__Dummy12(This)	\
    ( (This)->lpVtbl -> _Dummy12(This) ) 

#define IModules_Select(This,Replace,lcid)	\
    ( (This)->lpVtbl -> Select(This,Replace,lcid) ) 

#define IModules_get_HPageBreaks(This,RHS)	\
    ( (This)->lpVtbl -> get_HPageBreaks(This,RHS) ) 

#define IModules_get_VPageBreaks(This,RHS)	\
    ( (This)->lpVtbl -> get_VPageBreaks(This,RHS) ) 

#define IModules_get_Visible(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_Visible(This,lcid,RHS) ) 

#define IModules_put_Visible(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_Visible(This,lcid,RHS) ) 

#define IModules_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define IModules__PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate,PrToFileName,lcid)	\
    ( (This)->lpVtbl -> _PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate,PrToFileName,lcid) ) 

#define IModules_PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate,PrToFileName,IgnorePrintAreas,lcid)	\
    ( (This)->lpVtbl -> PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate,PrToFileName,IgnorePrintAreas,lcid) ) 

#define IModules_Add2(This,Before,After,Count,NewLayout,RHS)	\
    ( (This)->lpVtbl -> Add2(This,Before,After,Count,NewLayout,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IModules_INTERFACE_DEFINED__ */


#ifndef __IDialogSheet_INTERFACE_DEFINED__
#define __IDialogSheet_INTERFACE_DEFINED__

/* interface IDialogSheet */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IDialogSheet;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000208AF-0001-0000-C000-000000000046")
    IDialogSheet : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Activate( 
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Copy( 
            /* [optional][in] */ VARIANT Before,
            /* [optional][in] */ VARIANT After,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CodeName( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__CodeName( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put__CodeName( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Index( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Move( 
            /* [optional][in] */ VARIANT Before,
            /* [optional][in] */ VARIANT After,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Name( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Next( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_OnDoubleClick( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_OnDoubleClick( 
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_OnSheetActivate( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_OnSheetActivate( 
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_OnSheetDeactivate( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_OnSheetDeactivate( 
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PageSetup( 
            /* [retval][out] */ PageSetup	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Previous( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [custom][helpcontext][hidden][id] */ HRESULT __stdcall __PrintOut( 
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall PrintPreview( 
            /* [optional][in] */ VARIANT EnableChanges,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall _Protect( 
            /* [optional][in] */ VARIANT Password,
            /* [optional][in] */ VARIANT DrawingObjects,
            /* [optional][in] */ VARIANT Contents,
            /* [optional][in] */ VARIANT Scenarios,
            /* [optional][in] */ VARIANT UserInterfaceOnly,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ProtectContents( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ProtectDrawingObjects( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ProtectionMode( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ProtectScenarios( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall _SaveAs( 
            /* [in] */ BSTR Filename,
            /* [optional][in] */ VARIANT FileFormat,
            /* [optional][in] */ VARIANT Password,
            /* [optional][in] */ VARIANT WriteResPassword,
            /* [optional][in] */ VARIANT ReadOnlyRecommended,
            /* [optional][in] */ VARIANT CreateBackup,
            /* [optional][in] */ VARIANT AddToMru,
            /* [optional][in] */ VARIANT TextCodepage,
            /* [optional][in] */ VARIANT TextVisualLayout,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [optional][in] */ VARIANT Replace,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Unprotect( 
            /* [optional][in] */ VARIANT Password,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Visible( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ XlSheetVisibility *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Visible( 
            /* [lcid][in] */ long lcid,
            /* [in] */ XlSheetVisibility RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Shapes( 
            /* [retval][out] */ Shapes	**RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy29( void) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall Arcs( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy31( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy32( void) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall Buttons( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy34( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_EnableCalculation( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_EnableCalculation( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy36( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ChartObjects( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall CheckBoxes( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CheckSpelling( 
            /* [optional][in] */ VARIANT CustomDictionary,
            /* [optional][in] */ VARIANT IgnoreUppercase,
            /* [optional][in] */ VARIANT AlwaysSuggest,
            /* [optional][in] */ VARIANT SpellLang,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy40( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy41( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy42( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy43( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy44( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy45( void) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_DisplayAutomaticPageBreaks( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_DisplayAutomaticPageBreaks( 
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall Drawings( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall DrawingObjects( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall DropDowns( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_EnableAutoFilter( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_EnableAutoFilter( 
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_EnableSelection( 
            /* [retval][out] */ XlEnableSelection *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_EnableSelection( 
            /* [in] */ XlEnableSelection RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_EnableOutlining( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_EnableOutlining( 
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_EnablePivotTable( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_EnablePivotTable( 
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Evaluate( 
            /* [in] */ VARIANT Name,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall _Evaluate( 
            /* [in] */ VARIANT Name,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy56( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ResetAllPageBreaks( void) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall GroupBoxes( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall GroupObjects( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall Labels( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall Lines( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall ListBoxes( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Names( 
            /* [retval][out] */ Names	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall OLEObjects( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy65( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy66( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy67( void) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall OptionButtons( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy69( void) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall Ovals( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Paste( 
            /* [optional][in] */ VARIANT Destination,
            /* [optional][in] */ VARIANT Link,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall _PasteSpecial( 
            /* [optional][in] */ VARIANT Format,
            /* [optional][in] */ VARIANT Link,
            /* [optional][in] */ VARIANT DisplayAsIcon,
            /* [optional][in] */ VARIANT IconFileName,
            /* [optional][in] */ VARIANT IconIndex,
            /* [optional][in] */ VARIANT IconLabel,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall Pictures( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy74( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy75( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy76( void) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall Rectangles( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy78( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy79( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ScrollArea( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ScrollArea( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall ScrollBars( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy82( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy83( void) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall Spinners( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy85( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy86( void) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall TextBoxes( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy88( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy89( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy90( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HPageBreaks( 
            /* [retval][out] */ HPageBreaks	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_VPageBreaks( 
            /* [retval][out] */ VPageBreaks	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_QueryTables( 
            /* [retval][out] */ QueryTables	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DisplayPageBreaks( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DisplayPageBreaks( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Comments( 
            /* [retval][out] */ Comments	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Hyperlinks( 
            /* [retval][out] */ Hyperlinks	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ClearCircles( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CircleInvalid( void) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get__DisplayRightToLeft( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put__DisplayRightToLeft( 
            /* [lcid][in] */ long lcid,
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AutoFilter( 
            /* [retval][out] */ AutoFilter	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DisplayRightToLeft( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DisplayRightToLeft( 
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Scripts( 
            /* [retval][out] */ /* external definition not present */ Scripts **RHS) = 0;
        
        virtual /* [custom][helpcontext][hidden][id] */ HRESULT __stdcall _PrintOut( 
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate,
            /* [optional][in] */ VARIANT PrToFileName,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall _CheckSpelling( 
            /* [optional][in] */ VARIANT CustomDictionary,
            /* [optional][in] */ VARIANT IgnoreUppercase,
            /* [optional][in] */ VARIANT AlwaysSuggest,
            /* [optional][in] */ VARIANT SpellLang,
            /* [optional][in] */ VARIANT IgnoreFinalYaa,
            /* [optional][in] */ VARIANT SpellScript,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Tab( 
            /* [retval][out] */ Tab	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MailEnvelope( 
            /* [retval][out] */ /* external definition not present */ MsoEnvelope **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SaveAs( 
            /* [in] */ BSTR Filename,
            /* [optional][in] */ VARIANT FileFormat,
            /* [optional][in] */ VARIANT Password,
            /* [optional][in] */ VARIANT WriteResPassword,
            /* [optional][in] */ VARIANT ReadOnlyRecommended,
            /* [optional][in] */ VARIANT CreateBackup,
            /* [optional][in] */ VARIANT AddToMru,
            /* [optional][in] */ VARIANT TextCodepage,
            /* [optional][in] */ VARIANT TextVisualLayout,
            /* [optional][in] */ VARIANT Local) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CustomProperties( 
            /* [retval][out] */ CustomProperties	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_SmartTags( 
            /* [retval][out] */ SmartTags	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Protection( 
            /* [retval][out] */ Protection	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall PasteSpecial( 
            /* [optional][in] */ VARIANT Format,
            /* [optional][in] */ VARIANT Link,
            /* [optional][in] */ VARIANT DisplayAsIcon,
            /* [optional][in] */ VARIANT IconFileName,
            /* [optional][in] */ VARIANT IconIndex,
            /* [optional][in] */ VARIANT IconLabel,
            /* [optional][in] */ VARIANT NoHTMLFormatting,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Protect( 
            /* [optional][in] */ VARIANT Password,
            /* [optional][in] */ VARIANT DrawingObjects,
            /* [optional][in] */ VARIANT Contents,
            /* [optional][in] */ VARIANT Scenarios,
            /* [optional][in] */ VARIANT UserInterfaceOnly,
            /* [optional][in] */ VARIANT AllowFormattingCells,
            /* [optional][in] */ VARIANT AllowFormattingColumns,
            /* [optional][in] */ VARIANT AllowFormattingRows,
            /* [optional][in] */ VARIANT AllowInsertingColumns,
            /* [optional][in] */ VARIANT AllowInsertingRows,
            /* [optional][in] */ VARIANT AllowInsertingHyperlinks,
            /* [optional][in] */ VARIANT AllowDeletingColumns,
            /* [optional][in] */ VARIANT AllowDeletingRows,
            /* [optional][in] */ VARIANT AllowSorting,
            /* [optional][in] */ VARIANT AllowFiltering,
            /* [optional][in] */ VARIANT AllowUsingPivotTables) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy113( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy114( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy115( void) = 0;
        
        virtual /* [custom][helpcontext][id] */ HRESULT __stdcall PrintOut( 
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate,
            /* [optional][in] */ VARIANT PrToFileName) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_EnableFormatConditionsCalculation( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_EnableFormatConditionsCalculation( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Sort( 
            /* [retval][out] */ Sort	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ExportAsFixedFormat( 
            /* [in] */ XlFixedFormatType Type,
            /* [optional][in] */ VARIANT Filename,
            /* [optional][in] */ VARIANT Quality,
            /* [optional][in] */ VARIANT IncludeDocProperties,
            /* [optional][in] */ VARIANT IgnorePrintAreas,
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT OpenAfterPublish,
            /* [optional][in] */ VARIANT FixedFormatExtClassPtr) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PrintedCommentPages( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DefaultButton( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DefaultButton( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_DialogFrame( 
            /* [retval][out] */ DialogFrame	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall EditBoxes( 
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Focus( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Focus( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Hide( 
            /* [optional][in] */ VARIANT Cancel,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Show( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IDialogSheetVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IDialogSheet * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IDialogSheet * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IDialogSheet * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IDialogSheet * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IDialogSheet * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IDialogSheet * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IDialogSheet * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IDialogSheet * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IDialogSheet * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IDialogSheet * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Activate )( 
            IDialogSheet * This,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Copy )( 
            IDialogSheet * This,
            /* [optional][in] */ VARIANT Before,
            /* [optional][in] */ VARIANT After,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IDialogSheet * This,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CodeName )( 
            IDialogSheet * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__CodeName )( 
            IDialogSheet * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put__CodeName )( 
            IDialogSheet * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Index )( 
            IDialogSheet * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Move )( 
            IDialogSheet * This,
            /* [optional][in] */ VARIANT Before,
            /* [optional][in] */ VARIANT After,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            IDialogSheet * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Name )( 
            IDialogSheet * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Next )( 
            IDialogSheet * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_OnDoubleClick )( 
            IDialogSheet * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_OnDoubleClick )( 
            IDialogSheet * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_OnSheetActivate )( 
            IDialogSheet * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_OnSheetActivate )( 
            IDialogSheet * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_OnSheetDeactivate )( 
            IDialogSheet * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_OnSheetDeactivate )( 
            IDialogSheet * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PageSetup )( 
            IDialogSheet * This,
            /* [retval][out] */ PageSetup	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Previous )( 
            IDialogSheet * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [custom][helpcontext][hidden][id] */ HRESULT ( __stdcall *__PrintOut )( 
            IDialogSheet * This,
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *PrintPreview )( 
            IDialogSheet * This,
            /* [optional][in] */ VARIANT EnableChanges,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *_Protect )( 
            IDialogSheet * This,
            /* [optional][in] */ VARIANT Password,
            /* [optional][in] */ VARIANT DrawingObjects,
            /* [optional][in] */ VARIANT Contents,
            /* [optional][in] */ VARIANT Scenarios,
            /* [optional][in] */ VARIANT UserInterfaceOnly,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ProtectContents )( 
            IDialogSheet * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ProtectDrawingObjects )( 
            IDialogSheet * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ProtectionMode )( 
            IDialogSheet * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ProtectScenarios )( 
            IDialogSheet * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *_SaveAs )( 
            IDialogSheet * This,
            /* [in] */ BSTR Filename,
            /* [optional][in] */ VARIANT FileFormat,
            /* [optional][in] */ VARIANT Password,
            /* [optional][in] */ VARIANT WriteResPassword,
            /* [optional][in] */ VARIANT ReadOnlyRecommended,
            /* [optional][in] */ VARIANT CreateBackup,
            /* [optional][in] */ VARIANT AddToMru,
            /* [optional][in] */ VARIANT TextCodepage,
            /* [optional][in] */ VARIANT TextVisualLayout,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            IDialogSheet * This,
            /* [optional][in] */ VARIANT Replace,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Unprotect )( 
            IDialogSheet * This,
            /* [optional][in] */ VARIANT Password,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Visible )( 
            IDialogSheet * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ XlSheetVisibility *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Visible )( 
            IDialogSheet * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ XlSheetVisibility RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Shapes )( 
            IDialogSheet * This,
            /* [retval][out] */ Shapes	**RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy29 )( 
            IDialogSheet * This);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *Arcs )( 
            IDialogSheet * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy31 )( 
            IDialogSheet * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy32 )( 
            IDialogSheet * This);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *Buttons )( 
            IDialogSheet * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy34 )( 
            IDialogSheet * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_EnableCalculation )( 
            IDialogSheet * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_EnableCalculation )( 
            IDialogSheet * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy36 )( 
            IDialogSheet * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ChartObjects )( 
            IDialogSheet * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *CheckBoxes )( 
            IDialogSheet * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CheckSpelling )( 
            IDialogSheet * This,
            /* [optional][in] */ VARIANT CustomDictionary,
            /* [optional][in] */ VARIANT IgnoreUppercase,
            /* [optional][in] */ VARIANT AlwaysSuggest,
            /* [optional][in] */ VARIANT SpellLang,
            /* [lcid][in] */ long lcid);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy40 )( 
            IDialogSheet * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy41 )( 
            IDialogSheet * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy42 )( 
            IDialogSheet * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy43 )( 
            IDialogSheet * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy44 )( 
            IDialogSheet * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy45 )( 
            IDialogSheet * This);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_DisplayAutomaticPageBreaks )( 
            IDialogSheet * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_DisplayAutomaticPageBreaks )( 
            IDialogSheet * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *Drawings )( 
            IDialogSheet * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *DrawingObjects )( 
            IDialogSheet * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *DropDowns )( 
            IDialogSheet * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_EnableAutoFilter )( 
            IDialogSheet * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_EnableAutoFilter )( 
            IDialogSheet * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_EnableSelection )( 
            IDialogSheet * This,
            /* [retval][out] */ XlEnableSelection *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_EnableSelection )( 
            IDialogSheet * This,
            /* [in] */ XlEnableSelection RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_EnableOutlining )( 
            IDialogSheet * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_EnableOutlining )( 
            IDialogSheet * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_EnablePivotTable )( 
            IDialogSheet * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_EnablePivotTable )( 
            IDialogSheet * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Evaluate )( 
            IDialogSheet * This,
            /* [in] */ VARIANT Name,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *_Evaluate )( 
            IDialogSheet * This,
            /* [in] */ VARIANT Name,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy56 )( 
            IDialogSheet * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ResetAllPageBreaks )( 
            IDialogSheet * This);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *GroupBoxes )( 
            IDialogSheet * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *GroupObjects )( 
            IDialogSheet * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *Labels )( 
            IDialogSheet * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *Lines )( 
            IDialogSheet * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *ListBoxes )( 
            IDialogSheet * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Names )( 
            IDialogSheet * This,
            /* [retval][out] */ Names	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *OLEObjects )( 
            IDialogSheet * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy65 )( 
            IDialogSheet * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy66 )( 
            IDialogSheet * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy67 )( 
            IDialogSheet * This);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *OptionButtons )( 
            IDialogSheet * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy69 )( 
            IDialogSheet * This);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *Ovals )( 
            IDialogSheet * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Paste )( 
            IDialogSheet * This,
            /* [optional][in] */ VARIANT Destination,
            /* [optional][in] */ VARIANT Link,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *_PasteSpecial )( 
            IDialogSheet * This,
            /* [optional][in] */ VARIANT Format,
            /* [optional][in] */ VARIANT Link,
            /* [optional][in] */ VARIANT DisplayAsIcon,
            /* [optional][in] */ VARIANT IconFileName,
            /* [optional][in] */ VARIANT IconIndex,
            /* [optional][in] */ VARIANT IconLabel,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *Pictures )( 
            IDialogSheet * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy74 )( 
            IDialogSheet * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy75 )( 
            IDialogSheet * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy76 )( 
            IDialogSheet * This);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *Rectangles )( 
            IDialogSheet * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy78 )( 
            IDialogSheet * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy79 )( 
            IDialogSheet * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ScrollArea )( 
            IDialogSheet * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ScrollArea )( 
            IDialogSheet * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *ScrollBars )( 
            IDialogSheet * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy82 )( 
            IDialogSheet * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy83 )( 
            IDialogSheet * This);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *Spinners )( 
            IDialogSheet * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy85 )( 
            IDialogSheet * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy86 )( 
            IDialogSheet * This);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *TextBoxes )( 
            IDialogSheet * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy88 )( 
            IDialogSheet * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy89 )( 
            IDialogSheet * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy90 )( 
            IDialogSheet * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HPageBreaks )( 
            IDialogSheet * This,
            /* [retval][out] */ HPageBreaks	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_VPageBreaks )( 
            IDialogSheet * This,
            /* [retval][out] */ VPageBreaks	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_QueryTables )( 
            IDialogSheet * This,
            /* [retval][out] */ QueryTables	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DisplayPageBreaks )( 
            IDialogSheet * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DisplayPageBreaks )( 
            IDialogSheet * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Comments )( 
            IDialogSheet * This,
            /* [retval][out] */ Comments	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Hyperlinks )( 
            IDialogSheet * This,
            /* [retval][out] */ Hyperlinks	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ClearCircles )( 
            IDialogSheet * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CircleInvalid )( 
            IDialogSheet * This);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get__DisplayRightToLeft )( 
            IDialogSheet * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put__DisplayRightToLeft )( 
            IDialogSheet * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AutoFilter )( 
            IDialogSheet * This,
            /* [retval][out] */ AutoFilter	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DisplayRightToLeft )( 
            IDialogSheet * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DisplayRightToLeft )( 
            IDialogSheet * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Scripts )( 
            IDialogSheet * This,
            /* [retval][out] */ /* external definition not present */ Scripts **RHS);
        
        /* [custom][helpcontext][hidden][id] */ HRESULT ( __stdcall *_PrintOut )( 
            IDialogSheet * This,
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate,
            /* [optional][in] */ VARIANT PrToFileName,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *_CheckSpelling )( 
            IDialogSheet * This,
            /* [optional][in] */ VARIANT CustomDictionary,
            /* [optional][in] */ VARIANT IgnoreUppercase,
            /* [optional][in] */ VARIANT AlwaysSuggest,
            /* [optional][in] */ VARIANT SpellLang,
            /* [optional][in] */ VARIANT IgnoreFinalYaa,
            /* [optional][in] */ VARIANT SpellScript,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Tab )( 
            IDialogSheet * This,
            /* [retval][out] */ Tab	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MailEnvelope )( 
            IDialogSheet * This,
            /* [retval][out] */ /* external definition not present */ MsoEnvelope **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SaveAs )( 
            IDialogSheet * This,
            /* [in] */ BSTR Filename,
            /* [optional][in] */ VARIANT FileFormat,
            /* [optional][in] */ VARIANT Password,
            /* [optional][in] */ VARIANT WriteResPassword,
            /* [optional][in] */ VARIANT ReadOnlyRecommended,
            /* [optional][in] */ VARIANT CreateBackup,
            /* [optional][in] */ VARIANT AddToMru,
            /* [optional][in] */ VARIANT TextCodepage,
            /* [optional][in] */ VARIANT TextVisualLayout,
            /* [optional][in] */ VARIANT Local);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CustomProperties )( 
            IDialogSheet * This,
            /* [retval][out] */ CustomProperties	**RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_SmartTags )( 
            IDialogSheet * This,
            /* [retval][out] */ SmartTags	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Protection )( 
            IDialogSheet * This,
            /* [retval][out] */ Protection	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *PasteSpecial )( 
            IDialogSheet * This,
            /* [optional][in] */ VARIANT Format,
            /* [optional][in] */ VARIANT Link,
            /* [optional][in] */ VARIANT DisplayAsIcon,
            /* [optional][in] */ VARIANT IconFileName,
            /* [optional][in] */ VARIANT IconIndex,
            /* [optional][in] */ VARIANT IconLabel,
            /* [optional][in] */ VARIANT NoHTMLFormatting,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Protect )( 
            IDialogSheet * This,
            /* [optional][in] */ VARIANT Password,
            /* [optional][in] */ VARIANT DrawingObjects,
            /* [optional][in] */ VARIANT Contents,
            /* [optional][in] */ VARIANT Scenarios,
            /* [optional][in] */ VARIANT UserInterfaceOnly,
            /* [optional][in] */ VARIANT AllowFormattingCells,
            /* [optional][in] */ VARIANT AllowFormattingColumns,
            /* [optional][in] */ VARIANT AllowFormattingRows,
            /* [optional][in] */ VARIANT AllowInsertingColumns,
            /* [optional][in] */ VARIANT AllowInsertingRows,
            /* [optional][in] */ VARIANT AllowInsertingHyperlinks,
            /* [optional][in] */ VARIANT AllowDeletingColumns,
            /* [optional][in] */ VARIANT AllowDeletingRows,
            /* [optional][in] */ VARIANT AllowSorting,
            /* [optional][in] */ VARIANT AllowFiltering,
            /* [optional][in] */ VARIANT AllowUsingPivotTables);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy113 )( 
            IDialogSheet * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy114 )( 
            IDialogSheet * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy115 )( 
            IDialogSheet * This);
        
        /* [custom][helpcontext][id] */ HRESULT ( __stdcall *PrintOut )( 
            IDialogSheet * This,
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate,
            /* [optional][in] */ VARIANT PrToFileName);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_EnableFormatConditionsCalculation )( 
            IDialogSheet * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_EnableFormatConditionsCalculation )( 
            IDialogSheet * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Sort )( 
            IDialogSheet * This,
            /* [retval][out] */ Sort	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ExportAsFixedFormat )( 
            IDialogSheet * This,
            /* [in] */ XlFixedFormatType Type,
            /* [optional][in] */ VARIANT Filename,
            /* [optional][in] */ VARIANT Quality,
            /* [optional][in] */ VARIANT IncludeDocProperties,
            /* [optional][in] */ VARIANT IgnorePrintAreas,
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT OpenAfterPublish,
            /* [optional][in] */ VARIANT FixedFormatExtClassPtr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PrintedCommentPages )( 
            IDialogSheet * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DefaultButton )( 
            IDialogSheet * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DefaultButton )( 
            IDialogSheet * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_DialogFrame )( 
            IDialogSheet * This,
            /* [retval][out] */ DialogFrame	**RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *EditBoxes )( 
            IDialogSheet * This,
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Focus )( 
            IDialogSheet * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Focus )( 
            IDialogSheet * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Hide )( 
            IDialogSheet * This,
            /* [optional][in] */ VARIANT Cancel,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Show )( 
            IDialogSheet * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        END_INTERFACE
    } IDialogSheetVtbl;

    interface IDialogSheet
    {
        CONST_VTBL struct IDialogSheetVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IDialogSheet_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IDialogSheet_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IDialogSheet_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IDialogSheet_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IDialogSheet_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IDialogSheet_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IDialogSheet_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IDialogSheet_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IDialogSheet_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IDialogSheet_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IDialogSheet_Activate(This,lcid)	\
    ( (This)->lpVtbl -> Activate(This,lcid) ) 

#define IDialogSheet_Copy(This,Before,After,lcid)	\
    ( (This)->lpVtbl -> Copy(This,Before,After,lcid) ) 

#define IDialogSheet_Delete(This,lcid)	\
    ( (This)->lpVtbl -> Delete(This,lcid) ) 

#define IDialogSheet_get_CodeName(This,RHS)	\
    ( (This)->lpVtbl -> get_CodeName(This,RHS) ) 

#define IDialogSheet_get__CodeName(This,RHS)	\
    ( (This)->lpVtbl -> get__CodeName(This,RHS) ) 

#define IDialogSheet_put__CodeName(This,RHS)	\
    ( (This)->lpVtbl -> put__CodeName(This,RHS) ) 

#define IDialogSheet_get_Index(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_Index(This,lcid,RHS) ) 

#define IDialogSheet_Move(This,Before,After,lcid)	\
    ( (This)->lpVtbl -> Move(This,Before,After,lcid) ) 

#define IDialogSheet_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define IDialogSheet_put_Name(This,RHS)	\
    ( (This)->lpVtbl -> put_Name(This,RHS) ) 

#define IDialogSheet_get_Next(This,RHS)	\
    ( (This)->lpVtbl -> get_Next(This,RHS) ) 

#define IDialogSheet_get_OnDoubleClick(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_OnDoubleClick(This,lcid,RHS) ) 

#define IDialogSheet_put_OnDoubleClick(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_OnDoubleClick(This,lcid,RHS) ) 

#define IDialogSheet_get_OnSheetActivate(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_OnSheetActivate(This,lcid,RHS) ) 

#define IDialogSheet_put_OnSheetActivate(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_OnSheetActivate(This,lcid,RHS) ) 

#define IDialogSheet_get_OnSheetDeactivate(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_OnSheetDeactivate(This,lcid,RHS) ) 

#define IDialogSheet_put_OnSheetDeactivate(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_OnSheetDeactivate(This,lcid,RHS) ) 

#define IDialogSheet_get_PageSetup(This,RHS)	\
    ( (This)->lpVtbl -> get_PageSetup(This,RHS) ) 

#define IDialogSheet_get_Previous(This,RHS)	\
    ( (This)->lpVtbl -> get_Previous(This,RHS) ) 

#define IDialogSheet___PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate,lcid)	\
    ( (This)->lpVtbl -> __PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate,lcid) ) 

#define IDialogSheet_PrintPreview(This,EnableChanges,lcid)	\
    ( (This)->lpVtbl -> PrintPreview(This,EnableChanges,lcid) ) 

#define IDialogSheet__Protect(This,Password,DrawingObjects,Contents,Scenarios,UserInterfaceOnly,lcid)	\
    ( (This)->lpVtbl -> _Protect(This,Password,DrawingObjects,Contents,Scenarios,UserInterfaceOnly,lcid) ) 

#define IDialogSheet_get_ProtectContents(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_ProtectContents(This,lcid,RHS) ) 

#define IDialogSheet_get_ProtectDrawingObjects(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_ProtectDrawingObjects(This,lcid,RHS) ) 

#define IDialogSheet_get_ProtectionMode(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_ProtectionMode(This,lcid,RHS) ) 

#define IDialogSheet_get_ProtectScenarios(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_ProtectScenarios(This,lcid,RHS) ) 

#define IDialogSheet__SaveAs(This,Filename,FileFormat,Password,WriteResPassword,ReadOnlyRecommended,CreateBackup,AddToMru,TextCodepage,TextVisualLayout,lcid)	\
    ( (This)->lpVtbl -> _SaveAs(This,Filename,FileFormat,Password,WriteResPassword,ReadOnlyRecommended,CreateBackup,AddToMru,TextCodepage,TextVisualLayout,lcid) ) 

#define IDialogSheet_Select(This,Replace,lcid)	\
    ( (This)->lpVtbl -> Select(This,Replace,lcid) ) 

#define IDialogSheet_Unprotect(This,Password,lcid)	\
    ( (This)->lpVtbl -> Unprotect(This,Password,lcid) ) 

#define IDialogSheet_get_Visible(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_Visible(This,lcid,RHS) ) 

#define IDialogSheet_put_Visible(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_Visible(This,lcid,RHS) ) 

#define IDialogSheet_get_Shapes(This,RHS)	\
    ( (This)->lpVtbl -> get_Shapes(This,RHS) ) 

#define IDialogSheet__Dummy29(This)	\
    ( (This)->lpVtbl -> _Dummy29(This) ) 

#define IDialogSheet_Arcs(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> Arcs(This,Index,lcid,RHS) ) 

#define IDialogSheet__Dummy31(This)	\
    ( (This)->lpVtbl -> _Dummy31(This) ) 

#define IDialogSheet__Dummy32(This)	\
    ( (This)->lpVtbl -> _Dummy32(This) ) 

#define IDialogSheet_Buttons(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> Buttons(This,Index,lcid,RHS) ) 

#define IDialogSheet__Dummy34(This)	\
    ( (This)->lpVtbl -> _Dummy34(This) ) 

#define IDialogSheet_get_EnableCalculation(This,RHS)	\
    ( (This)->lpVtbl -> get_EnableCalculation(This,RHS) ) 

#define IDialogSheet_put_EnableCalculation(This,RHS)	\
    ( (This)->lpVtbl -> put_EnableCalculation(This,RHS) ) 

#define IDialogSheet__Dummy36(This)	\
    ( (This)->lpVtbl -> _Dummy36(This) ) 

#define IDialogSheet_ChartObjects(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> ChartObjects(This,Index,lcid,RHS) ) 

#define IDialogSheet_CheckBoxes(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> CheckBoxes(This,Index,lcid,RHS) ) 

#define IDialogSheet_CheckSpelling(This,CustomDictionary,IgnoreUppercase,AlwaysSuggest,SpellLang,lcid)	\
    ( (This)->lpVtbl -> CheckSpelling(This,CustomDictionary,IgnoreUppercase,AlwaysSuggest,SpellLang,lcid) ) 

#define IDialogSheet__Dummy40(This)	\
    ( (This)->lpVtbl -> _Dummy40(This) ) 

#define IDialogSheet__Dummy41(This)	\
    ( (This)->lpVtbl -> _Dummy41(This) ) 

#define IDialogSheet__Dummy42(This)	\
    ( (This)->lpVtbl -> _Dummy42(This) ) 

#define IDialogSheet__Dummy43(This)	\
    ( (This)->lpVtbl -> _Dummy43(This) ) 

#define IDialogSheet__Dummy44(This)	\
    ( (This)->lpVtbl -> _Dummy44(This) ) 

#define IDialogSheet__Dummy45(This)	\
    ( (This)->lpVtbl -> _Dummy45(This) ) 

#define IDialogSheet_get_DisplayAutomaticPageBreaks(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_DisplayAutomaticPageBreaks(This,lcid,RHS) ) 

#define IDialogSheet_put_DisplayAutomaticPageBreaks(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_DisplayAutomaticPageBreaks(This,lcid,RHS) ) 

#define IDialogSheet_Drawings(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> Drawings(This,Index,lcid,RHS) ) 

#define IDialogSheet_DrawingObjects(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> DrawingObjects(This,Index,lcid,RHS) ) 

#define IDialogSheet_DropDowns(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> DropDowns(This,Index,lcid,RHS) ) 

#define IDialogSheet_get_EnableAutoFilter(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_EnableAutoFilter(This,lcid,RHS) ) 

#define IDialogSheet_put_EnableAutoFilter(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_EnableAutoFilter(This,lcid,RHS) ) 

#define IDialogSheet_get_EnableSelection(This,RHS)	\
    ( (This)->lpVtbl -> get_EnableSelection(This,RHS) ) 

#define IDialogSheet_put_EnableSelection(This,RHS)	\
    ( (This)->lpVtbl -> put_EnableSelection(This,RHS) ) 

#define IDialogSheet_get_EnableOutlining(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_EnableOutlining(This,lcid,RHS) ) 

#define IDialogSheet_put_EnableOutlining(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_EnableOutlining(This,lcid,RHS) ) 

#define IDialogSheet_get_EnablePivotTable(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_EnablePivotTable(This,lcid,RHS) ) 

#define IDialogSheet_put_EnablePivotTable(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_EnablePivotTable(This,lcid,RHS) ) 

#define IDialogSheet_Evaluate(This,Name,lcid,RHS)	\
    ( (This)->lpVtbl -> Evaluate(This,Name,lcid,RHS) ) 

#define IDialogSheet__Evaluate(This,Name,lcid,RHS)	\
    ( (This)->lpVtbl -> _Evaluate(This,Name,lcid,RHS) ) 

#define IDialogSheet__Dummy56(This)	\
    ( (This)->lpVtbl -> _Dummy56(This) ) 

#define IDialogSheet_ResetAllPageBreaks(This)	\
    ( (This)->lpVtbl -> ResetAllPageBreaks(This) ) 

#define IDialogSheet_GroupBoxes(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> GroupBoxes(This,Index,lcid,RHS) ) 

#define IDialogSheet_GroupObjects(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> GroupObjects(This,Index,lcid,RHS) ) 

#define IDialogSheet_Labels(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> Labels(This,Index,lcid,RHS) ) 

#define IDialogSheet_Lines(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> Lines(This,Index,lcid,RHS) ) 

#define IDialogSheet_ListBoxes(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> ListBoxes(This,Index,lcid,RHS) ) 

#define IDialogSheet_get_Names(This,RHS)	\
    ( (This)->lpVtbl -> get_Names(This,RHS) ) 

#define IDialogSheet_OLEObjects(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> OLEObjects(This,Index,lcid,RHS) ) 

#define IDialogSheet__Dummy65(This)	\
    ( (This)->lpVtbl -> _Dummy65(This) ) 

#define IDialogSheet__Dummy66(This)	\
    ( (This)->lpVtbl -> _Dummy66(This) ) 

#define IDialogSheet__Dummy67(This)	\
    ( (This)->lpVtbl -> _Dummy67(This) ) 

#define IDialogSheet_OptionButtons(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> OptionButtons(This,Index,lcid,RHS) ) 

#define IDialogSheet__Dummy69(This)	\
    ( (This)->lpVtbl -> _Dummy69(This) ) 

#define IDialogSheet_Ovals(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> Ovals(This,Index,lcid,RHS) ) 

#define IDialogSheet_Paste(This,Destination,Link,lcid)	\
    ( (This)->lpVtbl -> Paste(This,Destination,Link,lcid) ) 

#define IDialogSheet__PasteSpecial(This,Format,Link,DisplayAsIcon,IconFileName,IconIndex,IconLabel,lcid)	\
    ( (This)->lpVtbl -> _PasteSpecial(This,Format,Link,DisplayAsIcon,IconFileName,IconIndex,IconLabel,lcid) ) 

#define IDialogSheet_Pictures(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> Pictures(This,Index,lcid,RHS) ) 

#define IDialogSheet__Dummy74(This)	\
    ( (This)->lpVtbl -> _Dummy74(This) ) 

#define IDialogSheet__Dummy75(This)	\
    ( (This)->lpVtbl -> _Dummy75(This) ) 

#define IDialogSheet__Dummy76(This)	\
    ( (This)->lpVtbl -> _Dummy76(This) ) 

#define IDialogSheet_Rectangles(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> Rectangles(This,Index,lcid,RHS) ) 

#define IDialogSheet__Dummy78(This)	\
    ( (This)->lpVtbl -> _Dummy78(This) ) 

#define IDialogSheet__Dummy79(This)	\
    ( (This)->lpVtbl -> _Dummy79(This) ) 

#define IDialogSheet_get_ScrollArea(This,RHS)	\
    ( (This)->lpVtbl -> get_ScrollArea(This,RHS) ) 

#define IDialogSheet_put_ScrollArea(This,RHS)	\
    ( (This)->lpVtbl -> put_ScrollArea(This,RHS) ) 

#define IDialogSheet_ScrollBars(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> ScrollBars(This,Index,lcid,RHS) ) 

#define IDialogSheet__Dummy82(This)	\
    ( (This)->lpVtbl -> _Dummy82(This) ) 

#define IDialogSheet__Dummy83(This)	\
    ( (This)->lpVtbl -> _Dummy83(This) ) 

#define IDialogSheet_Spinners(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> Spinners(This,Index,lcid,RHS) ) 

#define IDialogSheet__Dummy85(This)	\
    ( (This)->lpVtbl -> _Dummy85(This) ) 

#define IDialogSheet__Dummy86(This)	\
    ( (This)->lpVtbl -> _Dummy86(This) ) 

#define IDialogSheet_TextBoxes(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> TextBoxes(This,Index,lcid,RHS) ) 

#define IDialogSheet__Dummy88(This)	\
    ( (This)->lpVtbl -> _Dummy88(This) ) 

#define IDialogSheet__Dummy89(This)	\
    ( (This)->lpVtbl -> _Dummy89(This) ) 

#define IDialogSheet__Dummy90(This)	\
    ( (This)->lpVtbl -> _Dummy90(This) ) 

#define IDialogSheet_get_HPageBreaks(This,RHS)	\
    ( (This)->lpVtbl -> get_HPageBreaks(This,RHS) ) 

#define IDialogSheet_get_VPageBreaks(This,RHS)	\
    ( (This)->lpVtbl -> get_VPageBreaks(This,RHS) ) 

#define IDialogSheet_get_QueryTables(This,RHS)	\
    ( (This)->lpVtbl -> get_QueryTables(This,RHS) ) 

#define IDialogSheet_get_DisplayPageBreaks(This,RHS)	\
    ( (This)->lpVtbl -> get_DisplayPageBreaks(This,RHS) ) 

#define IDialogSheet_put_DisplayPageBreaks(This,RHS)	\
    ( (This)->lpVtbl -> put_DisplayPageBreaks(This,RHS) ) 

#define IDialogSheet_get_Comments(This,RHS)	\
    ( (This)->lpVtbl -> get_Comments(This,RHS) ) 

#define IDialogSheet_get_Hyperlinks(This,RHS)	\
    ( (This)->lpVtbl -> get_Hyperlinks(This,RHS) ) 

#define IDialogSheet_ClearCircles(This)	\
    ( (This)->lpVtbl -> ClearCircles(This) ) 

#define IDialogSheet_CircleInvalid(This)	\
    ( (This)->lpVtbl -> CircleInvalid(This) ) 

#define IDialogSheet_get__DisplayRightToLeft(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get__DisplayRightToLeft(This,lcid,RHS) ) 

#define IDialogSheet_put__DisplayRightToLeft(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put__DisplayRightToLeft(This,lcid,RHS) ) 

#define IDialogSheet_get_AutoFilter(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoFilter(This,RHS) ) 

#define IDialogSheet_get_DisplayRightToLeft(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_DisplayRightToLeft(This,lcid,RHS) ) 

#define IDialogSheet_put_DisplayRightToLeft(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_DisplayRightToLeft(This,lcid,RHS) ) 

#define IDialogSheet_get_Scripts(This,RHS)	\
    ( (This)->lpVtbl -> get_Scripts(This,RHS) ) 

#define IDialogSheet__PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate,PrToFileName,lcid)	\
    ( (This)->lpVtbl -> _PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate,PrToFileName,lcid) ) 

#define IDialogSheet__CheckSpelling(This,CustomDictionary,IgnoreUppercase,AlwaysSuggest,SpellLang,IgnoreFinalYaa,SpellScript,lcid)	\
    ( (This)->lpVtbl -> _CheckSpelling(This,CustomDictionary,IgnoreUppercase,AlwaysSuggest,SpellLang,IgnoreFinalYaa,SpellScript,lcid) ) 

#define IDialogSheet_get_Tab(This,RHS)	\
    ( (This)->lpVtbl -> get_Tab(This,RHS) ) 

#define IDialogSheet_get_MailEnvelope(This,RHS)	\
    ( (This)->lpVtbl -> get_MailEnvelope(This,RHS) ) 

#define IDialogSheet_SaveAs(This,Filename,FileFormat,Password,WriteResPassword,ReadOnlyRecommended,CreateBackup,AddToMru,TextCodepage,TextVisualLayout,Local)	\
    ( (This)->lpVtbl -> SaveAs(This,Filename,FileFormat,Password,WriteResPassword,ReadOnlyRecommended,CreateBackup,AddToMru,TextCodepage,TextVisualLayout,Local) ) 

#define IDialogSheet_get_CustomProperties(This,RHS)	\
    ( (This)->lpVtbl -> get_CustomProperties(This,RHS) ) 

#define IDialogSheet_get_SmartTags(This,RHS)	\
    ( (This)->lpVtbl -> get_SmartTags(This,RHS) ) 

#define IDialogSheet_get_Protection(This,RHS)	\
    ( (This)->lpVtbl -> get_Protection(This,RHS) ) 

#define IDialogSheet_PasteSpecial(This,Format,Link,DisplayAsIcon,IconFileName,IconIndex,IconLabel,NoHTMLFormatting,lcid)	\
    ( (This)->lpVtbl -> PasteSpecial(This,Format,Link,DisplayAsIcon,IconFileName,IconIndex,IconLabel,NoHTMLFormatting,lcid) ) 

#define IDialogSheet_Protect(This,Password,DrawingObjects,Contents,Scenarios,UserInterfaceOnly,AllowFormattingCells,AllowFormattingColumns,AllowFormattingRows,AllowInsertingColumns,AllowInsertingRows,AllowInsertingHyperlinks,AllowDeletingColumns,AllowDeletingRows,AllowSorting,AllowFiltering,AllowUsingPivotTables)	\
    ( (This)->lpVtbl -> Protect(This,Password,DrawingObjects,Contents,Scenarios,UserInterfaceOnly,AllowFormattingCells,AllowFormattingColumns,AllowFormattingRows,AllowInsertingColumns,AllowInsertingRows,AllowInsertingHyperlinks,AllowDeletingColumns,AllowDeletingRows,AllowSorting,AllowFiltering,AllowUsingPivotTables) ) 

#define IDialogSheet__Dummy113(This)	\
    ( (This)->lpVtbl -> _Dummy113(This) ) 

#define IDialogSheet__Dummy114(This)	\
    ( (This)->lpVtbl -> _Dummy114(This) ) 

#define IDialogSheet__Dummy115(This)	\
    ( (This)->lpVtbl -> _Dummy115(This) ) 

#define IDialogSheet_PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate,PrToFileName)	\
    ( (This)->lpVtbl -> PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate,PrToFileName) ) 

#define IDialogSheet_get_EnableFormatConditionsCalculation(This,RHS)	\
    ( (This)->lpVtbl -> get_EnableFormatConditionsCalculation(This,RHS) ) 

#define IDialogSheet_put_EnableFormatConditionsCalculation(This,RHS)	\
    ( (This)->lpVtbl -> put_EnableFormatConditionsCalculation(This,RHS) ) 

#define IDialogSheet_get_Sort(This,RHS)	\
    ( (This)->lpVtbl -> get_Sort(This,RHS) ) 

#define IDialogSheet_ExportAsFixedFormat(This,Type,Filename,Quality,IncludeDocProperties,IgnorePrintAreas,From,To,OpenAfterPublish,FixedFormatExtClassPtr)	\
    ( (This)->lpVtbl -> ExportAsFixedFormat(This,Type,Filename,Quality,IncludeDocProperties,IgnorePrintAreas,From,To,OpenAfterPublish,FixedFormatExtClassPtr) ) 

#define IDialogSheet_get_PrintedCommentPages(This,RHS)	\
    ( (This)->lpVtbl -> get_PrintedCommentPages(This,RHS) ) 

#define IDialogSheet_get_DefaultButton(This,RHS)	\
    ( (This)->lpVtbl -> get_DefaultButton(This,RHS) ) 

#define IDialogSheet_put_DefaultButton(This,RHS)	\
    ( (This)->lpVtbl -> put_DefaultButton(This,RHS) ) 

#define IDialogSheet_get_DialogFrame(This,RHS)	\
    ( (This)->lpVtbl -> get_DialogFrame(This,RHS) ) 

#define IDialogSheet_EditBoxes(This,Index,RHS)	\
    ( (This)->lpVtbl -> EditBoxes(This,Index,RHS) ) 

#define IDialogSheet_get_Focus(This,RHS)	\
    ( (This)->lpVtbl -> get_Focus(This,RHS) ) 

#define IDialogSheet_put_Focus(This,RHS)	\
    ( (This)->lpVtbl -> put_Focus(This,RHS) ) 

#define IDialogSheet_Hide(This,Cancel,RHS)	\
    ( (This)->lpVtbl -> Hide(This,Cancel,RHS) ) 

#define IDialogSheet_Show(This,RHS)	\
    ( (This)->lpVtbl -> Show(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */



/* [helpcontext][propget][id] */ HRESULT __stdcall IDialogSheet_get_Tab_Proxy( 
    IDialogSheet * This,
    /* [retval][out] */ Tab	**RHS);


void __RPC_STUB IDialogSheet_get_Tab_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IDialogSheet_get_MailEnvelope_Proxy( 
    IDialogSheet * This,
    /* [retval][out] */ /* external definition not present */ MsoEnvelope **RHS);


void __RPC_STUB IDialogSheet_get_MailEnvelope_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IDialogSheet_SaveAs_Proxy( 
    IDialogSheet * This,
    /* [in] */ BSTR Filename,
    /* [optional][in] */ VARIANT FileFormat,
    /* [optional][in] */ VARIANT Password,
    /* [optional][in] */ VARIANT WriteResPassword,
    /* [optional][in] */ VARIANT ReadOnlyRecommended,
    /* [optional][in] */ VARIANT CreateBackup,
    /* [optional][in] */ VARIANT AddToMru,
    /* [optional][in] */ VARIANT TextCodepage,
    /* [optional][in] */ VARIANT TextVisualLayout,
    /* [optional][in] */ VARIANT Local);


void __RPC_STUB IDialogSheet_SaveAs_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IDialogSheet_get_CustomProperties_Proxy( 
    IDialogSheet * This,
    /* [retval][out] */ CustomProperties	**RHS);


void __RPC_STUB IDialogSheet_get_CustomProperties_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][propget][id] */ HRESULT __stdcall IDialogSheet_get_SmartTags_Proxy( 
    IDialogSheet * This,
    /* [retval][out] */ SmartTags	**RHS);


void __RPC_STUB IDialogSheet_get_SmartTags_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IDialogSheet_get_Protection_Proxy( 
    IDialogSheet * This,
    /* [retval][out] */ Protection	**RHS);


void __RPC_STUB IDialogSheet_get_Protection_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IDialogSheet_PasteSpecial_Proxy( 
    IDialogSheet * This,
    /* [optional][in] */ VARIANT Format,
    /* [optional][in] */ VARIANT Link,
    /* [optional][in] */ VARIANT DisplayAsIcon,
    /* [optional][in] */ VARIANT IconFileName,
    /* [optional][in] */ VARIANT IconIndex,
    /* [optional][in] */ VARIANT IconLabel,
    /* [optional][in] */ VARIANT NoHTMLFormatting,
    /* [lcid][in] */ long lcid);


void __RPC_STUB IDialogSheet_PasteSpecial_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IDialogSheet_Protect_Proxy( 
    IDialogSheet * This,
    /* [optional][in] */ VARIANT Password,
    /* [optional][in] */ VARIANT DrawingObjects,
    /* [optional][in] */ VARIANT Contents,
    /* [optional][in] */ VARIANT Scenarios,
    /* [optional][in] */ VARIANT UserInterfaceOnly,
    /* [optional][in] */ VARIANT AllowFormattingCells,
    /* [optional][in] */ VARIANT AllowFormattingColumns,
    /* [optional][in] */ VARIANT AllowFormattingRows,
    /* [optional][in] */ VARIANT AllowInsertingColumns,
    /* [optional][in] */ VARIANT AllowInsertingRows,
    /* [optional][in] */ VARIANT AllowInsertingHyperlinks,
    /* [optional][in] */ VARIANT AllowDeletingColumns,
    /* [optional][in] */ VARIANT AllowDeletingRows,
    /* [optional][in] */ VARIANT AllowSorting,
    /* [optional][in] */ VARIANT AllowFiltering,
    /* [optional][in] */ VARIANT AllowUsingPivotTables);


void __RPC_STUB IDialogSheet_Protect_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [hidden][restricted] */ void __stdcall IDialogSheet__Dummy113_Proxy( 
    IDialogSheet * This);


void __RPC_STUB IDialogSheet__Dummy113_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [hidden][restricted] */ void __stdcall IDialogSheet__Dummy114_Proxy( 
    IDialogSheet * This);


void __RPC_STUB IDialogSheet__Dummy114_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [hidden][restricted] */ void __stdcall IDialogSheet__Dummy115_Proxy( 
    IDialogSheet * This);


void __RPC_STUB IDialogSheet__Dummy115_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [custom][helpcontext][id] */ HRESULT __stdcall IDialogSheet_PrintOut_Proxy( 
    IDialogSheet * This,
    /* [optional][in] */ VARIANT From,
    /* [optional][in] */ VARIANT To,
    /* [optional][in] */ VARIANT Copies,
    /* [optional][in] */ VARIANT Preview,
    /* [optional][in] */ VARIANT ActivePrinter,
    /* [optional][in] */ VARIANT PrintToFile,
    /* [optional][in] */ VARIANT Collate,
    /* [optional][in] */ VARIANT PrToFileName);


void __RPC_STUB IDialogSheet_PrintOut_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IDialogSheet_get_EnableFormatConditionsCalculation_Proxy( 
    IDialogSheet * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB IDialogSheet_get_EnableFormatConditionsCalculation_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT __stdcall IDialogSheet_put_EnableFormatConditionsCalculation_Proxy( 
    IDialogSheet * This,
    /* [in] */ VARIANT_BOOL RHS);


void __RPC_STUB IDialogSheet_put_EnableFormatConditionsCalculation_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IDialogSheet_get_Sort_Proxy( 
    IDialogSheet * This,
    /* [retval][out] */ Sort	**RHS);


void __RPC_STUB IDialogSheet_get_Sort_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IDialogSheet_ExportAsFixedFormat_Proxy( 
    IDialogSheet * This,
    /* [in] */ XlFixedFormatType Type,
    /* [optional][in] */ VARIANT Filename,
    /* [optional][in] */ VARIANT Quality,
    /* [optional][in] */ VARIANT IncludeDocProperties,
    /* [optional][in] */ VARIANT IgnorePrintAreas,
    /* [optional][in] */ VARIANT From,
    /* [optional][in] */ VARIANT To,
    /* [optional][in] */ VARIANT OpenAfterPublish,
    /* [optional][in] */ VARIANT FixedFormatExtClassPtr);


void __RPC_STUB IDialogSheet_ExportAsFixedFormat_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IDialogSheet_get_PrintedCommentPages_Proxy( 
    IDialogSheet * This,
    /* [retval][out] */ long *RHS);


void __RPC_STUB IDialogSheet_get_PrintedCommentPages_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IDialogSheet_get_DefaultButton_Proxy( 
    IDialogSheet * This,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB IDialogSheet_get_DefaultButton_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT __stdcall IDialogSheet_put_DefaultButton_Proxy( 
    IDialogSheet * This,
    /* [in] */ VARIANT RHS);


void __RPC_STUB IDialogSheet_put_DefaultButton_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][propget][id] */ HRESULT __stdcall IDialogSheet_get_DialogFrame_Proxy( 
    IDialogSheet * This,
    /* [retval][out] */ DialogFrame	**RHS);


void __RPC_STUB IDialogSheet_get_DialogFrame_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][hidden][id] */ HRESULT __stdcall IDialogSheet_EditBoxes_Proxy( 
    IDialogSheet * This,
    /* [optional][in] */ VARIANT Index,
    /* [retval][out] */ IDispatch **RHS);


void __RPC_STUB IDialogSheet_EditBoxes_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall IDialogSheet_get_Focus_Proxy( 
    IDialogSheet * This,
    /* [retval][out] */ VARIANT *RHS);


void __RPC_STUB IDialogSheet_get_Focus_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propput][id] */ HRESULT __stdcall IDialogSheet_put_Focus_Proxy( 
    IDialogSheet * This,
    /* [in] */ VARIANT RHS);


void __RPC_STUB IDialogSheet_put_Focus_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IDialogSheet_Hide_Proxy( 
    IDialogSheet * This,
    /* [optional][in] */ VARIANT Cancel,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB IDialogSheet_Hide_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][id] */ HRESULT __stdcall IDialogSheet_Show_Proxy( 
    IDialogSheet * This,
    /* [retval][out] */ VARIANT_BOOL *RHS);


void __RPC_STUB IDialogSheet_Show_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);



#endif 	/* __IDialogSheet_INTERFACE_DEFINED__ */


#ifndef __IDialogSheets_INTERFACE_DEFINED__
#define __IDialogSheets_INTERFACE_DEFINED__

/* interface IDialogSheets */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IDialogSheets;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000208B0-0001-0000-C000-000000000046")
    IDialogSheets : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add( 
            /* [optional][in] */ VARIANT Before,
            /* [optional][in] */ VARIANT After,
            /* [optional][in] */ VARIANT Count,
            /* [retval][out] */ DialogSheet	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Copy( 
            /* [optional][in] */ VARIANT Before,
            /* [optional][in] */ VARIANT After,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy7( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Move( 
            /* [optional][in] */ VARIANT Before,
            /* [optional][in] */ VARIANT After,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
        virtual /* [custom][helpcontext][hidden][id] */ HRESULT __stdcall __PrintOut( 
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall PrintPreview( 
            /* [optional][in] */ VARIANT EnableChanges,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [optional][in] */ VARIANT Replace,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HPageBreaks( 
            /* [retval][out] */ HPageBreaks	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_VPageBreaks( 
            /* [retval][out] */ VPageBreaks	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Visible( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Visible( 
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [custom][helpcontext][hidden][id] */ HRESULT __stdcall _PrintOut( 
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate,
            /* [optional][in] */ VARIANT PrToFileName,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [custom][helpcontext][id] */ HRESULT __stdcall PrintOut( 
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate,
            /* [optional][in] */ VARIANT PrToFileName) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add2( 
            /* [optional][in] */ VARIANT Before,
            /* [optional][in] */ VARIANT After,
            /* [optional][in] */ VARIANT Count,
            /* [optional][in] */ VARIANT NewLayout,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IDialogSheetsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IDialogSheets * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IDialogSheets * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IDialogSheets * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IDialogSheets * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IDialogSheets * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IDialogSheets * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IDialogSheets * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IDialogSheets * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IDialogSheets * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IDialogSheets * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add )( 
            IDialogSheets * This,
            /* [optional][in] */ VARIANT Before,
            /* [optional][in] */ VARIANT After,
            /* [optional][in] */ VARIANT Count,
            /* [retval][out] */ DialogSheet	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Copy )( 
            IDialogSheets * This,
            /* [optional][in] */ VARIANT Before,
            /* [optional][in] */ VARIANT After,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IDialogSheets * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IDialogSheets * This,
            /* [lcid][in] */ long lcid);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy7 )( 
            IDialogSheets * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Item )( 
            IDialogSheets * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Move )( 
            IDialogSheets * This,
            /* [optional][in] */ VARIANT Before,
            /* [optional][in] */ VARIANT After,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            IDialogSheets * This,
            /* [retval][out] */ IUnknown **RHS);
        
        /* [custom][helpcontext][hidden][id] */ HRESULT ( __stdcall *__PrintOut )( 
            IDialogSheets * This,
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *PrintPreview )( 
            IDialogSheets * This,
            /* [optional][in] */ VARIANT EnableChanges,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            IDialogSheets * This,
            /* [optional][in] */ VARIANT Replace,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HPageBreaks )( 
            IDialogSheets * This,
            /* [retval][out] */ HPageBreaks	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_VPageBreaks )( 
            IDialogSheets * This,
            /* [retval][out] */ VPageBreaks	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Visible )( 
            IDialogSheets * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Visible )( 
            IDialogSheets * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IDialogSheets * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [custom][helpcontext][hidden][id] */ HRESULT ( __stdcall *_PrintOut )( 
            IDialogSheets * This,
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate,
            /* [optional][in] */ VARIANT PrToFileName,
            /* [lcid][in] */ long lcid);
        
        /* [custom][helpcontext][id] */ HRESULT ( __stdcall *PrintOut )( 
            IDialogSheets * This,
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate,
            /* [optional][in] */ VARIANT PrToFileName);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add2 )( 
            IDialogSheets * This,
            /* [optional][in] */ VARIANT Before,
            /* [optional][in] */ VARIANT After,
            /* [optional][in] */ VARIANT Count,
            /* [optional][in] */ VARIANT NewLayout,
            /* [retval][out] */ IDispatch **RHS);
        
        END_INTERFACE
    } IDialogSheetsVtbl;

    interface IDialogSheets
    {
        CONST_VTBL struct IDialogSheetsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IDialogSheets_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IDialogSheets_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IDialogSheets_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IDialogSheets_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IDialogSheets_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IDialogSheets_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IDialogSheets_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IDialogSheets_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IDialogSheets_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IDialogSheets_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IDialogSheets_Add(This,Before,After,Count,RHS)	\
    ( (This)->lpVtbl -> Add(This,Before,After,Count,RHS) ) 

#define IDialogSheets_Copy(This,Before,After,lcid)	\
    ( (This)->lpVtbl -> Copy(This,Before,After,lcid) ) 

#define IDialogSheets_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IDialogSheets_Delete(This,lcid)	\
    ( (This)->lpVtbl -> Delete(This,lcid) ) 

#define IDialogSheets__Dummy7(This)	\
    ( (This)->lpVtbl -> _Dummy7(This) ) 

#define IDialogSheets_get_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Item(This,Index,RHS) ) 

#define IDialogSheets_Move(This,Before,After,lcid)	\
    ( (This)->lpVtbl -> Move(This,Before,After,lcid) ) 

#define IDialogSheets_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#define IDialogSheets___PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate,lcid)	\
    ( (This)->lpVtbl -> __PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate,lcid) ) 

#define IDialogSheets_PrintPreview(This,EnableChanges,lcid)	\
    ( (This)->lpVtbl -> PrintPreview(This,EnableChanges,lcid) ) 

#define IDialogSheets_Select(This,Replace,lcid)	\
    ( (This)->lpVtbl -> Select(This,Replace,lcid) ) 

#define IDialogSheets_get_HPageBreaks(This,RHS)	\
    ( (This)->lpVtbl -> get_HPageBreaks(This,RHS) ) 

#define IDialogSheets_get_VPageBreaks(This,RHS)	\
    ( (This)->lpVtbl -> get_VPageBreaks(This,RHS) ) 

#define IDialogSheets_get_Visible(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_Visible(This,lcid,RHS) ) 

#define IDialogSheets_put_Visible(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_Visible(This,lcid,RHS) ) 

#define IDialogSheets_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define IDialogSheets__PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate,PrToFileName,lcid)	\
    ( (This)->lpVtbl -> _PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate,PrToFileName,lcid) ) 

#define IDialogSheets_PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate,PrToFileName)	\
    ( (This)->lpVtbl -> PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate,PrToFileName) ) 

#define IDialogSheets_Add2(This,Before,After,Count,NewLayout,RHS)	\
    ( (This)->lpVtbl -> Add2(This,Before,After,Count,NewLayout,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IDialogSheets_INTERFACE_DEFINED__ */


#ifndef __IWorksheets_INTERFACE_DEFINED__
#define __IWorksheets_INTERFACE_DEFINED__

/* interface IWorksheets */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IWorksheets;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000208B1-0001-0000-C000-000000000046")
    IWorksheets : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add( 
            /* [optional][in] */ VARIANT Before,
            /* [optional][in] */ VARIANT After,
            /* [optional][in] */ VARIANT Count,
            /* [optional][in] */ VARIANT Type,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Copy( 
            /* [optional][in] */ VARIANT Before,
            /* [optional][in] */ VARIANT After,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall FillAcrossSheets( 
            /* [in] */ Range	*Range,
            /* [defaultvalue][optional][in] */ XlFillWith Type,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Move( 
            /* [optional][in] */ VARIANT Before,
            /* [optional][in] */ VARIANT After,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
        virtual /* [custom][helpcontext][hidden][id] */ HRESULT __stdcall __PrintOut( 
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall PrintPreview( 
            /* [optional][in] */ VARIANT EnableChanges,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [optional][in] */ VARIANT Replace,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HPageBreaks( 
            /* [retval][out] */ HPageBreaks	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_VPageBreaks( 
            /* [retval][out] */ VPageBreaks	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Visible( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Visible( 
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [custom][helpcontext][hidden][id] */ HRESULT __stdcall _PrintOut( 
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate,
            /* [optional][in] */ VARIANT PrToFileName,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [custom][helpcontext][id] */ HRESULT __stdcall PrintOut( 
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate,
            /* [optional][in] */ VARIANT PrToFileName,
            /* [optional][in] */ VARIANT IgnorePrintAreas,
            /* [lcid][in] */ long lcid) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add2( 
            /* [optional][in] */ VARIANT Before,
            /* [optional][in] */ VARIANT After,
            /* [optional][in] */ VARIANT Count,
            /* [optional][in] */ VARIANT NewLayout,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IWorksheetsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IWorksheets * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IWorksheets * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IWorksheets * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IWorksheets * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IWorksheets * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IWorksheets * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IWorksheets * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IWorksheets * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IWorksheets * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IWorksheets * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add )( 
            IWorksheets * This,
            /* [optional][in] */ VARIANT Before,
            /* [optional][in] */ VARIANT After,
            /* [optional][in] */ VARIANT Count,
            /* [optional][in] */ VARIANT Type,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Copy )( 
            IWorksheets * This,
            /* [optional][in] */ VARIANT Before,
            /* [optional][in] */ VARIANT After,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IWorksheets * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IWorksheets * This,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *FillAcrossSheets )( 
            IWorksheets * This,
            /* [in] */ Range	*Range,
            /* [defaultvalue][optional][in] */ XlFillWith Type,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Item )( 
            IWorksheets * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Move )( 
            IWorksheets * This,
            /* [optional][in] */ VARIANT Before,
            /* [optional][in] */ VARIANT After,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            IWorksheets * This,
            /* [retval][out] */ IUnknown **RHS);
        
        /* [custom][helpcontext][hidden][id] */ HRESULT ( __stdcall *__PrintOut )( 
            IWorksheets * This,
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *PrintPreview )( 
            IWorksheets * This,
            /* [optional][in] */ VARIANT EnableChanges,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            IWorksheets * This,
            /* [optional][in] */ VARIANT Replace,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HPageBreaks )( 
            IWorksheets * This,
            /* [retval][out] */ HPageBreaks	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_VPageBreaks )( 
            IWorksheets * This,
            /* [retval][out] */ VPageBreaks	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Visible )( 
            IWorksheets * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Visible )( 
            IWorksheets * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IWorksheets * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [custom][helpcontext][hidden][id] */ HRESULT ( __stdcall *_PrintOut )( 
            IWorksheets * This,
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate,
            /* [optional][in] */ VARIANT PrToFileName,
            /* [lcid][in] */ long lcid);
        
        /* [custom][helpcontext][id] */ HRESULT ( __stdcall *PrintOut )( 
            IWorksheets * This,
            /* [optional][in] */ VARIANT From,
            /* [optional][in] */ VARIANT To,
            /* [optional][in] */ VARIANT Copies,
            /* [optional][in] */ VARIANT Preview,
            /* [optional][in] */ VARIANT ActivePrinter,
            /* [optional][in] */ VARIANT PrintToFile,
            /* [optional][in] */ VARIANT Collate,
            /* [optional][in] */ VARIANT PrToFileName,
            /* [optional][in] */ VARIANT IgnorePrintAreas,
            /* [lcid][in] */ long lcid);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add2 )( 
            IWorksheets * This,
            /* [optional][in] */ VARIANT Before,
            /* [optional][in] */ VARIANT After,
            /* [optional][in] */ VARIANT Count,
            /* [optional][in] */ VARIANT NewLayout,
            /* [retval][out] */ IDispatch **RHS);
        
        END_INTERFACE
    } IWorksheetsVtbl;

    interface IWorksheets
    {
        CONST_VTBL struct IWorksheetsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IWorksheets_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IWorksheets_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IWorksheets_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IWorksheets_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IWorksheets_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IWorksheets_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IWorksheets_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IWorksheets_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IWorksheets_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IWorksheets_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IWorksheets_Add(This,Before,After,Count,Type,lcid,RHS)	\
    ( (This)->lpVtbl -> Add(This,Before,After,Count,Type,lcid,RHS) ) 

#define IWorksheets_Copy(This,Before,After,lcid)	\
    ( (This)->lpVtbl -> Copy(This,Before,After,lcid) ) 

#define IWorksheets_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IWorksheets_Delete(This,lcid)	\
    ( (This)->lpVtbl -> Delete(This,lcid) ) 

#define IWorksheets_FillAcrossSheets(This,Range,Type,lcid)	\
    ( (This)->lpVtbl -> FillAcrossSheets(This,Range,Type,lcid) ) 

#define IWorksheets_get_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Item(This,Index,RHS) ) 

#define IWorksheets_Move(This,Before,After,lcid)	\
    ( (This)->lpVtbl -> Move(This,Before,After,lcid) ) 

#define IWorksheets_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#define IWorksheets___PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate,lcid)	\
    ( (This)->lpVtbl -> __PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate,lcid) ) 

#define IWorksheets_PrintPreview(This,EnableChanges,lcid)	\
    ( (This)->lpVtbl -> PrintPreview(This,EnableChanges,lcid) ) 

#define IWorksheets_Select(This,Replace,lcid)	\
    ( (This)->lpVtbl -> Select(This,Replace,lcid) ) 

#define IWorksheets_get_HPageBreaks(This,RHS)	\
    ( (This)->lpVtbl -> get_HPageBreaks(This,RHS) ) 

#define IWorksheets_get_VPageBreaks(This,RHS)	\
    ( (This)->lpVtbl -> get_VPageBreaks(This,RHS) ) 

#define IWorksheets_get_Visible(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_Visible(This,lcid,RHS) ) 

#define IWorksheets_put_Visible(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_Visible(This,lcid,RHS) ) 

#define IWorksheets_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define IWorksheets__PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate,PrToFileName,lcid)	\
    ( (This)->lpVtbl -> _PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate,PrToFileName,lcid) ) 

#define IWorksheets_PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate,PrToFileName,IgnorePrintAreas,lcid)	\
    ( (This)->lpVtbl -> PrintOut(This,From,To,Copies,Preview,ActivePrinter,PrintToFile,Collate,PrToFileName,IgnorePrintAreas,lcid) ) 

#define IWorksheets_Add2(This,Before,After,Count,NewLayout,RHS)	\
    ( (This)->lpVtbl -> Add2(This,Before,After,Count,NewLayout,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IWorksheets_INTERFACE_DEFINED__ */


#ifndef __IPageSetup_INTERFACE_DEFINED__
#define __IPageSetup_INTERFACE_DEFINED__

/* interface IPageSetup */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IPageSetup;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000208B4-0001-0000-C000-000000000046")
    IPageSetup : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_BlackAndWhite( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_BlackAndWhite( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_BottomMargin( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_BottomMargin( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CenterFooter( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_CenterFooter( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CenterHeader( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_CenterHeader( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CenterHorizontally( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_CenterHorizontally( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CenterVertically( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_CenterVertically( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_ChartSize( 
            /* [retval][out] */ XlObjectSize *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_ChartSize( 
            /* [in] */ XlObjectSize RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Draft( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Draft( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_FirstPageNumber( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_FirstPageNumber( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_FitToPagesTall( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_FitToPagesTall( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_FitToPagesWide( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_FitToPagesWide( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_FooterMargin( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_FooterMargin( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HeaderMargin( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_HeaderMargin( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LeftFooter( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_LeftFooter( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LeftHeader( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_LeftHeader( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LeftMargin( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_LeftMargin( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Order( 
            /* [retval][out] */ XlOrder *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Order( 
            /* [in] */ XlOrder RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Orientation( 
            /* [retval][out] */ XlPageOrientation *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Orientation( 
            /* [in] */ XlPageOrientation RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PaperSize( 
            /* [retval][out] */ XlPaperSize *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PaperSize( 
            /* [in] */ XlPaperSize RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PrintArea( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PrintArea( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PrintGridlines( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PrintGridlines( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PrintHeadings( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PrintHeadings( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PrintNotes( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PrintNotes( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PrintQuality( 
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PrintQuality( 
            /* [optional][in] */ VARIANT Index,
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PrintTitleColumns( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PrintTitleColumns( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PrintTitleRows( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PrintTitleRows( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RightFooter( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_RightFooter( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RightHeader( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_RightHeader( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RightMargin( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_RightMargin( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TopMargin( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_TopMargin( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Zoom( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Zoom( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PrintComments( 
            /* [retval][out] */ XlPrintLocation *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PrintComments( 
            /* [in] */ XlPrintLocation RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PrintErrors( 
            /* [retval][out] */ XlPrintErrors *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PrintErrors( 
            /* [in] */ XlPrintErrors RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CenterHeaderPicture( 
            /* [retval][out] */ Graphic	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CenterFooterPicture( 
            /* [retval][out] */ Graphic	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LeftHeaderPicture( 
            /* [retval][out] */ Graphic	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LeftFooterPicture( 
            /* [retval][out] */ Graphic	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RightHeaderPicture( 
            /* [retval][out] */ Graphic	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RightFooterPicture( 
            /* [retval][out] */ Graphic	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_OddAndEvenPagesHeaderFooter( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_OddAndEvenPagesHeaderFooter( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DifferentFirstPageHeaderFooter( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DifferentFirstPageHeaderFooter( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ScaleWithDocHeaderFooter( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ScaleWithDocHeaderFooter( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AlignMarginsHeaderFooter( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AlignMarginsHeaderFooter( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Pages( 
            /* [retval][out] */ Pages	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_EvenPage( 
            /* [retval][out] */ Page	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_FirstPage( 
            /* [retval][out] */ Page	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IPageSetupVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IPageSetup * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IPageSetup * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IPageSetup * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IPageSetup * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IPageSetup * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IPageSetup * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IPageSetup * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IPageSetup * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IPageSetup * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IPageSetup * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_BlackAndWhite )( 
            IPageSetup * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_BlackAndWhite )( 
            IPageSetup * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_BottomMargin )( 
            IPageSetup * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_BottomMargin )( 
            IPageSetup * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CenterFooter )( 
            IPageSetup * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_CenterFooter )( 
            IPageSetup * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CenterHeader )( 
            IPageSetup * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_CenterHeader )( 
            IPageSetup * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CenterHorizontally )( 
            IPageSetup * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_CenterHorizontally )( 
            IPageSetup * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CenterVertically )( 
            IPageSetup * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_CenterVertically )( 
            IPageSetup * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_ChartSize )( 
            IPageSetup * This,
            /* [retval][out] */ XlObjectSize *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_ChartSize )( 
            IPageSetup * This,
            /* [in] */ XlObjectSize RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Draft )( 
            IPageSetup * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Draft )( 
            IPageSetup * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_FirstPageNumber )( 
            IPageSetup * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_FirstPageNumber )( 
            IPageSetup * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_FitToPagesTall )( 
            IPageSetup * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_FitToPagesTall )( 
            IPageSetup * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_FitToPagesWide )( 
            IPageSetup * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_FitToPagesWide )( 
            IPageSetup * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_FooterMargin )( 
            IPageSetup * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_FooterMargin )( 
            IPageSetup * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HeaderMargin )( 
            IPageSetup * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_HeaderMargin )( 
            IPageSetup * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LeftFooter )( 
            IPageSetup * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_LeftFooter )( 
            IPageSetup * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LeftHeader )( 
            IPageSetup * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_LeftHeader )( 
            IPageSetup * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LeftMargin )( 
            IPageSetup * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_LeftMargin )( 
            IPageSetup * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Order )( 
            IPageSetup * This,
            /* [retval][out] */ XlOrder *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Order )( 
            IPageSetup * This,
            /* [in] */ XlOrder RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Orientation )( 
            IPageSetup * This,
            /* [retval][out] */ XlPageOrientation *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Orientation )( 
            IPageSetup * This,
            /* [in] */ XlPageOrientation RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PaperSize )( 
            IPageSetup * This,
            /* [retval][out] */ XlPaperSize *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PaperSize )( 
            IPageSetup * This,
            /* [in] */ XlPaperSize RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PrintArea )( 
            IPageSetup * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PrintArea )( 
            IPageSetup * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PrintGridlines )( 
            IPageSetup * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PrintGridlines )( 
            IPageSetup * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PrintHeadings )( 
            IPageSetup * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PrintHeadings )( 
            IPageSetup * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PrintNotes )( 
            IPageSetup * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PrintNotes )( 
            IPageSetup * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PrintQuality )( 
            IPageSetup * This,
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PrintQuality )( 
            IPageSetup * This,
            /* [optional][in] */ VARIANT Index,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PrintTitleColumns )( 
            IPageSetup * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PrintTitleColumns )( 
            IPageSetup * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PrintTitleRows )( 
            IPageSetup * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PrintTitleRows )( 
            IPageSetup * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RightFooter )( 
            IPageSetup * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_RightFooter )( 
            IPageSetup * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RightHeader )( 
            IPageSetup * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_RightHeader )( 
            IPageSetup * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RightMargin )( 
            IPageSetup * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_RightMargin )( 
            IPageSetup * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TopMargin )( 
            IPageSetup * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_TopMargin )( 
            IPageSetup * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Zoom )( 
            IPageSetup * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Zoom )( 
            IPageSetup * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PrintComments )( 
            IPageSetup * This,
            /* [retval][out] */ XlPrintLocation *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PrintComments )( 
            IPageSetup * This,
            /* [in] */ XlPrintLocation RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PrintErrors )( 
            IPageSetup * This,
            /* [retval][out] */ XlPrintErrors *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PrintErrors )( 
            IPageSetup * This,
            /* [in] */ XlPrintErrors RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CenterHeaderPicture )( 
            IPageSetup * This,
            /* [retval][out] */ Graphic	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CenterFooterPicture )( 
            IPageSetup * This,
            /* [retval][out] */ Graphic	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LeftHeaderPicture )( 
            IPageSetup * This,
            /* [retval][out] */ Graphic	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LeftFooterPicture )( 
            IPageSetup * This,
            /* [retval][out] */ Graphic	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RightHeaderPicture )( 
            IPageSetup * This,
            /* [retval][out] */ Graphic	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RightFooterPicture )( 
            IPageSetup * This,
            /* [retval][out] */ Graphic	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_OddAndEvenPagesHeaderFooter )( 
            IPageSetup * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_OddAndEvenPagesHeaderFooter )( 
            IPageSetup * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DifferentFirstPageHeaderFooter )( 
            IPageSetup * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DifferentFirstPageHeaderFooter )( 
            IPageSetup * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ScaleWithDocHeaderFooter )( 
            IPageSetup * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ScaleWithDocHeaderFooter )( 
            IPageSetup * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AlignMarginsHeaderFooter )( 
            IPageSetup * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AlignMarginsHeaderFooter )( 
            IPageSetup * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Pages )( 
            IPageSetup * This,
            /* [retval][out] */ Pages	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_EvenPage )( 
            IPageSetup * This,
            /* [retval][out] */ Page	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_FirstPage )( 
            IPageSetup * This,
            /* [retval][out] */ Page	**RHS);
        
        END_INTERFACE
    } IPageSetupVtbl;

    interface IPageSetup
    {
        CONST_VTBL struct IPageSetupVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IPageSetup_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IPageSetup_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IPageSetup_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IPageSetup_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IPageSetup_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IPageSetup_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IPageSetup_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IPageSetup_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IPageSetup_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IPageSetup_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IPageSetup_get_BlackAndWhite(This,RHS)	\
    ( (This)->lpVtbl -> get_BlackAndWhite(This,RHS) ) 

#define IPageSetup_put_BlackAndWhite(This,RHS)	\
    ( (This)->lpVtbl -> put_BlackAndWhite(This,RHS) ) 

#define IPageSetup_get_BottomMargin(This,RHS)	\
    ( (This)->lpVtbl -> get_BottomMargin(This,RHS) ) 

#define IPageSetup_put_BottomMargin(This,RHS)	\
    ( (This)->lpVtbl -> put_BottomMargin(This,RHS) ) 

#define IPageSetup_get_CenterFooter(This,RHS)	\
    ( (This)->lpVtbl -> get_CenterFooter(This,RHS) ) 

#define IPageSetup_put_CenterFooter(This,RHS)	\
    ( (This)->lpVtbl -> put_CenterFooter(This,RHS) ) 

#define IPageSetup_get_CenterHeader(This,RHS)	\
    ( (This)->lpVtbl -> get_CenterHeader(This,RHS) ) 

#define IPageSetup_put_CenterHeader(This,RHS)	\
    ( (This)->lpVtbl -> put_CenterHeader(This,RHS) ) 

#define IPageSetup_get_CenterHorizontally(This,RHS)	\
    ( (This)->lpVtbl -> get_CenterHorizontally(This,RHS) ) 

#define IPageSetup_put_CenterHorizontally(This,RHS)	\
    ( (This)->lpVtbl -> put_CenterHorizontally(This,RHS) ) 

#define IPageSetup_get_CenterVertically(This,RHS)	\
    ( (This)->lpVtbl -> get_CenterVertically(This,RHS) ) 

#define IPageSetup_put_CenterVertically(This,RHS)	\
    ( (This)->lpVtbl -> put_CenterVertically(This,RHS) ) 

#define IPageSetup_get_ChartSize(This,RHS)	\
    ( (This)->lpVtbl -> get_ChartSize(This,RHS) ) 

#define IPageSetup_put_ChartSize(This,RHS)	\
    ( (This)->lpVtbl -> put_ChartSize(This,RHS) ) 

#define IPageSetup_get_Draft(This,RHS)	\
    ( (This)->lpVtbl -> get_Draft(This,RHS) ) 

#define IPageSetup_put_Draft(This,RHS)	\
    ( (This)->lpVtbl -> put_Draft(This,RHS) ) 

#define IPageSetup_get_FirstPageNumber(This,RHS)	\
    ( (This)->lpVtbl -> get_FirstPageNumber(This,RHS) ) 

#define IPageSetup_put_FirstPageNumber(This,RHS)	\
    ( (This)->lpVtbl -> put_FirstPageNumber(This,RHS) ) 

#define IPageSetup_get_FitToPagesTall(This,RHS)	\
    ( (This)->lpVtbl -> get_FitToPagesTall(This,RHS) ) 

#define IPageSetup_put_FitToPagesTall(This,RHS)	\
    ( (This)->lpVtbl -> put_FitToPagesTall(This,RHS) ) 

#define IPageSetup_get_FitToPagesWide(This,RHS)	\
    ( (This)->lpVtbl -> get_FitToPagesWide(This,RHS) ) 

#define IPageSetup_put_FitToPagesWide(This,RHS)	\
    ( (This)->lpVtbl -> put_FitToPagesWide(This,RHS) ) 

#define IPageSetup_get_FooterMargin(This,RHS)	\
    ( (This)->lpVtbl -> get_FooterMargin(This,RHS) ) 

#define IPageSetup_put_FooterMargin(This,RHS)	\
    ( (This)->lpVtbl -> put_FooterMargin(This,RHS) ) 

#define IPageSetup_get_HeaderMargin(This,RHS)	\
    ( (This)->lpVtbl -> get_HeaderMargin(This,RHS) ) 

#define IPageSetup_put_HeaderMargin(This,RHS)	\
    ( (This)->lpVtbl -> put_HeaderMargin(This,RHS) ) 

#define IPageSetup_get_LeftFooter(This,RHS)	\
    ( (This)->lpVtbl -> get_LeftFooter(This,RHS) ) 

#define IPageSetup_put_LeftFooter(This,RHS)	\
    ( (This)->lpVtbl -> put_LeftFooter(This,RHS) ) 

#define IPageSetup_get_LeftHeader(This,RHS)	\
    ( (This)->lpVtbl -> get_LeftHeader(This,RHS) ) 

#define IPageSetup_put_LeftHeader(This,RHS)	\
    ( (This)->lpVtbl -> put_LeftHeader(This,RHS) ) 

#define IPageSetup_get_LeftMargin(This,RHS)	\
    ( (This)->lpVtbl -> get_LeftMargin(This,RHS) ) 

#define IPageSetup_put_LeftMargin(This,RHS)	\
    ( (This)->lpVtbl -> put_LeftMargin(This,RHS) ) 

#define IPageSetup_get_Order(This,RHS)	\
    ( (This)->lpVtbl -> get_Order(This,RHS) ) 

#define IPageSetup_put_Order(This,RHS)	\
    ( (This)->lpVtbl -> put_Order(This,RHS) ) 

#define IPageSetup_get_Orientation(This,RHS)	\
    ( (This)->lpVtbl -> get_Orientation(This,RHS) ) 

#define IPageSetup_put_Orientation(This,RHS)	\
    ( (This)->lpVtbl -> put_Orientation(This,RHS) ) 

#define IPageSetup_get_PaperSize(This,RHS)	\
    ( (This)->lpVtbl -> get_PaperSize(This,RHS) ) 

#define IPageSetup_put_PaperSize(This,RHS)	\
    ( (This)->lpVtbl -> put_PaperSize(This,RHS) ) 

#define IPageSetup_get_PrintArea(This,RHS)	\
    ( (This)->lpVtbl -> get_PrintArea(This,RHS) ) 

#define IPageSetup_put_PrintArea(This,RHS)	\
    ( (This)->lpVtbl -> put_PrintArea(This,RHS) ) 

#define IPageSetup_get_PrintGridlines(This,RHS)	\
    ( (This)->lpVtbl -> get_PrintGridlines(This,RHS) ) 

#define IPageSetup_put_PrintGridlines(This,RHS)	\
    ( (This)->lpVtbl -> put_PrintGridlines(This,RHS) ) 

#define IPageSetup_get_PrintHeadings(This,RHS)	\
    ( (This)->lpVtbl -> get_PrintHeadings(This,RHS) ) 

#define IPageSetup_put_PrintHeadings(This,RHS)	\
    ( (This)->lpVtbl -> put_PrintHeadings(This,RHS) ) 

#define IPageSetup_get_PrintNotes(This,RHS)	\
    ( (This)->lpVtbl -> get_PrintNotes(This,RHS) ) 

#define IPageSetup_put_PrintNotes(This,RHS)	\
    ( (This)->lpVtbl -> put_PrintNotes(This,RHS) ) 

#define IPageSetup_get_PrintQuality(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_PrintQuality(This,Index,RHS) ) 

#define IPageSetup_put_PrintQuality(This,Index,RHS)	\
    ( (This)->lpVtbl -> put_PrintQuality(This,Index,RHS) ) 

#define IPageSetup_get_PrintTitleColumns(This,RHS)	\
    ( (This)->lpVtbl -> get_PrintTitleColumns(This,RHS) ) 

#define IPageSetup_put_PrintTitleColumns(This,RHS)	\
    ( (This)->lpVtbl -> put_PrintTitleColumns(This,RHS) ) 

#define IPageSetup_get_PrintTitleRows(This,RHS)	\
    ( (This)->lpVtbl -> get_PrintTitleRows(This,RHS) ) 

#define IPageSetup_put_PrintTitleRows(This,RHS)	\
    ( (This)->lpVtbl -> put_PrintTitleRows(This,RHS) ) 

#define IPageSetup_get_RightFooter(This,RHS)	\
    ( (This)->lpVtbl -> get_RightFooter(This,RHS) ) 

#define IPageSetup_put_RightFooter(This,RHS)	\
    ( (This)->lpVtbl -> put_RightFooter(This,RHS) ) 

#define IPageSetup_get_RightHeader(This,RHS)	\
    ( (This)->lpVtbl -> get_RightHeader(This,RHS) ) 

#define IPageSetup_put_RightHeader(This,RHS)	\
    ( (This)->lpVtbl -> put_RightHeader(This,RHS) ) 

#define IPageSetup_get_RightMargin(This,RHS)	\
    ( (This)->lpVtbl -> get_RightMargin(This,RHS) ) 

#define IPageSetup_put_RightMargin(This,RHS)	\
    ( (This)->lpVtbl -> put_RightMargin(This,RHS) ) 

#define IPageSetup_get_TopMargin(This,RHS)	\
    ( (This)->lpVtbl -> get_TopMargin(This,RHS) ) 

#define IPageSetup_put_TopMargin(This,RHS)	\
    ( (This)->lpVtbl -> put_TopMargin(This,RHS) ) 

#define IPageSetup_get_Zoom(This,RHS)	\
    ( (This)->lpVtbl -> get_Zoom(This,RHS) ) 

#define IPageSetup_put_Zoom(This,RHS)	\
    ( (This)->lpVtbl -> put_Zoom(This,RHS) ) 

#define IPageSetup_get_PrintComments(This,RHS)	\
    ( (This)->lpVtbl -> get_PrintComments(This,RHS) ) 

#define IPageSetup_put_PrintComments(This,RHS)	\
    ( (This)->lpVtbl -> put_PrintComments(This,RHS) ) 

#define IPageSetup_get_PrintErrors(This,RHS)	\
    ( (This)->lpVtbl -> get_PrintErrors(This,RHS) ) 

#define IPageSetup_put_PrintErrors(This,RHS)	\
    ( (This)->lpVtbl -> put_PrintErrors(This,RHS) ) 

#define IPageSetup_get_CenterHeaderPicture(This,RHS)	\
    ( (This)->lpVtbl -> get_CenterHeaderPicture(This,RHS) ) 

#define IPageSetup_get_CenterFooterPicture(This,RHS)	\
    ( (This)->lpVtbl -> get_CenterFooterPicture(This,RHS) ) 

#define IPageSetup_get_LeftHeaderPicture(This,RHS)	\
    ( (This)->lpVtbl -> get_LeftHeaderPicture(This,RHS) ) 

#define IPageSetup_get_LeftFooterPicture(This,RHS)	\
    ( (This)->lpVtbl -> get_LeftFooterPicture(This,RHS) ) 

#define IPageSetup_get_RightHeaderPicture(This,RHS)	\
    ( (This)->lpVtbl -> get_RightHeaderPicture(This,RHS) ) 

#define IPageSetup_get_RightFooterPicture(This,RHS)	\
    ( (This)->lpVtbl -> get_RightFooterPicture(This,RHS) ) 

#define IPageSetup_get_OddAndEvenPagesHeaderFooter(This,RHS)	\
    ( (This)->lpVtbl -> get_OddAndEvenPagesHeaderFooter(This,RHS) ) 

#define IPageSetup_put_OddAndEvenPagesHeaderFooter(This,RHS)	\
    ( (This)->lpVtbl -> put_OddAndEvenPagesHeaderFooter(This,RHS) ) 

#define IPageSetup_get_DifferentFirstPageHeaderFooter(This,RHS)	\
    ( (This)->lpVtbl -> get_DifferentFirstPageHeaderFooter(This,RHS) ) 

#define IPageSetup_put_DifferentFirstPageHeaderFooter(This,RHS)	\
    ( (This)->lpVtbl -> put_DifferentFirstPageHeaderFooter(This,RHS) ) 

#define IPageSetup_get_ScaleWithDocHeaderFooter(This,RHS)	\
    ( (This)->lpVtbl -> get_ScaleWithDocHeaderFooter(This,RHS) ) 

#define IPageSetup_put_ScaleWithDocHeaderFooter(This,RHS)	\
    ( (This)->lpVtbl -> put_ScaleWithDocHeaderFooter(This,RHS) ) 

#define IPageSetup_get_AlignMarginsHeaderFooter(This,RHS)	\
    ( (This)->lpVtbl -> get_AlignMarginsHeaderFooter(This,RHS) ) 

#define IPageSetup_put_AlignMarginsHeaderFooter(This,RHS)	\
    ( (This)->lpVtbl -> put_AlignMarginsHeaderFooter(This,RHS) ) 

#define IPageSetup_get_Pages(This,RHS)	\
    ( (This)->lpVtbl -> get_Pages(This,RHS) ) 

#define IPageSetup_get_EvenPage(This,RHS)	\
    ( (This)->lpVtbl -> get_EvenPage(This,RHS) ) 

#define IPageSetup_get_FirstPage(This,RHS)	\
    ( (This)->lpVtbl -> get_FirstPage(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IPageSetup_INTERFACE_DEFINED__ */


#ifndef __INames_INTERFACE_DEFINED__
#define __INames_INTERFACE_DEFINED__

/* interface INames */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_INames;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000208B8-0001-0000-C000-000000000046")
    INames : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add( 
            /* [optional][in] */ VARIANT name,
            /* [optional][in] */ VARIANT RefersTo,
            /* [optional][in] */ VARIANT Visible,
            /* [optional][in] */ VARIANT MacroType,
            /* [optional][in] */ VARIANT ShortcutKey,
            /* [optional][in] */ VARIANT Category,
            /* [optional][in] */ VARIANT NameLocal,
            /* [optional][in] */ VARIANT RefersToLocal,
            /* [optional][in] */ VARIANT CategoryLocal,
            /* [optional][in] */ VARIANT RefersToR1C1,
            /* [optional][in] */ VARIANT RefersToR1C1Local,
            /* [retval][out] */ Name	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Item( 
            /* [optional][in] */ VARIANT Index,
            /* [optional][in] */ VARIANT IndexLocal,
            /* [optional][in] */ VARIANT RefersTo,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ Name	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall _Default( 
            /* [optional][in] */ VARIANT Index,
            /* [optional][in] */ VARIANT IndexLocal,
            /* [optional][in] */ VARIANT RefersTo,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ Name	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct INamesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            INames * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            INames * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            INames * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            INames * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            INames * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            INames * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            INames * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            INames * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            INames * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            INames * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add )( 
            INames * This,
            /* [optional][in] */ VARIANT name,
            /* [optional][in] */ VARIANT RefersTo,
            /* [optional][in] */ VARIANT Visible,
            /* [optional][in] */ VARIANT MacroType,
            /* [optional][in] */ VARIANT ShortcutKey,
            /* [optional][in] */ VARIANT Category,
            /* [optional][in] */ VARIANT NameLocal,
            /* [optional][in] */ VARIANT RefersToLocal,
            /* [optional][in] */ VARIANT CategoryLocal,
            /* [optional][in] */ VARIANT RefersToR1C1,
            /* [optional][in] */ VARIANT RefersToR1C1Local,
            /* [retval][out] */ Name	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Item )( 
            INames * This,
            /* [optional][in] */ VARIANT Index,
            /* [optional][in] */ VARIANT IndexLocal,
            /* [optional][in] */ VARIANT RefersTo,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ Name	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *_Default )( 
            INames * This,
            /* [optional][in] */ VARIANT Index,
            /* [optional][in] */ VARIANT IndexLocal,
            /* [optional][in] */ VARIANT RefersTo,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ Name	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            INames * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            INames * This,
            /* [retval][out] */ IUnknown **RHS);
        
        END_INTERFACE
    } INamesVtbl;

    interface INames
    {
        CONST_VTBL struct INamesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define INames_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define INames_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define INames_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define INames_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define INames_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define INames_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define INames_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define INames_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define INames_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define INames_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define INames_Add(This,name,RefersTo,Visible,MacroType,ShortcutKey,Category,NameLocal,RefersToLocal,CategoryLocal,RefersToR1C1,RefersToR1C1Local,RHS)	\
    ( (This)->lpVtbl -> Add(This,name,RefersTo,Visible,MacroType,ShortcutKey,Category,NameLocal,RefersToLocal,CategoryLocal,RefersToR1C1,RefersToR1C1Local,RHS) ) 

#define INames_Item(This,Index,IndexLocal,RefersTo,lcid,RHS)	\
    ( (This)->lpVtbl -> Item(This,Index,IndexLocal,RefersTo,lcid,RHS) ) 

#define INames__Default(This,Index,IndexLocal,RefersTo,lcid,RHS)	\
    ( (This)->lpVtbl -> _Default(This,Index,IndexLocal,RefersTo,lcid,RHS) ) 

#define INames_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define INames_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __INames_INTERFACE_DEFINED__ */


#ifndef __IName_INTERFACE_DEFINED__
#define __IName_INTERFACE_DEFINED__

/* interface IName */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IName;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000208B9-0001-0000-C000-000000000046")
    IName : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Index( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Category( 
            /* [lcid][in] */ long lcidIn,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Category( 
            /* [lcid][in] */ long lcidIn,
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CategoryLocal( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_CategoryLocal( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MacroType( 
            /* [retval][out] */ XlXLMMacroType *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_MacroType( 
            /* [in] */ XlXLMMacroType RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [lcid][in] */ long lcidIn,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Name( 
            /* [lcid][in] */ long lcidIn,
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RefersTo( 
            /* [lcid][in] */ long lcidIn,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_RefersTo( 
            /* [lcid][in] */ long lcidIn,
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShortcutKey( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ShortcutKey( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Value( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Value( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Visible( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Visible( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_NameLocal( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_NameLocal( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RefersToLocal( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_RefersToLocal( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RefersToR1C1( 
            /* [lcid][in] */ long lcidIn,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_RefersToR1C1( 
            /* [lcid][in] */ long lcidIn,
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RefersToR1C1Local( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_RefersToR1C1Local( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RefersToRange( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Comment( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Comment( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_WorkbookParameter( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_WorkbookParameter( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ValidWorkbookParameter( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct INameVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IName * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IName * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IName * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IName * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IName * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IName * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IName * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IName * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IName * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IName * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IName * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Index )( 
            IName * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Category )( 
            IName * This,
            /* [lcid][in] */ long lcidIn,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Category )( 
            IName * This,
            /* [lcid][in] */ long lcidIn,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CategoryLocal )( 
            IName * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_CategoryLocal )( 
            IName * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IName * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MacroType )( 
            IName * This,
            /* [retval][out] */ XlXLMMacroType *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_MacroType )( 
            IName * This,
            /* [in] */ XlXLMMacroType RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            IName * This,
            /* [lcid][in] */ long lcidIn,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Name )( 
            IName * This,
            /* [lcid][in] */ long lcidIn,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RefersTo )( 
            IName * This,
            /* [lcid][in] */ long lcidIn,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_RefersTo )( 
            IName * This,
            /* [lcid][in] */ long lcidIn,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShortcutKey )( 
            IName * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ShortcutKey )( 
            IName * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Value )( 
            IName * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Value )( 
            IName * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Visible )( 
            IName * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Visible )( 
            IName * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_NameLocal )( 
            IName * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_NameLocal )( 
            IName * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RefersToLocal )( 
            IName * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_RefersToLocal )( 
            IName * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RefersToR1C1 )( 
            IName * This,
            /* [lcid][in] */ long lcidIn,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_RefersToR1C1 )( 
            IName * This,
            /* [lcid][in] */ long lcidIn,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RefersToR1C1Local )( 
            IName * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_RefersToR1C1Local )( 
            IName * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RefersToRange )( 
            IName * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Comment )( 
            IName * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Comment )( 
            IName * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_WorkbookParameter )( 
            IName * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_WorkbookParameter )( 
            IName * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ValidWorkbookParameter )( 
            IName * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        END_INTERFACE
    } INameVtbl;

    interface IName
    {
        CONST_VTBL struct INameVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IName_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IName_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IName_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IName_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IName_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IName_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IName_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IName_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IName_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IName_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IName_get__Default(This,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,RHS) ) 

#define IName_get_Index(This,RHS)	\
    ( (This)->lpVtbl -> get_Index(This,RHS) ) 

#define IName_get_Category(This,lcidIn,RHS)	\
    ( (This)->lpVtbl -> get_Category(This,lcidIn,RHS) ) 

#define IName_put_Category(This,lcidIn,RHS)	\
    ( (This)->lpVtbl -> put_Category(This,lcidIn,RHS) ) 

#define IName_get_CategoryLocal(This,RHS)	\
    ( (This)->lpVtbl -> get_CategoryLocal(This,RHS) ) 

#define IName_put_CategoryLocal(This,RHS)	\
    ( (This)->lpVtbl -> put_CategoryLocal(This,RHS) ) 

#define IName_Delete(This)	\
    ( (This)->lpVtbl -> Delete(This) ) 

#define IName_get_MacroType(This,RHS)	\
    ( (This)->lpVtbl -> get_MacroType(This,RHS) ) 

#define IName_put_MacroType(This,RHS)	\
    ( (This)->lpVtbl -> put_MacroType(This,RHS) ) 

#define IName_get_Name(This,lcidIn,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,lcidIn,RHS) ) 

#define IName_put_Name(This,lcidIn,RHS)	\
    ( (This)->lpVtbl -> put_Name(This,lcidIn,RHS) ) 

#define IName_get_RefersTo(This,lcidIn,RHS)	\
    ( (This)->lpVtbl -> get_RefersTo(This,lcidIn,RHS) ) 

#define IName_put_RefersTo(This,lcidIn,RHS)	\
    ( (This)->lpVtbl -> put_RefersTo(This,lcidIn,RHS) ) 

#define IName_get_ShortcutKey(This,RHS)	\
    ( (This)->lpVtbl -> get_ShortcutKey(This,RHS) ) 

#define IName_put_ShortcutKey(This,RHS)	\
    ( (This)->lpVtbl -> put_ShortcutKey(This,RHS) ) 

#define IName_get_Value(This,RHS)	\
    ( (This)->lpVtbl -> get_Value(This,RHS) ) 

#define IName_put_Value(This,RHS)	\
    ( (This)->lpVtbl -> put_Value(This,RHS) ) 

#define IName_get_Visible(This,RHS)	\
    ( (This)->lpVtbl -> get_Visible(This,RHS) ) 

#define IName_put_Visible(This,RHS)	\
    ( (This)->lpVtbl -> put_Visible(This,RHS) ) 

#define IName_get_NameLocal(This,RHS)	\
    ( (This)->lpVtbl -> get_NameLocal(This,RHS) ) 

#define IName_put_NameLocal(This,RHS)	\
    ( (This)->lpVtbl -> put_NameLocal(This,RHS) ) 

#define IName_get_RefersToLocal(This,RHS)	\
    ( (This)->lpVtbl -> get_RefersToLocal(This,RHS) ) 

#define IName_put_RefersToLocal(This,RHS)	\
    ( (This)->lpVtbl -> put_RefersToLocal(This,RHS) ) 

#define IName_get_RefersToR1C1(This,lcidIn,RHS)	\
    ( (This)->lpVtbl -> get_RefersToR1C1(This,lcidIn,RHS) ) 

#define IName_put_RefersToR1C1(This,lcidIn,RHS)	\
    ( (This)->lpVtbl -> put_RefersToR1C1(This,lcidIn,RHS) ) 

#define IName_get_RefersToR1C1Local(This,RHS)	\
    ( (This)->lpVtbl -> get_RefersToR1C1Local(This,RHS) ) 

#define IName_put_RefersToR1C1Local(This,RHS)	\
    ( (This)->lpVtbl -> put_RefersToR1C1Local(This,RHS) ) 

#define IName_get_RefersToRange(This,RHS)	\
    ( (This)->lpVtbl -> get_RefersToRange(This,RHS) ) 

#define IName_get_Comment(This,RHS)	\
    ( (This)->lpVtbl -> get_Comment(This,RHS) ) 

#define IName_put_Comment(This,RHS)	\
    ( (This)->lpVtbl -> put_Comment(This,RHS) ) 

#define IName_get_WorkbookParameter(This,RHS)	\
    ( (This)->lpVtbl -> get_WorkbookParameter(This,RHS) ) 

#define IName_put_WorkbookParameter(This,RHS)	\
    ( (This)->lpVtbl -> put_WorkbookParameter(This,RHS) ) 

#define IName_get_ValidWorkbookParameter(This,RHS)	\
    ( (This)->lpVtbl -> get_ValidWorkbookParameter(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IName_INTERFACE_DEFINED__ */


#ifndef __IChartObject_INTERFACE_DEFINED__
#define __IChartObject_INTERFACE_DEFINED__

/* interface IChartObject */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IChartObject;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000208CF-0001-0000-C000-000000000046")
    IChartObject : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_BottomRightCell( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall BringToFront( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall _Copy( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CopyPicture( 
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Cut( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Duplicate( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Enabled( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_Enabled( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Height( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Height( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Index( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Left( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Left( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Locked( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Locked( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Name( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_OnAction( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_OnAction( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Placement( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Placement( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PrintObject( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PrintObject( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SendToBack( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Top( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Top( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TopLeftCell( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Visible( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Visible( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Width( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Width( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ZOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShapeRange( 
            /* [retval][out] */ ShapeRange	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Activate( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Chart( 
            /* [retval][out] */ Chart	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ProtectChartObject( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ProtectChartObject( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RoundedCorners( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_RoundedCorners( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Border( 
            /* [retval][out] */ Border	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Interior( 
            /* [retval][out] */ Interior	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Shadow( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Shadow( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Copy( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IChartObjectVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IChartObject * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IChartObject * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IChartObject * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IChartObject * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IChartObject * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IChartObject * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IChartObject * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IChartObject * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IChartObject * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IChartObject * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_BottomRightCell )( 
            IChartObject * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *BringToFront )( 
            IChartObject * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *_Copy )( 
            IChartObject * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CopyPicture )( 
            IChartObject * This,
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Cut )( 
            IChartObject * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IChartObject * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Duplicate )( 
            IChartObject * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Enabled )( 
            IChartObject * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_Enabled )( 
            IChartObject * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Height )( 
            IChartObject * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Height )( 
            IChartObject * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Index )( 
            IChartObject * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Left )( 
            IChartObject * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Left )( 
            IChartObject * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Locked )( 
            IChartObject * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Locked )( 
            IChartObject * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            IChartObject * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Name )( 
            IChartObject * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_OnAction )( 
            IChartObject * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_OnAction )( 
            IChartObject * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Placement )( 
            IChartObject * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Placement )( 
            IChartObject * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PrintObject )( 
            IChartObject * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PrintObject )( 
            IChartObject * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            IChartObject * This,
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SendToBack )( 
            IChartObject * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Top )( 
            IChartObject * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Top )( 
            IChartObject * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TopLeftCell )( 
            IChartObject * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Visible )( 
            IChartObject * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Visible )( 
            IChartObject * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Width )( 
            IChartObject * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Width )( 
            IChartObject * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ZOrder )( 
            IChartObject * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShapeRange )( 
            IChartObject * This,
            /* [retval][out] */ ShapeRange	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Activate )( 
            IChartObject * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Chart )( 
            IChartObject * This,
            /* [retval][out] */ Chart	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ProtectChartObject )( 
            IChartObject * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ProtectChartObject )( 
            IChartObject * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RoundedCorners )( 
            IChartObject * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_RoundedCorners )( 
            IChartObject * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Border )( 
            IChartObject * This,
            /* [retval][out] */ Border	**RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Interior )( 
            IChartObject * This,
            /* [retval][out] */ Interior	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Shadow )( 
            IChartObject * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Shadow )( 
            IChartObject * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Copy )( 
            IChartObject * This,
            /* [retval][out] */ VARIANT *RHS);
        
        END_INTERFACE
    } IChartObjectVtbl;

    interface IChartObject
    {
        CONST_VTBL struct IChartObjectVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IChartObject_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IChartObject_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IChartObject_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IChartObject_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IChartObject_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IChartObject_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IChartObject_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IChartObject_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IChartObject_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IChartObject_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IChartObject_get_BottomRightCell(This,RHS)	\
    ( (This)->lpVtbl -> get_BottomRightCell(This,RHS) ) 

#define IChartObject_BringToFront(This,RHS)	\
    ( (This)->lpVtbl -> BringToFront(This,RHS) ) 

#define IChartObject__Copy(This,RHS)	\
    ( (This)->lpVtbl -> _Copy(This,RHS) ) 

#define IChartObject_CopyPicture(This,Appearance,Format,RHS)	\
    ( (This)->lpVtbl -> CopyPicture(This,Appearance,Format,RHS) ) 

#define IChartObject_Cut(This,RHS)	\
    ( (This)->lpVtbl -> Cut(This,RHS) ) 

#define IChartObject_Delete(This,RHS)	\
    ( (This)->lpVtbl -> Delete(This,RHS) ) 

#define IChartObject_Duplicate(This,RHS)	\
    ( (This)->lpVtbl -> Duplicate(This,RHS) ) 

#define IChartObject_get_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> get_Enabled(This,RHS) ) 

#define IChartObject_put_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> put_Enabled(This,RHS) ) 

#define IChartObject_get_Height(This,RHS)	\
    ( (This)->lpVtbl -> get_Height(This,RHS) ) 

#define IChartObject_put_Height(This,RHS)	\
    ( (This)->lpVtbl -> put_Height(This,RHS) ) 

#define IChartObject_get_Index(This,RHS)	\
    ( (This)->lpVtbl -> get_Index(This,RHS) ) 

#define IChartObject_get_Left(This,RHS)	\
    ( (This)->lpVtbl -> get_Left(This,RHS) ) 

#define IChartObject_put_Left(This,RHS)	\
    ( (This)->lpVtbl -> put_Left(This,RHS) ) 

#define IChartObject_get_Locked(This,RHS)	\
    ( (This)->lpVtbl -> get_Locked(This,RHS) ) 

#define IChartObject_put_Locked(This,RHS)	\
    ( (This)->lpVtbl -> put_Locked(This,RHS) ) 

#define IChartObject_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define IChartObject_put_Name(This,RHS)	\
    ( (This)->lpVtbl -> put_Name(This,RHS) ) 

#define IChartObject_get_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> get_OnAction(This,RHS) ) 

#define IChartObject_put_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> put_OnAction(This,RHS) ) 

#define IChartObject_get_Placement(This,RHS)	\
    ( (This)->lpVtbl -> get_Placement(This,RHS) ) 

#define IChartObject_put_Placement(This,RHS)	\
    ( (This)->lpVtbl -> put_Placement(This,RHS) ) 

#define IChartObject_get_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> get_PrintObject(This,RHS) ) 

#define IChartObject_put_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> put_PrintObject(This,RHS) ) 

#define IChartObject_Select(This,Replace,RHS)	\
    ( (This)->lpVtbl -> Select(This,Replace,RHS) ) 

#define IChartObject_SendToBack(This,RHS)	\
    ( (This)->lpVtbl -> SendToBack(This,RHS) ) 

#define IChartObject_get_Top(This,RHS)	\
    ( (This)->lpVtbl -> get_Top(This,RHS) ) 

#define IChartObject_put_Top(This,RHS)	\
    ( (This)->lpVtbl -> put_Top(This,RHS) ) 

#define IChartObject_get_TopLeftCell(This,RHS)	\
    ( (This)->lpVtbl -> get_TopLeftCell(This,RHS) ) 

#define IChartObject_get_Visible(This,RHS)	\
    ( (This)->lpVtbl -> get_Visible(This,RHS) ) 

#define IChartObject_put_Visible(This,RHS)	\
    ( (This)->lpVtbl -> put_Visible(This,RHS) ) 

#define IChartObject_get_Width(This,RHS)	\
    ( (This)->lpVtbl -> get_Width(This,RHS) ) 

#define IChartObject_put_Width(This,RHS)	\
    ( (This)->lpVtbl -> put_Width(This,RHS) ) 

#define IChartObject_get_ZOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_ZOrder(This,RHS) ) 

#define IChartObject_get_ShapeRange(This,RHS)	\
    ( (This)->lpVtbl -> get_ShapeRange(This,RHS) ) 

#define IChartObject_Activate(This,RHS)	\
    ( (This)->lpVtbl -> Activate(This,RHS) ) 

#define IChartObject_get_Chart(This,RHS)	\
    ( (This)->lpVtbl -> get_Chart(This,RHS) ) 

#define IChartObject_get_ProtectChartObject(This,RHS)	\
    ( (This)->lpVtbl -> get_ProtectChartObject(This,RHS) ) 

#define IChartObject_put_ProtectChartObject(This,RHS)	\
    ( (This)->lpVtbl -> put_ProtectChartObject(This,RHS) ) 

#define IChartObject_get_RoundedCorners(This,RHS)	\
    ( (This)->lpVtbl -> get_RoundedCorners(This,RHS) ) 

#define IChartObject_put_RoundedCorners(This,RHS)	\
    ( (This)->lpVtbl -> put_RoundedCorners(This,RHS) ) 

#define IChartObject_get_Border(This,RHS)	\
    ( (This)->lpVtbl -> get_Border(This,RHS) ) 

#define IChartObject_get_Interior(This,RHS)	\
    ( (This)->lpVtbl -> get_Interior(This,RHS) ) 

#define IChartObject_get_Shadow(This,RHS)	\
    ( (This)->lpVtbl -> get_Shadow(This,RHS) ) 

#define IChartObject_put_Shadow(This,RHS)	\
    ( (This)->lpVtbl -> put_Shadow(This,RHS) ) 

#define IChartObject_Copy(This,RHS)	\
    ( (This)->lpVtbl -> Copy(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IChartObject_INTERFACE_DEFINED__ */


#ifndef __IChartObjects_INTERFACE_DEFINED__
#define __IChartObjects_INTERFACE_DEFINED__

/* interface IChartObjects */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IChartObjects;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000208D0-0001-0000-C000-000000000046")
    IChartObjects : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy3( void) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall BringToFront( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall _Copy( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CopyPicture( 
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Cut( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Duplicate( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Enabled( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_Enabled( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Height( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Height( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy12( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Left( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Left( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Locked( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Locked( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy15( void) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_OnAction( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_OnAction( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Placement( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Placement( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PrintObject( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PrintObject( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall SendToBack( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Top( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Top( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy22( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Visible( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Visible( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Width( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Width( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy25( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShapeRange( 
            /* [retval][out] */ ShapeRange	**RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy27( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy28( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ProtectChartObject( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ProtectChartObject( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_RoundedCorners( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_RoundedCorners( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Border( 
            /* [retval][out] */ Border	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Interior( 
            /* [retval][out] */ Interior	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Shadow( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_Shadow( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Copy( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add( 
            /* [in] */ double Left,
            /* [in] */ double Top,
            /* [in] */ double Width,
            /* [in] */ double Height,
            /* [retval][out] */ ChartObject	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall Group( 
            /* [retval][out] */ GroupObject	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall _NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall _Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IChartObjectsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IChartObjects * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IChartObjects * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IChartObjects * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IChartObjects * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IChartObjects * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IChartObjects * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IChartObjects * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IChartObjects * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IChartObjects * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IChartObjects * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy3 )( 
            IChartObjects * This);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *BringToFront )( 
            IChartObjects * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *_Copy )( 
            IChartObjects * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CopyPicture )( 
            IChartObjects * This,
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Cut )( 
            IChartObjects * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IChartObjects * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Duplicate )( 
            IChartObjects * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Enabled )( 
            IChartObjects * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_Enabled )( 
            IChartObjects * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Height )( 
            IChartObjects * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Height )( 
            IChartObjects * This,
            /* [in] */ double RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy12 )( 
            IChartObjects * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Left )( 
            IChartObjects * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Left )( 
            IChartObjects * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Locked )( 
            IChartObjects * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Locked )( 
            IChartObjects * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy15 )( 
            IChartObjects * This);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_OnAction )( 
            IChartObjects * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_OnAction )( 
            IChartObjects * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Placement )( 
            IChartObjects * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Placement )( 
            IChartObjects * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PrintObject )( 
            IChartObjects * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PrintObject )( 
            IChartObjects * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            IChartObjects * This,
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *SendToBack )( 
            IChartObjects * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Top )( 
            IChartObjects * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Top )( 
            IChartObjects * This,
            /* [in] */ double RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy22 )( 
            IChartObjects * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Visible )( 
            IChartObjects * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Visible )( 
            IChartObjects * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Width )( 
            IChartObjects * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Width )( 
            IChartObjects * This,
            /* [in] */ double RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy25 )( 
            IChartObjects * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShapeRange )( 
            IChartObjects * This,
            /* [retval][out] */ ShapeRange	**RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy27 )( 
            IChartObjects * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy28 )( 
            IChartObjects * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ProtectChartObject )( 
            IChartObjects * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ProtectChartObject )( 
            IChartObjects * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_RoundedCorners )( 
            IChartObjects * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_RoundedCorners )( 
            IChartObjects * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Border )( 
            IChartObjects * This,
            /* [retval][out] */ Border	**RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Interior )( 
            IChartObjects * This,
            /* [retval][out] */ Interior	**RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Shadow )( 
            IChartObjects * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_Shadow )( 
            IChartObjects * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Copy )( 
            IChartObjects * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add )( 
            IChartObjects * This,
            /* [in] */ double Left,
            /* [in] */ double Top,
            /* [in] */ double Width,
            /* [in] */ double Height,
            /* [retval][out] */ ChartObject	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IChartObjects * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *Group )( 
            IChartObjects * This,
            /* [retval][out] */ GroupObject	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Item )( 
            IChartObjects * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *_NewEnum )( 
            IChartObjects * This,
            /* [retval][out] */ IUnknown **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *_Default )( 
            IChartObjects * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS);
        
        END_INTERFACE
    } IChartObjectsVtbl;

    interface IChartObjects
    {
        CONST_VTBL struct IChartObjectsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IChartObjects_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IChartObjects_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IChartObjects_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IChartObjects_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IChartObjects_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IChartObjects_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IChartObjects_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IChartObjects_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IChartObjects_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IChartObjects_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IChartObjects__Dummy3(This)	\
    ( (This)->lpVtbl -> _Dummy3(This) ) 

#define IChartObjects_BringToFront(This,RHS)	\
    ( (This)->lpVtbl -> BringToFront(This,RHS) ) 

#define IChartObjects__Copy(This,RHS)	\
    ( (This)->lpVtbl -> _Copy(This,RHS) ) 

#define IChartObjects_CopyPicture(This,Appearance,Format,RHS)	\
    ( (This)->lpVtbl -> CopyPicture(This,Appearance,Format,RHS) ) 

#define IChartObjects_Cut(This,RHS)	\
    ( (This)->lpVtbl -> Cut(This,RHS) ) 

#define IChartObjects_Delete(This,RHS)	\
    ( (This)->lpVtbl -> Delete(This,RHS) ) 

#define IChartObjects_Duplicate(This,RHS)	\
    ( (This)->lpVtbl -> Duplicate(This,RHS) ) 

#define IChartObjects_get_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> get_Enabled(This,RHS) ) 

#define IChartObjects_put_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> put_Enabled(This,RHS) ) 

#define IChartObjects_get_Height(This,RHS)	\
    ( (This)->lpVtbl -> get_Height(This,RHS) ) 

#define IChartObjects_put_Height(This,RHS)	\
    ( (This)->lpVtbl -> put_Height(This,RHS) ) 

#define IChartObjects__Dummy12(This)	\
    ( (This)->lpVtbl -> _Dummy12(This) ) 

#define IChartObjects_get_Left(This,RHS)	\
    ( (This)->lpVtbl -> get_Left(This,RHS) ) 

#define IChartObjects_put_Left(This,RHS)	\
    ( (This)->lpVtbl -> put_Left(This,RHS) ) 

#define IChartObjects_get_Locked(This,RHS)	\
    ( (This)->lpVtbl -> get_Locked(This,RHS) ) 

#define IChartObjects_put_Locked(This,RHS)	\
    ( (This)->lpVtbl -> put_Locked(This,RHS) ) 

#define IChartObjects__Dummy15(This)	\
    ( (This)->lpVtbl -> _Dummy15(This) ) 

#define IChartObjects_get_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> get_OnAction(This,RHS) ) 

#define IChartObjects_put_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> put_OnAction(This,RHS) ) 

#define IChartObjects_get_Placement(This,RHS)	\
    ( (This)->lpVtbl -> get_Placement(This,RHS) ) 

#define IChartObjects_put_Placement(This,RHS)	\
    ( (This)->lpVtbl -> put_Placement(This,RHS) ) 

#define IChartObjects_get_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> get_PrintObject(This,RHS) ) 

#define IChartObjects_put_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> put_PrintObject(This,RHS) ) 

#define IChartObjects_Select(This,Replace,RHS)	\
    ( (This)->lpVtbl -> Select(This,Replace,RHS) ) 

#define IChartObjects_SendToBack(This,RHS)	\
    ( (This)->lpVtbl -> SendToBack(This,RHS) ) 

#define IChartObjects_get_Top(This,RHS)	\
    ( (This)->lpVtbl -> get_Top(This,RHS) ) 

#define IChartObjects_put_Top(This,RHS)	\
    ( (This)->lpVtbl -> put_Top(This,RHS) ) 

#define IChartObjects__Dummy22(This)	\
    ( (This)->lpVtbl -> _Dummy22(This) ) 

#define IChartObjects_get_Visible(This,RHS)	\
    ( (This)->lpVtbl -> get_Visible(This,RHS) ) 

#define IChartObjects_put_Visible(This,RHS)	\
    ( (This)->lpVtbl -> put_Visible(This,RHS) ) 

#define IChartObjects_get_Width(This,RHS)	\
    ( (This)->lpVtbl -> get_Width(This,RHS) ) 

#define IChartObjects_put_Width(This,RHS)	\
    ( (This)->lpVtbl -> put_Width(This,RHS) ) 

#define IChartObjects__Dummy25(This)	\
    ( (This)->lpVtbl -> _Dummy25(This) ) 

#define IChartObjects_get_ShapeRange(This,RHS)	\
    ( (This)->lpVtbl -> get_ShapeRange(This,RHS) ) 

#define IChartObjects__Dummy27(This)	\
    ( (This)->lpVtbl -> _Dummy27(This) ) 

#define IChartObjects__Dummy28(This)	\
    ( (This)->lpVtbl -> _Dummy28(This) ) 

#define IChartObjects_get_ProtectChartObject(This,RHS)	\
    ( (This)->lpVtbl -> get_ProtectChartObject(This,RHS) ) 

#define IChartObjects_put_ProtectChartObject(This,RHS)	\
    ( (This)->lpVtbl -> put_ProtectChartObject(This,RHS) ) 

#define IChartObjects_get_RoundedCorners(This,RHS)	\
    ( (This)->lpVtbl -> get_RoundedCorners(This,RHS) ) 

#define IChartObjects_put_RoundedCorners(This,RHS)	\
    ( (This)->lpVtbl -> put_RoundedCorners(This,RHS) ) 

#define IChartObjects_get_Border(This,RHS)	\
    ( (This)->lpVtbl -> get_Border(This,RHS) ) 

#define IChartObjects_get_Interior(This,RHS)	\
    ( (This)->lpVtbl -> get_Interior(This,RHS) ) 

#define IChartObjects_get_Shadow(This,RHS)	\
    ( (This)->lpVtbl -> get_Shadow(This,RHS) ) 

#define IChartObjects_put_Shadow(This,RHS)	\
    ( (This)->lpVtbl -> put_Shadow(This,RHS) ) 

#define IChartObjects_Copy(This,RHS)	\
    ( (This)->lpVtbl -> Copy(This,RHS) ) 

#define IChartObjects_Add(This,Left,Top,Width,Height,RHS)	\
    ( (This)->lpVtbl -> Add(This,Left,Top,Width,Height,RHS) ) 

#define IChartObjects_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IChartObjects_Group(This,RHS)	\
    ( (This)->lpVtbl -> Group(This,RHS) ) 

#define IChartObjects_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> Item(This,Index,RHS) ) 

#define IChartObjects__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> _NewEnum(This,RHS) ) 

#define IChartObjects__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> _Default(This,Index,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IChartObjects_INTERFACE_DEFINED__ */


#ifndef __IMailer_INTERFACE_DEFINED__
#define __IMailer_INTERFACE_DEFINED__

/* interface IMailer */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IMailer;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000208D1-0001-0000-C000-000000000046")
    IMailer : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_BCCRecipients( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_BCCRecipients( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CCRecipients( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_CCRecipients( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Enclosures( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Enclosures( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Received( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SendDateTime( 
            /* [retval][out] */ DATE *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Sender( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Subject( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Subject( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ToRecipients( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ToRecipients( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_WhichAddress( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_WhichAddress( 
            /* [in] */ VARIANT RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IMailerVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IMailer * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IMailer * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IMailer * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IMailer * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IMailer * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IMailer * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IMailer * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IMailer * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IMailer * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IMailer * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_BCCRecipients )( 
            IMailer * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_BCCRecipients )( 
            IMailer * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CCRecipients )( 
            IMailer * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_CCRecipients )( 
            IMailer * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Enclosures )( 
            IMailer * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Enclosures )( 
            IMailer * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Received )( 
            IMailer * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SendDateTime )( 
            IMailer * This,
            /* [retval][out] */ DATE *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Sender )( 
            IMailer * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Subject )( 
            IMailer * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Subject )( 
            IMailer * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ToRecipients )( 
            IMailer * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ToRecipients )( 
            IMailer * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_WhichAddress )( 
            IMailer * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_WhichAddress )( 
            IMailer * This,
            /* [in] */ VARIANT RHS);
        
        END_INTERFACE
    } IMailerVtbl;

    interface IMailer
    {
        CONST_VTBL struct IMailerVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IMailer_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IMailer_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IMailer_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IMailer_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IMailer_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IMailer_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IMailer_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IMailer_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IMailer_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IMailer_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IMailer_get_BCCRecipients(This,RHS)	\
    ( (This)->lpVtbl -> get_BCCRecipients(This,RHS) ) 

#define IMailer_put_BCCRecipients(This,RHS)	\
    ( (This)->lpVtbl -> put_BCCRecipients(This,RHS) ) 

#define IMailer_get_CCRecipients(This,RHS)	\
    ( (This)->lpVtbl -> get_CCRecipients(This,RHS) ) 

#define IMailer_put_CCRecipients(This,RHS)	\
    ( (This)->lpVtbl -> put_CCRecipients(This,RHS) ) 

#define IMailer_get_Enclosures(This,RHS)	\
    ( (This)->lpVtbl -> get_Enclosures(This,RHS) ) 

#define IMailer_put_Enclosures(This,RHS)	\
    ( (This)->lpVtbl -> put_Enclosures(This,RHS) ) 

#define IMailer_get_Received(This,RHS)	\
    ( (This)->lpVtbl -> get_Received(This,RHS) ) 

#define IMailer_get_SendDateTime(This,RHS)	\
    ( (This)->lpVtbl -> get_SendDateTime(This,RHS) ) 

#define IMailer_get_Sender(This,RHS)	\
    ( (This)->lpVtbl -> get_Sender(This,RHS) ) 

#define IMailer_get_Subject(This,RHS)	\
    ( (This)->lpVtbl -> get_Subject(This,RHS) ) 

#define IMailer_put_Subject(This,RHS)	\
    ( (This)->lpVtbl -> put_Subject(This,RHS) ) 

#define IMailer_get_ToRecipients(This,RHS)	\
    ( (This)->lpVtbl -> get_ToRecipients(This,RHS) ) 

#define IMailer_put_ToRecipients(This,RHS)	\
    ( (This)->lpVtbl -> put_ToRecipients(This,RHS) ) 

#define IMailer_get_WhichAddress(This,RHS)	\
    ( (This)->lpVtbl -> get_WhichAddress(This,RHS) ) 

#define IMailer_put_WhichAddress(This,RHS)	\
    ( (This)->lpVtbl -> put_WhichAddress(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IMailer_INTERFACE_DEFINED__ */


#ifndef __ICustomViews_INTERFACE_DEFINED__
#define __ICustomViews_INTERFACE_DEFINED__

/* interface ICustomViews */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ICustomViews;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024422-0001-0000-C000-000000000046")
    ICustomViews : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Item( 
            /* [in] */ VARIANT ViewName,
            /* [retval][out] */ CustomView	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add( 
            /* [in] */ BSTR ViewName,
            /* [optional][in] */ VARIANT PrintSettings,
            /* [optional][in] */ VARIANT RowColSettings,
            /* [retval][out] */ CustomView	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT ViewName,
            /* [retval][out] */ CustomView	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ICustomViewsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ICustomViews * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ICustomViews * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ICustomViews * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ICustomViews * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ICustomViews * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ICustomViews * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ICustomViews * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ICustomViews * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ICustomViews * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ICustomViews * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            ICustomViews * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Item )( 
            ICustomViews * This,
            /* [in] */ VARIANT ViewName,
            /* [retval][out] */ CustomView	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add )( 
            ICustomViews * This,
            /* [in] */ BSTR ViewName,
            /* [optional][in] */ VARIANT PrintSettings,
            /* [optional][in] */ VARIANT RowColSettings,
            /* [retval][out] */ CustomView	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            ICustomViews * This,
            /* [in] */ VARIANT ViewName,
            /* [retval][out] */ CustomView	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            ICustomViews * This,
            /* [retval][out] */ IUnknown **RHS);
        
        END_INTERFACE
    } ICustomViewsVtbl;

    interface ICustomViews
    {
        CONST_VTBL struct ICustomViewsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ICustomViews_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ICustomViews_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ICustomViews_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ICustomViews_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ICustomViews_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ICustomViews_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ICustomViews_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ICustomViews_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ICustomViews_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ICustomViews_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ICustomViews_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define ICustomViews_Item(This,ViewName,RHS)	\
    ( (This)->lpVtbl -> Item(This,ViewName,RHS) ) 

#define ICustomViews_Add(This,ViewName,PrintSettings,RowColSettings,RHS)	\
    ( (This)->lpVtbl -> Add(This,ViewName,PrintSettings,RowColSettings,RHS) ) 

#define ICustomViews_get__Default(This,ViewName,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,ViewName,RHS) ) 

#define ICustomViews_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ICustomViews_INTERFACE_DEFINED__ */


#ifndef __ICustomView_INTERFACE_DEFINED__
#define __ICustomView_INTERFACE_DEFINED__

/* interface ICustomView */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ICustomView;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024423-0001-0000-C000-000000000046")
    ICustomView : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PrintSettings( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RowColSettings( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Show( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( void) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ICustomViewVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ICustomView * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ICustomView * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ICustomView * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ICustomView * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ICustomView * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ICustomView * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ICustomView * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ICustomView * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ICustomView * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ICustomView * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            ICustomView * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PrintSettings )( 
            ICustomView * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RowColSettings )( 
            ICustomView * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Show )( 
            ICustomView * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            ICustomView * This);
        
        END_INTERFACE
    } ICustomViewVtbl;

    interface ICustomView
    {
        CONST_VTBL struct ICustomViewVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ICustomView_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ICustomView_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ICustomView_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ICustomView_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ICustomView_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ICustomView_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ICustomView_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ICustomView_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ICustomView_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ICustomView_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ICustomView_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define ICustomView_get_PrintSettings(This,RHS)	\
    ( (This)->lpVtbl -> get_PrintSettings(This,RHS) ) 

#define ICustomView_get_RowColSettings(This,RHS)	\
    ( (This)->lpVtbl -> get_RowColSettings(This,RHS) ) 

#define ICustomView_Show(This)	\
    ( (This)->lpVtbl -> Show(This) ) 

#define ICustomView_Delete(This)	\
    ( (This)->lpVtbl -> Delete(This) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ICustomView_INTERFACE_DEFINED__ */


#ifndef __IFormatConditions_INTERFACE_DEFINED__
#define __IFormatConditions_INTERFACE_DEFINED__

/* interface IFormatConditions */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IFormatConditions;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024424-0001-0000-C000-000000000046")
    IFormatConditions : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add( 
            /* [in] */ XlFormatConditionType Type,
            /* [optional][in] */ VARIANT Operator,
            /* [optional][in] */ VARIANT Formula1,
            /* [optional][in] */ VARIANT Formula2,
            /* [optional][in] */ VARIANT String,
            /* [optional][in] */ VARIANT TextOperator,
            /* [optional][in] */ VARIANT DateOperator,
            /* [optional][in] */ VARIANT ScopeType,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall AddColorScale( 
            /* [in] */ long ColorScaleType,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall AddDatabar( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall AddIconSetCondition( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall AddTop10( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall AddAboveAverage( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall AddUniqueValues( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IFormatConditionsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IFormatConditions * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IFormatConditions * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IFormatConditions * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IFormatConditions * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IFormatConditions * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IFormatConditions * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IFormatConditions * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IFormatConditions * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IFormatConditions * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IFormatConditions * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IFormatConditions * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Item )( 
            IFormatConditions * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add )( 
            IFormatConditions * This,
            /* [in] */ XlFormatConditionType Type,
            /* [optional][in] */ VARIANT Operator,
            /* [optional][in] */ VARIANT Formula1,
            /* [optional][in] */ VARIANT Formula2,
            /* [optional][in] */ VARIANT String,
            /* [optional][in] */ VARIANT TextOperator,
            /* [optional][in] */ VARIANT DateOperator,
            /* [optional][in] */ VARIANT ScopeType,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IFormatConditions * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            IFormatConditions * This,
            /* [retval][out] */ IUnknown **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IFormatConditions * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *AddColorScale )( 
            IFormatConditions * This,
            /* [in] */ long ColorScaleType,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *AddDatabar )( 
            IFormatConditions * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *AddIconSetCondition )( 
            IFormatConditions * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *AddTop10 )( 
            IFormatConditions * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *AddAboveAverage )( 
            IFormatConditions * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *AddUniqueValues )( 
            IFormatConditions * This,
            /* [retval][out] */ IDispatch **RHS);
        
        END_INTERFACE
    } IFormatConditionsVtbl;

    interface IFormatConditions
    {
        CONST_VTBL struct IFormatConditionsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IFormatConditions_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IFormatConditions_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IFormatConditions_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IFormatConditions_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IFormatConditions_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IFormatConditions_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IFormatConditions_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IFormatConditions_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IFormatConditions_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IFormatConditions_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IFormatConditions_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IFormatConditions_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> Item(This,Index,RHS) ) 

#define IFormatConditions_Add(This,Type,Operator,Formula1,Formula2,String,TextOperator,DateOperator,ScopeType,RHS)	\
    ( (This)->lpVtbl -> Add(This,Type,Operator,Formula1,Formula2,String,TextOperator,DateOperator,ScopeType,RHS) ) 

#define IFormatConditions_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define IFormatConditions_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#define IFormatConditions_Delete(This)	\
    ( (This)->lpVtbl -> Delete(This) ) 

#define IFormatConditions_AddColorScale(This,ColorScaleType,RHS)	\
    ( (This)->lpVtbl -> AddColorScale(This,ColorScaleType,RHS) ) 

#define IFormatConditions_AddDatabar(This,RHS)	\
    ( (This)->lpVtbl -> AddDatabar(This,RHS) ) 

#define IFormatConditions_AddIconSetCondition(This,RHS)	\
    ( (This)->lpVtbl -> AddIconSetCondition(This,RHS) ) 

#define IFormatConditions_AddTop10(This,RHS)	\
    ( (This)->lpVtbl -> AddTop10(This,RHS) ) 

#define IFormatConditions_AddAboveAverage(This,RHS)	\
    ( (This)->lpVtbl -> AddAboveAverage(This,RHS) ) 

#define IFormatConditions_AddUniqueValues(This,RHS)	\
    ( (This)->lpVtbl -> AddUniqueValues(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IFormatConditions_INTERFACE_DEFINED__ */


#ifndef __IFormatCondition_INTERFACE_DEFINED__
#define __IFormatCondition_INTERFACE_DEFINED__

/* interface IFormatCondition */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IFormatCondition;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024425-0001-0000-C000-000000000046")
    IFormatCondition : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [custom][helpcontext][hidden][id] */ HRESULT __stdcall _Modify( 
            /* [in] */ XlFormatConditionType Type,
            /* [optional][in] */ VARIANT Operator,
            /* [optional][in] */ VARIANT Formula1,
            /* [optional][in] */ VARIANT Formula2) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Type( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Operator( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Formula1( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Formula2( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Interior( 
            /* [retval][out] */ Interior	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Borders( 
            /* [retval][out] */ Borders	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Font( 
            /* [retval][out] */ Font	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( void) = 0;
        
        virtual /* [custom][helpcontext][id] */ HRESULT __stdcall Modify( 
            /* [in] */ XlFormatConditionType Type,
            /* [optional][in] */ VARIANT Operator,
            /* [optional][in] */ VARIANT Formula1,
            /* [optional][in] */ VARIANT Formula2,
            /* [optional][in] */ VARIANT String,
            /* [optional][in] */ VARIANT Operator2) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Text( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Text( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TextOperator( 
            /* [retval][out] */ XlContainsOperator *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_TextOperator( 
            /* [in] */ XlContainsOperator RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DateOperator( 
            /* [retval][out] */ XlTimePeriods *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DateOperator( 
            /* [in] */ XlTimePeriods RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_NumberFormat( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_NumberFormat( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Priority( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Priority( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_StopIfTrue( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_StopIfTrue( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AppliesTo( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ModifyAppliesToRange( 
            /* [in] */ Range	*Range) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SetFirstPriority( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SetLastPriority( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PTCondition( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ScopeType( 
            /* [retval][out] */ XlPivotConditionScope *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ScopeType( 
            /* [in] */ XlPivotConditionScope RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IFormatConditionVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IFormatCondition * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IFormatCondition * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IFormatCondition * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IFormatCondition * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IFormatCondition * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IFormatCondition * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IFormatCondition * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IFormatCondition * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IFormatCondition * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IFormatCondition * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [custom][helpcontext][hidden][id] */ HRESULT ( __stdcall *_Modify )( 
            IFormatCondition * This,
            /* [in] */ XlFormatConditionType Type,
            /* [optional][in] */ VARIANT Operator,
            /* [optional][in] */ VARIANT Formula1,
            /* [optional][in] */ VARIANT Formula2);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Type )( 
            IFormatCondition * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Operator )( 
            IFormatCondition * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Formula1 )( 
            IFormatCondition * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Formula2 )( 
            IFormatCondition * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Interior )( 
            IFormatCondition * This,
            /* [retval][out] */ Interior	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Borders )( 
            IFormatCondition * This,
            /* [retval][out] */ Borders	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Font )( 
            IFormatCondition * This,
            /* [retval][out] */ Font	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IFormatCondition * This);
        
        /* [custom][helpcontext][id] */ HRESULT ( __stdcall *Modify )( 
            IFormatCondition * This,
            /* [in] */ XlFormatConditionType Type,
            /* [optional][in] */ VARIANT Operator,
            /* [optional][in] */ VARIANT Formula1,
            /* [optional][in] */ VARIANT Formula2,
            /* [optional][in] */ VARIANT String,
            /* [optional][in] */ VARIANT Operator2);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Text )( 
            IFormatCondition * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Text )( 
            IFormatCondition * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TextOperator )( 
            IFormatCondition * This,
            /* [retval][out] */ XlContainsOperator *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_TextOperator )( 
            IFormatCondition * This,
            /* [in] */ XlContainsOperator RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DateOperator )( 
            IFormatCondition * This,
            /* [retval][out] */ XlTimePeriods *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DateOperator )( 
            IFormatCondition * This,
            /* [in] */ XlTimePeriods RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_NumberFormat )( 
            IFormatCondition * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_NumberFormat )( 
            IFormatCondition * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Priority )( 
            IFormatCondition * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Priority )( 
            IFormatCondition * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_StopIfTrue )( 
            IFormatCondition * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_StopIfTrue )( 
            IFormatCondition * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AppliesTo )( 
            IFormatCondition * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ModifyAppliesToRange )( 
            IFormatCondition * This,
            /* [in] */ Range	*Range);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SetFirstPriority )( 
            IFormatCondition * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SetLastPriority )( 
            IFormatCondition * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PTCondition )( 
            IFormatCondition * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ScopeType )( 
            IFormatCondition * This,
            /* [retval][out] */ XlPivotConditionScope *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ScopeType )( 
            IFormatCondition * This,
            /* [in] */ XlPivotConditionScope RHS);
        
        END_INTERFACE
    } IFormatConditionVtbl;

    interface IFormatCondition
    {
        CONST_VTBL struct IFormatConditionVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IFormatCondition_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IFormatCondition_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IFormatCondition_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IFormatCondition_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IFormatCondition_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IFormatCondition_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IFormatCondition_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IFormatCondition_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IFormatCondition_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IFormatCondition_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IFormatCondition__Modify(This,Type,Operator,Formula1,Formula2)	\
    ( (This)->lpVtbl -> _Modify(This,Type,Operator,Formula1,Formula2) ) 

#define IFormatCondition_get_Type(This,RHS)	\
    ( (This)->lpVtbl -> get_Type(This,RHS) ) 

#define IFormatCondition_get_Operator(This,RHS)	\
    ( (This)->lpVtbl -> get_Operator(This,RHS) ) 

#define IFormatCondition_get_Formula1(This,RHS)	\
    ( (This)->lpVtbl -> get_Formula1(This,RHS) ) 

#define IFormatCondition_get_Formula2(This,RHS)	\
    ( (This)->lpVtbl -> get_Formula2(This,RHS) ) 

#define IFormatCondition_get_Interior(This,RHS)	\
    ( (This)->lpVtbl -> get_Interior(This,RHS) ) 

#define IFormatCondition_get_Borders(This,RHS)	\
    ( (This)->lpVtbl -> get_Borders(This,RHS) ) 

#define IFormatCondition_get_Font(This,RHS)	\
    ( (This)->lpVtbl -> get_Font(This,RHS) ) 

#define IFormatCondition_Delete(This)	\
    ( (This)->lpVtbl -> Delete(This) ) 

#define IFormatCondition_Modify(This,Type,Operator,Formula1,Formula2,String,Operator2)	\
    ( (This)->lpVtbl -> Modify(This,Type,Operator,Formula1,Formula2,String,Operator2) ) 

#define IFormatCondition_get_Text(This,RHS)	\
    ( (This)->lpVtbl -> get_Text(This,RHS) ) 

#define IFormatCondition_put_Text(This,RHS)	\
    ( (This)->lpVtbl -> put_Text(This,RHS) ) 

#define IFormatCondition_get_TextOperator(This,RHS)	\
    ( (This)->lpVtbl -> get_TextOperator(This,RHS) ) 

#define IFormatCondition_put_TextOperator(This,RHS)	\
    ( (This)->lpVtbl -> put_TextOperator(This,RHS) ) 

#define IFormatCondition_get_DateOperator(This,RHS)	\
    ( (This)->lpVtbl -> get_DateOperator(This,RHS) ) 

#define IFormatCondition_put_DateOperator(This,RHS)	\
    ( (This)->lpVtbl -> put_DateOperator(This,RHS) ) 

#define IFormatCondition_get_NumberFormat(This,RHS)	\
    ( (This)->lpVtbl -> get_NumberFormat(This,RHS) ) 

#define IFormatCondition_put_NumberFormat(This,RHS)	\
    ( (This)->lpVtbl -> put_NumberFormat(This,RHS) ) 

#define IFormatCondition_get_Priority(This,RHS)	\
    ( (This)->lpVtbl -> get_Priority(This,RHS) ) 

#define IFormatCondition_put_Priority(This,RHS)	\
    ( (This)->lpVtbl -> put_Priority(This,RHS) ) 

#define IFormatCondition_get_StopIfTrue(This,RHS)	\
    ( (This)->lpVtbl -> get_StopIfTrue(This,RHS) ) 

#define IFormatCondition_put_StopIfTrue(This,RHS)	\
    ( (This)->lpVtbl -> put_StopIfTrue(This,RHS) ) 

#define IFormatCondition_get_AppliesTo(This,RHS)	\
    ( (This)->lpVtbl -> get_AppliesTo(This,RHS) ) 

#define IFormatCondition_ModifyAppliesToRange(This,Range)	\
    ( (This)->lpVtbl -> ModifyAppliesToRange(This,Range) ) 

#define IFormatCondition_SetFirstPriority(This)	\
    ( (This)->lpVtbl -> SetFirstPriority(This) ) 

#define IFormatCondition_SetLastPriority(This)	\
    ( (This)->lpVtbl -> SetLastPriority(This) ) 

#define IFormatCondition_get_PTCondition(This,RHS)	\
    ( (This)->lpVtbl -> get_PTCondition(This,RHS) ) 

#define IFormatCondition_get_ScopeType(This,RHS)	\
    ( (This)->lpVtbl -> get_ScopeType(This,RHS) ) 

#define IFormatCondition_put_ScopeType(This,RHS)	\
    ( (This)->lpVtbl -> put_ScopeType(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IFormatCondition_INTERFACE_DEFINED__ */


#ifndef __IComments_INTERFACE_DEFINED__
#define __IComments_INTERFACE_DEFINED__

/* interface IComments */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IComments;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024426-0001-0000-C000-000000000046")
    IComments : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Item( 
            /* [in] */ long Index,
            /* [retval][out] */ Comment	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ long Index,
            /* [retval][out] */ Comment	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ICommentsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IComments * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IComments * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IComments * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IComments * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IComments * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IComments * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IComments * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IComments * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IComments * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IComments * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IComments * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Item )( 
            IComments * This,
            /* [in] */ long Index,
            /* [retval][out] */ Comment	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IComments * This,
            /* [in] */ long Index,
            /* [retval][out] */ Comment	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            IComments * This,
            /* [retval][out] */ IUnknown **RHS);
        
        END_INTERFACE
    } ICommentsVtbl;

    interface IComments
    {
        CONST_VTBL struct ICommentsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IComments_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IComments_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IComments_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IComments_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IComments_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IComments_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IComments_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IComments_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IComments_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IComments_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IComments_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IComments_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> Item(This,Index,RHS) ) 

#define IComments_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define IComments_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IComments_INTERFACE_DEFINED__ */


#ifndef __IComment_INTERFACE_DEFINED__
#define __IComment_INTERFACE_DEFINED__

/* interface IComment */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IComment;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024427-0001-0000-C000-000000000046")
    IComment : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Author( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Shape( 
            /* [retval][out] */ Shape	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Visible( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Visible( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Text( 
            /* [optional][in] */ VARIANT Text,
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Overwrite,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Next( 
            /* [retval][out] */ Comment	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Previous( 
            /* [retval][out] */ Comment	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ICommentVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IComment * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IComment * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IComment * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IComment * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IComment * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IComment * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IComment * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IComment * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IComment * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IComment * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Author )( 
            IComment * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Shape )( 
            IComment * This,
            /* [retval][out] */ Shape	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Visible )( 
            IComment * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Visible )( 
            IComment * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Text )( 
            IComment * This,
            /* [optional][in] */ VARIANT Text,
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Overwrite,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IComment * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Next )( 
            IComment * This,
            /* [retval][out] */ Comment	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Previous )( 
            IComment * This,
            /* [retval][out] */ Comment	**RHS);
        
        END_INTERFACE
    } ICommentVtbl;

    interface IComment
    {
        CONST_VTBL struct ICommentVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IComment_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IComment_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IComment_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IComment_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IComment_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IComment_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IComment_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IComment_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IComment_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IComment_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IComment_get_Author(This,RHS)	\
    ( (This)->lpVtbl -> get_Author(This,RHS) ) 

#define IComment_get_Shape(This,RHS)	\
    ( (This)->lpVtbl -> get_Shape(This,RHS) ) 

#define IComment_get_Visible(This,RHS)	\
    ( (This)->lpVtbl -> get_Visible(This,RHS) ) 

#define IComment_put_Visible(This,RHS)	\
    ( (This)->lpVtbl -> put_Visible(This,RHS) ) 

#define IComment_Text(This,Text,Start,Overwrite,RHS)	\
    ( (This)->lpVtbl -> Text(This,Text,Start,Overwrite,RHS) ) 

#define IComment_Delete(This)	\
    ( (This)->lpVtbl -> Delete(This) ) 

#define IComment_Next(This,RHS)	\
    ( (This)->lpVtbl -> Next(This,RHS) ) 

#define IComment_Previous(This,RHS)	\
    ( (This)->lpVtbl -> Previous(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IComment_INTERFACE_DEFINED__ */


#ifndef __IRefreshEvents_INTERFACE_DEFINED__
#define __IRefreshEvents_INTERFACE_DEFINED__

/* interface IRefreshEvents */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IRefreshEvents;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002441B-0001-0000-C000-000000000046")
    IRefreshEvents : public IDispatch
    {
    public:
        virtual /* [helpcontext][id] */ HRESULT __stdcall BeforeRefresh( 
            /* [out][in] */ VARIANT_BOOL *Cancel) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall AfterRefresh( 
            /* [in] */ VARIANT_BOOL Success) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IRefreshEventsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IRefreshEvents * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IRefreshEvents * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IRefreshEvents * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IRefreshEvents * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IRefreshEvents * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IRefreshEvents * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IRefreshEvents * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *BeforeRefresh )( 
            IRefreshEvents * This,
            /* [out][in] */ VARIANT_BOOL *Cancel);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *AfterRefresh )( 
            IRefreshEvents * This,
            /* [in] */ VARIANT_BOOL Success);
        
        END_INTERFACE
    } IRefreshEventsVtbl;

    interface IRefreshEvents
    {
        CONST_VTBL struct IRefreshEventsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IRefreshEvents_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IRefreshEvents_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IRefreshEvents_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IRefreshEvents_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IRefreshEvents_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IRefreshEvents_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IRefreshEvents_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IRefreshEvents_BeforeRefresh(This,Cancel)	\
    ( (This)->lpVtbl -> BeforeRefresh(This,Cancel) ) 

#define IRefreshEvents_AfterRefresh(This,Success)	\
    ( (This)->lpVtbl -> AfterRefresh(This,Success) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IRefreshEvents_INTERFACE_DEFINED__ */


#ifndef ___IQueryTable_INTERFACE_DEFINED__
#define ___IQueryTable_INTERFACE_DEFINED__

/* interface _IQueryTable */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID__IQueryTable;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024428-0001-0000-C000-000000000046")
    _IQueryTable : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Name( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_FieldNames( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_FieldNames( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RowNumbers( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_RowNumbers( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_FillAdjacentFormulas( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_FillAdjacentFormulas( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_HasAutoFormat( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_HasAutoFormat( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RefreshOnFileOpen( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_RefreshOnFileOpen( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Refreshing( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_FetchedRowOverflow( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_BackgroundQuery( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_BackgroundQuery( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CancelRefresh( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RefreshStyle( 
            /* [retval][out] */ XlCellInsertionMode *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_RefreshStyle( 
            /* [in] */ XlCellInsertionMode RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_EnableRefresh( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_EnableRefresh( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SavePassword( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_SavePassword( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Destination( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Connection( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Connection( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Sql( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_Sql( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PostText( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PostText( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ResultRange( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Refresh( 
            /* [optional][in] */ VARIANT BackgroundQuery,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parameters( 
            /* [retval][out] */ Parameters	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Recordset( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propputref][id] */ HRESULT __stdcall putref_Recordset( 
            /* [in] */ IDispatch *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SaveData( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_SaveData( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_TablesOnlyFromHTML( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_TablesOnlyFromHTML( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_EnableEditing( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_EnableEditing( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TextFilePlatform( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_TextFilePlatform( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TextFileStartRow( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_TextFileStartRow( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TextFileParseType( 
            /* [retval][out] */ XlTextParsingType *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_TextFileParseType( 
            /* [in] */ XlTextParsingType RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TextFileTextQualifier( 
            /* [retval][out] */ XlTextQualifier *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_TextFileTextQualifier( 
            /* [in] */ XlTextQualifier RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TextFileConsecutiveDelimiter( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_TextFileConsecutiveDelimiter( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TextFileTabDelimiter( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_TextFileTabDelimiter( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TextFileSemicolonDelimiter( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_TextFileSemicolonDelimiter( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TextFileCommaDelimiter( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_TextFileCommaDelimiter( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TextFileSpaceDelimiter( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_TextFileSpaceDelimiter( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TextFileOtherDelimiter( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_TextFileOtherDelimiter( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TextFileColumnDataTypes( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_TextFileColumnDataTypes( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TextFileFixedColumnWidths( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_TextFileFixedColumnWidths( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PreserveColumnInfo( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PreserveColumnInfo( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PreserveFormatting( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PreserveFormatting( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AdjustColumnWidth( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AdjustColumnWidth( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CommandText( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_CommandText( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CommandType( 
            /* [retval][out] */ XlCmdType *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_CommandType( 
            /* [in] */ XlCmdType RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TextFilePromptOnRefresh( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_TextFilePromptOnRefresh( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_QueryType( 
            /* [retval][out] */ XlQueryType *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MaintainConnection( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_MaintainConnection( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TextFileDecimalSeparator( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_TextFileDecimalSeparator( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TextFileThousandsSeparator( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_TextFileThousandsSeparator( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RefreshPeriod( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_RefreshPeriod( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ResetTimer( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_WebSelectionType( 
            /* [retval][out] */ XlWebSelectionType *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_WebSelectionType( 
            /* [in] */ XlWebSelectionType RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_WebFormatting( 
            /* [retval][out] */ XlWebFormatting *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_WebFormatting( 
            /* [in] */ XlWebFormatting RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_WebTables( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_WebTables( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_WebPreFormattedTextToColumns( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_WebPreFormattedTextToColumns( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_WebSingleBlockTextImport( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_WebSingleBlockTextImport( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_WebDisableDateRecognition( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_WebDisableDateRecognition( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_WebConsecutiveDelimitersAsOne( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_WebConsecutiveDelimitersAsOne( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_WebDisableRedirections( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_WebDisableRedirections( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_EditWebPage( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_EditWebPage( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SourceConnectionFile( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_SourceConnectionFile( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SourceDataFile( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_SourceDataFile( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RobustConnect( 
            /* [retval][out] */ XlRobustConnect *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_RobustConnect( 
            /* [in] */ XlRobustConnect RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TextFileTrailingMinusNumbers( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_TextFileTrailingMinusNumbers( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SaveAsODC( 
            /* [in] */ BSTR ODCFileName,
            /* [optional][in] */ VARIANT Description,
            /* [optional][in] */ VARIANT Keywords) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ListObject( 
            /* [retval][out] */ ListObject	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TextFileVisualLayout( 
            /* [retval][out] */ XlTextVisualLayoutType *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_TextFileVisualLayout( 
            /* [in] */ XlTextVisualLayoutType RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_WorkbookConnection( 
            /* [retval][out] */ WorkbookConnection	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Sort( 
            /* [retval][out] */ Sort	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct _IQueryTableVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            _IQueryTable * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            _IQueryTable * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            _IQueryTable * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            _IQueryTable * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            _IQueryTable * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            _IQueryTable * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            _IQueryTable * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            _IQueryTable * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            _IQueryTable * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            _IQueryTable * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            _IQueryTable * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Name )( 
            _IQueryTable * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_FieldNames )( 
            _IQueryTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_FieldNames )( 
            _IQueryTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RowNumbers )( 
            _IQueryTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_RowNumbers )( 
            _IQueryTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_FillAdjacentFormulas )( 
            _IQueryTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_FillAdjacentFormulas )( 
            _IQueryTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_HasAutoFormat )( 
            _IQueryTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_HasAutoFormat )( 
            _IQueryTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RefreshOnFileOpen )( 
            _IQueryTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_RefreshOnFileOpen )( 
            _IQueryTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Refreshing )( 
            _IQueryTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_FetchedRowOverflow )( 
            _IQueryTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_BackgroundQuery )( 
            _IQueryTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_BackgroundQuery )( 
            _IQueryTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CancelRefresh )( 
            _IQueryTable * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RefreshStyle )( 
            _IQueryTable * This,
            /* [retval][out] */ XlCellInsertionMode *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_RefreshStyle )( 
            _IQueryTable * This,
            /* [in] */ XlCellInsertionMode RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_EnableRefresh )( 
            _IQueryTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_EnableRefresh )( 
            _IQueryTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SavePassword )( 
            _IQueryTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_SavePassword )( 
            _IQueryTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Destination )( 
            _IQueryTable * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Connection )( 
            _IQueryTable * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Connection )( 
            _IQueryTable * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Sql )( 
            _IQueryTable * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_Sql )( 
            _IQueryTable * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PostText )( 
            _IQueryTable * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PostText )( 
            _IQueryTable * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ResultRange )( 
            _IQueryTable * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            _IQueryTable * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Refresh )( 
            _IQueryTable * This,
            /* [optional][in] */ VARIANT BackgroundQuery,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parameters )( 
            _IQueryTable * This,
            /* [retval][out] */ Parameters	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Recordset )( 
            _IQueryTable * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propputref][id] */ HRESULT ( __stdcall *putref_Recordset )( 
            _IQueryTable * This,
            /* [in] */ IDispatch *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SaveData )( 
            _IQueryTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_SaveData )( 
            _IQueryTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_TablesOnlyFromHTML )( 
            _IQueryTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_TablesOnlyFromHTML )( 
            _IQueryTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_EnableEditing )( 
            _IQueryTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_EnableEditing )( 
            _IQueryTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TextFilePlatform )( 
            _IQueryTable * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_TextFilePlatform )( 
            _IQueryTable * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TextFileStartRow )( 
            _IQueryTable * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_TextFileStartRow )( 
            _IQueryTable * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TextFileParseType )( 
            _IQueryTable * This,
            /* [retval][out] */ XlTextParsingType *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_TextFileParseType )( 
            _IQueryTable * This,
            /* [in] */ XlTextParsingType RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TextFileTextQualifier )( 
            _IQueryTable * This,
            /* [retval][out] */ XlTextQualifier *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_TextFileTextQualifier )( 
            _IQueryTable * This,
            /* [in] */ XlTextQualifier RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TextFileConsecutiveDelimiter )( 
            _IQueryTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_TextFileConsecutiveDelimiter )( 
            _IQueryTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TextFileTabDelimiter )( 
            _IQueryTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_TextFileTabDelimiter )( 
            _IQueryTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TextFileSemicolonDelimiter )( 
            _IQueryTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_TextFileSemicolonDelimiter )( 
            _IQueryTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TextFileCommaDelimiter )( 
            _IQueryTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_TextFileCommaDelimiter )( 
            _IQueryTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TextFileSpaceDelimiter )( 
            _IQueryTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_TextFileSpaceDelimiter )( 
            _IQueryTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TextFileOtherDelimiter )( 
            _IQueryTable * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_TextFileOtherDelimiter )( 
            _IQueryTable * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TextFileColumnDataTypes )( 
            _IQueryTable * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_TextFileColumnDataTypes )( 
            _IQueryTable * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TextFileFixedColumnWidths )( 
            _IQueryTable * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_TextFileFixedColumnWidths )( 
            _IQueryTable * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PreserveColumnInfo )( 
            _IQueryTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PreserveColumnInfo )( 
            _IQueryTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PreserveFormatting )( 
            _IQueryTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PreserveFormatting )( 
            _IQueryTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AdjustColumnWidth )( 
            _IQueryTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AdjustColumnWidth )( 
            _IQueryTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CommandText )( 
            _IQueryTable * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_CommandText )( 
            _IQueryTable * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CommandType )( 
            _IQueryTable * This,
            /* [retval][out] */ XlCmdType *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_CommandType )( 
            _IQueryTable * This,
            /* [in] */ XlCmdType RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TextFilePromptOnRefresh )( 
            _IQueryTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_TextFilePromptOnRefresh )( 
            _IQueryTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_QueryType )( 
            _IQueryTable * This,
            /* [retval][out] */ XlQueryType *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MaintainConnection )( 
            _IQueryTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_MaintainConnection )( 
            _IQueryTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TextFileDecimalSeparator )( 
            _IQueryTable * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_TextFileDecimalSeparator )( 
            _IQueryTable * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TextFileThousandsSeparator )( 
            _IQueryTable * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_TextFileThousandsSeparator )( 
            _IQueryTable * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RefreshPeriod )( 
            _IQueryTable * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_RefreshPeriod )( 
            _IQueryTable * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ResetTimer )( 
            _IQueryTable * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_WebSelectionType )( 
            _IQueryTable * This,
            /* [retval][out] */ XlWebSelectionType *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_WebSelectionType )( 
            _IQueryTable * This,
            /* [in] */ XlWebSelectionType RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_WebFormatting )( 
            _IQueryTable * This,
            /* [retval][out] */ XlWebFormatting *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_WebFormatting )( 
            _IQueryTable * This,
            /* [in] */ XlWebFormatting RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_WebTables )( 
            _IQueryTable * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_WebTables )( 
            _IQueryTable * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_WebPreFormattedTextToColumns )( 
            _IQueryTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_WebPreFormattedTextToColumns )( 
            _IQueryTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_WebSingleBlockTextImport )( 
            _IQueryTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_WebSingleBlockTextImport )( 
            _IQueryTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_WebDisableDateRecognition )( 
            _IQueryTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_WebDisableDateRecognition )( 
            _IQueryTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_WebConsecutiveDelimitersAsOne )( 
            _IQueryTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_WebConsecutiveDelimitersAsOne )( 
            _IQueryTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_WebDisableRedirections )( 
            _IQueryTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_WebDisableRedirections )( 
            _IQueryTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_EditWebPage )( 
            _IQueryTable * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_EditWebPage )( 
            _IQueryTable * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SourceConnectionFile )( 
            _IQueryTable * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_SourceConnectionFile )( 
            _IQueryTable * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SourceDataFile )( 
            _IQueryTable * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_SourceDataFile )( 
            _IQueryTable * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RobustConnect )( 
            _IQueryTable * This,
            /* [retval][out] */ XlRobustConnect *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_RobustConnect )( 
            _IQueryTable * This,
            /* [in] */ XlRobustConnect RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TextFileTrailingMinusNumbers )( 
            _IQueryTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_TextFileTrailingMinusNumbers )( 
            _IQueryTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SaveAsODC )( 
            _IQueryTable * This,
            /* [in] */ BSTR ODCFileName,
            /* [optional][in] */ VARIANT Description,
            /* [optional][in] */ VARIANT Keywords);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ListObject )( 
            _IQueryTable * This,
            /* [retval][out] */ ListObject	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TextFileVisualLayout )( 
            _IQueryTable * This,
            /* [retval][out] */ XlTextVisualLayoutType *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_TextFileVisualLayout )( 
            _IQueryTable * This,
            /* [in] */ XlTextVisualLayoutType RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_WorkbookConnection )( 
            _IQueryTable * This,
            /* [retval][out] */ WorkbookConnection	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Sort )( 
            _IQueryTable * This,
            /* [retval][out] */ Sort	**RHS);
        
        END_INTERFACE
    } _IQueryTableVtbl;

    interface _IQueryTable
    {
        CONST_VTBL struct _IQueryTableVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define _IQueryTable_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define _IQueryTable_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define _IQueryTable_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define _IQueryTable_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define _IQueryTable_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define _IQueryTable_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define _IQueryTable_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define _IQueryTable_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define _IQueryTable_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define _IQueryTable_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define _IQueryTable_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define _IQueryTable_put_Name(This,RHS)	\
    ( (This)->lpVtbl -> put_Name(This,RHS) ) 

#define _IQueryTable_get_FieldNames(This,RHS)	\
    ( (This)->lpVtbl -> get_FieldNames(This,RHS) ) 

#define _IQueryTable_put_FieldNames(This,RHS)	\
    ( (This)->lpVtbl -> put_FieldNames(This,RHS) ) 

#define _IQueryTable_get_RowNumbers(This,RHS)	\
    ( (This)->lpVtbl -> get_RowNumbers(This,RHS) ) 

#define _IQueryTable_put_RowNumbers(This,RHS)	\
    ( (This)->lpVtbl -> put_RowNumbers(This,RHS) ) 

#define _IQueryTable_get_FillAdjacentFormulas(This,RHS)	\
    ( (This)->lpVtbl -> get_FillAdjacentFormulas(This,RHS) ) 

#define _IQueryTable_put_FillAdjacentFormulas(This,RHS)	\
    ( (This)->lpVtbl -> put_FillAdjacentFormulas(This,RHS) ) 

#define _IQueryTable_get_HasAutoFormat(This,RHS)	\
    ( (This)->lpVtbl -> get_HasAutoFormat(This,RHS) ) 

#define _IQueryTable_put_HasAutoFormat(This,RHS)	\
    ( (This)->lpVtbl -> put_HasAutoFormat(This,RHS) ) 

#define _IQueryTable_get_RefreshOnFileOpen(This,RHS)	\
    ( (This)->lpVtbl -> get_RefreshOnFileOpen(This,RHS) ) 

#define _IQueryTable_put_RefreshOnFileOpen(This,RHS)	\
    ( (This)->lpVtbl -> put_RefreshOnFileOpen(This,RHS) ) 

#define _IQueryTable_get_Refreshing(This,RHS)	\
    ( (This)->lpVtbl -> get_Refreshing(This,RHS) ) 

#define _IQueryTable_get_FetchedRowOverflow(This,RHS)	\
    ( (This)->lpVtbl -> get_FetchedRowOverflow(This,RHS) ) 

#define _IQueryTable_get_BackgroundQuery(This,RHS)	\
    ( (This)->lpVtbl -> get_BackgroundQuery(This,RHS) ) 

#define _IQueryTable_put_BackgroundQuery(This,RHS)	\
    ( (This)->lpVtbl -> put_BackgroundQuery(This,RHS) ) 

#define _IQueryTable_CancelRefresh(This)	\
    ( (This)->lpVtbl -> CancelRefresh(This) ) 

#define _IQueryTable_get_RefreshStyle(This,RHS)	\
    ( (This)->lpVtbl -> get_RefreshStyle(This,RHS) ) 

#define _IQueryTable_put_RefreshStyle(This,RHS)	\
    ( (This)->lpVtbl -> put_RefreshStyle(This,RHS) ) 

#define _IQueryTable_get_EnableRefresh(This,RHS)	\
    ( (This)->lpVtbl -> get_EnableRefresh(This,RHS) ) 

#define _IQueryTable_put_EnableRefresh(This,RHS)	\
    ( (This)->lpVtbl -> put_EnableRefresh(This,RHS) ) 

#define _IQueryTable_get_SavePassword(This,RHS)	\
    ( (This)->lpVtbl -> get_SavePassword(This,RHS) ) 

#define _IQueryTable_put_SavePassword(This,RHS)	\
    ( (This)->lpVtbl -> put_SavePassword(This,RHS) ) 

#define _IQueryTable_get_Destination(This,RHS)	\
    ( (This)->lpVtbl -> get_Destination(This,RHS) ) 

#define _IQueryTable_get_Connection(This,RHS)	\
    ( (This)->lpVtbl -> get_Connection(This,RHS) ) 

#define _IQueryTable_put_Connection(This,RHS)	\
    ( (This)->lpVtbl -> put_Connection(This,RHS) ) 

#define _IQueryTable_get_Sql(This,RHS)	\
    ( (This)->lpVtbl -> get_Sql(This,RHS) ) 

#define _IQueryTable_put_Sql(This,RHS)	\
    ( (This)->lpVtbl -> put_Sql(This,RHS) ) 

#define _IQueryTable_get_PostText(This,RHS)	\
    ( (This)->lpVtbl -> get_PostText(This,RHS) ) 

#define _IQueryTable_put_PostText(This,RHS)	\
    ( (This)->lpVtbl -> put_PostText(This,RHS) ) 

#define _IQueryTable_get_ResultRange(This,RHS)	\
    ( (This)->lpVtbl -> get_ResultRange(This,RHS) ) 

#define _IQueryTable_Delete(This)	\
    ( (This)->lpVtbl -> Delete(This) ) 

#define _IQueryTable_Refresh(This,BackgroundQuery,RHS)	\
    ( (This)->lpVtbl -> Refresh(This,BackgroundQuery,RHS) ) 

#define _IQueryTable_get_Parameters(This,RHS)	\
    ( (This)->lpVtbl -> get_Parameters(This,RHS) ) 

#define _IQueryTable_get_Recordset(This,RHS)	\
    ( (This)->lpVtbl -> get_Recordset(This,RHS) ) 

#define _IQueryTable_putref_Recordset(This,RHS)	\
    ( (This)->lpVtbl -> putref_Recordset(This,RHS) ) 

#define _IQueryTable_get_SaveData(This,RHS)	\
    ( (This)->lpVtbl -> get_SaveData(This,RHS) ) 

#define _IQueryTable_put_SaveData(This,RHS)	\
    ( (This)->lpVtbl -> put_SaveData(This,RHS) ) 

#define _IQueryTable_get_TablesOnlyFromHTML(This,RHS)	\
    ( (This)->lpVtbl -> get_TablesOnlyFromHTML(This,RHS) ) 

#define _IQueryTable_put_TablesOnlyFromHTML(This,RHS)	\
    ( (This)->lpVtbl -> put_TablesOnlyFromHTML(This,RHS) ) 

#define _IQueryTable_get_EnableEditing(This,RHS)	\
    ( (This)->lpVtbl -> get_EnableEditing(This,RHS) ) 

#define _IQueryTable_put_EnableEditing(This,RHS)	\
    ( (This)->lpVtbl -> put_EnableEditing(This,RHS) ) 

#define _IQueryTable_get_TextFilePlatform(This,RHS)	\
    ( (This)->lpVtbl -> get_TextFilePlatform(This,RHS) ) 

#define _IQueryTable_put_TextFilePlatform(This,RHS)	\
    ( (This)->lpVtbl -> put_TextFilePlatform(This,RHS) ) 

#define _IQueryTable_get_TextFileStartRow(This,RHS)	\
    ( (This)->lpVtbl -> get_TextFileStartRow(This,RHS) ) 

#define _IQueryTable_put_TextFileStartRow(This,RHS)	\
    ( (This)->lpVtbl -> put_TextFileStartRow(This,RHS) ) 

#define _IQueryTable_get_TextFileParseType(This,RHS)	\
    ( (This)->lpVtbl -> get_TextFileParseType(This,RHS) ) 

#define _IQueryTable_put_TextFileParseType(This,RHS)	\
    ( (This)->lpVtbl -> put_TextFileParseType(This,RHS) ) 

#define _IQueryTable_get_TextFileTextQualifier(This,RHS)	\
    ( (This)->lpVtbl -> get_TextFileTextQualifier(This,RHS) ) 

#define _IQueryTable_put_TextFileTextQualifier(This,RHS)	\
    ( (This)->lpVtbl -> put_TextFileTextQualifier(This,RHS) ) 

#define _IQueryTable_get_TextFileConsecutiveDelimiter(This,RHS)	\
    ( (This)->lpVtbl -> get_TextFileConsecutiveDelimiter(This,RHS) ) 

#define _IQueryTable_put_TextFileConsecutiveDelimiter(This,RHS)	\
    ( (This)->lpVtbl -> put_TextFileConsecutiveDelimiter(This,RHS) ) 

#define _IQueryTable_get_TextFileTabDelimiter(This,RHS)	\
    ( (This)->lpVtbl -> get_TextFileTabDelimiter(This,RHS) ) 

#define _IQueryTable_put_TextFileTabDelimiter(This,RHS)	\
    ( (This)->lpVtbl -> put_TextFileTabDelimiter(This,RHS) ) 

#define _IQueryTable_get_TextFileSemicolonDelimiter(This,RHS)	\
    ( (This)->lpVtbl -> get_TextFileSemicolonDelimiter(This,RHS) ) 

#define _IQueryTable_put_TextFileSemicolonDelimiter(This,RHS)	\
    ( (This)->lpVtbl -> put_TextFileSemicolonDelimiter(This,RHS) ) 

#define _IQueryTable_get_TextFileCommaDelimiter(This,RHS)	\
    ( (This)->lpVtbl -> get_TextFileCommaDelimiter(This,RHS) ) 

#define _IQueryTable_put_TextFileCommaDelimiter(This,RHS)	\
    ( (This)->lpVtbl -> put_TextFileCommaDelimiter(This,RHS) ) 

#define _IQueryTable_get_TextFileSpaceDelimiter(This,RHS)	\
    ( (This)->lpVtbl -> get_TextFileSpaceDelimiter(This,RHS) ) 

#define _IQueryTable_put_TextFileSpaceDelimiter(This,RHS)	\
    ( (This)->lpVtbl -> put_TextFileSpaceDelimiter(This,RHS) ) 

#define _IQueryTable_get_TextFileOtherDelimiter(This,RHS)	\
    ( (This)->lpVtbl -> get_TextFileOtherDelimiter(This,RHS) ) 

#define _IQueryTable_put_TextFileOtherDelimiter(This,RHS)	\
    ( (This)->lpVtbl -> put_TextFileOtherDelimiter(This,RHS) ) 

#define _IQueryTable_get_TextFileColumnDataTypes(This,RHS)	\
    ( (This)->lpVtbl -> get_TextFileColumnDataTypes(This,RHS) ) 

#define _IQueryTable_put_TextFileColumnDataTypes(This,RHS)	\
    ( (This)->lpVtbl -> put_TextFileColumnDataTypes(This,RHS) ) 

#define _IQueryTable_get_TextFileFixedColumnWidths(This,RHS)	\
    ( (This)->lpVtbl -> get_TextFileFixedColumnWidths(This,RHS) ) 

#define _IQueryTable_put_TextFileFixedColumnWidths(This,RHS)	\
    ( (This)->lpVtbl -> put_TextFileFixedColumnWidths(This,RHS) ) 

#define _IQueryTable_get_PreserveColumnInfo(This,RHS)	\
    ( (This)->lpVtbl -> get_PreserveColumnInfo(This,RHS) ) 

#define _IQueryTable_put_PreserveColumnInfo(This,RHS)	\
    ( (This)->lpVtbl -> put_PreserveColumnInfo(This,RHS) ) 

#define _IQueryTable_get_PreserveFormatting(This,RHS)	\
    ( (This)->lpVtbl -> get_PreserveFormatting(This,RHS) ) 

#define _IQueryTable_put_PreserveFormatting(This,RHS)	\
    ( (This)->lpVtbl -> put_PreserveFormatting(This,RHS) ) 

#define _IQueryTable_get_AdjustColumnWidth(This,RHS)	\
    ( (This)->lpVtbl -> get_AdjustColumnWidth(This,RHS) ) 

#define _IQueryTable_put_AdjustColumnWidth(This,RHS)	\
    ( (This)->lpVtbl -> put_AdjustColumnWidth(This,RHS) ) 

#define _IQueryTable_get_CommandText(This,RHS)	\
    ( (This)->lpVtbl -> get_CommandText(This,RHS) ) 

#define _IQueryTable_put_CommandText(This,RHS)	\
    ( (This)->lpVtbl -> put_CommandText(This,RHS) ) 

#define _IQueryTable_get_CommandType(This,RHS)	\
    ( (This)->lpVtbl -> get_CommandType(This,RHS) ) 

#define _IQueryTable_put_CommandType(This,RHS)	\
    ( (This)->lpVtbl -> put_CommandType(This,RHS) ) 

#define _IQueryTable_get_TextFilePromptOnRefresh(This,RHS)	\
    ( (This)->lpVtbl -> get_TextFilePromptOnRefresh(This,RHS) ) 

#define _IQueryTable_put_TextFilePromptOnRefresh(This,RHS)	\
    ( (This)->lpVtbl -> put_TextFilePromptOnRefresh(This,RHS) ) 

#define _IQueryTable_get_QueryType(This,RHS)	\
    ( (This)->lpVtbl -> get_QueryType(This,RHS) ) 

#define _IQueryTable_get_MaintainConnection(This,RHS)	\
    ( (This)->lpVtbl -> get_MaintainConnection(This,RHS) ) 

#define _IQueryTable_put_MaintainConnection(This,RHS)	\
    ( (This)->lpVtbl -> put_MaintainConnection(This,RHS) ) 

#define _IQueryTable_get_TextFileDecimalSeparator(This,RHS)	\
    ( (This)->lpVtbl -> get_TextFileDecimalSeparator(This,RHS) ) 

#define _IQueryTable_put_TextFileDecimalSeparator(This,RHS)	\
    ( (This)->lpVtbl -> put_TextFileDecimalSeparator(This,RHS) ) 

#define _IQueryTable_get_TextFileThousandsSeparator(This,RHS)	\
    ( (This)->lpVtbl -> get_TextFileThousandsSeparator(This,RHS) ) 

#define _IQueryTable_put_TextFileThousandsSeparator(This,RHS)	\
    ( (This)->lpVtbl -> put_TextFileThousandsSeparator(This,RHS) ) 

#define _IQueryTable_get_RefreshPeriod(This,RHS)	\
    ( (This)->lpVtbl -> get_RefreshPeriod(This,RHS) ) 

#define _IQueryTable_put_RefreshPeriod(This,RHS)	\
    ( (This)->lpVtbl -> put_RefreshPeriod(This,RHS) ) 

#define _IQueryTable_ResetTimer(This)	\
    ( (This)->lpVtbl -> ResetTimer(This) ) 

#define _IQueryTable_get_WebSelectionType(This,RHS)	\
    ( (This)->lpVtbl -> get_WebSelectionType(This,RHS) ) 

#define _IQueryTable_put_WebSelectionType(This,RHS)	\
    ( (This)->lpVtbl -> put_WebSelectionType(This,RHS) ) 

#define _IQueryTable_get_WebFormatting(This,RHS)	\
    ( (This)->lpVtbl -> get_WebFormatting(This,RHS) ) 

#define _IQueryTable_put_WebFormatting(This,RHS)	\
    ( (This)->lpVtbl -> put_WebFormatting(This,RHS) ) 

#define _IQueryTable_get_WebTables(This,RHS)	\
    ( (This)->lpVtbl -> get_WebTables(This,RHS) ) 

#define _IQueryTable_put_WebTables(This,RHS)	\
    ( (This)->lpVtbl -> put_WebTables(This,RHS) ) 

#define _IQueryTable_get_WebPreFormattedTextToColumns(This,RHS)	\
    ( (This)->lpVtbl -> get_WebPreFormattedTextToColumns(This,RHS) ) 

#define _IQueryTable_put_WebPreFormattedTextToColumns(This,RHS)	\
    ( (This)->lpVtbl -> put_WebPreFormattedTextToColumns(This,RHS) ) 

#define _IQueryTable_get_WebSingleBlockTextImport(This,RHS)	\
    ( (This)->lpVtbl -> get_WebSingleBlockTextImport(This,RHS) ) 

#define _IQueryTable_put_WebSingleBlockTextImport(This,RHS)	\
    ( (This)->lpVtbl -> put_WebSingleBlockTextImport(This,RHS) ) 

#define _IQueryTable_get_WebDisableDateRecognition(This,RHS)	\
    ( (This)->lpVtbl -> get_WebDisableDateRecognition(This,RHS) ) 

#define _IQueryTable_put_WebDisableDateRecognition(This,RHS)	\
    ( (This)->lpVtbl -> put_WebDisableDateRecognition(This,RHS) ) 

#define _IQueryTable_get_WebConsecutiveDelimitersAsOne(This,RHS)	\
    ( (This)->lpVtbl -> get_WebConsecutiveDelimitersAsOne(This,RHS) ) 

#define _IQueryTable_put_WebConsecutiveDelimitersAsOne(This,RHS)	\
    ( (This)->lpVtbl -> put_WebConsecutiveDelimitersAsOne(This,RHS) ) 

#define _IQueryTable_get_WebDisableRedirections(This,RHS)	\
    ( (This)->lpVtbl -> get_WebDisableRedirections(This,RHS) ) 

#define _IQueryTable_put_WebDisableRedirections(This,RHS)	\
    ( (This)->lpVtbl -> put_WebDisableRedirections(This,RHS) ) 

#define _IQueryTable_get_EditWebPage(This,RHS)	\
    ( (This)->lpVtbl -> get_EditWebPage(This,RHS) ) 

#define _IQueryTable_put_EditWebPage(This,RHS)	\
    ( (This)->lpVtbl -> put_EditWebPage(This,RHS) ) 

#define _IQueryTable_get_SourceConnectionFile(This,RHS)	\
    ( (This)->lpVtbl -> get_SourceConnectionFile(This,RHS) ) 

#define _IQueryTable_put_SourceConnectionFile(This,RHS)	\
    ( (This)->lpVtbl -> put_SourceConnectionFile(This,RHS) ) 

#define _IQueryTable_get_SourceDataFile(This,RHS)	\
    ( (This)->lpVtbl -> get_SourceDataFile(This,RHS) ) 

#define _IQueryTable_put_SourceDataFile(This,RHS)	\
    ( (This)->lpVtbl -> put_SourceDataFile(This,RHS) ) 

#define _IQueryTable_get_RobustConnect(This,RHS)	\
    ( (This)->lpVtbl -> get_RobustConnect(This,RHS) ) 

#define _IQueryTable_put_RobustConnect(This,RHS)	\
    ( (This)->lpVtbl -> put_RobustConnect(This,RHS) ) 

#define _IQueryTable_get_TextFileTrailingMinusNumbers(This,RHS)	\
    ( (This)->lpVtbl -> get_TextFileTrailingMinusNumbers(This,RHS) ) 

#define _IQueryTable_put_TextFileTrailingMinusNumbers(This,RHS)	\
    ( (This)->lpVtbl -> put_TextFileTrailingMinusNumbers(This,RHS) ) 

#define _IQueryTable_SaveAsODC(This,ODCFileName,Description,Keywords)	\
    ( (This)->lpVtbl -> SaveAsODC(This,ODCFileName,Description,Keywords) ) 

#define _IQueryTable_get_ListObject(This,RHS)	\
    ( (This)->lpVtbl -> get_ListObject(This,RHS) ) 

#define _IQueryTable_get_TextFileVisualLayout(This,RHS)	\
    ( (This)->lpVtbl -> get_TextFileVisualLayout(This,RHS) ) 

#define _IQueryTable_put_TextFileVisualLayout(This,RHS)	\
    ( (This)->lpVtbl -> put_TextFileVisualLayout(This,RHS) ) 

#define _IQueryTable_get_WorkbookConnection(This,RHS)	\
    ( (This)->lpVtbl -> get_WorkbookConnection(This,RHS) ) 

#define _IQueryTable_get_Sort(This,RHS)	\
    ( (This)->lpVtbl -> get_Sort(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */



/* [helpcontext][propget][id] */ HRESULT __stdcall _IQueryTable_get_WorkbookConnection_Proxy( 
    _IQueryTable * This,
    /* [retval][out] */ WorkbookConnection	**RHS);


void __RPC_STUB _IQueryTable_get_WorkbookConnection_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);


/* [helpcontext][propget][id] */ HRESULT __stdcall _IQueryTable_get_Sort_Proxy( 
    _IQueryTable * This,
    /* [retval][out] */ Sort	**RHS);


void __RPC_STUB _IQueryTable_get_Sort_Stub(
    IRpcStubBuffer *This,
    IRpcChannelBuffer *_pRpcChannelBuffer,
    PRPC_MESSAGE _pRpcMessage,
    DWORD *_pdwStubPhase);



#endif 	/* ___IQueryTable_INTERFACE_DEFINED__ */


#ifndef __IQueryTables_INTERFACE_DEFINED__
#define __IQueryTables_INTERFACE_DEFINED__

/* interface IQueryTables */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IQueryTables;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024429-0001-0000-C000-000000000046")
    IQueryTables : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add( 
            /* [in] */ VARIANT Connection,
            /* [in] */ Range	*Destination,
            /* [optional][in] */ VARIANT Sql,
            /* [retval][out] */ QueryTable	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ QueryTable	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ QueryTable	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall _NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IQueryTablesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IQueryTables * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IQueryTables * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IQueryTables * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IQueryTables * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IQueryTables * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IQueryTables * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IQueryTables * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IQueryTables * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IQueryTables * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IQueryTables * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IQueryTables * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add )( 
            IQueryTables * This,
            /* [in] */ VARIANT Connection,
            /* [in] */ Range	*Destination,
            /* [optional][in] */ VARIANT Sql,
            /* [retval][out] */ QueryTable	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Item )( 
            IQueryTables * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ QueryTable	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IQueryTables * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ QueryTable	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *_NewEnum )( 
            IQueryTables * This,
            /* [retval][out] */ IUnknown **RHS);
        
        END_INTERFACE
    } IQueryTablesVtbl;

    interface IQueryTables
    {
        CONST_VTBL struct IQueryTablesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IQueryTables_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IQueryTables_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IQueryTables_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IQueryTables_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IQueryTables_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IQueryTables_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IQueryTables_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IQueryTables_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IQueryTables_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IQueryTables_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IQueryTables_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IQueryTables_Add(This,Connection,Destination,Sql,RHS)	\
    ( (This)->lpVtbl -> Add(This,Connection,Destination,Sql,RHS) ) 

#define IQueryTables_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> Item(This,Index,RHS) ) 

#define IQueryTables_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define IQueryTables__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> _NewEnum(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IQueryTables_INTERFACE_DEFINED__ */


#ifndef __IParameter_INTERFACE_DEFINED__
#define __IParameter_INTERFACE_DEFINED__

/* interface IParameter */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IParameter;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002442A-0001-0000-C000-000000000046")
    IParameter : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DataType( 
            /* [retval][out] */ XlParameterDataType *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DataType( 
            /* [in] */ XlParameterDataType RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Type( 
            /* [retval][out] */ XlParameterType *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PromptString( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Value( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SourceRange( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Name( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SetParam( 
            /* [in] */ XlParameterType Type,
            /* [in] */ VARIANT Value) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RefreshOnChange( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_RefreshOnChange( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IParameterVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IParameter * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IParameter * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IParameter * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IParameter * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IParameter * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IParameter * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IParameter * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IParameter * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IParameter * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IParameter * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DataType )( 
            IParameter * This,
            /* [retval][out] */ XlParameterDataType *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DataType )( 
            IParameter * This,
            /* [in] */ XlParameterDataType RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Type )( 
            IParameter * This,
            /* [retval][out] */ XlParameterType *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PromptString )( 
            IParameter * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Value )( 
            IParameter * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SourceRange )( 
            IParameter * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            IParameter * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Name )( 
            IParameter * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SetParam )( 
            IParameter * This,
            /* [in] */ XlParameterType Type,
            /* [in] */ VARIANT Value);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RefreshOnChange )( 
            IParameter * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_RefreshOnChange )( 
            IParameter * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        END_INTERFACE
    } IParameterVtbl;

    interface IParameter
    {
        CONST_VTBL struct IParameterVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IParameter_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IParameter_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IParameter_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IParameter_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IParameter_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IParameter_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IParameter_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IParameter_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IParameter_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IParameter_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IParameter_get_DataType(This,RHS)	\
    ( (This)->lpVtbl -> get_DataType(This,RHS) ) 

#define IParameter_put_DataType(This,RHS)	\
    ( (This)->lpVtbl -> put_DataType(This,RHS) ) 

#define IParameter_get_Type(This,RHS)	\
    ( (This)->lpVtbl -> get_Type(This,RHS) ) 

#define IParameter_get_PromptString(This,RHS)	\
    ( (This)->lpVtbl -> get_PromptString(This,RHS) ) 

#define IParameter_get_Value(This,RHS)	\
    ( (This)->lpVtbl -> get_Value(This,RHS) ) 

#define IParameter_get_SourceRange(This,RHS)	\
    ( (This)->lpVtbl -> get_SourceRange(This,RHS) ) 

#define IParameter_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define IParameter_put_Name(This,RHS)	\
    ( (This)->lpVtbl -> put_Name(This,RHS) ) 

#define IParameter_SetParam(This,Type,Value)	\
    ( (This)->lpVtbl -> SetParam(This,Type,Value) ) 

#define IParameter_get_RefreshOnChange(This,RHS)	\
    ( (This)->lpVtbl -> get_RefreshOnChange(This,RHS) ) 

#define IParameter_put_RefreshOnChange(This,RHS)	\
    ( (This)->lpVtbl -> put_RefreshOnChange(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IParameter_INTERFACE_DEFINED__ */


#ifndef __IParameters_INTERFACE_DEFINED__
#define __IParameters_INTERFACE_DEFINED__

/* interface IParameters */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IParameters;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002442B-0001-0000-C000-000000000046")
    IParameters : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add( 
            /* [in] */ BSTR Name,
            /* [optional][in] */ VARIANT iDataType,
            /* [retval][out] */ Parameter	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Parameter	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Parameter	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall _NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IParametersVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IParameters * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IParameters * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IParameters * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IParameters * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IParameters * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IParameters * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IParameters * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IParameters * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IParameters * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IParameters * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add )( 
            IParameters * This,
            /* [in] */ BSTR Name,
            /* [optional][in] */ VARIANT iDataType,
            /* [retval][out] */ Parameter	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IParameters * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Item )( 
            IParameters * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Parameter	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IParameters * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Parameter	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IParameters * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *_NewEnum )( 
            IParameters * This,
            /* [retval][out] */ IUnknown **RHS);
        
        END_INTERFACE
    } IParametersVtbl;

    interface IParameters
    {
        CONST_VTBL struct IParametersVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IParameters_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IParameters_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IParameters_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IParameters_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IParameters_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IParameters_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IParameters_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IParameters_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IParameters_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IParameters_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IParameters_Add(This,Name,iDataType,RHS)	\
    ( (This)->lpVtbl -> Add(This,Name,iDataType,RHS) ) 

#define IParameters_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IParameters_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> Item(This,Index,RHS) ) 

#define IParameters_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define IParameters_Delete(This)	\
    ( (This)->lpVtbl -> Delete(This) ) 

#define IParameters__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> _NewEnum(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IParameters_INTERFACE_DEFINED__ */


#ifndef __IODBCError_INTERFACE_DEFINED__
#define __IODBCError_INTERFACE_DEFINED__

/* interface IODBCError */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IODBCError;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002442C-0001-0000-C000-000000000046")
    IODBCError : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SqlState( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ErrorString( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IODBCErrorVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IODBCError * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IODBCError * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IODBCError * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IODBCError * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IODBCError * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IODBCError * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IODBCError * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IODBCError * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IODBCError * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IODBCError * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SqlState )( 
            IODBCError * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ErrorString )( 
            IODBCError * This,
            /* [retval][out] */ BSTR *RHS);
        
        END_INTERFACE
    } IODBCErrorVtbl;

    interface IODBCError
    {
        CONST_VTBL struct IODBCErrorVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IODBCError_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IODBCError_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IODBCError_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IODBCError_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IODBCError_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IODBCError_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IODBCError_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IODBCError_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IODBCError_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IODBCError_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IODBCError_get_SqlState(This,RHS)	\
    ( (This)->lpVtbl -> get_SqlState(This,RHS) ) 

#define IODBCError_get_ErrorString(This,RHS)	\
    ( (This)->lpVtbl -> get_ErrorString(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IODBCError_INTERFACE_DEFINED__ */


#ifndef __IODBCErrors_INTERFACE_DEFINED__
#define __IODBCErrors_INTERFACE_DEFINED__

/* interface IODBCErrors */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IODBCErrors;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002442D-0001-0000-C000-000000000046")
    IODBCErrors : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Item( 
            /* [in] */ long Index,
            /* [retval][out] */ ODBCError	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ long Index,
            /* [retval][out] */ ODBCError	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall _NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IODBCErrorsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IODBCErrors * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IODBCErrors * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IODBCErrors * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IODBCErrors * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IODBCErrors * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IODBCErrors * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IODBCErrors * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IODBCErrors * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IODBCErrors * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IODBCErrors * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IODBCErrors * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Item )( 
            IODBCErrors * This,
            /* [in] */ long Index,
            /* [retval][out] */ ODBCError	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IODBCErrors * This,
            /* [in] */ long Index,
            /* [retval][out] */ ODBCError	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *_NewEnum )( 
            IODBCErrors * This,
            /* [retval][out] */ IUnknown **RHS);
        
        END_INTERFACE
    } IODBCErrorsVtbl;

    interface IODBCErrors
    {
        CONST_VTBL struct IODBCErrorsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IODBCErrors_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IODBCErrors_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IODBCErrors_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IODBCErrors_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IODBCErrors_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IODBCErrors_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IODBCErrors_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IODBCErrors_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IODBCErrors_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IODBCErrors_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IODBCErrors_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IODBCErrors_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> Item(This,Index,RHS) ) 

#define IODBCErrors_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define IODBCErrors__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> _NewEnum(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IODBCErrors_INTERFACE_DEFINED__ */


#ifndef __IValidation_INTERFACE_DEFINED__
#define __IValidation_INTERFACE_DEFINED__

/* interface IValidation */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IValidation;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002442F-0001-0000-C000-000000000046")
    IValidation : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add( 
            /* [in] */ XlDVType Type,
            /* [optional][in] */ VARIANT AlertStyle,
            /* [optional][in] */ VARIANT Operator,
            /* [optional][in] */ VARIANT Formula1,
            /* [optional][in] */ VARIANT Formula2) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AlertStyle( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_IgnoreBlank( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_IgnoreBlank( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_IMEMode( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_IMEMode( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_InCellDropdown( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_InCellDropdown( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ErrorMessage( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ErrorMessage( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ErrorTitle( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ErrorTitle( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_InputMessage( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_InputMessage( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_InputTitle( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_InputTitle( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Formula1( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Formula2( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Modify( 
            /* [optional][in] */ VARIANT Type,
            /* [optional][in] */ VARIANT AlertStyle,
            /* [optional][in] */ VARIANT Operator,
            /* [optional][in] */ VARIANT Formula1,
            /* [optional][in] */ VARIANT Formula2) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Operator( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShowError( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ShowError( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShowInput( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ShowInput( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Type( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Value( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IValidationVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IValidation * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IValidation * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IValidation * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IValidation * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IValidation * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IValidation * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IValidation * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IValidation * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IValidation * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IValidation * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add )( 
            IValidation * This,
            /* [in] */ XlDVType Type,
            /* [optional][in] */ VARIANT AlertStyle,
            /* [optional][in] */ VARIANT Operator,
            /* [optional][in] */ VARIANT Formula1,
            /* [optional][in] */ VARIANT Formula2);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AlertStyle )( 
            IValidation * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_IgnoreBlank )( 
            IValidation * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_IgnoreBlank )( 
            IValidation * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_IMEMode )( 
            IValidation * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_IMEMode )( 
            IValidation * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_InCellDropdown )( 
            IValidation * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_InCellDropdown )( 
            IValidation * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IValidation * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ErrorMessage )( 
            IValidation * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ErrorMessage )( 
            IValidation * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ErrorTitle )( 
            IValidation * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ErrorTitle )( 
            IValidation * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_InputMessage )( 
            IValidation * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_InputMessage )( 
            IValidation * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_InputTitle )( 
            IValidation * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_InputTitle )( 
            IValidation * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Formula1 )( 
            IValidation * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Formula2 )( 
            IValidation * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Modify )( 
            IValidation * This,
            /* [optional][in] */ VARIANT Type,
            /* [optional][in] */ VARIANT AlertStyle,
            /* [optional][in] */ VARIANT Operator,
            /* [optional][in] */ VARIANT Formula1,
            /* [optional][in] */ VARIANT Formula2);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Operator )( 
            IValidation * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShowError )( 
            IValidation * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ShowError )( 
            IValidation * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShowInput )( 
            IValidation * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ShowInput )( 
            IValidation * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Type )( 
            IValidation * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Value )( 
            IValidation * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        END_INTERFACE
    } IValidationVtbl;

    interface IValidation
    {
        CONST_VTBL struct IValidationVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IValidation_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IValidation_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IValidation_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IValidation_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IValidation_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IValidation_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IValidation_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IValidation_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IValidation_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IValidation_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IValidation_Add(This,Type,AlertStyle,Operator,Formula1,Formula2)	\
    ( (This)->lpVtbl -> Add(This,Type,AlertStyle,Operator,Formula1,Formula2) ) 

#define IValidation_get_AlertStyle(This,RHS)	\
    ( (This)->lpVtbl -> get_AlertStyle(This,RHS) ) 

#define IValidation_get_IgnoreBlank(This,RHS)	\
    ( (This)->lpVtbl -> get_IgnoreBlank(This,RHS) ) 

#define IValidation_put_IgnoreBlank(This,RHS)	\
    ( (This)->lpVtbl -> put_IgnoreBlank(This,RHS) ) 

#define IValidation_get_IMEMode(This,RHS)	\
    ( (This)->lpVtbl -> get_IMEMode(This,RHS) ) 

#define IValidation_put_IMEMode(This,RHS)	\
    ( (This)->lpVtbl -> put_IMEMode(This,RHS) ) 

#define IValidation_get_InCellDropdown(This,RHS)	\
    ( (This)->lpVtbl -> get_InCellDropdown(This,RHS) ) 

#define IValidation_put_InCellDropdown(This,RHS)	\
    ( (This)->lpVtbl -> put_InCellDropdown(This,RHS) ) 

#define IValidation_Delete(This)	\
    ( (This)->lpVtbl -> Delete(This) ) 

#define IValidation_get_ErrorMessage(This,RHS)	\
    ( (This)->lpVtbl -> get_ErrorMessage(This,RHS) ) 

#define IValidation_put_ErrorMessage(This,RHS)	\
    ( (This)->lpVtbl -> put_ErrorMessage(This,RHS) ) 

#define IValidation_get_ErrorTitle(This,RHS)	\
    ( (This)->lpVtbl -> get_ErrorTitle(This,RHS) ) 

#define IValidation_put_ErrorTitle(This,RHS)	\
    ( (This)->lpVtbl -> put_ErrorTitle(This,RHS) ) 

#define IValidation_get_InputMessage(This,RHS)	\
    ( (This)->lpVtbl -> get_InputMessage(This,RHS) ) 

#define IValidation_put_InputMessage(This,RHS)	\
    ( (This)->lpVtbl -> put_InputMessage(This,RHS) ) 

#define IValidation_get_InputTitle(This,RHS)	\
    ( (This)->lpVtbl -> get_InputTitle(This,RHS) ) 

#define IValidation_put_InputTitle(This,RHS)	\
    ( (This)->lpVtbl -> put_InputTitle(This,RHS) ) 

#define IValidation_get_Formula1(This,RHS)	\
    ( (This)->lpVtbl -> get_Formula1(This,RHS) ) 

#define IValidation_get_Formula2(This,RHS)	\
    ( (This)->lpVtbl -> get_Formula2(This,RHS) ) 

#define IValidation_Modify(This,Type,AlertStyle,Operator,Formula1,Formula2)	\
    ( (This)->lpVtbl -> Modify(This,Type,AlertStyle,Operator,Formula1,Formula2) ) 

#define IValidation_get_Operator(This,RHS)	\
    ( (This)->lpVtbl -> get_Operator(This,RHS) ) 

#define IValidation_get_ShowError(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowError(This,RHS) ) 

#define IValidation_put_ShowError(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowError(This,RHS) ) 

#define IValidation_get_ShowInput(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowInput(This,RHS) ) 

#define IValidation_put_ShowInput(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowInput(This,RHS) ) 

#define IValidation_get_Type(This,RHS)	\
    ( (This)->lpVtbl -> get_Type(This,RHS) ) 

#define IValidation_get_Value(This,RHS)	\
    ( (This)->lpVtbl -> get_Value(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IValidation_INTERFACE_DEFINED__ */


#ifndef __IHyperlinks_INTERFACE_DEFINED__
#define __IHyperlinks_INTERFACE_DEFINED__

/* interface IHyperlinks */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IHyperlinks;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024430-0001-0000-C000-000000000046")
    IHyperlinks : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add( 
            /* [in] */ IDispatch *Anchor,
            /* [in] */ BSTR Address,
            /* [optional][in] */ VARIANT SubAddress,
            /* [optional][in] */ VARIANT ScreenTip,
            /* [optional][in] */ VARIANT TextToDisplay,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Hyperlink	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Hyperlink	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( void) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IHyperlinksVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IHyperlinks * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IHyperlinks * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IHyperlinks * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IHyperlinks * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IHyperlinks * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IHyperlinks * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IHyperlinks * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IHyperlinks * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IHyperlinks * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IHyperlinks * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add )( 
            IHyperlinks * This,
            /* [in] */ IDispatch *Anchor,
            /* [in] */ BSTR Address,
            /* [optional][in] */ VARIANT SubAddress,
            /* [optional][in] */ VARIANT ScreenTip,
            /* [optional][in] */ VARIANT TextToDisplay,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IHyperlinks * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Item )( 
            IHyperlinks * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Hyperlink	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IHyperlinks * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Hyperlink	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            IHyperlinks * This,
            /* [retval][out] */ IUnknown **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IHyperlinks * This);
        
        END_INTERFACE
    } IHyperlinksVtbl;

    interface IHyperlinks
    {
        CONST_VTBL struct IHyperlinksVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IHyperlinks_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IHyperlinks_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IHyperlinks_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IHyperlinks_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IHyperlinks_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IHyperlinks_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IHyperlinks_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IHyperlinks_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IHyperlinks_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IHyperlinks_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IHyperlinks_Add(This,Anchor,Address,SubAddress,ScreenTip,TextToDisplay,RHS)	\
    ( (This)->lpVtbl -> Add(This,Anchor,Address,SubAddress,ScreenTip,TextToDisplay,RHS) ) 

#define IHyperlinks_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IHyperlinks_get_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Item(This,Index,RHS) ) 

#define IHyperlinks_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define IHyperlinks_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#define IHyperlinks_Delete(This)	\
    ( (This)->lpVtbl -> Delete(This) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IHyperlinks_INTERFACE_DEFINED__ */


#ifndef __IHyperlink_INTERFACE_DEFINED__
#define __IHyperlink_INTERFACE_DEFINED__

/* interface IHyperlink */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IHyperlink;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024431-0001-0000-C000-000000000046")
    IHyperlink : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Range( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Shape( 
            /* [retval][out] */ Shape	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SubAddress( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_SubAddress( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Address( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Address( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Type( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall AddToFavorites( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Follow( 
            /* [optional][in] */ VARIANT NewWindow,
            /* [optional][in] */ VARIANT AddHistory,
            /* [optional][in] */ VARIANT ExtraInfo,
            /* [optional][in] */ VARIANT Method,
            /* [optional][in] */ VARIANT HeaderInfo) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_EmailSubject( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_EmailSubject( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ScreenTip( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ScreenTip( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TextToDisplay( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_TextToDisplay( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CreateNewDocument( 
            /* [in] */ BSTR Filename,
            /* [in] */ VARIANT_BOOL EditNow,
            /* [in] */ VARIANT_BOOL Overwrite) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IHyperlinkVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IHyperlink * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IHyperlink * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IHyperlink * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IHyperlink * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IHyperlink * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IHyperlink * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IHyperlink * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IHyperlink * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IHyperlink * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IHyperlink * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            IHyperlink * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Range )( 
            IHyperlink * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Shape )( 
            IHyperlink * This,
            /* [retval][out] */ Shape	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SubAddress )( 
            IHyperlink * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_SubAddress )( 
            IHyperlink * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Address )( 
            IHyperlink * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Address )( 
            IHyperlink * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Type )( 
            IHyperlink * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *AddToFavorites )( 
            IHyperlink * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IHyperlink * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Follow )( 
            IHyperlink * This,
            /* [optional][in] */ VARIANT NewWindow,
            /* [optional][in] */ VARIANT AddHistory,
            /* [optional][in] */ VARIANT ExtraInfo,
            /* [optional][in] */ VARIANT Method,
            /* [optional][in] */ VARIANT HeaderInfo);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_EmailSubject )( 
            IHyperlink * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_EmailSubject )( 
            IHyperlink * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ScreenTip )( 
            IHyperlink * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ScreenTip )( 
            IHyperlink * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TextToDisplay )( 
            IHyperlink * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_TextToDisplay )( 
            IHyperlink * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CreateNewDocument )( 
            IHyperlink * This,
            /* [in] */ BSTR Filename,
            /* [in] */ VARIANT_BOOL EditNow,
            /* [in] */ VARIANT_BOOL Overwrite);
        
        END_INTERFACE
    } IHyperlinkVtbl;

    interface IHyperlink
    {
        CONST_VTBL struct IHyperlinkVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IHyperlink_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IHyperlink_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IHyperlink_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IHyperlink_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IHyperlink_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IHyperlink_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IHyperlink_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IHyperlink_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IHyperlink_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IHyperlink_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IHyperlink_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define IHyperlink_get_Range(This,RHS)	\
    ( (This)->lpVtbl -> get_Range(This,RHS) ) 

#define IHyperlink_get_Shape(This,RHS)	\
    ( (This)->lpVtbl -> get_Shape(This,RHS) ) 

#define IHyperlink_get_SubAddress(This,RHS)	\
    ( (This)->lpVtbl -> get_SubAddress(This,RHS) ) 

#define IHyperlink_put_SubAddress(This,RHS)	\
    ( (This)->lpVtbl -> put_SubAddress(This,RHS) ) 

#define IHyperlink_get_Address(This,RHS)	\
    ( (This)->lpVtbl -> get_Address(This,RHS) ) 

#define IHyperlink_put_Address(This,RHS)	\
    ( (This)->lpVtbl -> put_Address(This,RHS) ) 

#define IHyperlink_get_Type(This,RHS)	\
    ( (This)->lpVtbl -> get_Type(This,RHS) ) 

#define IHyperlink_AddToFavorites(This)	\
    ( (This)->lpVtbl -> AddToFavorites(This) ) 

#define IHyperlink_Delete(This)	\
    ( (This)->lpVtbl -> Delete(This) ) 

#define IHyperlink_Follow(This,NewWindow,AddHistory,ExtraInfo,Method,HeaderInfo)	\
    ( (This)->lpVtbl -> Follow(This,NewWindow,AddHistory,ExtraInfo,Method,HeaderInfo) ) 

#define IHyperlink_get_EmailSubject(This,RHS)	\
    ( (This)->lpVtbl -> get_EmailSubject(This,RHS) ) 

#define IHyperlink_put_EmailSubject(This,RHS)	\
    ( (This)->lpVtbl -> put_EmailSubject(This,RHS) ) 

#define IHyperlink_get_ScreenTip(This,RHS)	\
    ( (This)->lpVtbl -> get_ScreenTip(This,RHS) ) 

#define IHyperlink_put_ScreenTip(This,RHS)	\
    ( (This)->lpVtbl -> put_ScreenTip(This,RHS) ) 

#define IHyperlink_get_TextToDisplay(This,RHS)	\
    ( (This)->lpVtbl -> get_TextToDisplay(This,RHS) ) 

#define IHyperlink_put_TextToDisplay(This,RHS)	\
    ( (This)->lpVtbl -> put_TextToDisplay(This,RHS) ) 

#define IHyperlink_CreateNewDocument(This,Filename,EditNow,Overwrite)	\
    ( (This)->lpVtbl -> CreateNewDocument(This,Filename,EditNow,Overwrite) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IHyperlink_INTERFACE_DEFINED__ */


#ifndef __IAutoFilter_INTERFACE_DEFINED__
#define __IAutoFilter_INTERFACE_DEFINED__

/* interface IAutoFilter */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IAutoFilter;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024432-0001-0000-C000-000000000046")
    IAutoFilter : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Range( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Filters( 
            /* [retval][out] */ Filters	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_FilterMode( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Sort( 
            /* [retval][out] */ Sort	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ApplyFilter( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ShowAllData( void) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IAutoFilterVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IAutoFilter * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IAutoFilter * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IAutoFilter * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IAutoFilter * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IAutoFilter * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IAutoFilter * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IAutoFilter * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IAutoFilter * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IAutoFilter * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IAutoFilter * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Range )( 
            IAutoFilter * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Filters )( 
            IAutoFilter * This,
            /* [retval][out] */ Filters	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_FilterMode )( 
            IAutoFilter * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Sort )( 
            IAutoFilter * This,
            /* [retval][out] */ Sort	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ApplyFilter )( 
            IAutoFilter * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ShowAllData )( 
            IAutoFilter * This);
        
        END_INTERFACE
    } IAutoFilterVtbl;

    interface IAutoFilter
    {
        CONST_VTBL struct IAutoFilterVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IAutoFilter_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IAutoFilter_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IAutoFilter_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IAutoFilter_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IAutoFilter_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IAutoFilter_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IAutoFilter_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IAutoFilter_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IAutoFilter_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IAutoFilter_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IAutoFilter_get_Range(This,RHS)	\
    ( (This)->lpVtbl -> get_Range(This,RHS) ) 

#define IAutoFilter_get_Filters(This,RHS)	\
    ( (This)->lpVtbl -> get_Filters(This,RHS) ) 

#define IAutoFilter_get_FilterMode(This,RHS)	\
    ( (This)->lpVtbl -> get_FilterMode(This,RHS) ) 

#define IAutoFilter_get_Sort(This,RHS)	\
    ( (This)->lpVtbl -> get_Sort(This,RHS) ) 

#define IAutoFilter_ApplyFilter(This)	\
    ( (This)->lpVtbl -> ApplyFilter(This) ) 

#define IAutoFilter_ShowAllData(This)	\
    ( (This)->lpVtbl -> ShowAllData(This) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IAutoFilter_INTERFACE_DEFINED__ */


#ifndef __IFilters_INTERFACE_DEFINED__
#define __IFilters_INTERFACE_DEFINED__

/* interface IFilters */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IFilters;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024433-0001-0000-C000-000000000046")
    IFilters : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ long Index,
            /* [retval][out] */ Filter	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Item( 
            /* [in] */ long Index,
            /* [retval][out] */ Filter	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IFiltersVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IFilters * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IFilters * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IFilters * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IFilters * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IFilters * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IFilters * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IFilters * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IFilters * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IFilters * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IFilters * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IFilters * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IFilters * This,
            /* [in] */ long Index,
            /* [retval][out] */ Filter	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Item )( 
            IFilters * This,
            /* [in] */ long Index,
            /* [retval][out] */ Filter	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            IFilters * This,
            /* [retval][out] */ IUnknown **RHS);
        
        END_INTERFACE
    } IFiltersVtbl;

    interface IFilters
    {
        CONST_VTBL struct IFiltersVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IFilters_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IFilters_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IFilters_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IFilters_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IFilters_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IFilters_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IFilters_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IFilters_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IFilters_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IFilters_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IFilters_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IFilters_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define IFilters_get_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Item(This,Index,RHS) ) 

#define IFilters_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IFilters_INTERFACE_DEFINED__ */


#ifndef __IFilter_INTERFACE_DEFINED__
#define __IFilter_INTERFACE_DEFINED__

/* interface IFilter */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IFilter;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024434-0001-0000-C000-000000000046")
    IFilter : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_On( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Criteria1( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get__Operator( 
            /* [retval][out] */ XlAutoFilterOperator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Criteria2( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Operator( 
            /* [retval][out] */ XlAutoFilterOperator *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Operator( 
            /* [in] */ XlAutoFilterOperator RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IFilterVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IFilter * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IFilter * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IFilter * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IFilter * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IFilter * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IFilter * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IFilter * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IFilter * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IFilter * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IFilter * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_On )( 
            IFilter * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Criteria1 )( 
            IFilter * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get__Operator )( 
            IFilter * This,
            /* [retval][out] */ XlAutoFilterOperator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Criteria2 )( 
            IFilter * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Operator )( 
            IFilter * This,
            /* [retval][out] */ XlAutoFilterOperator *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Operator )( 
            IFilter * This,
            /* [in] */ XlAutoFilterOperator RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IFilter * This,
            /* [retval][out] */ long *RHS);
        
        END_INTERFACE
    } IFilterVtbl;

    interface IFilter
    {
        CONST_VTBL struct IFilterVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IFilter_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IFilter_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IFilter_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IFilter_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IFilter_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IFilter_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IFilter_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IFilter_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IFilter_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IFilter_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IFilter_get_On(This,RHS)	\
    ( (This)->lpVtbl -> get_On(This,RHS) ) 

#define IFilter_get_Criteria1(This,RHS)	\
    ( (This)->lpVtbl -> get_Criteria1(This,RHS) ) 

#define IFilter_get__Operator(This,RHS)	\
    ( (This)->lpVtbl -> get__Operator(This,RHS) ) 

#define IFilter_get_Criteria2(This,RHS)	\
    ( (This)->lpVtbl -> get_Criteria2(This,RHS) ) 

#define IFilter_get_Operator(This,RHS)	\
    ( (This)->lpVtbl -> get_Operator(This,RHS) ) 

#define IFilter_put_Operator(This,RHS)	\
    ( (This)->lpVtbl -> put_Operator(This,RHS) ) 

#define IFilter_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IFilter_INTERFACE_DEFINED__ */


#ifndef __IAutoCorrect_INTERFACE_DEFINED__
#define __IAutoCorrect_INTERFACE_DEFINED__

/* interface IAutoCorrect */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IAutoCorrect;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000208D4-0001-0000-C000-000000000046")
    IAutoCorrect : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall AddReplacement( 
            /* [in] */ BSTR What,
            /* [in] */ BSTR Replacement,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CapitalizeNamesOfDays( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_CapitalizeNamesOfDays( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall DeleteReplacement( 
            /* [in] */ BSTR What,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ReplacementList( 
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ReplacementList( 
            /* [optional][in] */ VARIANT Index,
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ReplaceText( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ReplaceText( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TwoInitialCapitals( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_TwoInitialCapitals( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CorrectSentenceCap( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_CorrectSentenceCap( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CorrectCapsLock( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_CorrectCapsLock( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DisplayAutoCorrectOptions( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DisplayAutoCorrectOptions( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AutoExpandListRange( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AutoExpandListRange( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AutoFillFormulasInLists( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AutoFillFormulasInLists( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IAutoCorrectVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IAutoCorrect * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IAutoCorrect * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IAutoCorrect * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IAutoCorrect * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IAutoCorrect * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IAutoCorrect * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IAutoCorrect * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IAutoCorrect * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IAutoCorrect * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IAutoCorrect * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *AddReplacement )( 
            IAutoCorrect * This,
            /* [in] */ BSTR What,
            /* [in] */ BSTR Replacement,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CapitalizeNamesOfDays )( 
            IAutoCorrect * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_CapitalizeNamesOfDays )( 
            IAutoCorrect * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *DeleteReplacement )( 
            IAutoCorrect * This,
            /* [in] */ BSTR What,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ReplacementList )( 
            IAutoCorrect * This,
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ReplacementList )( 
            IAutoCorrect * This,
            /* [optional][in] */ VARIANT Index,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ReplaceText )( 
            IAutoCorrect * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ReplaceText )( 
            IAutoCorrect * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TwoInitialCapitals )( 
            IAutoCorrect * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_TwoInitialCapitals )( 
            IAutoCorrect * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CorrectSentenceCap )( 
            IAutoCorrect * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_CorrectSentenceCap )( 
            IAutoCorrect * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CorrectCapsLock )( 
            IAutoCorrect * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_CorrectCapsLock )( 
            IAutoCorrect * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DisplayAutoCorrectOptions )( 
            IAutoCorrect * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DisplayAutoCorrectOptions )( 
            IAutoCorrect * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AutoExpandListRange )( 
            IAutoCorrect * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AutoExpandListRange )( 
            IAutoCorrect * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AutoFillFormulasInLists )( 
            IAutoCorrect * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AutoFillFormulasInLists )( 
            IAutoCorrect * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        END_INTERFACE
    } IAutoCorrectVtbl;

    interface IAutoCorrect
    {
        CONST_VTBL struct IAutoCorrectVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IAutoCorrect_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IAutoCorrect_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IAutoCorrect_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IAutoCorrect_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IAutoCorrect_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IAutoCorrect_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IAutoCorrect_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IAutoCorrect_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IAutoCorrect_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IAutoCorrect_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IAutoCorrect_AddReplacement(This,What,Replacement,RHS)	\
    ( (This)->lpVtbl -> AddReplacement(This,What,Replacement,RHS) ) 

#define IAutoCorrect_get_CapitalizeNamesOfDays(This,RHS)	\
    ( (This)->lpVtbl -> get_CapitalizeNamesOfDays(This,RHS) ) 

#define IAutoCorrect_put_CapitalizeNamesOfDays(This,RHS)	\
    ( (This)->lpVtbl -> put_CapitalizeNamesOfDays(This,RHS) ) 

#define IAutoCorrect_DeleteReplacement(This,What,RHS)	\
    ( (This)->lpVtbl -> DeleteReplacement(This,What,RHS) ) 

#define IAutoCorrect_get_ReplacementList(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_ReplacementList(This,Index,RHS) ) 

#define IAutoCorrect_put_ReplacementList(This,Index,RHS)	\
    ( (This)->lpVtbl -> put_ReplacementList(This,Index,RHS) ) 

#define IAutoCorrect_get_ReplaceText(This,RHS)	\
    ( (This)->lpVtbl -> get_ReplaceText(This,RHS) ) 

#define IAutoCorrect_put_ReplaceText(This,RHS)	\
    ( (This)->lpVtbl -> put_ReplaceText(This,RHS) ) 

#define IAutoCorrect_get_TwoInitialCapitals(This,RHS)	\
    ( (This)->lpVtbl -> get_TwoInitialCapitals(This,RHS) ) 

#define IAutoCorrect_put_TwoInitialCapitals(This,RHS)	\
    ( (This)->lpVtbl -> put_TwoInitialCapitals(This,RHS) ) 

#define IAutoCorrect_get_CorrectSentenceCap(This,RHS)	\
    ( (This)->lpVtbl -> get_CorrectSentenceCap(This,RHS) ) 

#define IAutoCorrect_put_CorrectSentenceCap(This,RHS)	\
    ( (This)->lpVtbl -> put_CorrectSentenceCap(This,RHS) ) 

#define IAutoCorrect_get_CorrectCapsLock(This,RHS)	\
    ( (This)->lpVtbl -> get_CorrectCapsLock(This,RHS) ) 

#define IAutoCorrect_put_CorrectCapsLock(This,RHS)	\
    ( (This)->lpVtbl -> put_CorrectCapsLock(This,RHS) ) 

#define IAutoCorrect_get_DisplayAutoCorrectOptions(This,RHS)	\
    ( (This)->lpVtbl -> get_DisplayAutoCorrectOptions(This,RHS) ) 

#define IAutoCorrect_put_DisplayAutoCorrectOptions(This,RHS)	\
    ( (This)->lpVtbl -> put_DisplayAutoCorrectOptions(This,RHS) ) 

#define IAutoCorrect_get_AutoExpandListRange(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoExpandListRange(This,RHS) ) 

#define IAutoCorrect_put_AutoExpandListRange(This,RHS)	\
    ( (This)->lpVtbl -> put_AutoExpandListRange(This,RHS) ) 

#define IAutoCorrect_get_AutoFillFormulasInLists(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoFillFormulasInLists(This,RHS) ) 

#define IAutoCorrect_put_AutoFillFormulasInLists(This,RHS)	\
    ( (This)->lpVtbl -> put_AutoFillFormulasInLists(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IAutoCorrect_INTERFACE_DEFINED__ */


#ifndef __IBorder_INTERFACE_DEFINED__
#define __IBorder_INTERFACE_DEFINED__

/* interface IBorder */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IBorder;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00020854-0001-0000-C000-000000000046")
    IBorder : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Color( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Color( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ColorIndex( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ColorIndex( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LineStyle( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_LineStyle( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Weight( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Weight( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ThemeColor( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ThemeColor( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TintAndShade( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_TintAndShade( 
            /* [in] */ VARIANT RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IBorderVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IBorder * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IBorder * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IBorder * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IBorder * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IBorder * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IBorder * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IBorder * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IBorder * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IBorder * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IBorder * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Color )( 
            IBorder * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Color )( 
            IBorder * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ColorIndex )( 
            IBorder * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ColorIndex )( 
            IBorder * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LineStyle )( 
            IBorder * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_LineStyle )( 
            IBorder * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Weight )( 
            IBorder * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Weight )( 
            IBorder * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ThemeColor )( 
            IBorder * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ThemeColor )( 
            IBorder * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TintAndShade )( 
            IBorder * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_TintAndShade )( 
            IBorder * This,
            /* [in] */ VARIANT RHS);
        
        END_INTERFACE
    } IBorderVtbl;

    interface IBorder
    {
        CONST_VTBL struct IBorderVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IBorder_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IBorder_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IBorder_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IBorder_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IBorder_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IBorder_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IBorder_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IBorder_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IBorder_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IBorder_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IBorder_get_Color(This,RHS)	\
    ( (This)->lpVtbl -> get_Color(This,RHS) ) 

#define IBorder_put_Color(This,RHS)	\
    ( (This)->lpVtbl -> put_Color(This,RHS) ) 

#define IBorder_get_ColorIndex(This,RHS)	\
    ( (This)->lpVtbl -> get_ColorIndex(This,RHS) ) 

#define IBorder_put_ColorIndex(This,RHS)	\
    ( (This)->lpVtbl -> put_ColorIndex(This,RHS) ) 

#define IBorder_get_LineStyle(This,RHS)	\
    ( (This)->lpVtbl -> get_LineStyle(This,RHS) ) 

#define IBorder_put_LineStyle(This,RHS)	\
    ( (This)->lpVtbl -> put_LineStyle(This,RHS) ) 

#define IBorder_get_Weight(This,RHS)	\
    ( (This)->lpVtbl -> get_Weight(This,RHS) ) 

#define IBorder_put_Weight(This,RHS)	\
    ( (This)->lpVtbl -> put_Weight(This,RHS) ) 

#define IBorder_get_ThemeColor(This,RHS)	\
    ( (This)->lpVtbl -> get_ThemeColor(This,RHS) ) 

#define IBorder_put_ThemeColor(This,RHS)	\
    ( (This)->lpVtbl -> put_ThemeColor(This,RHS) ) 

#define IBorder_get_TintAndShade(This,RHS)	\
    ( (This)->lpVtbl -> get_TintAndShade(This,RHS) ) 

#define IBorder_put_TintAndShade(This,RHS)	\
    ( (This)->lpVtbl -> put_TintAndShade(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IBorder_INTERFACE_DEFINED__ */


#ifndef __IInterior_INTERFACE_DEFINED__
#define __IInterior_INTERFACE_DEFINED__

/* interface IInterior */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IInterior;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00020870-0001-0000-C000-000000000046")
    IInterior : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Color( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Color( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ColorIndex( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ColorIndex( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_InvertIfNegative( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_InvertIfNegative( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Pattern( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Pattern( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PatternColor( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PatternColor( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PatternColorIndex( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PatternColorIndex( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ThemeColor( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ThemeColor( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TintAndShade( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_TintAndShade( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PatternThemeColor( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PatternThemeColor( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PatternTintAndShade( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PatternTintAndShade( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Gradient( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IInteriorVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IInterior * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IInterior * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IInterior * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IInterior * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IInterior * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IInterior * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IInterior * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IInterior * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IInterior * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IInterior * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Color )( 
            IInterior * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Color )( 
            IInterior * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ColorIndex )( 
            IInterior * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ColorIndex )( 
            IInterior * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_InvertIfNegative )( 
            IInterior * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_InvertIfNegative )( 
            IInterior * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Pattern )( 
            IInterior * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Pattern )( 
            IInterior * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PatternColor )( 
            IInterior * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PatternColor )( 
            IInterior * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PatternColorIndex )( 
            IInterior * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PatternColorIndex )( 
            IInterior * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ThemeColor )( 
            IInterior * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ThemeColor )( 
            IInterior * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TintAndShade )( 
            IInterior * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_TintAndShade )( 
            IInterior * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PatternThemeColor )( 
            IInterior * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PatternThemeColor )( 
            IInterior * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PatternTintAndShade )( 
            IInterior * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PatternTintAndShade )( 
            IInterior * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Gradient )( 
            IInterior * This,
            /* [retval][out] */ IDispatch **RHS);
        
        END_INTERFACE
    } IInteriorVtbl;

    interface IInterior
    {
        CONST_VTBL struct IInteriorVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IInterior_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IInterior_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IInterior_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IInterior_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IInterior_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IInterior_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IInterior_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IInterior_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IInterior_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IInterior_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IInterior_get_Color(This,RHS)	\
    ( (This)->lpVtbl -> get_Color(This,RHS) ) 

#define IInterior_put_Color(This,RHS)	\
    ( (This)->lpVtbl -> put_Color(This,RHS) ) 

#define IInterior_get_ColorIndex(This,RHS)	\
    ( (This)->lpVtbl -> get_ColorIndex(This,RHS) ) 

#define IInterior_put_ColorIndex(This,RHS)	\
    ( (This)->lpVtbl -> put_ColorIndex(This,RHS) ) 

#define IInterior_get_InvertIfNegative(This,RHS)	\
    ( (This)->lpVtbl -> get_InvertIfNegative(This,RHS) ) 

#define IInterior_put_InvertIfNegative(This,RHS)	\
    ( (This)->lpVtbl -> put_InvertIfNegative(This,RHS) ) 

#define IInterior_get_Pattern(This,RHS)	\
    ( (This)->lpVtbl -> get_Pattern(This,RHS) ) 

#define IInterior_put_Pattern(This,RHS)	\
    ( (This)->lpVtbl -> put_Pattern(This,RHS) ) 

#define IInterior_get_PatternColor(This,RHS)	\
    ( (This)->lpVtbl -> get_PatternColor(This,RHS) ) 

#define IInterior_put_PatternColor(This,RHS)	\
    ( (This)->lpVtbl -> put_PatternColor(This,RHS) ) 

#define IInterior_get_PatternColorIndex(This,RHS)	\
    ( (This)->lpVtbl -> get_PatternColorIndex(This,RHS) ) 

#define IInterior_put_PatternColorIndex(This,RHS)	\
    ( (This)->lpVtbl -> put_PatternColorIndex(This,RHS) ) 

#define IInterior_get_ThemeColor(This,RHS)	\
    ( (This)->lpVtbl -> get_ThemeColor(This,RHS) ) 

#define IInterior_put_ThemeColor(This,RHS)	\
    ( (This)->lpVtbl -> put_ThemeColor(This,RHS) ) 

#define IInterior_get_TintAndShade(This,RHS)	\
    ( (This)->lpVtbl -> get_TintAndShade(This,RHS) ) 

#define IInterior_put_TintAndShade(This,RHS)	\
    ( (This)->lpVtbl -> put_TintAndShade(This,RHS) ) 

#define IInterior_get_PatternThemeColor(This,RHS)	\
    ( (This)->lpVtbl -> get_PatternThemeColor(This,RHS) ) 

#define IInterior_put_PatternThemeColor(This,RHS)	\
    ( (This)->lpVtbl -> put_PatternThemeColor(This,RHS) ) 

#define IInterior_get_PatternTintAndShade(This,RHS)	\
    ( (This)->lpVtbl -> get_PatternTintAndShade(This,RHS) ) 

#define IInterior_put_PatternTintAndShade(This,RHS)	\
    ( (This)->lpVtbl -> put_PatternTintAndShade(This,RHS) ) 

#define IInterior_get_Gradient(This,RHS)	\
    ( (This)->lpVtbl -> get_Gradient(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IInterior_INTERFACE_DEFINED__ */


#ifndef __IChartFillFormat_INTERFACE_DEFINED__
#define __IChartFillFormat_INTERFACE_DEFINED__

/* interface IChartFillFormat */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IChartFillFormat;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024435-0001-0000-C000-000000000046")
    IChartFillFormat : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall OneColorGradient( 
            /* [in] */ MsoGradientStyle Style,
            /* [in] */ long Variant,
            /* [in] */ single Degree) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall TwoColorGradient( 
            /* [in] */ MsoGradientStyle Style,
            /* [in] */ long Variant) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall PresetTextured( 
            /* [in] */ MsoPresetTexture PresetTexture) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Solid( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Patterned( 
            /* [in] */ MsoPatternType Pattern) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall UserPicture( 
            /* [optional][in] */ VARIANT PictureFile,
            /* [optional][in] */ VARIANT PictureFormat,
            /* [optional][in] */ VARIANT PictureStackUnit,
            /* [optional][in] */ VARIANT PicturePlacement) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall UserTextured( 
            /* [in] */ BSTR TextureFile) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall PresetGradient( 
            /* [in] */ MsoGradientStyle Style,
            /* [in] */ long Variant,
            /* [in] */ MsoPresetGradientType PresetGradientType) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_BackColor( 
            /* [retval][out] */ ChartColorFormat	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ForeColor( 
            /* [retval][out] */ ChartColorFormat	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_GradientColorType( 
            /* [retval][out] */ MsoGradientColorType *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_GradientDegree( 
            /* [retval][out] */ single *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_GradientStyle( 
            /* [retval][out] */ MsoGradientStyle *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_GradientVariant( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Pattern( 
            /* [retval][out] */ MsoPatternType *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PresetGradientType( 
            /* [retval][out] */ MsoPresetGradientType *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PresetTexture( 
            /* [retval][out] */ MsoPresetTexture *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TextureName( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TextureType( 
            /* [retval][out] */ MsoTextureType *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Type( 
            /* [retval][out] */ MsoFillType *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Visible( 
            /* [retval][out] */ MsoTriState *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Visible( 
            /* [in] */ MsoTriState RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IChartFillFormatVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IChartFillFormat * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IChartFillFormat * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IChartFillFormat * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IChartFillFormat * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IChartFillFormat * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IChartFillFormat * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IChartFillFormat * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IChartFillFormat * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IChartFillFormat * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IChartFillFormat * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *OneColorGradient )( 
            IChartFillFormat * This,
            /* [in] */ MsoGradientStyle Style,
            /* [in] */ long Variant,
            /* [in] */ single Degree);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *TwoColorGradient )( 
            IChartFillFormat * This,
            /* [in] */ MsoGradientStyle Style,
            /* [in] */ long Variant);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *PresetTextured )( 
            IChartFillFormat * This,
            /* [in] */ MsoPresetTexture PresetTexture);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Solid )( 
            IChartFillFormat * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Patterned )( 
            IChartFillFormat * This,
            /* [in] */ MsoPatternType Pattern);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *UserPicture )( 
            IChartFillFormat * This,
            /* [optional][in] */ VARIANT PictureFile,
            /* [optional][in] */ VARIANT PictureFormat,
            /* [optional][in] */ VARIANT PictureStackUnit,
            /* [optional][in] */ VARIANT PicturePlacement);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *UserTextured )( 
            IChartFillFormat * This,
            /* [in] */ BSTR TextureFile);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *PresetGradient )( 
            IChartFillFormat * This,
            /* [in] */ MsoGradientStyle Style,
            /* [in] */ long Variant,
            /* [in] */ MsoPresetGradientType PresetGradientType);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_BackColor )( 
            IChartFillFormat * This,
            /* [retval][out] */ ChartColorFormat	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ForeColor )( 
            IChartFillFormat * This,
            /* [retval][out] */ ChartColorFormat	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_GradientColorType )( 
            IChartFillFormat * This,
            /* [retval][out] */ MsoGradientColorType *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_GradientDegree )( 
            IChartFillFormat * This,
            /* [retval][out] */ single *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_GradientStyle )( 
            IChartFillFormat * This,
            /* [retval][out] */ MsoGradientStyle *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_GradientVariant )( 
            IChartFillFormat * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Pattern )( 
            IChartFillFormat * This,
            /* [retval][out] */ MsoPatternType *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PresetGradientType )( 
            IChartFillFormat * This,
            /* [retval][out] */ MsoPresetGradientType *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PresetTexture )( 
            IChartFillFormat * This,
            /* [retval][out] */ MsoPresetTexture *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TextureName )( 
            IChartFillFormat * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TextureType )( 
            IChartFillFormat * This,
            /* [retval][out] */ MsoTextureType *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Type )( 
            IChartFillFormat * This,
            /* [retval][out] */ MsoFillType *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Visible )( 
            IChartFillFormat * This,
            /* [retval][out] */ MsoTriState *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Visible )( 
            IChartFillFormat * This,
            /* [in] */ MsoTriState RHS);
        
        END_INTERFACE
    } IChartFillFormatVtbl;

    interface IChartFillFormat
    {
        CONST_VTBL struct IChartFillFormatVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IChartFillFormat_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IChartFillFormat_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IChartFillFormat_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IChartFillFormat_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IChartFillFormat_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IChartFillFormat_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IChartFillFormat_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IChartFillFormat_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IChartFillFormat_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IChartFillFormat_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IChartFillFormat_OneColorGradient(This,Style,Variant,Degree)	\
    ( (This)->lpVtbl -> OneColorGradient(This,Style,Variant,Degree) ) 

#define IChartFillFormat_TwoColorGradient(This,Style,Variant)	\
    ( (This)->lpVtbl -> TwoColorGradient(This,Style,Variant) ) 

#define IChartFillFormat_PresetTextured(This,PresetTexture)	\
    ( (This)->lpVtbl -> PresetTextured(This,PresetTexture) ) 

#define IChartFillFormat_Solid(This)	\
    ( (This)->lpVtbl -> Solid(This) ) 

#define IChartFillFormat_Patterned(This,Pattern)	\
    ( (This)->lpVtbl -> Patterned(This,Pattern) ) 

#define IChartFillFormat_UserPicture(This,PictureFile,PictureFormat,PictureStackUnit,PicturePlacement)	\
    ( (This)->lpVtbl -> UserPicture(This,PictureFile,PictureFormat,PictureStackUnit,PicturePlacement) ) 

#define IChartFillFormat_UserTextured(This,TextureFile)	\
    ( (This)->lpVtbl -> UserTextured(This,TextureFile) ) 

#define IChartFillFormat_PresetGradient(This,Style,Variant,PresetGradientType)	\
    ( (This)->lpVtbl -> PresetGradient(This,Style,Variant,PresetGradientType) ) 

#define IChartFillFormat_get_BackColor(This,RHS)	\
    ( (This)->lpVtbl -> get_BackColor(This,RHS) ) 

#define IChartFillFormat_get_ForeColor(This,RHS)	\
    ( (This)->lpVtbl -> get_ForeColor(This,RHS) ) 

#define IChartFillFormat_get_GradientColorType(This,RHS)	\
    ( (This)->lpVtbl -> get_GradientColorType(This,RHS) ) 

#define IChartFillFormat_get_GradientDegree(This,RHS)	\
    ( (This)->lpVtbl -> get_GradientDegree(This,RHS) ) 

#define IChartFillFormat_get_GradientStyle(This,RHS)	\
    ( (This)->lpVtbl -> get_GradientStyle(This,RHS) ) 

#define IChartFillFormat_get_GradientVariant(This,RHS)	\
    ( (This)->lpVtbl -> get_GradientVariant(This,RHS) ) 

#define IChartFillFormat_get_Pattern(This,RHS)	\
    ( (This)->lpVtbl -> get_Pattern(This,RHS) ) 

#define IChartFillFormat_get_PresetGradientType(This,RHS)	\
    ( (This)->lpVtbl -> get_PresetGradientType(This,RHS) ) 

#define IChartFillFormat_get_PresetTexture(This,RHS)	\
    ( (This)->lpVtbl -> get_PresetTexture(This,RHS) ) 

#define IChartFillFormat_get_TextureName(This,RHS)	\
    ( (This)->lpVtbl -> get_TextureName(This,RHS) ) 

#define IChartFillFormat_get_TextureType(This,RHS)	\
    ( (This)->lpVtbl -> get_TextureType(This,RHS) ) 

#define IChartFillFormat_get_Type(This,RHS)	\
    ( (This)->lpVtbl -> get_Type(This,RHS) ) 

#define IChartFillFormat_get_Visible(This,RHS)	\
    ( (This)->lpVtbl -> get_Visible(This,RHS) ) 

#define IChartFillFormat_put_Visible(This,RHS)	\
    ( (This)->lpVtbl -> put_Visible(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IChartFillFormat_INTERFACE_DEFINED__ */


#ifndef __IChartColorFormat_INTERFACE_DEFINED__
#define __IChartColorFormat_INTERFACE_DEFINED__

/* interface IChartColorFormat */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IChartColorFormat;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024436-0001-0000-C000-000000000046")
    IChartColorFormat : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SchemeColor( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_SchemeColor( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RGB( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Type( 
            /* [retval][out] */ long *RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IChartColorFormatVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IChartColorFormat * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IChartColorFormat * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IChartColorFormat * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IChartColorFormat * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IChartColorFormat * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IChartColorFormat * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IChartColorFormat * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IChartColorFormat * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IChartColorFormat * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IChartColorFormat * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SchemeColor )( 
            IChartColorFormat * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_SchemeColor )( 
            IChartColorFormat * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RGB )( 
            IChartColorFormat * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IChartColorFormat * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Type )( 
            IChartColorFormat * This,
            /* [retval][out] */ long *RHS);
        
        END_INTERFACE
    } IChartColorFormatVtbl;

    interface IChartColorFormat
    {
        CONST_VTBL struct IChartColorFormatVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IChartColorFormat_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IChartColorFormat_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IChartColorFormat_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IChartColorFormat_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IChartColorFormat_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IChartColorFormat_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IChartColorFormat_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IChartColorFormat_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IChartColorFormat_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IChartColorFormat_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IChartColorFormat_get_SchemeColor(This,RHS)	\
    ( (This)->lpVtbl -> get_SchemeColor(This,RHS) ) 

#define IChartColorFormat_put_SchemeColor(This,RHS)	\
    ( (This)->lpVtbl -> put_SchemeColor(This,RHS) ) 

#define IChartColorFormat_get_RGB(This,RHS)	\
    ( (This)->lpVtbl -> get_RGB(This,RHS) ) 

#define IChartColorFormat_get__Default(This,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,RHS) ) 

#define IChartColorFormat_get_Type(This,RHS)	\
    ( (This)->lpVtbl -> get_Type(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IChartColorFormat_INTERFACE_DEFINED__ */


#ifndef __IAxis_INTERFACE_DEFINED__
#define __IAxis_INTERFACE_DEFINED__

/* interface IAxis */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IAxis;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00020848-0001-0000-C000-000000000046")
    IAxis : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AxisBetweenCategories( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AxisBetweenCategories( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AxisGroup( 
            /* [retval][out] */ XlAxisGroup *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AxisTitle( 
            /* [retval][out] */ AxisTitle	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Border( 
            /* [retval][out] */ Border	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CategoryNames( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_CategoryNames( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Crosses( 
            /* [retval][out] */ XlAxisCrosses *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Crosses( 
            /* [in] */ XlAxisCrosses RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CrossesAt( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_CrossesAt( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HasMajorGridlines( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_HasMajorGridlines( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HasMinorGridlines( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_HasMinorGridlines( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HasTitle( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_HasTitle( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MajorGridlines( 
            /* [retval][out] */ Gridlines	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MajorTickMark( 
            /* [retval][out] */ XlTickMark *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_MajorTickMark( 
            /* [in] */ XlTickMark RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MajorUnit( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_MajorUnit( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MajorUnitIsAuto( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_MajorUnitIsAuto( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MaximumScale( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_MaximumScale( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MaximumScaleIsAuto( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_MaximumScaleIsAuto( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MinimumScale( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_MinimumScale( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MinimumScaleIsAuto( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_MinimumScaleIsAuto( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MinorGridlines( 
            /* [retval][out] */ Gridlines	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MinorTickMark( 
            /* [retval][out] */ XlTickMark *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_MinorTickMark( 
            /* [in] */ XlTickMark RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MinorUnit( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_MinorUnit( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MinorUnitIsAuto( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_MinorUnitIsAuto( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ReversePlotOrder( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ReversePlotOrder( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ScaleType( 
            /* [retval][out] */ XlScaleType *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ScaleType( 
            /* [in] */ XlScaleType RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TickLabelPosition( 
            /* [retval][out] */ XlTickLabelPosition *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_TickLabelPosition( 
            /* [in] */ XlTickLabelPosition RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TickLabels( 
            /* [retval][out] */ TickLabels	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TickLabelSpacing( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_TickLabelSpacing( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TickMarkSpacing( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_TickMarkSpacing( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Type( 
            /* [retval][out] */ XlAxisType *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Type( 
            /* [in] */ XlAxisType RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_BaseUnit( 
            /* [retval][out] */ XlTimeUnit *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_BaseUnit( 
            /* [in] */ XlTimeUnit RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_BaseUnitIsAuto( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_BaseUnitIsAuto( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MajorUnitScale( 
            /* [retval][out] */ XlTimeUnit *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_MajorUnitScale( 
            /* [in] */ XlTimeUnit RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MinorUnitScale( 
            /* [retval][out] */ XlTimeUnit *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_MinorUnitScale( 
            /* [in] */ XlTimeUnit RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CategoryType( 
            /* [retval][out] */ XlCategoryType *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_CategoryType( 
            /* [in] */ XlCategoryType RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Left( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Top( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Width( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Height( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DisplayUnit( 
            /* [retval][out] */ XlDisplayUnit *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DisplayUnit( 
            /* [in] */ XlDisplayUnit RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DisplayUnitCustom( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DisplayUnitCustom( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HasDisplayUnitLabel( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_HasDisplayUnitLabel( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DisplayUnitLabel( 
            /* [retval][out] */ DisplayUnitLabel	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LogBase( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_LogBase( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TickLabelSpacingIsAuto( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_TickLabelSpacingIsAuto( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Format( 
            /* [retval][out] */ ChartFormat	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IAxisVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IAxis * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IAxis * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IAxis * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IAxis * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IAxis * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IAxis * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IAxis * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IAxis * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IAxis * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IAxis * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AxisBetweenCategories )( 
            IAxis * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AxisBetweenCategories )( 
            IAxis * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AxisGroup )( 
            IAxis * This,
            /* [retval][out] */ XlAxisGroup *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AxisTitle )( 
            IAxis * This,
            /* [retval][out] */ AxisTitle	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Border )( 
            IAxis * This,
            /* [retval][out] */ Border	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CategoryNames )( 
            IAxis * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_CategoryNames )( 
            IAxis * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Crosses )( 
            IAxis * This,
            /* [retval][out] */ XlAxisCrosses *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Crosses )( 
            IAxis * This,
            /* [in] */ XlAxisCrosses RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CrossesAt )( 
            IAxis * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_CrossesAt )( 
            IAxis * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IAxis * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HasMajorGridlines )( 
            IAxis * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_HasMajorGridlines )( 
            IAxis * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HasMinorGridlines )( 
            IAxis * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_HasMinorGridlines )( 
            IAxis * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HasTitle )( 
            IAxis * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_HasTitle )( 
            IAxis * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MajorGridlines )( 
            IAxis * This,
            /* [retval][out] */ Gridlines	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MajorTickMark )( 
            IAxis * This,
            /* [retval][out] */ XlTickMark *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_MajorTickMark )( 
            IAxis * This,
            /* [in] */ XlTickMark RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MajorUnit )( 
            IAxis * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_MajorUnit )( 
            IAxis * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MajorUnitIsAuto )( 
            IAxis * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_MajorUnitIsAuto )( 
            IAxis * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MaximumScale )( 
            IAxis * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_MaximumScale )( 
            IAxis * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MaximumScaleIsAuto )( 
            IAxis * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_MaximumScaleIsAuto )( 
            IAxis * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MinimumScale )( 
            IAxis * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_MinimumScale )( 
            IAxis * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MinimumScaleIsAuto )( 
            IAxis * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_MinimumScaleIsAuto )( 
            IAxis * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MinorGridlines )( 
            IAxis * This,
            /* [retval][out] */ Gridlines	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MinorTickMark )( 
            IAxis * This,
            /* [retval][out] */ XlTickMark *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_MinorTickMark )( 
            IAxis * This,
            /* [in] */ XlTickMark RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MinorUnit )( 
            IAxis * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_MinorUnit )( 
            IAxis * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MinorUnitIsAuto )( 
            IAxis * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_MinorUnitIsAuto )( 
            IAxis * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ReversePlotOrder )( 
            IAxis * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ReversePlotOrder )( 
            IAxis * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ScaleType )( 
            IAxis * This,
            /* [retval][out] */ XlScaleType *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ScaleType )( 
            IAxis * This,
            /* [in] */ XlScaleType RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            IAxis * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TickLabelPosition )( 
            IAxis * This,
            /* [retval][out] */ XlTickLabelPosition *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_TickLabelPosition )( 
            IAxis * This,
            /* [in] */ XlTickLabelPosition RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TickLabels )( 
            IAxis * This,
            /* [retval][out] */ TickLabels	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TickLabelSpacing )( 
            IAxis * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_TickLabelSpacing )( 
            IAxis * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TickMarkSpacing )( 
            IAxis * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_TickMarkSpacing )( 
            IAxis * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Type )( 
            IAxis * This,
            /* [retval][out] */ XlAxisType *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Type )( 
            IAxis * This,
            /* [in] */ XlAxisType RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_BaseUnit )( 
            IAxis * This,
            /* [retval][out] */ XlTimeUnit *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_BaseUnit )( 
            IAxis * This,
            /* [in] */ XlTimeUnit RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_BaseUnitIsAuto )( 
            IAxis * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_BaseUnitIsAuto )( 
            IAxis * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MajorUnitScale )( 
            IAxis * This,
            /* [retval][out] */ XlTimeUnit *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_MajorUnitScale )( 
            IAxis * This,
            /* [in] */ XlTimeUnit RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MinorUnitScale )( 
            IAxis * This,
            /* [retval][out] */ XlTimeUnit *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_MinorUnitScale )( 
            IAxis * This,
            /* [in] */ XlTimeUnit RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CategoryType )( 
            IAxis * This,
            /* [retval][out] */ XlCategoryType *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_CategoryType )( 
            IAxis * This,
            /* [in] */ XlCategoryType RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Left )( 
            IAxis * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Top )( 
            IAxis * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Width )( 
            IAxis * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Height )( 
            IAxis * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DisplayUnit )( 
            IAxis * This,
            /* [retval][out] */ XlDisplayUnit *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DisplayUnit )( 
            IAxis * This,
            /* [in] */ XlDisplayUnit RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DisplayUnitCustom )( 
            IAxis * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DisplayUnitCustom )( 
            IAxis * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HasDisplayUnitLabel )( 
            IAxis * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_HasDisplayUnitLabel )( 
            IAxis * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DisplayUnitLabel )( 
            IAxis * This,
            /* [retval][out] */ DisplayUnitLabel	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LogBase )( 
            IAxis * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_LogBase )( 
            IAxis * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TickLabelSpacingIsAuto )( 
            IAxis * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_TickLabelSpacingIsAuto )( 
            IAxis * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Format )( 
            IAxis * This,
            /* [retval][out] */ ChartFormat	**RHS);
        
        END_INTERFACE
    } IAxisVtbl;

    interface IAxis
    {
        CONST_VTBL struct IAxisVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IAxis_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IAxis_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IAxis_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IAxis_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IAxis_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IAxis_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IAxis_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IAxis_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IAxis_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IAxis_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IAxis_get_AxisBetweenCategories(This,RHS)	\
    ( (This)->lpVtbl -> get_AxisBetweenCategories(This,RHS) ) 

#define IAxis_put_AxisBetweenCategories(This,RHS)	\
    ( (This)->lpVtbl -> put_AxisBetweenCategories(This,RHS) ) 

#define IAxis_get_AxisGroup(This,RHS)	\
    ( (This)->lpVtbl -> get_AxisGroup(This,RHS) ) 

#define IAxis_get_AxisTitle(This,RHS)	\
    ( (This)->lpVtbl -> get_AxisTitle(This,RHS) ) 

#define IAxis_get_Border(This,RHS)	\
    ( (This)->lpVtbl -> get_Border(This,RHS) ) 

#define IAxis_get_CategoryNames(This,RHS)	\
    ( (This)->lpVtbl -> get_CategoryNames(This,RHS) ) 

#define IAxis_put_CategoryNames(This,RHS)	\
    ( (This)->lpVtbl -> put_CategoryNames(This,RHS) ) 

#define IAxis_get_Crosses(This,RHS)	\
    ( (This)->lpVtbl -> get_Crosses(This,RHS) ) 

#define IAxis_put_Crosses(This,RHS)	\
    ( (This)->lpVtbl -> put_Crosses(This,RHS) ) 

#define IAxis_get_CrossesAt(This,RHS)	\
    ( (This)->lpVtbl -> get_CrossesAt(This,RHS) ) 

#define IAxis_put_CrossesAt(This,RHS)	\
    ( (This)->lpVtbl -> put_CrossesAt(This,RHS) ) 

#define IAxis_Delete(This,RHS)	\
    ( (This)->lpVtbl -> Delete(This,RHS) ) 

#define IAxis_get_HasMajorGridlines(This,RHS)	\
    ( (This)->lpVtbl -> get_HasMajorGridlines(This,RHS) ) 

#define IAxis_put_HasMajorGridlines(This,RHS)	\
    ( (This)->lpVtbl -> put_HasMajorGridlines(This,RHS) ) 

#define IAxis_get_HasMinorGridlines(This,RHS)	\
    ( (This)->lpVtbl -> get_HasMinorGridlines(This,RHS) ) 

#define IAxis_put_HasMinorGridlines(This,RHS)	\
    ( (This)->lpVtbl -> put_HasMinorGridlines(This,RHS) ) 

#define IAxis_get_HasTitle(This,RHS)	\
    ( (This)->lpVtbl -> get_HasTitle(This,RHS) ) 

#define IAxis_put_HasTitle(This,RHS)	\
    ( (This)->lpVtbl -> put_HasTitle(This,RHS) ) 

#define IAxis_get_MajorGridlines(This,RHS)	\
    ( (This)->lpVtbl -> get_MajorGridlines(This,RHS) ) 

#define IAxis_get_MajorTickMark(This,RHS)	\
    ( (This)->lpVtbl -> get_MajorTickMark(This,RHS) ) 

#define IAxis_put_MajorTickMark(This,RHS)	\
    ( (This)->lpVtbl -> put_MajorTickMark(This,RHS) ) 

#define IAxis_get_MajorUnit(This,RHS)	\
    ( (This)->lpVtbl -> get_MajorUnit(This,RHS) ) 

#define IAxis_put_MajorUnit(This,RHS)	\
    ( (This)->lpVtbl -> put_MajorUnit(This,RHS) ) 

#define IAxis_get_MajorUnitIsAuto(This,RHS)	\
    ( (This)->lpVtbl -> get_MajorUnitIsAuto(This,RHS) ) 

#define IAxis_put_MajorUnitIsAuto(This,RHS)	\
    ( (This)->lpVtbl -> put_MajorUnitIsAuto(This,RHS) ) 

#define IAxis_get_MaximumScale(This,RHS)	\
    ( (This)->lpVtbl -> get_MaximumScale(This,RHS) ) 

#define IAxis_put_MaximumScale(This,RHS)	\
    ( (This)->lpVtbl -> put_MaximumScale(This,RHS) ) 

#define IAxis_get_MaximumScaleIsAuto(This,RHS)	\
    ( (This)->lpVtbl -> get_MaximumScaleIsAuto(This,RHS) ) 

#define IAxis_put_MaximumScaleIsAuto(This,RHS)	\
    ( (This)->lpVtbl -> put_MaximumScaleIsAuto(This,RHS) ) 

#define IAxis_get_MinimumScale(This,RHS)	\
    ( (This)->lpVtbl -> get_MinimumScale(This,RHS) ) 

#define IAxis_put_MinimumScale(This,RHS)	\
    ( (This)->lpVtbl -> put_MinimumScale(This,RHS) ) 

#define IAxis_get_MinimumScaleIsAuto(This,RHS)	\
    ( (This)->lpVtbl -> get_MinimumScaleIsAuto(This,RHS) ) 

#define IAxis_put_MinimumScaleIsAuto(This,RHS)	\
    ( (This)->lpVtbl -> put_MinimumScaleIsAuto(This,RHS) ) 

#define IAxis_get_MinorGridlines(This,RHS)	\
    ( (This)->lpVtbl -> get_MinorGridlines(This,RHS) ) 

#define IAxis_get_MinorTickMark(This,RHS)	\
    ( (This)->lpVtbl -> get_MinorTickMark(This,RHS) ) 

#define IAxis_put_MinorTickMark(This,RHS)	\
    ( (This)->lpVtbl -> put_MinorTickMark(This,RHS) ) 

#define IAxis_get_MinorUnit(This,RHS)	\
    ( (This)->lpVtbl -> get_MinorUnit(This,RHS) ) 

#define IAxis_put_MinorUnit(This,RHS)	\
    ( (This)->lpVtbl -> put_MinorUnit(This,RHS) ) 

#define IAxis_get_MinorUnitIsAuto(This,RHS)	\
    ( (This)->lpVtbl -> get_MinorUnitIsAuto(This,RHS) ) 

#define IAxis_put_MinorUnitIsAuto(This,RHS)	\
    ( (This)->lpVtbl -> put_MinorUnitIsAuto(This,RHS) ) 

#define IAxis_get_ReversePlotOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_ReversePlotOrder(This,RHS) ) 

#define IAxis_put_ReversePlotOrder(This,RHS)	\
    ( (This)->lpVtbl -> put_ReversePlotOrder(This,RHS) ) 

#define IAxis_get_ScaleType(This,RHS)	\
    ( (This)->lpVtbl -> get_ScaleType(This,RHS) ) 

#define IAxis_put_ScaleType(This,RHS)	\
    ( (This)->lpVtbl -> put_ScaleType(This,RHS) ) 

#define IAxis_Select(This,RHS)	\
    ( (This)->lpVtbl -> Select(This,RHS) ) 

#define IAxis_get_TickLabelPosition(This,RHS)	\
    ( (This)->lpVtbl -> get_TickLabelPosition(This,RHS) ) 

#define IAxis_put_TickLabelPosition(This,RHS)	\
    ( (This)->lpVtbl -> put_TickLabelPosition(This,RHS) ) 

#define IAxis_get_TickLabels(This,RHS)	\
    ( (This)->lpVtbl -> get_TickLabels(This,RHS) ) 

#define IAxis_get_TickLabelSpacing(This,RHS)	\
    ( (This)->lpVtbl -> get_TickLabelSpacing(This,RHS) ) 

#define IAxis_put_TickLabelSpacing(This,RHS)	\
    ( (This)->lpVtbl -> put_TickLabelSpacing(This,RHS) ) 

#define IAxis_get_TickMarkSpacing(This,RHS)	\
    ( (This)->lpVtbl -> get_TickMarkSpacing(This,RHS) ) 

#define IAxis_put_TickMarkSpacing(This,RHS)	\
    ( (This)->lpVtbl -> put_TickMarkSpacing(This,RHS) ) 

#define IAxis_get_Type(This,RHS)	\
    ( (This)->lpVtbl -> get_Type(This,RHS) ) 

#define IAxis_put_Type(This,RHS)	\
    ( (This)->lpVtbl -> put_Type(This,RHS) ) 

#define IAxis_get_BaseUnit(This,RHS)	\
    ( (This)->lpVtbl -> get_BaseUnit(This,RHS) ) 

#define IAxis_put_BaseUnit(This,RHS)	\
    ( (This)->lpVtbl -> put_BaseUnit(This,RHS) ) 

#define IAxis_get_BaseUnitIsAuto(This,RHS)	\
    ( (This)->lpVtbl -> get_BaseUnitIsAuto(This,RHS) ) 

#define IAxis_put_BaseUnitIsAuto(This,RHS)	\
    ( (This)->lpVtbl -> put_BaseUnitIsAuto(This,RHS) ) 

#define IAxis_get_MajorUnitScale(This,RHS)	\
    ( (This)->lpVtbl -> get_MajorUnitScale(This,RHS) ) 

#define IAxis_put_MajorUnitScale(This,RHS)	\
    ( (This)->lpVtbl -> put_MajorUnitScale(This,RHS) ) 

#define IAxis_get_MinorUnitScale(This,RHS)	\
    ( (This)->lpVtbl -> get_MinorUnitScale(This,RHS) ) 

#define IAxis_put_MinorUnitScale(This,RHS)	\
    ( (This)->lpVtbl -> put_MinorUnitScale(This,RHS) ) 

#define IAxis_get_CategoryType(This,RHS)	\
    ( (This)->lpVtbl -> get_CategoryType(This,RHS) ) 

#define IAxis_put_CategoryType(This,RHS)	\
    ( (This)->lpVtbl -> put_CategoryType(This,RHS) ) 

#define IAxis_get_Left(This,RHS)	\
    ( (This)->lpVtbl -> get_Left(This,RHS) ) 

#define IAxis_get_Top(This,RHS)	\
    ( (This)->lpVtbl -> get_Top(This,RHS) ) 

#define IAxis_get_Width(This,RHS)	\
    ( (This)->lpVtbl -> get_Width(This,RHS) ) 

#define IAxis_get_Height(This,RHS)	\
    ( (This)->lpVtbl -> get_Height(This,RHS) ) 

#define IAxis_get_DisplayUnit(This,RHS)	\
    ( (This)->lpVtbl -> get_DisplayUnit(This,RHS) ) 

#define IAxis_put_DisplayUnit(This,RHS)	\
    ( (This)->lpVtbl -> put_DisplayUnit(This,RHS) ) 

#define IAxis_get_DisplayUnitCustom(This,RHS)	\
    ( (This)->lpVtbl -> get_DisplayUnitCustom(This,RHS) ) 

#define IAxis_put_DisplayUnitCustom(This,RHS)	\
    ( (This)->lpVtbl -> put_DisplayUnitCustom(This,RHS) ) 

#define IAxis_get_HasDisplayUnitLabel(This,RHS)	\
    ( (This)->lpVtbl -> get_HasDisplayUnitLabel(This,RHS) ) 

#define IAxis_put_HasDisplayUnitLabel(This,RHS)	\
    ( (This)->lpVtbl -> put_HasDisplayUnitLabel(This,RHS) ) 

#define IAxis_get_DisplayUnitLabel(This,RHS)	\
    ( (This)->lpVtbl -> get_DisplayUnitLabel(This,RHS) ) 

#define IAxis_get_LogBase(This,RHS)	\
    ( (This)->lpVtbl -> get_LogBase(This,RHS) ) 

#define IAxis_put_LogBase(This,RHS)	\
    ( (This)->lpVtbl -> put_LogBase(This,RHS) ) 

#define IAxis_get_TickLabelSpacingIsAuto(This,RHS)	\
    ( (This)->lpVtbl -> get_TickLabelSpacingIsAuto(This,RHS) ) 

#define IAxis_put_TickLabelSpacingIsAuto(This,RHS)	\
    ( (This)->lpVtbl -> put_TickLabelSpacingIsAuto(This,RHS) ) 

#define IAxis_get_Format(This,RHS)	\
    ( (This)->lpVtbl -> get_Format(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IAxis_INTERFACE_DEFINED__ */


#ifndef __IChartTitle_INTERFACE_DEFINED__
#define __IChartTitle_INTERFACE_DEFINED__

/* interface IChartTitle */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IChartTitle;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00020849-0001-0000-C000-000000000046")
    IChartTitle : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Border( 
            /* [retval][out] */ Border	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Interior( 
            /* [retval][out] */ Interior	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Fill( 
            /* [retval][out] */ ChartFillFormat	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Caption( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Caption( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Characters( 
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Length,
            /* [retval][out] */ Characters	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Font( 
            /* [retval][out] */ Font	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HorizontalAlignment( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_HorizontalAlignment( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Left( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Left( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Orientation( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Orientation( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Shadow( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Shadow( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Text( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Text( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Top( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Top( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_VerticalAlignment( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_VerticalAlignment( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ReadingOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ReadingOrder( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_AutoScaleFont( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_AutoScaleFont( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_IncludeInLayout( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_IncludeInLayout( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Position( 
            /* [retval][out] */ XlChartElementPosition *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Position( 
            /* [in] */ XlChartElementPosition RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Format( 
            /* [retval][out] */ ChartFormat	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Height( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Width( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Formula( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Formula( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_FormulaR1C1( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_FormulaR1C1( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_FormulaLocal( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_FormulaLocal( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_FormulaR1C1Local( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_FormulaR1C1Local( 
            /* [in] */ BSTR RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IChartTitleVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IChartTitle * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IChartTitle * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IChartTitle * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IChartTitle * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IChartTitle * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IChartTitle * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IChartTitle * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IChartTitle * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IChartTitle * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IChartTitle * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            IChartTitle * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            IChartTitle * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Border )( 
            IChartTitle * This,
            /* [retval][out] */ Border	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IChartTitle * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Interior )( 
            IChartTitle * This,
            /* [retval][out] */ Interior	**RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Fill )( 
            IChartTitle * This,
            /* [retval][out] */ ChartFillFormat	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Caption )( 
            IChartTitle * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Caption )( 
            IChartTitle * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Characters )( 
            IChartTitle * This,
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Length,
            /* [retval][out] */ Characters	**RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Font )( 
            IChartTitle * This,
            /* [retval][out] */ Font	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HorizontalAlignment )( 
            IChartTitle * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_HorizontalAlignment )( 
            IChartTitle * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Left )( 
            IChartTitle * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Left )( 
            IChartTitle * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Orientation )( 
            IChartTitle * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Orientation )( 
            IChartTitle * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Shadow )( 
            IChartTitle * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Shadow )( 
            IChartTitle * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Text )( 
            IChartTitle * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Text )( 
            IChartTitle * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Top )( 
            IChartTitle * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Top )( 
            IChartTitle * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_VerticalAlignment )( 
            IChartTitle * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_VerticalAlignment )( 
            IChartTitle * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ReadingOrder )( 
            IChartTitle * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ReadingOrder )( 
            IChartTitle * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_AutoScaleFont )( 
            IChartTitle * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_AutoScaleFont )( 
            IChartTitle * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_IncludeInLayout )( 
            IChartTitle * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_IncludeInLayout )( 
            IChartTitle * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Position )( 
            IChartTitle * This,
            /* [retval][out] */ XlChartElementPosition *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Position )( 
            IChartTitle * This,
            /* [in] */ XlChartElementPosition RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Format )( 
            IChartTitle * This,
            /* [retval][out] */ ChartFormat	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Height )( 
            IChartTitle * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Width )( 
            IChartTitle * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Formula )( 
            IChartTitle * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Formula )( 
            IChartTitle * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_FormulaR1C1 )( 
            IChartTitle * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_FormulaR1C1 )( 
            IChartTitle * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_FormulaLocal )( 
            IChartTitle * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_FormulaLocal )( 
            IChartTitle * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_FormulaR1C1Local )( 
            IChartTitle * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_FormulaR1C1Local )( 
            IChartTitle * This,
            /* [in] */ BSTR RHS);
        
        END_INTERFACE
    } IChartTitleVtbl;

    interface IChartTitle
    {
        CONST_VTBL struct IChartTitleVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IChartTitle_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IChartTitle_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IChartTitle_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IChartTitle_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IChartTitle_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IChartTitle_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IChartTitle_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IChartTitle_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IChartTitle_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IChartTitle_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IChartTitle_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define IChartTitle_Select(This,RHS)	\
    ( (This)->lpVtbl -> Select(This,RHS) ) 

#define IChartTitle_get_Border(This,RHS)	\
    ( (This)->lpVtbl -> get_Border(This,RHS) ) 

#define IChartTitle_Delete(This,RHS)	\
    ( (This)->lpVtbl -> Delete(This,RHS) ) 

#define IChartTitle_get_Interior(This,RHS)	\
    ( (This)->lpVtbl -> get_Interior(This,RHS) ) 

#define IChartTitle_get_Fill(This,RHS)	\
    ( (This)->lpVtbl -> get_Fill(This,RHS) ) 

#define IChartTitle_get_Caption(This,RHS)	\
    ( (This)->lpVtbl -> get_Caption(This,RHS) ) 

#define IChartTitle_put_Caption(This,RHS)	\
    ( (This)->lpVtbl -> put_Caption(This,RHS) ) 

#define IChartTitle_get_Characters(This,Start,Length,RHS)	\
    ( (This)->lpVtbl -> get_Characters(This,Start,Length,RHS) ) 

#define IChartTitle_get_Font(This,RHS)	\
    ( (This)->lpVtbl -> get_Font(This,RHS) ) 

#define IChartTitle_get_HorizontalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> get_HorizontalAlignment(This,RHS) ) 

#define IChartTitle_put_HorizontalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> put_HorizontalAlignment(This,RHS) ) 

#define IChartTitle_get_Left(This,RHS)	\
    ( (This)->lpVtbl -> get_Left(This,RHS) ) 

#define IChartTitle_put_Left(This,RHS)	\
    ( (This)->lpVtbl -> put_Left(This,RHS) ) 

#define IChartTitle_get_Orientation(This,RHS)	\
    ( (This)->lpVtbl -> get_Orientation(This,RHS) ) 

#define IChartTitle_put_Orientation(This,RHS)	\
    ( (This)->lpVtbl -> put_Orientation(This,RHS) ) 

#define IChartTitle_get_Shadow(This,RHS)	\
    ( (This)->lpVtbl -> get_Shadow(This,RHS) ) 

#define IChartTitle_put_Shadow(This,RHS)	\
    ( (This)->lpVtbl -> put_Shadow(This,RHS) ) 

#define IChartTitle_get_Text(This,RHS)	\
    ( (This)->lpVtbl -> get_Text(This,RHS) ) 

#define IChartTitle_put_Text(This,RHS)	\
    ( (This)->lpVtbl -> put_Text(This,RHS) ) 

#define IChartTitle_get_Top(This,RHS)	\
    ( (This)->lpVtbl -> get_Top(This,RHS) ) 

#define IChartTitle_put_Top(This,RHS)	\
    ( (This)->lpVtbl -> put_Top(This,RHS) ) 

#define IChartTitle_get_VerticalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> get_VerticalAlignment(This,RHS) ) 

#define IChartTitle_put_VerticalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> put_VerticalAlignment(This,RHS) ) 

#define IChartTitle_get_ReadingOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_ReadingOrder(This,RHS) ) 

#define IChartTitle_put_ReadingOrder(This,RHS)	\
    ( (This)->lpVtbl -> put_ReadingOrder(This,RHS) ) 

#define IChartTitle_get_AutoScaleFont(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoScaleFont(This,RHS) ) 

#define IChartTitle_put_AutoScaleFont(This,RHS)	\
    ( (This)->lpVtbl -> put_AutoScaleFont(This,RHS) ) 

#define IChartTitle_get_IncludeInLayout(This,RHS)	\
    ( (This)->lpVtbl -> get_IncludeInLayout(This,RHS) ) 

#define IChartTitle_put_IncludeInLayout(This,RHS)	\
    ( (This)->lpVtbl -> put_IncludeInLayout(This,RHS) ) 

#define IChartTitle_get_Position(This,RHS)	\
    ( (This)->lpVtbl -> get_Position(This,RHS) ) 

#define IChartTitle_put_Position(This,RHS)	\
    ( (This)->lpVtbl -> put_Position(This,RHS) ) 

#define IChartTitle_get_Format(This,RHS)	\
    ( (This)->lpVtbl -> get_Format(This,RHS) ) 

#define IChartTitle_get_Height(This,RHS)	\
    ( (This)->lpVtbl -> get_Height(This,RHS) ) 

#define IChartTitle_get_Width(This,RHS)	\
    ( (This)->lpVtbl -> get_Width(This,RHS) ) 

#define IChartTitle_get_Formula(This,RHS)	\
    ( (This)->lpVtbl -> get_Formula(This,RHS) ) 

#define IChartTitle_put_Formula(This,RHS)	\
    ( (This)->lpVtbl -> put_Formula(This,RHS) ) 

#define IChartTitle_get_FormulaR1C1(This,RHS)	\
    ( (This)->lpVtbl -> get_FormulaR1C1(This,RHS) ) 

#define IChartTitle_put_FormulaR1C1(This,RHS)	\
    ( (This)->lpVtbl -> put_FormulaR1C1(This,RHS) ) 

#define IChartTitle_get_FormulaLocal(This,RHS)	\
    ( (This)->lpVtbl -> get_FormulaLocal(This,RHS) ) 

#define IChartTitle_put_FormulaLocal(This,RHS)	\
    ( (This)->lpVtbl -> put_FormulaLocal(This,RHS) ) 

#define IChartTitle_get_FormulaR1C1Local(This,RHS)	\
    ( (This)->lpVtbl -> get_FormulaR1C1Local(This,RHS) ) 

#define IChartTitle_put_FormulaR1C1Local(This,RHS)	\
    ( (This)->lpVtbl -> put_FormulaR1C1Local(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IChartTitle_INTERFACE_DEFINED__ */


#ifndef __IAxisTitle_INTERFACE_DEFINED__
#define __IAxisTitle_INTERFACE_DEFINED__

/* interface IAxisTitle */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IAxisTitle;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002084A-0001-0000-C000-000000000046")
    IAxisTitle : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Border( 
            /* [retval][out] */ Border	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Interior( 
            /* [retval][out] */ Interior	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Fill( 
            /* [retval][out] */ ChartFillFormat	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Caption( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Caption( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Characters( 
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Length,
            /* [retval][out] */ Characters	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Font( 
            /* [retval][out] */ Font	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HorizontalAlignment( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_HorizontalAlignment( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Left( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Left( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Orientation( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Orientation( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Shadow( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Shadow( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Text( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Text( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Top( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Top( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_VerticalAlignment( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_VerticalAlignment( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ReadingOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ReadingOrder( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_AutoScaleFont( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_AutoScaleFont( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_IncludeInLayout( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_IncludeInLayout( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Position( 
            /* [retval][out] */ XlChartElementPosition *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Position( 
            /* [in] */ XlChartElementPosition RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Format( 
            /* [retval][out] */ ChartFormat	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Height( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Width( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Formula( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Formula( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_FormulaR1C1( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_FormulaR1C1( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_FormulaLocal( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_FormulaLocal( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_FormulaR1C1Local( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_FormulaR1C1Local( 
            /* [in] */ BSTR RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IAxisTitleVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IAxisTitle * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IAxisTitle * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IAxisTitle * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IAxisTitle * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IAxisTitle * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IAxisTitle * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IAxisTitle * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IAxisTitle * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IAxisTitle * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IAxisTitle * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            IAxisTitle * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            IAxisTitle * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Border )( 
            IAxisTitle * This,
            /* [retval][out] */ Border	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IAxisTitle * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Interior )( 
            IAxisTitle * This,
            /* [retval][out] */ Interior	**RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Fill )( 
            IAxisTitle * This,
            /* [retval][out] */ ChartFillFormat	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Caption )( 
            IAxisTitle * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Caption )( 
            IAxisTitle * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Characters )( 
            IAxisTitle * This,
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Length,
            /* [retval][out] */ Characters	**RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Font )( 
            IAxisTitle * This,
            /* [retval][out] */ Font	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HorizontalAlignment )( 
            IAxisTitle * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_HorizontalAlignment )( 
            IAxisTitle * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Left )( 
            IAxisTitle * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Left )( 
            IAxisTitle * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Orientation )( 
            IAxisTitle * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Orientation )( 
            IAxisTitle * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Shadow )( 
            IAxisTitle * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Shadow )( 
            IAxisTitle * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Text )( 
            IAxisTitle * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Text )( 
            IAxisTitle * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Top )( 
            IAxisTitle * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Top )( 
            IAxisTitle * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_VerticalAlignment )( 
            IAxisTitle * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_VerticalAlignment )( 
            IAxisTitle * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ReadingOrder )( 
            IAxisTitle * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ReadingOrder )( 
            IAxisTitle * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_AutoScaleFont )( 
            IAxisTitle * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_AutoScaleFont )( 
            IAxisTitle * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_IncludeInLayout )( 
            IAxisTitle * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_IncludeInLayout )( 
            IAxisTitle * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Position )( 
            IAxisTitle * This,
            /* [retval][out] */ XlChartElementPosition *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Position )( 
            IAxisTitle * This,
            /* [in] */ XlChartElementPosition RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Format )( 
            IAxisTitle * This,
            /* [retval][out] */ ChartFormat	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Height )( 
            IAxisTitle * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Width )( 
            IAxisTitle * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Formula )( 
            IAxisTitle * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Formula )( 
            IAxisTitle * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_FormulaR1C1 )( 
            IAxisTitle * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_FormulaR1C1 )( 
            IAxisTitle * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_FormulaLocal )( 
            IAxisTitle * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_FormulaLocal )( 
            IAxisTitle * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_FormulaR1C1Local )( 
            IAxisTitle * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_FormulaR1C1Local )( 
            IAxisTitle * This,
            /* [in] */ BSTR RHS);
        
        END_INTERFACE
    } IAxisTitleVtbl;

    interface IAxisTitle
    {
        CONST_VTBL struct IAxisTitleVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IAxisTitle_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IAxisTitle_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IAxisTitle_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IAxisTitle_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IAxisTitle_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IAxisTitle_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IAxisTitle_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IAxisTitle_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IAxisTitle_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IAxisTitle_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IAxisTitle_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define IAxisTitle_Select(This,RHS)	\
    ( (This)->lpVtbl -> Select(This,RHS) ) 

#define IAxisTitle_get_Border(This,RHS)	\
    ( (This)->lpVtbl -> get_Border(This,RHS) ) 

#define IAxisTitle_Delete(This,RHS)	\
    ( (This)->lpVtbl -> Delete(This,RHS) ) 

#define IAxisTitle_get_Interior(This,RHS)	\
    ( (This)->lpVtbl -> get_Interior(This,RHS) ) 

#define IAxisTitle_get_Fill(This,RHS)	\
    ( (This)->lpVtbl -> get_Fill(This,RHS) ) 

#define IAxisTitle_get_Caption(This,RHS)	\
    ( (This)->lpVtbl -> get_Caption(This,RHS) ) 

#define IAxisTitle_put_Caption(This,RHS)	\
    ( (This)->lpVtbl -> put_Caption(This,RHS) ) 

#define IAxisTitle_get_Characters(This,Start,Length,RHS)	\
    ( (This)->lpVtbl -> get_Characters(This,Start,Length,RHS) ) 

#define IAxisTitle_get_Font(This,RHS)	\
    ( (This)->lpVtbl -> get_Font(This,RHS) ) 

#define IAxisTitle_get_HorizontalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> get_HorizontalAlignment(This,RHS) ) 

#define IAxisTitle_put_HorizontalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> put_HorizontalAlignment(This,RHS) ) 

#define IAxisTitle_get_Left(This,RHS)	\
    ( (This)->lpVtbl -> get_Left(This,RHS) ) 

#define IAxisTitle_put_Left(This,RHS)	\
    ( (This)->lpVtbl -> put_Left(This,RHS) ) 

#define IAxisTitle_get_Orientation(This,RHS)	\
    ( (This)->lpVtbl -> get_Orientation(This,RHS) ) 

#define IAxisTitle_put_Orientation(This,RHS)	\
    ( (This)->lpVtbl -> put_Orientation(This,RHS) ) 

#define IAxisTitle_get_Shadow(This,RHS)	\
    ( (This)->lpVtbl -> get_Shadow(This,RHS) ) 

#define IAxisTitle_put_Shadow(This,RHS)	\
    ( (This)->lpVtbl -> put_Shadow(This,RHS) ) 

#define IAxisTitle_get_Text(This,RHS)	\
    ( (This)->lpVtbl -> get_Text(This,RHS) ) 

#define IAxisTitle_put_Text(This,RHS)	\
    ( (This)->lpVtbl -> put_Text(This,RHS) ) 

#define IAxisTitle_get_Top(This,RHS)	\
    ( (This)->lpVtbl -> get_Top(This,RHS) ) 

#define IAxisTitle_put_Top(This,RHS)	\
    ( (This)->lpVtbl -> put_Top(This,RHS) ) 

#define IAxisTitle_get_VerticalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> get_VerticalAlignment(This,RHS) ) 

#define IAxisTitle_put_VerticalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> put_VerticalAlignment(This,RHS) ) 

#define IAxisTitle_get_ReadingOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_ReadingOrder(This,RHS) ) 

#define IAxisTitle_put_ReadingOrder(This,RHS)	\
    ( (This)->lpVtbl -> put_ReadingOrder(This,RHS) ) 

#define IAxisTitle_get_AutoScaleFont(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoScaleFont(This,RHS) ) 

#define IAxisTitle_put_AutoScaleFont(This,RHS)	\
    ( (This)->lpVtbl -> put_AutoScaleFont(This,RHS) ) 

#define IAxisTitle_get_IncludeInLayout(This,RHS)	\
    ( (This)->lpVtbl -> get_IncludeInLayout(This,RHS) ) 

#define IAxisTitle_put_IncludeInLayout(This,RHS)	\
    ( (This)->lpVtbl -> put_IncludeInLayout(This,RHS) ) 

#define IAxisTitle_get_Position(This,RHS)	\
    ( (This)->lpVtbl -> get_Position(This,RHS) ) 

#define IAxisTitle_put_Position(This,RHS)	\
    ( (This)->lpVtbl -> put_Position(This,RHS) ) 

#define IAxisTitle_get_Format(This,RHS)	\
    ( (This)->lpVtbl -> get_Format(This,RHS) ) 

#define IAxisTitle_get_Height(This,RHS)	\
    ( (This)->lpVtbl -> get_Height(This,RHS) ) 

#define IAxisTitle_get_Width(This,RHS)	\
    ( (This)->lpVtbl -> get_Width(This,RHS) ) 

#define IAxisTitle_get_Formula(This,RHS)	\
    ( (This)->lpVtbl -> get_Formula(This,RHS) ) 

#define IAxisTitle_put_Formula(This,RHS)	\
    ( (This)->lpVtbl -> put_Formula(This,RHS) ) 

#define IAxisTitle_get_FormulaR1C1(This,RHS)	\
    ( (This)->lpVtbl -> get_FormulaR1C1(This,RHS) ) 

#define IAxisTitle_put_FormulaR1C1(This,RHS)	\
    ( (This)->lpVtbl -> put_FormulaR1C1(This,RHS) ) 

#define IAxisTitle_get_FormulaLocal(This,RHS)	\
    ( (This)->lpVtbl -> get_FormulaLocal(This,RHS) ) 

#define IAxisTitle_put_FormulaLocal(This,RHS)	\
    ( (This)->lpVtbl -> put_FormulaLocal(This,RHS) ) 

#define IAxisTitle_get_FormulaR1C1Local(This,RHS)	\
    ( (This)->lpVtbl -> get_FormulaR1C1Local(This,RHS) ) 

#define IAxisTitle_put_FormulaR1C1Local(This,RHS)	\
    ( (This)->lpVtbl -> put_FormulaR1C1Local(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IAxisTitle_INTERFACE_DEFINED__ */


#ifndef __IChartGroup_INTERFACE_DEFINED__
#define __IChartGroup_INTERFACE_DEFINED__

/* interface IChartGroup */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IChartGroup;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00020859-0001-0000-C000-000000000046")
    IChartGroup : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AxisGroup( 
            /* [retval][out] */ XlAxisGroup *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AxisGroup( 
            /* [in] */ XlAxisGroup RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DoughnutHoleSize( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DoughnutHoleSize( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DownBars( 
            /* [retval][out] */ DownBars	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DropLines( 
            /* [retval][out] */ DropLines	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_FirstSliceAngle( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_FirstSliceAngle( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_GapWidth( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_GapWidth( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HasDropLines( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_HasDropLines( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HasHiLoLines( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_HasHiLoLines( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HasRadarAxisLabels( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_HasRadarAxisLabels( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HasSeriesLines( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_HasSeriesLines( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HasUpDownBars( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_HasUpDownBars( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HiLoLines( 
            /* [retval][out] */ HiLoLines	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Index( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Overlap( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Overlap( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RadarAxisLabels( 
            /* [retval][out] */ TickLabels	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SeriesCollection( 
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SeriesLines( 
            /* [retval][out] */ SeriesLines	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_SubType( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_SubType( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Type( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_Type( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_UpBars( 
            /* [retval][out] */ UpBars	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_VaryByCategories( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_VaryByCategories( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SizeRepresents( 
            /* [retval][out] */ XlSizeRepresents *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_SizeRepresents( 
            /* [in] */ XlSizeRepresents RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_BubbleScale( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_BubbleScale( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShowNegativeBubbles( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ShowNegativeBubbles( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SplitType( 
            /* [retval][out] */ XlChartSplitType *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_SplitType( 
            /* [in] */ XlChartSplitType RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SplitValue( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_SplitValue( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SecondPlotSize( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_SecondPlotSize( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Has3DShading( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Has3DShading( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall FullCategoryCollection( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CategoryCollection( 
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IChartGroupVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IChartGroup * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IChartGroup * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IChartGroup * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IChartGroup * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IChartGroup * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IChartGroup * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IChartGroup * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IChartGroup * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IChartGroup * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IChartGroup * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AxisGroup )( 
            IChartGroup * This,
            /* [retval][out] */ XlAxisGroup *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AxisGroup )( 
            IChartGroup * This,
            /* [in] */ XlAxisGroup RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DoughnutHoleSize )( 
            IChartGroup * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DoughnutHoleSize )( 
            IChartGroup * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DownBars )( 
            IChartGroup * This,
            /* [retval][out] */ DownBars	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DropLines )( 
            IChartGroup * This,
            /* [retval][out] */ DropLines	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_FirstSliceAngle )( 
            IChartGroup * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_FirstSliceAngle )( 
            IChartGroup * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_GapWidth )( 
            IChartGroup * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_GapWidth )( 
            IChartGroup * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HasDropLines )( 
            IChartGroup * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_HasDropLines )( 
            IChartGroup * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HasHiLoLines )( 
            IChartGroup * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_HasHiLoLines )( 
            IChartGroup * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HasRadarAxisLabels )( 
            IChartGroup * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_HasRadarAxisLabels )( 
            IChartGroup * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HasSeriesLines )( 
            IChartGroup * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_HasSeriesLines )( 
            IChartGroup * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HasUpDownBars )( 
            IChartGroup * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_HasUpDownBars )( 
            IChartGroup * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HiLoLines )( 
            IChartGroup * This,
            /* [retval][out] */ HiLoLines	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Index )( 
            IChartGroup * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Overlap )( 
            IChartGroup * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Overlap )( 
            IChartGroup * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RadarAxisLabels )( 
            IChartGroup * This,
            /* [retval][out] */ TickLabels	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SeriesCollection )( 
            IChartGroup * This,
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SeriesLines )( 
            IChartGroup * This,
            /* [retval][out] */ SeriesLines	**RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_SubType )( 
            IChartGroup * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_SubType )( 
            IChartGroup * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Type )( 
            IChartGroup * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_Type )( 
            IChartGroup * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_UpBars )( 
            IChartGroup * This,
            /* [retval][out] */ UpBars	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_VaryByCategories )( 
            IChartGroup * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_VaryByCategories )( 
            IChartGroup * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SizeRepresents )( 
            IChartGroup * This,
            /* [retval][out] */ XlSizeRepresents *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_SizeRepresents )( 
            IChartGroup * This,
            /* [in] */ XlSizeRepresents RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_BubbleScale )( 
            IChartGroup * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_BubbleScale )( 
            IChartGroup * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShowNegativeBubbles )( 
            IChartGroup * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ShowNegativeBubbles )( 
            IChartGroup * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SplitType )( 
            IChartGroup * This,
            /* [retval][out] */ XlChartSplitType *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_SplitType )( 
            IChartGroup * This,
            /* [in] */ XlChartSplitType RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SplitValue )( 
            IChartGroup * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_SplitValue )( 
            IChartGroup * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SecondPlotSize )( 
            IChartGroup * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_SecondPlotSize )( 
            IChartGroup * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Has3DShading )( 
            IChartGroup * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Has3DShading )( 
            IChartGroup * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *FullCategoryCollection )( 
            IChartGroup * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CategoryCollection )( 
            IChartGroup * This,
            /* [optional][in] */ VARIANT Index,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ IDispatch **RHS);
        
        END_INTERFACE
    } IChartGroupVtbl;

    interface IChartGroup
    {
        CONST_VTBL struct IChartGroupVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IChartGroup_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IChartGroup_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IChartGroup_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IChartGroup_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IChartGroup_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IChartGroup_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IChartGroup_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IChartGroup_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IChartGroup_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IChartGroup_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IChartGroup_get_AxisGroup(This,RHS)	\
    ( (This)->lpVtbl -> get_AxisGroup(This,RHS) ) 

#define IChartGroup_put_AxisGroup(This,RHS)	\
    ( (This)->lpVtbl -> put_AxisGroup(This,RHS) ) 

#define IChartGroup_get_DoughnutHoleSize(This,RHS)	\
    ( (This)->lpVtbl -> get_DoughnutHoleSize(This,RHS) ) 

#define IChartGroup_put_DoughnutHoleSize(This,RHS)	\
    ( (This)->lpVtbl -> put_DoughnutHoleSize(This,RHS) ) 

#define IChartGroup_get_DownBars(This,RHS)	\
    ( (This)->lpVtbl -> get_DownBars(This,RHS) ) 

#define IChartGroup_get_DropLines(This,RHS)	\
    ( (This)->lpVtbl -> get_DropLines(This,RHS) ) 

#define IChartGroup_get_FirstSliceAngle(This,RHS)	\
    ( (This)->lpVtbl -> get_FirstSliceAngle(This,RHS) ) 

#define IChartGroup_put_FirstSliceAngle(This,RHS)	\
    ( (This)->lpVtbl -> put_FirstSliceAngle(This,RHS) ) 

#define IChartGroup_get_GapWidth(This,RHS)	\
    ( (This)->lpVtbl -> get_GapWidth(This,RHS) ) 

#define IChartGroup_put_GapWidth(This,RHS)	\
    ( (This)->lpVtbl -> put_GapWidth(This,RHS) ) 

#define IChartGroup_get_HasDropLines(This,RHS)	\
    ( (This)->lpVtbl -> get_HasDropLines(This,RHS) ) 

#define IChartGroup_put_HasDropLines(This,RHS)	\
    ( (This)->lpVtbl -> put_HasDropLines(This,RHS) ) 

#define IChartGroup_get_HasHiLoLines(This,RHS)	\
    ( (This)->lpVtbl -> get_HasHiLoLines(This,RHS) ) 

#define IChartGroup_put_HasHiLoLines(This,RHS)	\
    ( (This)->lpVtbl -> put_HasHiLoLines(This,RHS) ) 

#define IChartGroup_get_HasRadarAxisLabels(This,RHS)	\
    ( (This)->lpVtbl -> get_HasRadarAxisLabels(This,RHS) ) 

#define IChartGroup_put_HasRadarAxisLabels(This,RHS)	\
    ( (This)->lpVtbl -> put_HasRadarAxisLabels(This,RHS) ) 

#define IChartGroup_get_HasSeriesLines(This,RHS)	\
    ( (This)->lpVtbl -> get_HasSeriesLines(This,RHS) ) 

#define IChartGroup_put_HasSeriesLines(This,RHS)	\
    ( (This)->lpVtbl -> put_HasSeriesLines(This,RHS) ) 

#define IChartGroup_get_HasUpDownBars(This,RHS)	\
    ( (This)->lpVtbl -> get_HasUpDownBars(This,RHS) ) 

#define IChartGroup_put_HasUpDownBars(This,RHS)	\
    ( (This)->lpVtbl -> put_HasUpDownBars(This,RHS) ) 

#define IChartGroup_get_HiLoLines(This,RHS)	\
    ( (This)->lpVtbl -> get_HiLoLines(This,RHS) ) 

#define IChartGroup_get_Index(This,RHS)	\
    ( (This)->lpVtbl -> get_Index(This,RHS) ) 

#define IChartGroup_get_Overlap(This,RHS)	\
    ( (This)->lpVtbl -> get_Overlap(This,RHS) ) 

#define IChartGroup_put_Overlap(This,RHS)	\
    ( (This)->lpVtbl -> put_Overlap(This,RHS) ) 

#define IChartGroup_get_RadarAxisLabels(This,RHS)	\
    ( (This)->lpVtbl -> get_RadarAxisLabels(This,RHS) ) 

#define IChartGroup_SeriesCollection(This,Index,RHS)	\
    ( (This)->lpVtbl -> SeriesCollection(This,Index,RHS) ) 

#define IChartGroup_get_SeriesLines(This,RHS)	\
    ( (This)->lpVtbl -> get_SeriesLines(This,RHS) ) 

#define IChartGroup_get_SubType(This,RHS)	\
    ( (This)->lpVtbl -> get_SubType(This,RHS) ) 

#define IChartGroup_put_SubType(This,RHS)	\
    ( (This)->lpVtbl -> put_SubType(This,RHS) ) 

#define IChartGroup_get_Type(This,RHS)	\
    ( (This)->lpVtbl -> get_Type(This,RHS) ) 

#define IChartGroup_put_Type(This,RHS)	\
    ( (This)->lpVtbl -> put_Type(This,RHS) ) 

#define IChartGroup_get_UpBars(This,RHS)	\
    ( (This)->lpVtbl -> get_UpBars(This,RHS) ) 

#define IChartGroup_get_VaryByCategories(This,RHS)	\
    ( (This)->lpVtbl -> get_VaryByCategories(This,RHS) ) 

#define IChartGroup_put_VaryByCategories(This,RHS)	\
    ( (This)->lpVtbl -> put_VaryByCategories(This,RHS) ) 

#define IChartGroup_get_SizeRepresents(This,RHS)	\
    ( (This)->lpVtbl -> get_SizeRepresents(This,RHS) ) 

#define IChartGroup_put_SizeRepresents(This,RHS)	\
    ( (This)->lpVtbl -> put_SizeRepresents(This,RHS) ) 

#define IChartGroup_get_BubbleScale(This,RHS)	\
    ( (This)->lpVtbl -> get_BubbleScale(This,RHS) ) 

#define IChartGroup_put_BubbleScale(This,RHS)	\
    ( (This)->lpVtbl -> put_BubbleScale(This,RHS) ) 

#define IChartGroup_get_ShowNegativeBubbles(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowNegativeBubbles(This,RHS) ) 

#define IChartGroup_put_ShowNegativeBubbles(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowNegativeBubbles(This,RHS) ) 

#define IChartGroup_get_SplitType(This,RHS)	\
    ( (This)->lpVtbl -> get_SplitType(This,RHS) ) 

#define IChartGroup_put_SplitType(This,RHS)	\
    ( (This)->lpVtbl -> put_SplitType(This,RHS) ) 

#define IChartGroup_get_SplitValue(This,RHS)	\
    ( (This)->lpVtbl -> get_SplitValue(This,RHS) ) 

#define IChartGroup_put_SplitValue(This,RHS)	\
    ( (This)->lpVtbl -> put_SplitValue(This,RHS) ) 

#define IChartGroup_get_SecondPlotSize(This,RHS)	\
    ( (This)->lpVtbl -> get_SecondPlotSize(This,RHS) ) 

#define IChartGroup_put_SecondPlotSize(This,RHS)	\
    ( (This)->lpVtbl -> put_SecondPlotSize(This,RHS) ) 

#define IChartGroup_get_Has3DShading(This,RHS)	\
    ( (This)->lpVtbl -> get_Has3DShading(This,RHS) ) 

#define IChartGroup_put_Has3DShading(This,RHS)	\
    ( (This)->lpVtbl -> put_Has3DShading(This,RHS) ) 

#define IChartGroup_FullCategoryCollection(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> FullCategoryCollection(This,Index,lcid,RHS) ) 

#define IChartGroup_CategoryCollection(This,Index,lcid,RHS)	\
    ( (This)->lpVtbl -> CategoryCollection(This,Index,lcid,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IChartGroup_INTERFACE_DEFINED__ */


#ifndef __IChartGroups_INTERFACE_DEFINED__
#define __IChartGroups_INTERFACE_DEFINED__

/* interface IChartGroups */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IChartGroups;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002085A-0001-0000-C000-000000000046")
    IChartGroups : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ ChartGroup	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall _NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IChartGroupsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IChartGroups * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IChartGroups * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IChartGroups * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IChartGroups * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IChartGroups * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IChartGroups * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IChartGroups * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IChartGroups * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IChartGroups * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IChartGroups * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IChartGroups * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Item )( 
            IChartGroups * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ ChartGroup	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *_NewEnum )( 
            IChartGroups * This,
            /* [retval][out] */ IUnknown **RHS);
        
        END_INTERFACE
    } IChartGroupsVtbl;

    interface IChartGroups
    {
        CONST_VTBL struct IChartGroupsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IChartGroups_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IChartGroups_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IChartGroups_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IChartGroups_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IChartGroups_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IChartGroups_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IChartGroups_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IChartGroups_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IChartGroups_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IChartGroups_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IChartGroups_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IChartGroups_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> Item(This,Index,RHS) ) 

#define IChartGroups__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> _NewEnum(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IChartGroups_INTERFACE_DEFINED__ */


#ifndef __IAxes_INTERFACE_DEFINED__
#define __IAxes_INTERFACE_DEFINED__

/* interface IAxes */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IAxes;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002085B-0001-0000-C000-000000000046")
    IAxes : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Item( 
            /* [in] */ XlAxisType Type,
            /* [defaultvalue][optional][in] */ XlAxisGroup AxisGroup,
            /* [retval][out] */ Axis	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall _NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall _Default( 
            /* [in] */ XlAxisType Type,
            /* [defaultvalue][optional][in] */ XlAxisGroup AxisGroup,
            /* [retval][out] */ Axis	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IAxesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IAxes * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IAxes * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IAxes * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IAxes * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IAxes * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IAxes * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IAxes * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IAxes * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IAxes * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IAxes * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IAxes * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Item )( 
            IAxes * This,
            /* [in] */ XlAxisType Type,
            /* [defaultvalue][optional][in] */ XlAxisGroup AxisGroup,
            /* [retval][out] */ Axis	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *_NewEnum )( 
            IAxes * This,
            /* [retval][out] */ IUnknown **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *_Default )( 
            IAxes * This,
            /* [in] */ XlAxisType Type,
            /* [defaultvalue][optional][in] */ XlAxisGroup AxisGroup,
            /* [retval][out] */ Axis	**RHS);
        
        END_INTERFACE
    } IAxesVtbl;

    interface IAxes
    {
        CONST_VTBL struct IAxesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IAxes_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IAxes_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IAxes_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IAxes_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IAxes_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IAxes_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IAxes_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IAxes_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IAxes_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IAxes_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IAxes_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IAxes_Item(This,Type,AxisGroup,RHS)	\
    ( (This)->lpVtbl -> Item(This,Type,AxisGroup,RHS) ) 

#define IAxes__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> _NewEnum(This,RHS) ) 

#define IAxes__Default(This,Type,AxisGroup,RHS)	\
    ( (This)->lpVtbl -> _Default(This,Type,AxisGroup,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IAxes_INTERFACE_DEFINED__ */


#ifndef __IPoints_INTERFACE_DEFINED__
#define __IPoints_INTERFACE_DEFINED__

/* interface IPoints */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IPoints;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00020869-0001-0000-C000-000000000046")
    IPoints : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Item( 
            /* [in] */ long Index,
            /* [retval][out] */ Point	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall _NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall _Default( 
            /* [in] */ long Index,
            /* [retval][out] */ Point	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IPointsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IPoints * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IPoints * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IPoints * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IPoints * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IPoints * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IPoints * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IPoints * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IPoints * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IPoints * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IPoints * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IPoints * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Item )( 
            IPoints * This,
            /* [in] */ long Index,
            /* [retval][out] */ Point	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *_NewEnum )( 
            IPoints * This,
            /* [retval][out] */ IUnknown **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *_Default )( 
            IPoints * This,
            /* [in] */ long Index,
            /* [retval][out] */ Point	**RHS);
        
        END_INTERFACE
    } IPointsVtbl;

    interface IPoints
    {
        CONST_VTBL struct IPointsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IPoints_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IPoints_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IPoints_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IPoints_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IPoints_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IPoints_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IPoints_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IPoints_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IPoints_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IPoints_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IPoints_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IPoints_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> Item(This,Index,RHS) ) 

#define IPoints__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> _NewEnum(This,RHS) ) 

#define IPoints__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> _Default(This,Index,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IPoints_INTERFACE_DEFINED__ */


#ifndef __IPoint_INTERFACE_DEFINED__
#define __IPoint_INTERFACE_DEFINED__

/* interface IPoint */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IPoint;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002086A-0001-0000-C000-000000000046")
    IPoint : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall _ApplyDataLabels( 
            /* [defaultvalue][optional][in] */ XlDataLabelsType Type,
            /* [optional][in] */ VARIANT LegendKey,
            /* [optional][in] */ VARIANT AutoText,
            /* [optional][in] */ VARIANT HasLeaderLines,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Border( 
            /* [retval][out] */ Border	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ClearFormats( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Copy( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DataLabel( 
            /* [retval][out] */ DataLabel	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Explosion( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Explosion( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HasDataLabel( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_HasDataLabel( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Interior( 
            /* [retval][out] */ Interior	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_InvertIfNegative( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_InvertIfNegative( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MarkerBackgroundColor( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_MarkerBackgroundColor( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MarkerBackgroundColorIndex( 
            /* [retval][out] */ XlColorIndex *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_MarkerBackgroundColorIndex( 
            /* [in] */ XlColorIndex RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MarkerForegroundColor( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_MarkerForegroundColor( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MarkerForegroundColorIndex( 
            /* [retval][out] */ XlColorIndex *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_MarkerForegroundColorIndex( 
            /* [in] */ XlColorIndex RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MarkerSize( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_MarkerSize( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MarkerStyle( 
            /* [retval][out] */ XlMarkerStyle *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_MarkerStyle( 
            /* [in] */ XlMarkerStyle RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Paste( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PictureType( 
            /* [retval][out] */ XlChartPictureType *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PictureType( 
            /* [in] */ XlChartPictureType RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_PictureUnit( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_PictureUnit( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ApplyPictToSides( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ApplyPictToSides( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ApplyPictToFront( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ApplyPictToFront( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ApplyPictToEnd( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ApplyPictToEnd( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Shadow( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Shadow( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SecondaryPlot( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_SecondaryPlot( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Fill( 
            /* [retval][out] */ ChartFillFormat	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ApplyDataLabels( 
            /* [defaultvalue][optional][in] */ XlDataLabelsType Type,
            /* [optional][in] */ VARIANT LegendKey,
            /* [optional][in] */ VARIANT AutoText,
            /* [optional][in] */ VARIANT HasLeaderLines,
            /* [optional][in] */ VARIANT ShowSeriesName,
            /* [optional][in] */ VARIANT ShowCategoryName,
            /* [optional][in] */ VARIANT ShowValue,
            /* [optional][in] */ VARIANT ShowPercentage,
            /* [optional][in] */ VARIANT ShowBubbleSize,
            /* [optional][in] */ VARIANT Separator,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Has3DEffect( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Has3DEffect( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PictureUnit2( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PictureUnit2( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Format( 
            /* [retval][out] */ ChartFormat	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Height( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Width( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Top( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Left( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall PieSliceLocation( 
            /* [in] */ XlPieSliceLocation loc,
            /* [defaultvalue][optional][in] */ XlPieSliceIndex Index,
            /* [retval][out] */ double *RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IPointVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IPoint * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IPoint * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IPoint * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IPoint * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IPoint * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IPoint * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IPoint * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IPoint * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IPoint * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IPoint * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *_ApplyDataLabels )( 
            IPoint * This,
            /* [defaultvalue][optional][in] */ XlDataLabelsType Type,
            /* [optional][in] */ VARIANT LegendKey,
            /* [optional][in] */ VARIANT AutoText,
            /* [optional][in] */ VARIANT HasLeaderLines,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Border )( 
            IPoint * This,
            /* [retval][out] */ Border	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ClearFormats )( 
            IPoint * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Copy )( 
            IPoint * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DataLabel )( 
            IPoint * This,
            /* [retval][out] */ DataLabel	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IPoint * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Explosion )( 
            IPoint * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Explosion )( 
            IPoint * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HasDataLabel )( 
            IPoint * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_HasDataLabel )( 
            IPoint * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Interior )( 
            IPoint * This,
            /* [retval][out] */ Interior	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_InvertIfNegative )( 
            IPoint * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_InvertIfNegative )( 
            IPoint * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MarkerBackgroundColor )( 
            IPoint * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_MarkerBackgroundColor )( 
            IPoint * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MarkerBackgroundColorIndex )( 
            IPoint * This,
            /* [retval][out] */ XlColorIndex *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_MarkerBackgroundColorIndex )( 
            IPoint * This,
            /* [in] */ XlColorIndex RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MarkerForegroundColor )( 
            IPoint * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_MarkerForegroundColor )( 
            IPoint * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MarkerForegroundColorIndex )( 
            IPoint * This,
            /* [retval][out] */ XlColorIndex *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_MarkerForegroundColorIndex )( 
            IPoint * This,
            /* [in] */ XlColorIndex RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MarkerSize )( 
            IPoint * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_MarkerSize )( 
            IPoint * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MarkerStyle )( 
            IPoint * This,
            /* [retval][out] */ XlMarkerStyle *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_MarkerStyle )( 
            IPoint * This,
            /* [in] */ XlMarkerStyle RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Paste )( 
            IPoint * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PictureType )( 
            IPoint * This,
            /* [retval][out] */ XlChartPictureType *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PictureType )( 
            IPoint * This,
            /* [in] */ XlChartPictureType RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_PictureUnit )( 
            IPoint * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_PictureUnit )( 
            IPoint * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            IPoint * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ApplyPictToSides )( 
            IPoint * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ApplyPictToSides )( 
            IPoint * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ApplyPictToFront )( 
            IPoint * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ApplyPictToFront )( 
            IPoint * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ApplyPictToEnd )( 
            IPoint * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ApplyPictToEnd )( 
            IPoint * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Shadow )( 
            IPoint * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Shadow )( 
            IPoint * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SecondaryPlot )( 
            IPoint * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_SecondaryPlot )( 
            IPoint * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Fill )( 
            IPoint * This,
            /* [retval][out] */ ChartFillFormat	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ApplyDataLabels )( 
            IPoint * This,
            /* [defaultvalue][optional][in] */ XlDataLabelsType Type,
            /* [optional][in] */ VARIANT LegendKey,
            /* [optional][in] */ VARIANT AutoText,
            /* [optional][in] */ VARIANT HasLeaderLines,
            /* [optional][in] */ VARIANT ShowSeriesName,
            /* [optional][in] */ VARIANT ShowCategoryName,
            /* [optional][in] */ VARIANT ShowValue,
            /* [optional][in] */ VARIANT ShowPercentage,
            /* [optional][in] */ VARIANT ShowBubbleSize,
            /* [optional][in] */ VARIANT Separator,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Has3DEffect )( 
            IPoint * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Has3DEffect )( 
            IPoint * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PictureUnit2 )( 
            IPoint * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PictureUnit2 )( 
            IPoint * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Format )( 
            IPoint * This,
            /* [retval][out] */ ChartFormat	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Height )( 
            IPoint * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Width )( 
            IPoint * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Top )( 
            IPoint * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Left )( 
            IPoint * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            IPoint * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *PieSliceLocation )( 
            IPoint * This,
            /* [in] */ XlPieSliceLocation loc,
            /* [defaultvalue][optional][in] */ XlPieSliceIndex Index,
            /* [retval][out] */ double *RHS);
        
        END_INTERFACE
    } IPointVtbl;

    interface IPoint
    {
        CONST_VTBL struct IPointVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IPoint_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IPoint_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IPoint_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IPoint_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IPoint_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IPoint_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IPoint_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IPoint_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IPoint_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IPoint_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IPoint__ApplyDataLabels(This,Type,LegendKey,AutoText,HasLeaderLines,RHS)	\
    ( (This)->lpVtbl -> _ApplyDataLabels(This,Type,LegendKey,AutoText,HasLeaderLines,RHS) ) 

#define IPoint_get_Border(This,RHS)	\
    ( (This)->lpVtbl -> get_Border(This,RHS) ) 

#define IPoint_ClearFormats(This,RHS)	\
    ( (This)->lpVtbl -> ClearFormats(This,RHS) ) 

#define IPoint_Copy(This,RHS)	\
    ( (This)->lpVtbl -> Copy(This,RHS) ) 

#define IPoint_get_DataLabel(This,RHS)	\
    ( (This)->lpVtbl -> get_DataLabel(This,RHS) ) 

#define IPoint_Delete(This,RHS)	\
    ( (This)->lpVtbl -> Delete(This,RHS) ) 

#define IPoint_get_Explosion(This,RHS)	\
    ( (This)->lpVtbl -> get_Explosion(This,RHS) ) 

#define IPoint_put_Explosion(This,RHS)	\
    ( (This)->lpVtbl -> put_Explosion(This,RHS) ) 

#define IPoint_get_HasDataLabel(This,RHS)	\
    ( (This)->lpVtbl -> get_HasDataLabel(This,RHS) ) 

#define IPoint_put_HasDataLabel(This,RHS)	\
    ( (This)->lpVtbl -> put_HasDataLabel(This,RHS) ) 

#define IPoint_get_Interior(This,RHS)	\
    ( (This)->lpVtbl -> get_Interior(This,RHS) ) 

#define IPoint_get_InvertIfNegative(This,RHS)	\
    ( (This)->lpVtbl -> get_InvertIfNegative(This,RHS) ) 

#define IPoint_put_InvertIfNegative(This,RHS)	\
    ( (This)->lpVtbl -> put_InvertIfNegative(This,RHS) ) 

#define IPoint_get_MarkerBackgroundColor(This,RHS)	\
    ( (This)->lpVtbl -> get_MarkerBackgroundColor(This,RHS) ) 

#define IPoint_put_MarkerBackgroundColor(This,RHS)	\
    ( (This)->lpVtbl -> put_MarkerBackgroundColor(This,RHS) ) 

#define IPoint_get_MarkerBackgroundColorIndex(This,RHS)	\
    ( (This)->lpVtbl -> get_MarkerBackgroundColorIndex(This,RHS) ) 

#define IPoint_put_MarkerBackgroundColorIndex(This,RHS)	\
    ( (This)->lpVtbl -> put_MarkerBackgroundColorIndex(This,RHS) ) 

#define IPoint_get_MarkerForegroundColor(This,RHS)	\
    ( (This)->lpVtbl -> get_MarkerForegroundColor(This,RHS) ) 

#define IPoint_put_MarkerForegroundColor(This,RHS)	\
    ( (This)->lpVtbl -> put_MarkerForegroundColor(This,RHS) ) 

#define IPoint_get_MarkerForegroundColorIndex(This,RHS)	\
    ( (This)->lpVtbl -> get_MarkerForegroundColorIndex(This,RHS) ) 

#define IPoint_put_MarkerForegroundColorIndex(This,RHS)	\
    ( (This)->lpVtbl -> put_MarkerForegroundColorIndex(This,RHS) ) 

#define IPoint_get_MarkerSize(This,RHS)	\
    ( (This)->lpVtbl -> get_MarkerSize(This,RHS) ) 

#define IPoint_put_MarkerSize(This,RHS)	\
    ( (This)->lpVtbl -> put_MarkerSize(This,RHS) ) 

#define IPoint_get_MarkerStyle(This,RHS)	\
    ( (This)->lpVtbl -> get_MarkerStyle(This,RHS) ) 

#define IPoint_put_MarkerStyle(This,RHS)	\
    ( (This)->lpVtbl -> put_MarkerStyle(This,RHS) ) 

#define IPoint_Paste(This,RHS)	\
    ( (This)->lpVtbl -> Paste(This,RHS) ) 

#define IPoint_get_PictureType(This,RHS)	\
    ( (This)->lpVtbl -> get_PictureType(This,RHS) ) 

#define IPoint_put_PictureType(This,RHS)	\
    ( (This)->lpVtbl -> put_PictureType(This,RHS) ) 

#define IPoint_get_PictureUnit(This,RHS)	\
    ( (This)->lpVtbl -> get_PictureUnit(This,RHS) ) 

#define IPoint_put_PictureUnit(This,RHS)	\
    ( (This)->lpVtbl -> put_PictureUnit(This,RHS) ) 

#define IPoint_Select(This,RHS)	\
    ( (This)->lpVtbl -> Select(This,RHS) ) 

#define IPoint_get_ApplyPictToSides(This,RHS)	\
    ( (This)->lpVtbl -> get_ApplyPictToSides(This,RHS) ) 

#define IPoint_put_ApplyPictToSides(This,RHS)	\
    ( (This)->lpVtbl -> put_ApplyPictToSides(This,RHS) ) 

#define IPoint_get_ApplyPictToFront(This,RHS)	\
    ( (This)->lpVtbl -> get_ApplyPictToFront(This,RHS) ) 

#define IPoint_put_ApplyPictToFront(This,RHS)	\
    ( (This)->lpVtbl -> put_ApplyPictToFront(This,RHS) ) 

#define IPoint_get_ApplyPictToEnd(This,RHS)	\
    ( (This)->lpVtbl -> get_ApplyPictToEnd(This,RHS) ) 

#define IPoint_put_ApplyPictToEnd(This,RHS)	\
    ( (This)->lpVtbl -> put_ApplyPictToEnd(This,RHS) ) 

#define IPoint_get_Shadow(This,RHS)	\
    ( (This)->lpVtbl -> get_Shadow(This,RHS) ) 

#define IPoint_put_Shadow(This,RHS)	\
    ( (This)->lpVtbl -> put_Shadow(This,RHS) ) 

#define IPoint_get_SecondaryPlot(This,RHS)	\
    ( (This)->lpVtbl -> get_SecondaryPlot(This,RHS) ) 

#define IPoint_put_SecondaryPlot(This,RHS)	\
    ( (This)->lpVtbl -> put_SecondaryPlot(This,RHS) ) 

#define IPoint_get_Fill(This,RHS)	\
    ( (This)->lpVtbl -> get_Fill(This,RHS) ) 

#define IPoint_ApplyDataLabels(This,Type,LegendKey,AutoText,HasLeaderLines,ShowSeriesName,ShowCategoryName,ShowValue,ShowPercentage,ShowBubbleSize,Separator,RHS)	\
    ( (This)->lpVtbl -> ApplyDataLabels(This,Type,LegendKey,AutoText,HasLeaderLines,ShowSeriesName,ShowCategoryName,ShowValue,ShowPercentage,ShowBubbleSize,Separator,RHS) ) 

#define IPoint_get_Has3DEffect(This,RHS)	\
    ( (This)->lpVtbl -> get_Has3DEffect(This,RHS) ) 

#define IPoint_put_Has3DEffect(This,RHS)	\
    ( (This)->lpVtbl -> put_Has3DEffect(This,RHS) ) 

#define IPoint_get_PictureUnit2(This,RHS)	\
    ( (This)->lpVtbl -> get_PictureUnit2(This,RHS) ) 

#define IPoint_put_PictureUnit2(This,RHS)	\
    ( (This)->lpVtbl -> put_PictureUnit2(This,RHS) ) 

#define IPoint_get_Format(This,RHS)	\
    ( (This)->lpVtbl -> get_Format(This,RHS) ) 

#define IPoint_get_Height(This,RHS)	\
    ( (This)->lpVtbl -> get_Height(This,RHS) ) 

#define IPoint_get_Width(This,RHS)	\
    ( (This)->lpVtbl -> get_Width(This,RHS) ) 

#define IPoint_get_Top(This,RHS)	\
    ( (This)->lpVtbl -> get_Top(This,RHS) ) 

#define IPoint_get_Left(This,RHS)	\
    ( (This)->lpVtbl -> get_Left(This,RHS) ) 

#define IPoint_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define IPoint_PieSliceLocation(This,loc,Index,RHS)	\
    ( (This)->lpVtbl -> PieSliceLocation(This,loc,Index,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IPoint_INTERFACE_DEFINED__ */


#ifndef __ISeries_INTERFACE_DEFINED__
#define __ISeries_INTERFACE_DEFINED__

/* interface ISeries */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ISeries;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002086B-0001-0000-C000-000000000046")
    ISeries : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall _ApplyDataLabels( 
            /* [defaultvalue][optional][in] */ XlDataLabelsType Type,
            /* [optional][in] */ VARIANT LegendKey,
            /* [optional][in] */ VARIANT AutoText,
            /* [optional][in] */ VARIANT HasLeaderLines,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AxisGroup( 
            /* [retval][out] */ XlAxisGroup *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AxisGroup( 
            /* [in] */ XlAxisGroup RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Border( 
            /* [retval][out] */ Border	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ClearFormats( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Copy( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall DataLabels( 
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ErrorBar( 
            /* [in] */ XlErrorBarDirection Direction,
            /* [in] */ XlErrorBarInclude Include,
            /* [in] */ XlErrorBarType Type,
            /* [optional][in] */ VARIANT Amount,
            /* [optional][in] */ VARIANT MinusValues,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ErrorBars( 
            /* [retval][out] */ ErrorBars	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Explosion( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Explosion( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Formula( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Formula( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_FormulaLocal( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_FormulaLocal( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_FormulaR1C1( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_FormulaR1C1( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_FormulaR1C1Local( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_FormulaR1C1Local( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HasDataLabels( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_HasDataLabels( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HasErrorBars( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_HasErrorBars( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Interior( 
            /* [retval][out] */ Interior	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Fill( 
            /* [retval][out] */ ChartFillFormat	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_InvertIfNegative( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_InvertIfNegative( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MarkerBackgroundColor( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_MarkerBackgroundColor( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MarkerBackgroundColorIndex( 
            /* [retval][out] */ XlColorIndex *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_MarkerBackgroundColorIndex( 
            /* [in] */ XlColorIndex RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MarkerForegroundColor( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_MarkerForegroundColor( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MarkerForegroundColorIndex( 
            /* [retval][out] */ XlColorIndex *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_MarkerForegroundColorIndex( 
            /* [in] */ XlColorIndex RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MarkerSize( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_MarkerSize( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MarkerStyle( 
            /* [retval][out] */ XlMarkerStyle *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_MarkerStyle( 
            /* [in] */ XlMarkerStyle RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Name( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Paste( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PictureType( 
            /* [retval][out] */ XlChartPictureType *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PictureType( 
            /* [in] */ XlChartPictureType RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_PictureUnit( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_PictureUnit( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PlotOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PlotOrder( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Points( 
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Smooth( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Smooth( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Trendlines( 
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Type( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Type( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ChartType( 
            /* [retval][out] */ XlChartType *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ChartType( 
            /* [in] */ XlChartType RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall ApplyCustomType( 
            /* [in] */ XlChartType ChartType) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Values( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Values( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_XValues( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_XValues( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_BubbleSizes( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_BubbleSizes( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_BarShape( 
            /* [retval][out] */ XlBarShape *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_BarShape( 
            /* [in] */ XlBarShape RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ApplyPictToSides( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ApplyPictToSides( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ApplyPictToFront( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ApplyPictToFront( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ApplyPictToEnd( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ApplyPictToEnd( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Has3DEffect( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Has3DEffect( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Shadow( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Shadow( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HasLeaderLines( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_HasLeaderLines( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LeaderLines( 
            /* [retval][out] */ LeaderLines	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ApplyDataLabels( 
            /* [defaultvalue][optional][in] */ XlDataLabelsType Type,
            /* [optional][in] */ VARIANT LegendKey,
            /* [optional][in] */ VARIANT AutoText,
            /* [optional][in] */ VARIANT HasLeaderLines,
            /* [optional][in] */ VARIANT ShowSeriesName,
            /* [optional][in] */ VARIANT ShowCategoryName,
            /* [optional][in] */ VARIANT ShowValue,
            /* [optional][in] */ VARIANT ShowPercentage,
            /* [optional][in] */ VARIANT ShowBubbleSize,
            /* [optional][in] */ VARIANT Separator,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PictureUnit2( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PictureUnit2( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Format( 
            /* [retval][out] */ ChartFormat	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PlotColorIndex( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_InvertColor( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_InvertColor( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_InvertColorIndex( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_InvertColorIndex( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_IsFiltered( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_IsFiltered( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ISeriesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ISeries * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ISeries * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ISeries * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ISeries * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ISeries * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ISeries * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ISeries * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ISeries * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ISeries * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ISeries * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *_ApplyDataLabels )( 
            ISeries * This,
            /* [defaultvalue][optional][in] */ XlDataLabelsType Type,
            /* [optional][in] */ VARIANT LegendKey,
            /* [optional][in] */ VARIANT AutoText,
            /* [optional][in] */ VARIANT HasLeaderLines,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AxisGroup )( 
            ISeries * This,
            /* [retval][out] */ XlAxisGroup *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AxisGroup )( 
            ISeries * This,
            /* [in] */ XlAxisGroup RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Border )( 
            ISeries * This,
            /* [retval][out] */ Border	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ClearFormats )( 
            ISeries * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Copy )( 
            ISeries * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *DataLabels )( 
            ISeries * This,
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            ISeries * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ErrorBar )( 
            ISeries * This,
            /* [in] */ XlErrorBarDirection Direction,
            /* [in] */ XlErrorBarInclude Include,
            /* [in] */ XlErrorBarType Type,
            /* [optional][in] */ VARIANT Amount,
            /* [optional][in] */ VARIANT MinusValues,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ErrorBars )( 
            ISeries * This,
            /* [retval][out] */ ErrorBars	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Explosion )( 
            ISeries * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Explosion )( 
            ISeries * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Formula )( 
            ISeries * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Formula )( 
            ISeries * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_FormulaLocal )( 
            ISeries * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_FormulaLocal )( 
            ISeries * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_FormulaR1C1 )( 
            ISeries * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_FormulaR1C1 )( 
            ISeries * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_FormulaR1C1Local )( 
            ISeries * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_FormulaR1C1Local )( 
            ISeries * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HasDataLabels )( 
            ISeries * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_HasDataLabels )( 
            ISeries * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HasErrorBars )( 
            ISeries * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_HasErrorBars )( 
            ISeries * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Interior )( 
            ISeries * This,
            /* [retval][out] */ Interior	**RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Fill )( 
            ISeries * This,
            /* [retval][out] */ ChartFillFormat	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_InvertIfNegative )( 
            ISeries * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_InvertIfNegative )( 
            ISeries * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MarkerBackgroundColor )( 
            ISeries * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_MarkerBackgroundColor )( 
            ISeries * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MarkerBackgroundColorIndex )( 
            ISeries * This,
            /* [retval][out] */ XlColorIndex *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_MarkerBackgroundColorIndex )( 
            ISeries * This,
            /* [in] */ XlColorIndex RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MarkerForegroundColor )( 
            ISeries * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_MarkerForegroundColor )( 
            ISeries * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MarkerForegroundColorIndex )( 
            ISeries * This,
            /* [retval][out] */ XlColorIndex *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_MarkerForegroundColorIndex )( 
            ISeries * This,
            /* [in] */ XlColorIndex RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MarkerSize )( 
            ISeries * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_MarkerSize )( 
            ISeries * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MarkerStyle )( 
            ISeries * This,
            /* [retval][out] */ XlMarkerStyle *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_MarkerStyle )( 
            ISeries * This,
            /* [in] */ XlMarkerStyle RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            ISeries * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Name )( 
            ISeries * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Paste )( 
            ISeries * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PictureType )( 
            ISeries * This,
            /* [retval][out] */ XlChartPictureType *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PictureType )( 
            ISeries * This,
            /* [in] */ XlChartPictureType RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_PictureUnit )( 
            ISeries * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_PictureUnit )( 
            ISeries * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PlotOrder )( 
            ISeries * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PlotOrder )( 
            ISeries * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Points )( 
            ISeries * This,
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            ISeries * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Smooth )( 
            ISeries * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Smooth )( 
            ISeries * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Trendlines )( 
            ISeries * This,
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Type )( 
            ISeries * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Type )( 
            ISeries * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ChartType )( 
            ISeries * This,
            /* [retval][out] */ XlChartType *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ChartType )( 
            ISeries * This,
            /* [in] */ XlChartType RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *ApplyCustomType )( 
            ISeries * This,
            /* [in] */ XlChartType ChartType);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Values )( 
            ISeries * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Values )( 
            ISeries * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_XValues )( 
            ISeries * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_XValues )( 
            ISeries * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_BubbleSizes )( 
            ISeries * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_BubbleSizes )( 
            ISeries * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_BarShape )( 
            ISeries * This,
            /* [retval][out] */ XlBarShape *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_BarShape )( 
            ISeries * This,
            /* [in] */ XlBarShape RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ApplyPictToSides )( 
            ISeries * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ApplyPictToSides )( 
            ISeries * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ApplyPictToFront )( 
            ISeries * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ApplyPictToFront )( 
            ISeries * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ApplyPictToEnd )( 
            ISeries * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ApplyPictToEnd )( 
            ISeries * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Has3DEffect )( 
            ISeries * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Has3DEffect )( 
            ISeries * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Shadow )( 
            ISeries * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Shadow )( 
            ISeries * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HasLeaderLines )( 
            ISeries * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_HasLeaderLines )( 
            ISeries * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LeaderLines )( 
            ISeries * This,
            /* [retval][out] */ LeaderLines	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ApplyDataLabels )( 
            ISeries * This,
            /* [defaultvalue][optional][in] */ XlDataLabelsType Type,
            /* [optional][in] */ VARIANT LegendKey,
            /* [optional][in] */ VARIANT AutoText,
            /* [optional][in] */ VARIANT HasLeaderLines,
            /* [optional][in] */ VARIANT ShowSeriesName,
            /* [optional][in] */ VARIANT ShowCategoryName,
            /* [optional][in] */ VARIANT ShowValue,
            /* [optional][in] */ VARIANT ShowPercentage,
            /* [optional][in] */ VARIANT ShowBubbleSize,
            /* [optional][in] */ VARIANT Separator,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PictureUnit2 )( 
            ISeries * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PictureUnit2 )( 
            ISeries * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Format )( 
            ISeries * This,
            /* [retval][out] */ ChartFormat	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PlotColorIndex )( 
            ISeries * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_InvertColor )( 
            ISeries * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_InvertColor )( 
            ISeries * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_InvertColorIndex )( 
            ISeries * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_InvertColorIndex )( 
            ISeries * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_IsFiltered )( 
            ISeries * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_IsFiltered )( 
            ISeries * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        END_INTERFACE
    } ISeriesVtbl;

    interface ISeries
    {
        CONST_VTBL struct ISeriesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ISeries_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ISeries_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ISeries_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ISeries_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ISeries_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ISeries_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ISeries_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ISeries_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ISeries_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ISeries_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ISeries__ApplyDataLabels(This,Type,LegendKey,AutoText,HasLeaderLines,RHS)	\
    ( (This)->lpVtbl -> _ApplyDataLabels(This,Type,LegendKey,AutoText,HasLeaderLines,RHS) ) 

#define ISeries_get_AxisGroup(This,RHS)	\
    ( (This)->lpVtbl -> get_AxisGroup(This,RHS) ) 

#define ISeries_put_AxisGroup(This,RHS)	\
    ( (This)->lpVtbl -> put_AxisGroup(This,RHS) ) 

#define ISeries_get_Border(This,RHS)	\
    ( (This)->lpVtbl -> get_Border(This,RHS) ) 

#define ISeries_ClearFormats(This,RHS)	\
    ( (This)->lpVtbl -> ClearFormats(This,RHS) ) 

#define ISeries_Copy(This,RHS)	\
    ( (This)->lpVtbl -> Copy(This,RHS) ) 

#define ISeries_DataLabels(This,Index,RHS)	\
    ( (This)->lpVtbl -> DataLabels(This,Index,RHS) ) 

#define ISeries_Delete(This,RHS)	\
    ( (This)->lpVtbl -> Delete(This,RHS) ) 

#define ISeries_ErrorBar(This,Direction,Include,Type,Amount,MinusValues,RHS)	\
    ( (This)->lpVtbl -> ErrorBar(This,Direction,Include,Type,Amount,MinusValues,RHS) ) 

#define ISeries_get_ErrorBars(This,RHS)	\
    ( (This)->lpVtbl -> get_ErrorBars(This,RHS) ) 

#define ISeries_get_Explosion(This,RHS)	\
    ( (This)->lpVtbl -> get_Explosion(This,RHS) ) 

#define ISeries_put_Explosion(This,RHS)	\
    ( (This)->lpVtbl -> put_Explosion(This,RHS) ) 

#define ISeries_get_Formula(This,RHS)	\
    ( (This)->lpVtbl -> get_Formula(This,RHS) ) 

#define ISeries_put_Formula(This,RHS)	\
    ( (This)->lpVtbl -> put_Formula(This,RHS) ) 

#define ISeries_get_FormulaLocal(This,RHS)	\
    ( (This)->lpVtbl -> get_FormulaLocal(This,RHS) ) 

#define ISeries_put_FormulaLocal(This,RHS)	\
    ( (This)->lpVtbl -> put_FormulaLocal(This,RHS) ) 

#define ISeries_get_FormulaR1C1(This,RHS)	\
    ( (This)->lpVtbl -> get_FormulaR1C1(This,RHS) ) 

#define ISeries_put_FormulaR1C1(This,RHS)	\
    ( (This)->lpVtbl -> put_FormulaR1C1(This,RHS) ) 

#define ISeries_get_FormulaR1C1Local(This,RHS)	\
    ( (This)->lpVtbl -> get_FormulaR1C1Local(This,RHS) ) 

#define ISeries_put_FormulaR1C1Local(This,RHS)	\
    ( (This)->lpVtbl -> put_FormulaR1C1Local(This,RHS) ) 

#define ISeries_get_HasDataLabels(This,RHS)	\
    ( (This)->lpVtbl -> get_HasDataLabels(This,RHS) ) 

#define ISeries_put_HasDataLabels(This,RHS)	\
    ( (This)->lpVtbl -> put_HasDataLabels(This,RHS) ) 

#define ISeries_get_HasErrorBars(This,RHS)	\
    ( (This)->lpVtbl -> get_HasErrorBars(This,RHS) ) 

#define ISeries_put_HasErrorBars(This,RHS)	\
    ( (This)->lpVtbl -> put_HasErrorBars(This,RHS) ) 

#define ISeries_get_Interior(This,RHS)	\
    ( (This)->lpVtbl -> get_Interior(This,RHS) ) 

#define ISeries_get_Fill(This,RHS)	\
    ( (This)->lpVtbl -> get_Fill(This,RHS) ) 

#define ISeries_get_InvertIfNegative(This,RHS)	\
    ( (This)->lpVtbl -> get_InvertIfNegative(This,RHS) ) 

#define ISeries_put_InvertIfNegative(This,RHS)	\
    ( (This)->lpVtbl -> put_InvertIfNegative(This,RHS) ) 

#define ISeries_get_MarkerBackgroundColor(This,RHS)	\
    ( (This)->lpVtbl -> get_MarkerBackgroundColor(This,RHS) ) 

#define ISeries_put_MarkerBackgroundColor(This,RHS)	\
    ( (This)->lpVtbl -> put_MarkerBackgroundColor(This,RHS) ) 

#define ISeries_get_MarkerBackgroundColorIndex(This,RHS)	\
    ( (This)->lpVtbl -> get_MarkerBackgroundColorIndex(This,RHS) ) 

#define ISeries_put_MarkerBackgroundColorIndex(This,RHS)	\
    ( (This)->lpVtbl -> put_MarkerBackgroundColorIndex(This,RHS) ) 

#define ISeries_get_MarkerForegroundColor(This,RHS)	\
    ( (This)->lpVtbl -> get_MarkerForegroundColor(This,RHS) ) 

#define ISeries_put_MarkerForegroundColor(This,RHS)	\
    ( (This)->lpVtbl -> put_MarkerForegroundColor(This,RHS) ) 

#define ISeries_get_MarkerForegroundColorIndex(This,RHS)	\
    ( (This)->lpVtbl -> get_MarkerForegroundColorIndex(This,RHS) ) 

#define ISeries_put_MarkerForegroundColorIndex(This,RHS)	\
    ( (This)->lpVtbl -> put_MarkerForegroundColorIndex(This,RHS) ) 

#define ISeries_get_MarkerSize(This,RHS)	\
    ( (This)->lpVtbl -> get_MarkerSize(This,RHS) ) 

#define ISeries_put_MarkerSize(This,RHS)	\
    ( (This)->lpVtbl -> put_MarkerSize(This,RHS) ) 

#define ISeries_get_MarkerStyle(This,RHS)	\
    ( (This)->lpVtbl -> get_MarkerStyle(This,RHS) ) 

#define ISeries_put_MarkerStyle(This,RHS)	\
    ( (This)->lpVtbl -> put_MarkerStyle(This,RHS) ) 

#define ISeries_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define ISeries_put_Name(This,RHS)	\
    ( (This)->lpVtbl -> put_Name(This,RHS) ) 

#define ISeries_Paste(This,RHS)	\
    ( (This)->lpVtbl -> Paste(This,RHS) ) 

#define ISeries_get_PictureType(This,RHS)	\
    ( (This)->lpVtbl -> get_PictureType(This,RHS) ) 

#define ISeries_put_PictureType(This,RHS)	\
    ( (This)->lpVtbl -> put_PictureType(This,RHS) ) 

#define ISeries_get_PictureUnit(This,RHS)	\
    ( (This)->lpVtbl -> get_PictureUnit(This,RHS) ) 

#define ISeries_put_PictureUnit(This,RHS)	\
    ( (This)->lpVtbl -> put_PictureUnit(This,RHS) ) 

#define ISeries_get_PlotOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_PlotOrder(This,RHS) ) 

#define ISeries_put_PlotOrder(This,RHS)	\
    ( (This)->lpVtbl -> put_PlotOrder(This,RHS) ) 

#define ISeries_Points(This,Index,RHS)	\
    ( (This)->lpVtbl -> Points(This,Index,RHS) ) 

#define ISeries_Select(This,RHS)	\
    ( (This)->lpVtbl -> Select(This,RHS) ) 

#define ISeries_get_Smooth(This,RHS)	\
    ( (This)->lpVtbl -> get_Smooth(This,RHS) ) 

#define ISeries_put_Smooth(This,RHS)	\
    ( (This)->lpVtbl -> put_Smooth(This,RHS) ) 

#define ISeries_Trendlines(This,Index,RHS)	\
    ( (This)->lpVtbl -> Trendlines(This,Index,RHS) ) 

#define ISeries_get_Type(This,RHS)	\
    ( (This)->lpVtbl -> get_Type(This,RHS) ) 

#define ISeries_put_Type(This,RHS)	\
    ( (This)->lpVtbl -> put_Type(This,RHS) ) 

#define ISeries_get_ChartType(This,RHS)	\
    ( (This)->lpVtbl -> get_ChartType(This,RHS) ) 

#define ISeries_put_ChartType(This,RHS)	\
    ( (This)->lpVtbl -> put_ChartType(This,RHS) ) 

#define ISeries_ApplyCustomType(This,ChartType)	\
    ( (This)->lpVtbl -> ApplyCustomType(This,ChartType) ) 

#define ISeries_get_Values(This,RHS)	\
    ( (This)->lpVtbl -> get_Values(This,RHS) ) 

#define ISeries_put_Values(This,RHS)	\
    ( (This)->lpVtbl -> put_Values(This,RHS) ) 

#define ISeries_get_XValues(This,RHS)	\
    ( (This)->lpVtbl -> get_XValues(This,RHS) ) 

#define ISeries_put_XValues(This,RHS)	\
    ( (This)->lpVtbl -> put_XValues(This,RHS) ) 

#define ISeries_get_BubbleSizes(This,RHS)	\
    ( (This)->lpVtbl -> get_BubbleSizes(This,RHS) ) 

#define ISeries_put_BubbleSizes(This,RHS)	\
    ( (This)->lpVtbl -> put_BubbleSizes(This,RHS) ) 

#define ISeries_get_BarShape(This,RHS)	\
    ( (This)->lpVtbl -> get_BarShape(This,RHS) ) 

#define ISeries_put_BarShape(This,RHS)	\
    ( (This)->lpVtbl -> put_BarShape(This,RHS) ) 

#define ISeries_get_ApplyPictToSides(This,RHS)	\
    ( (This)->lpVtbl -> get_ApplyPictToSides(This,RHS) ) 

#define ISeries_put_ApplyPictToSides(This,RHS)	\
    ( (This)->lpVtbl -> put_ApplyPictToSides(This,RHS) ) 

#define ISeries_get_ApplyPictToFront(This,RHS)	\
    ( (This)->lpVtbl -> get_ApplyPictToFront(This,RHS) ) 

#define ISeries_put_ApplyPictToFront(This,RHS)	\
    ( (This)->lpVtbl -> put_ApplyPictToFront(This,RHS) ) 

#define ISeries_get_ApplyPictToEnd(This,RHS)	\
    ( (This)->lpVtbl -> get_ApplyPictToEnd(This,RHS) ) 

#define ISeries_put_ApplyPictToEnd(This,RHS)	\
    ( (This)->lpVtbl -> put_ApplyPictToEnd(This,RHS) ) 

#define ISeries_get_Has3DEffect(This,RHS)	\
    ( (This)->lpVtbl -> get_Has3DEffect(This,RHS) ) 

#define ISeries_put_Has3DEffect(This,RHS)	\
    ( (This)->lpVtbl -> put_Has3DEffect(This,RHS) ) 

#define ISeries_get_Shadow(This,RHS)	\
    ( (This)->lpVtbl -> get_Shadow(This,RHS) ) 

#define ISeries_put_Shadow(This,RHS)	\
    ( (This)->lpVtbl -> put_Shadow(This,RHS) ) 

#define ISeries_get_HasLeaderLines(This,RHS)	\
    ( (This)->lpVtbl -> get_HasLeaderLines(This,RHS) ) 

#define ISeries_put_HasLeaderLines(This,RHS)	\
    ( (This)->lpVtbl -> put_HasLeaderLines(This,RHS) ) 

#define ISeries_get_LeaderLines(This,RHS)	\
    ( (This)->lpVtbl -> get_LeaderLines(This,RHS) ) 

#define ISeries_ApplyDataLabels(This,Type,LegendKey,AutoText,HasLeaderLines,ShowSeriesName,ShowCategoryName,ShowValue,ShowPercentage,ShowBubbleSize,Separator,RHS)	\
    ( (This)->lpVtbl -> ApplyDataLabels(This,Type,LegendKey,AutoText,HasLeaderLines,ShowSeriesName,ShowCategoryName,ShowValue,ShowPercentage,ShowBubbleSize,Separator,RHS) ) 

#define ISeries_get_PictureUnit2(This,RHS)	\
    ( (This)->lpVtbl -> get_PictureUnit2(This,RHS) ) 

#define ISeries_put_PictureUnit2(This,RHS)	\
    ( (This)->lpVtbl -> put_PictureUnit2(This,RHS) ) 

#define ISeries_get_Format(This,RHS)	\
    ( (This)->lpVtbl -> get_Format(This,RHS) ) 

#define ISeries_get_PlotColorIndex(This,RHS)	\
    ( (This)->lpVtbl -> get_PlotColorIndex(This,RHS) ) 

#define ISeries_get_InvertColor(This,RHS)	\
    ( (This)->lpVtbl -> get_InvertColor(This,RHS) ) 

#define ISeries_put_InvertColor(This,RHS)	\
    ( (This)->lpVtbl -> put_InvertColor(This,RHS) ) 

#define ISeries_get_InvertColorIndex(This,RHS)	\
    ( (This)->lpVtbl -> get_InvertColorIndex(This,RHS) ) 

#define ISeries_put_InvertColorIndex(This,RHS)	\
    ( (This)->lpVtbl -> put_InvertColorIndex(This,RHS) ) 

#define ISeries_get_IsFiltered(This,RHS)	\
    ( (This)->lpVtbl -> get_IsFiltered(This,RHS) ) 

#define ISeries_put_IsFiltered(This,RHS)	\
    ( (This)->lpVtbl -> put_IsFiltered(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ISeries_INTERFACE_DEFINED__ */


#ifndef __ISeriesCollection_INTERFACE_DEFINED__
#define __ISeriesCollection_INTERFACE_DEFINED__

/* interface ISeriesCollection */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ISeriesCollection;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002086C-0001-0000-C000-000000000046")
    ISeriesCollection : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add( 
            /* [in] */ VARIANT Source,
            /* [defaultvalue][optional][in] */ XlRowCol Rowcol,
            /* [optional][in] */ VARIANT SeriesLabels,
            /* [optional][in] */ VARIANT CategoryLabels,
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ Series	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Extend( 
            /* [in] */ VARIANT Source,
            /* [optional][in] */ VARIANT Rowcol,
            /* [optional][in] */ VARIANT CategoryLabels,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Series	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall _NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Paste( 
            /* [defaultvalue][optional][in] */ XlRowCol Rowcol,
            /* [optional][in] */ VARIANT SeriesLabels,
            /* [optional][in] */ VARIANT CategoryLabels,
            /* [optional][in] */ VARIANT Replace,
            /* [optional][in] */ VARIANT NewSeries,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall NewSeries( 
            /* [retval][out] */ Series	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall _Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Series	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ISeriesCollectionVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ISeriesCollection * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ISeriesCollection * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ISeriesCollection * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ISeriesCollection * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ISeriesCollection * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ISeriesCollection * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ISeriesCollection * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ISeriesCollection * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ISeriesCollection * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ISeriesCollection * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add )( 
            ISeriesCollection * This,
            /* [in] */ VARIANT Source,
            /* [defaultvalue][optional][in] */ XlRowCol Rowcol,
            /* [optional][in] */ VARIANT SeriesLabels,
            /* [optional][in] */ VARIANT CategoryLabels,
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ Series	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            ISeriesCollection * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Extend )( 
            ISeriesCollection * This,
            /* [in] */ VARIANT Source,
            /* [optional][in] */ VARIANT Rowcol,
            /* [optional][in] */ VARIANT CategoryLabels,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Item )( 
            ISeriesCollection * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Series	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *_NewEnum )( 
            ISeriesCollection * This,
            /* [retval][out] */ IUnknown **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Paste )( 
            ISeriesCollection * This,
            /* [defaultvalue][optional][in] */ XlRowCol Rowcol,
            /* [optional][in] */ VARIANT SeriesLabels,
            /* [optional][in] */ VARIANT CategoryLabels,
            /* [optional][in] */ VARIANT Replace,
            /* [optional][in] */ VARIANT NewSeries,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *NewSeries )( 
            ISeriesCollection * This,
            /* [retval][out] */ Series	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *_Default )( 
            ISeriesCollection * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Series	**RHS);
        
        END_INTERFACE
    } ISeriesCollectionVtbl;

    interface ISeriesCollection
    {
        CONST_VTBL struct ISeriesCollectionVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ISeriesCollection_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ISeriesCollection_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ISeriesCollection_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ISeriesCollection_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ISeriesCollection_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ISeriesCollection_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ISeriesCollection_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ISeriesCollection_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ISeriesCollection_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ISeriesCollection_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ISeriesCollection_Add(This,Source,Rowcol,SeriesLabels,CategoryLabels,Replace,RHS)	\
    ( (This)->lpVtbl -> Add(This,Source,Rowcol,SeriesLabels,CategoryLabels,Replace,RHS) ) 

#define ISeriesCollection_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define ISeriesCollection_Extend(This,Source,Rowcol,CategoryLabels,RHS)	\
    ( (This)->lpVtbl -> Extend(This,Source,Rowcol,CategoryLabels,RHS) ) 

#define ISeriesCollection_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> Item(This,Index,RHS) ) 

#define ISeriesCollection__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> _NewEnum(This,RHS) ) 

#define ISeriesCollection_Paste(This,Rowcol,SeriesLabels,CategoryLabels,Replace,NewSeries,RHS)	\
    ( (This)->lpVtbl -> Paste(This,Rowcol,SeriesLabels,CategoryLabels,Replace,NewSeries,RHS) ) 

#define ISeriesCollection_NewSeries(This,RHS)	\
    ( (This)->lpVtbl -> NewSeries(This,RHS) ) 

#define ISeriesCollection__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> _Default(This,Index,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ISeriesCollection_INTERFACE_DEFINED__ */


#ifndef __IDataLabel_INTERFACE_DEFINED__
#define __IDataLabel_INTERFACE_DEFINED__

/* interface IDataLabel */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IDataLabel;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000208B2-0001-0000-C000-000000000046")
    IDataLabel : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Border( 
            /* [retval][out] */ Border	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Interior( 
            /* [retval][out] */ Interior	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Fill( 
            /* [retval][out] */ ChartFillFormat	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Caption( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Caption( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Characters( 
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Length,
            /* [retval][out] */ Characters	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Font( 
            /* [retval][out] */ Font	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HorizontalAlignment( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_HorizontalAlignment( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Left( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Left( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Orientation( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Orientation( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Shadow( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Shadow( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Text( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Text( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Top( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Top( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_VerticalAlignment( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_VerticalAlignment( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ReadingOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ReadingOrder( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_AutoScaleFont( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_AutoScaleFont( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AutoText( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AutoText( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_NumberFormat( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_NumberFormat( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_NumberFormatLinked( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_NumberFormatLinked( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_NumberFormatLocal( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_NumberFormatLocal( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShowLegendKey( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ShowLegendKey( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Type( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_Type( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Position( 
            /* [retval][out] */ XlDataLabelPosition *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Position( 
            /* [in] */ XlDataLabelPosition RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShowSeriesName( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ShowSeriesName( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShowCategoryName( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ShowCategoryName( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShowValue( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ShowValue( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShowPercentage( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ShowPercentage( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShowBubbleSize( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ShowBubbleSize( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Separator( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Separator( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Format( 
            /* [retval][out] */ ChartFormat	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get__Height( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get__Width( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Formula( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Formula( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_FormulaR1C1( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_FormulaR1C1( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_FormulaLocal( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_FormulaLocal( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_FormulaR1C1Local( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_FormulaR1C1Local( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShowRange( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ShowRange( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Height( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Height( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Width( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Width( 
            /* [in] */ double RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IDataLabelVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IDataLabel * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IDataLabel * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IDataLabel * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IDataLabel * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IDataLabel * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IDataLabel * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IDataLabel * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IDataLabel * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IDataLabel * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IDataLabel * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            IDataLabel * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            IDataLabel * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Border )( 
            IDataLabel * This,
            /* [retval][out] */ Border	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IDataLabel * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Interior )( 
            IDataLabel * This,
            /* [retval][out] */ Interior	**RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Fill )( 
            IDataLabel * This,
            /* [retval][out] */ ChartFillFormat	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Caption )( 
            IDataLabel * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Caption )( 
            IDataLabel * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Characters )( 
            IDataLabel * This,
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Length,
            /* [retval][out] */ Characters	**RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Font )( 
            IDataLabel * This,
            /* [retval][out] */ Font	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HorizontalAlignment )( 
            IDataLabel * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_HorizontalAlignment )( 
            IDataLabel * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Left )( 
            IDataLabel * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Left )( 
            IDataLabel * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Orientation )( 
            IDataLabel * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Orientation )( 
            IDataLabel * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Shadow )( 
            IDataLabel * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Shadow )( 
            IDataLabel * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Text )( 
            IDataLabel * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Text )( 
            IDataLabel * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Top )( 
            IDataLabel * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Top )( 
            IDataLabel * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_VerticalAlignment )( 
            IDataLabel * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_VerticalAlignment )( 
            IDataLabel * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ReadingOrder )( 
            IDataLabel * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ReadingOrder )( 
            IDataLabel * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_AutoScaleFont )( 
            IDataLabel * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_AutoScaleFont )( 
            IDataLabel * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AutoText )( 
            IDataLabel * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AutoText )( 
            IDataLabel * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_NumberFormat )( 
            IDataLabel * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_NumberFormat )( 
            IDataLabel * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_NumberFormatLinked )( 
            IDataLabel * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_NumberFormatLinked )( 
            IDataLabel * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_NumberFormatLocal )( 
            IDataLabel * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_NumberFormatLocal )( 
            IDataLabel * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShowLegendKey )( 
            IDataLabel * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ShowLegendKey )( 
            IDataLabel * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Type )( 
            IDataLabel * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_Type )( 
            IDataLabel * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Position )( 
            IDataLabel * This,
            /* [retval][out] */ XlDataLabelPosition *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Position )( 
            IDataLabel * This,
            /* [in] */ XlDataLabelPosition RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShowSeriesName )( 
            IDataLabel * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ShowSeriesName )( 
            IDataLabel * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShowCategoryName )( 
            IDataLabel * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ShowCategoryName )( 
            IDataLabel * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShowValue )( 
            IDataLabel * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ShowValue )( 
            IDataLabel * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShowPercentage )( 
            IDataLabel * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ShowPercentage )( 
            IDataLabel * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShowBubbleSize )( 
            IDataLabel * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ShowBubbleSize )( 
            IDataLabel * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Separator )( 
            IDataLabel * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Separator )( 
            IDataLabel * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Format )( 
            IDataLabel * This,
            /* [retval][out] */ ChartFormat	**RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get__Height )( 
            IDataLabel * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get__Width )( 
            IDataLabel * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Formula )( 
            IDataLabel * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Formula )( 
            IDataLabel * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_FormulaR1C1 )( 
            IDataLabel * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_FormulaR1C1 )( 
            IDataLabel * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_FormulaLocal )( 
            IDataLabel * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_FormulaLocal )( 
            IDataLabel * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_FormulaR1C1Local )( 
            IDataLabel * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_FormulaR1C1Local )( 
            IDataLabel * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShowRange )( 
            IDataLabel * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ShowRange )( 
            IDataLabel * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Height )( 
            IDataLabel * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Height )( 
            IDataLabel * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Width )( 
            IDataLabel * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Width )( 
            IDataLabel * This,
            /* [in] */ double RHS);
        
        END_INTERFACE
    } IDataLabelVtbl;

    interface IDataLabel
    {
        CONST_VTBL struct IDataLabelVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IDataLabel_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IDataLabel_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IDataLabel_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IDataLabel_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IDataLabel_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IDataLabel_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IDataLabel_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IDataLabel_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IDataLabel_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IDataLabel_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IDataLabel_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define IDataLabel_Select(This,RHS)	\
    ( (This)->lpVtbl -> Select(This,RHS) ) 

#define IDataLabel_get_Border(This,RHS)	\
    ( (This)->lpVtbl -> get_Border(This,RHS) ) 

#define IDataLabel_Delete(This,RHS)	\
    ( (This)->lpVtbl -> Delete(This,RHS) ) 

#define IDataLabel_get_Interior(This,RHS)	\
    ( (This)->lpVtbl -> get_Interior(This,RHS) ) 

#define IDataLabel_get_Fill(This,RHS)	\
    ( (This)->lpVtbl -> get_Fill(This,RHS) ) 

#define IDataLabel_get_Caption(This,RHS)	\
    ( (This)->lpVtbl -> get_Caption(This,RHS) ) 

#define IDataLabel_put_Caption(This,RHS)	\
    ( (This)->lpVtbl -> put_Caption(This,RHS) ) 

#define IDataLabel_get_Characters(This,Start,Length,RHS)	\
    ( (This)->lpVtbl -> get_Characters(This,Start,Length,RHS) ) 

#define IDataLabel_get_Font(This,RHS)	\
    ( (This)->lpVtbl -> get_Font(This,RHS) ) 

#define IDataLabel_get_HorizontalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> get_HorizontalAlignment(This,RHS) ) 

#define IDataLabel_put_HorizontalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> put_HorizontalAlignment(This,RHS) ) 

#define IDataLabel_get_Left(This,RHS)	\
    ( (This)->lpVtbl -> get_Left(This,RHS) ) 

#define IDataLabel_put_Left(This,RHS)	\
    ( (This)->lpVtbl -> put_Left(This,RHS) ) 

#define IDataLabel_get_Orientation(This,RHS)	\
    ( (This)->lpVtbl -> get_Orientation(This,RHS) ) 

#define IDataLabel_put_Orientation(This,RHS)	\
    ( (This)->lpVtbl -> put_Orientation(This,RHS) ) 

#define IDataLabel_get_Shadow(This,RHS)	\
    ( (This)->lpVtbl -> get_Shadow(This,RHS) ) 

#define IDataLabel_put_Shadow(This,RHS)	\
    ( (This)->lpVtbl -> put_Shadow(This,RHS) ) 

#define IDataLabel_get_Text(This,RHS)	\
    ( (This)->lpVtbl -> get_Text(This,RHS) ) 

#define IDataLabel_put_Text(This,RHS)	\
    ( (This)->lpVtbl -> put_Text(This,RHS) ) 

#define IDataLabel_get_Top(This,RHS)	\
    ( (This)->lpVtbl -> get_Top(This,RHS) ) 

#define IDataLabel_put_Top(This,RHS)	\
    ( (This)->lpVtbl -> put_Top(This,RHS) ) 

#define IDataLabel_get_VerticalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> get_VerticalAlignment(This,RHS) ) 

#define IDataLabel_put_VerticalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> put_VerticalAlignment(This,RHS) ) 

#define IDataLabel_get_ReadingOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_ReadingOrder(This,RHS) ) 

#define IDataLabel_put_ReadingOrder(This,RHS)	\
    ( (This)->lpVtbl -> put_ReadingOrder(This,RHS) ) 

#define IDataLabel_get_AutoScaleFont(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoScaleFont(This,RHS) ) 

#define IDataLabel_put_AutoScaleFont(This,RHS)	\
    ( (This)->lpVtbl -> put_AutoScaleFont(This,RHS) ) 

#define IDataLabel_get_AutoText(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoText(This,RHS) ) 

#define IDataLabel_put_AutoText(This,RHS)	\
    ( (This)->lpVtbl -> put_AutoText(This,RHS) ) 

#define IDataLabel_get_NumberFormat(This,RHS)	\
    ( (This)->lpVtbl -> get_NumberFormat(This,RHS) ) 

#define IDataLabel_put_NumberFormat(This,RHS)	\
    ( (This)->lpVtbl -> put_NumberFormat(This,RHS) ) 

#define IDataLabel_get_NumberFormatLinked(This,RHS)	\
    ( (This)->lpVtbl -> get_NumberFormatLinked(This,RHS) ) 

#define IDataLabel_put_NumberFormatLinked(This,RHS)	\
    ( (This)->lpVtbl -> put_NumberFormatLinked(This,RHS) ) 

#define IDataLabel_get_NumberFormatLocal(This,RHS)	\
    ( (This)->lpVtbl -> get_NumberFormatLocal(This,RHS) ) 

#define IDataLabel_put_NumberFormatLocal(This,RHS)	\
    ( (This)->lpVtbl -> put_NumberFormatLocal(This,RHS) ) 

#define IDataLabel_get_ShowLegendKey(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowLegendKey(This,RHS) ) 

#define IDataLabel_put_ShowLegendKey(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowLegendKey(This,RHS) ) 

#define IDataLabel_get_Type(This,RHS)	\
    ( (This)->lpVtbl -> get_Type(This,RHS) ) 

#define IDataLabel_put_Type(This,RHS)	\
    ( (This)->lpVtbl -> put_Type(This,RHS) ) 

#define IDataLabel_get_Position(This,RHS)	\
    ( (This)->lpVtbl -> get_Position(This,RHS) ) 

#define IDataLabel_put_Position(This,RHS)	\
    ( (This)->lpVtbl -> put_Position(This,RHS) ) 

#define IDataLabel_get_ShowSeriesName(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowSeriesName(This,RHS) ) 

#define IDataLabel_put_ShowSeriesName(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowSeriesName(This,RHS) ) 

#define IDataLabel_get_ShowCategoryName(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowCategoryName(This,RHS) ) 

#define IDataLabel_put_ShowCategoryName(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowCategoryName(This,RHS) ) 

#define IDataLabel_get_ShowValue(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowValue(This,RHS) ) 

#define IDataLabel_put_ShowValue(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowValue(This,RHS) ) 

#define IDataLabel_get_ShowPercentage(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowPercentage(This,RHS) ) 

#define IDataLabel_put_ShowPercentage(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowPercentage(This,RHS) ) 

#define IDataLabel_get_ShowBubbleSize(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowBubbleSize(This,RHS) ) 

#define IDataLabel_put_ShowBubbleSize(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowBubbleSize(This,RHS) ) 

#define IDataLabel_get_Separator(This,RHS)	\
    ( (This)->lpVtbl -> get_Separator(This,RHS) ) 

#define IDataLabel_put_Separator(This,RHS)	\
    ( (This)->lpVtbl -> put_Separator(This,RHS) ) 

#define IDataLabel_get_Format(This,RHS)	\
    ( (This)->lpVtbl -> get_Format(This,RHS) ) 

#define IDataLabel_get__Height(This,RHS)	\
    ( (This)->lpVtbl -> get__Height(This,RHS) ) 

#define IDataLabel_get__Width(This,RHS)	\
    ( (This)->lpVtbl -> get__Width(This,RHS) ) 

#define IDataLabel_get_Formula(This,RHS)	\
    ( (This)->lpVtbl -> get_Formula(This,RHS) ) 

#define IDataLabel_put_Formula(This,RHS)	\
    ( (This)->lpVtbl -> put_Formula(This,RHS) ) 

#define IDataLabel_get_FormulaR1C1(This,RHS)	\
    ( (This)->lpVtbl -> get_FormulaR1C1(This,RHS) ) 

#define IDataLabel_put_FormulaR1C1(This,RHS)	\
    ( (This)->lpVtbl -> put_FormulaR1C1(This,RHS) ) 

#define IDataLabel_get_FormulaLocal(This,RHS)	\
    ( (This)->lpVtbl -> get_FormulaLocal(This,RHS) ) 

#define IDataLabel_put_FormulaLocal(This,RHS)	\
    ( (This)->lpVtbl -> put_FormulaLocal(This,RHS) ) 

#define IDataLabel_get_FormulaR1C1Local(This,RHS)	\
    ( (This)->lpVtbl -> get_FormulaR1C1Local(This,RHS) ) 

#define IDataLabel_put_FormulaR1C1Local(This,RHS)	\
    ( (This)->lpVtbl -> put_FormulaR1C1Local(This,RHS) ) 

#define IDataLabel_get_ShowRange(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowRange(This,RHS) ) 

#define IDataLabel_put_ShowRange(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowRange(This,RHS) ) 

#define IDataLabel_get_Height(This,RHS)	\
    ( (This)->lpVtbl -> get_Height(This,RHS) ) 

#define IDataLabel_put_Height(This,RHS)	\
    ( (This)->lpVtbl -> put_Height(This,RHS) ) 

#define IDataLabel_get_Width(This,RHS)	\
    ( (This)->lpVtbl -> get_Width(This,RHS) ) 

#define IDataLabel_put_Width(This,RHS)	\
    ( (This)->lpVtbl -> put_Width(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IDataLabel_INTERFACE_DEFINED__ */


#ifndef __IDataLabels_INTERFACE_DEFINED__
#define __IDataLabels_INTERFACE_DEFINED__

/* interface IDataLabels */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IDataLabels;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000208B3-0001-0000-C000-000000000046")
    IDataLabels : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Border( 
            /* [retval][out] */ Border	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Interior( 
            /* [retval][out] */ Interior	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Fill( 
            /* [retval][out] */ ChartFillFormat	**RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy9( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy10( void) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Font( 
            /* [retval][out] */ Font	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HorizontalAlignment( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_HorizontalAlignment( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy13( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Orientation( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Orientation( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Shadow( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Shadow( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy16( void) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy17( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_VerticalAlignment( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_VerticalAlignment( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ReadingOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ReadingOrder( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_AutoScaleFont( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_AutoScaleFont( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AutoText( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AutoText( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_NumberFormat( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_NumberFormat( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_NumberFormatLinked( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_NumberFormatLinked( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_NumberFormatLocal( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_NumberFormatLocal( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShowLegendKey( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ShowLegendKey( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Type( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_Type( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Position( 
            /* [retval][out] */ XlDataLabelPosition *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Position( 
            /* [in] */ XlDataLabelPosition RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShowSeriesName( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ShowSeriesName( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShowCategoryName( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ShowCategoryName( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShowValue( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ShowValue( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShowPercentage( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ShowPercentage( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShowBubbleSize( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ShowBubbleSize( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Separator( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Separator( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ DataLabel	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall _NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall _Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ DataLabel	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Format( 
            /* [retval][out] */ ChartFormat	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Propagate( 
            /* [in] */ VARIANT Index) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShowRange( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ShowRange( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IDataLabelsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IDataLabels * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IDataLabels * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IDataLabels * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IDataLabels * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IDataLabels * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IDataLabels * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IDataLabels * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IDataLabels * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IDataLabels * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IDataLabels * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            IDataLabels * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            IDataLabels * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Border )( 
            IDataLabels * This,
            /* [retval][out] */ Border	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IDataLabels * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Interior )( 
            IDataLabels * This,
            /* [retval][out] */ Interior	**RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Fill )( 
            IDataLabels * This,
            /* [retval][out] */ ChartFillFormat	**RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy9 )( 
            IDataLabels * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy10 )( 
            IDataLabels * This);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Font )( 
            IDataLabels * This,
            /* [retval][out] */ Font	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HorizontalAlignment )( 
            IDataLabels * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_HorizontalAlignment )( 
            IDataLabels * This,
            /* [in] */ VARIANT RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy13 )( 
            IDataLabels * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Orientation )( 
            IDataLabels * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Orientation )( 
            IDataLabels * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Shadow )( 
            IDataLabels * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Shadow )( 
            IDataLabels * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy16 )( 
            IDataLabels * This);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy17 )( 
            IDataLabels * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_VerticalAlignment )( 
            IDataLabels * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_VerticalAlignment )( 
            IDataLabels * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ReadingOrder )( 
            IDataLabels * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ReadingOrder )( 
            IDataLabels * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_AutoScaleFont )( 
            IDataLabels * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_AutoScaleFont )( 
            IDataLabels * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AutoText )( 
            IDataLabels * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AutoText )( 
            IDataLabels * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_NumberFormat )( 
            IDataLabels * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_NumberFormat )( 
            IDataLabels * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_NumberFormatLinked )( 
            IDataLabels * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_NumberFormatLinked )( 
            IDataLabels * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_NumberFormatLocal )( 
            IDataLabels * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_NumberFormatLocal )( 
            IDataLabels * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShowLegendKey )( 
            IDataLabels * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ShowLegendKey )( 
            IDataLabels * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Type )( 
            IDataLabels * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_Type )( 
            IDataLabels * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Position )( 
            IDataLabels * This,
            /* [retval][out] */ XlDataLabelPosition *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Position )( 
            IDataLabels * This,
            /* [in] */ XlDataLabelPosition RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShowSeriesName )( 
            IDataLabels * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ShowSeriesName )( 
            IDataLabels * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShowCategoryName )( 
            IDataLabels * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ShowCategoryName )( 
            IDataLabels * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShowValue )( 
            IDataLabels * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ShowValue )( 
            IDataLabels * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShowPercentage )( 
            IDataLabels * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ShowPercentage )( 
            IDataLabels * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShowBubbleSize )( 
            IDataLabels * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ShowBubbleSize )( 
            IDataLabels * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Separator )( 
            IDataLabels * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Separator )( 
            IDataLabels * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IDataLabels * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Item )( 
            IDataLabels * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ DataLabel	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *_NewEnum )( 
            IDataLabels * This,
            /* [retval][out] */ IUnknown **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *_Default )( 
            IDataLabels * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ DataLabel	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Format )( 
            IDataLabels * This,
            /* [retval][out] */ ChartFormat	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Propagate )( 
            IDataLabels * This,
            /* [in] */ VARIANT Index);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShowRange )( 
            IDataLabels * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ShowRange )( 
            IDataLabels * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        END_INTERFACE
    } IDataLabelsVtbl;

    interface IDataLabels
    {
        CONST_VTBL struct IDataLabelsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IDataLabels_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IDataLabels_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IDataLabels_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IDataLabels_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IDataLabels_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IDataLabels_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IDataLabels_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IDataLabels_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IDataLabels_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IDataLabels_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IDataLabels_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define IDataLabels_Select(This,RHS)	\
    ( (This)->lpVtbl -> Select(This,RHS) ) 

#define IDataLabels_get_Border(This,RHS)	\
    ( (This)->lpVtbl -> get_Border(This,RHS) ) 

#define IDataLabels_Delete(This,RHS)	\
    ( (This)->lpVtbl -> Delete(This,RHS) ) 

#define IDataLabels_get_Interior(This,RHS)	\
    ( (This)->lpVtbl -> get_Interior(This,RHS) ) 

#define IDataLabels_get_Fill(This,RHS)	\
    ( (This)->lpVtbl -> get_Fill(This,RHS) ) 

#define IDataLabels__Dummy9(This)	\
    ( (This)->lpVtbl -> _Dummy9(This) ) 

#define IDataLabels__Dummy10(This)	\
    ( (This)->lpVtbl -> _Dummy10(This) ) 

#define IDataLabels_get_Font(This,RHS)	\
    ( (This)->lpVtbl -> get_Font(This,RHS) ) 

#define IDataLabels_get_HorizontalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> get_HorizontalAlignment(This,RHS) ) 

#define IDataLabels_put_HorizontalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> put_HorizontalAlignment(This,RHS) ) 

#define IDataLabels__Dummy13(This)	\
    ( (This)->lpVtbl -> _Dummy13(This) ) 

#define IDataLabels_get_Orientation(This,RHS)	\
    ( (This)->lpVtbl -> get_Orientation(This,RHS) ) 

#define IDataLabels_put_Orientation(This,RHS)	\
    ( (This)->lpVtbl -> put_Orientation(This,RHS) ) 

#define IDataLabels_get_Shadow(This,RHS)	\
    ( (This)->lpVtbl -> get_Shadow(This,RHS) ) 

#define IDataLabels_put_Shadow(This,RHS)	\
    ( (This)->lpVtbl -> put_Shadow(This,RHS) ) 

#define IDataLabels__Dummy16(This)	\
    ( (This)->lpVtbl -> _Dummy16(This) ) 

#define IDataLabels__Dummy17(This)	\
    ( (This)->lpVtbl -> _Dummy17(This) ) 

#define IDataLabels_get_VerticalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> get_VerticalAlignment(This,RHS) ) 

#define IDataLabels_put_VerticalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> put_VerticalAlignment(This,RHS) ) 

#define IDataLabels_get_ReadingOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_ReadingOrder(This,RHS) ) 

#define IDataLabels_put_ReadingOrder(This,RHS)	\
    ( (This)->lpVtbl -> put_ReadingOrder(This,RHS) ) 

#define IDataLabels_get_AutoScaleFont(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoScaleFont(This,RHS) ) 

#define IDataLabels_put_AutoScaleFont(This,RHS)	\
    ( (This)->lpVtbl -> put_AutoScaleFont(This,RHS) ) 

#define IDataLabels_get_AutoText(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoText(This,RHS) ) 

#define IDataLabels_put_AutoText(This,RHS)	\
    ( (This)->lpVtbl -> put_AutoText(This,RHS) ) 

#define IDataLabels_get_NumberFormat(This,RHS)	\
    ( (This)->lpVtbl -> get_NumberFormat(This,RHS) ) 

#define IDataLabels_put_NumberFormat(This,RHS)	\
    ( (This)->lpVtbl -> put_NumberFormat(This,RHS) ) 

#define IDataLabels_get_NumberFormatLinked(This,RHS)	\
    ( (This)->lpVtbl -> get_NumberFormatLinked(This,RHS) ) 

#define IDataLabels_put_NumberFormatLinked(This,RHS)	\
    ( (This)->lpVtbl -> put_NumberFormatLinked(This,RHS) ) 

#define IDataLabels_get_NumberFormatLocal(This,RHS)	\
    ( (This)->lpVtbl -> get_NumberFormatLocal(This,RHS) ) 

#define IDataLabels_put_NumberFormatLocal(This,RHS)	\
    ( (This)->lpVtbl -> put_NumberFormatLocal(This,RHS) ) 

#define IDataLabels_get_ShowLegendKey(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowLegendKey(This,RHS) ) 

#define IDataLabels_put_ShowLegendKey(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowLegendKey(This,RHS) ) 

#define IDataLabels_get_Type(This,RHS)	\
    ( (This)->lpVtbl -> get_Type(This,RHS) ) 

#define IDataLabels_put_Type(This,RHS)	\
    ( (This)->lpVtbl -> put_Type(This,RHS) ) 

#define IDataLabels_get_Position(This,RHS)	\
    ( (This)->lpVtbl -> get_Position(This,RHS) ) 

#define IDataLabels_put_Position(This,RHS)	\
    ( (This)->lpVtbl -> put_Position(This,RHS) ) 

#define IDataLabels_get_ShowSeriesName(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowSeriesName(This,RHS) ) 

#define IDataLabels_put_ShowSeriesName(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowSeriesName(This,RHS) ) 

#define IDataLabels_get_ShowCategoryName(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowCategoryName(This,RHS) ) 

#define IDataLabels_put_ShowCategoryName(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowCategoryName(This,RHS) ) 

#define IDataLabels_get_ShowValue(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowValue(This,RHS) ) 

#define IDataLabels_put_ShowValue(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowValue(This,RHS) ) 

#define IDataLabels_get_ShowPercentage(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowPercentage(This,RHS) ) 

#define IDataLabels_put_ShowPercentage(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowPercentage(This,RHS) ) 

#define IDataLabels_get_ShowBubbleSize(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowBubbleSize(This,RHS) ) 

#define IDataLabels_put_ShowBubbleSize(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowBubbleSize(This,RHS) ) 

#define IDataLabels_get_Separator(This,RHS)	\
    ( (This)->lpVtbl -> get_Separator(This,RHS) ) 

#define IDataLabels_put_Separator(This,RHS)	\
    ( (This)->lpVtbl -> put_Separator(This,RHS) ) 

#define IDataLabels_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IDataLabels_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> Item(This,Index,RHS) ) 

#define IDataLabels__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> _NewEnum(This,RHS) ) 

#define IDataLabels__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> _Default(This,Index,RHS) ) 

#define IDataLabels_get_Format(This,RHS)	\
    ( (This)->lpVtbl -> get_Format(This,RHS) ) 

#define IDataLabels_Propagate(This,Index)	\
    ( (This)->lpVtbl -> Propagate(This,Index) ) 

#define IDataLabels_get_ShowRange(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowRange(This,RHS) ) 

#define IDataLabels_put_ShowRange(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowRange(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IDataLabels_INTERFACE_DEFINED__ */


#ifndef __ILegendEntry_INTERFACE_DEFINED__
#define __ILegendEntry_INTERFACE_DEFINED__

/* interface ILegendEntry */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ILegendEntry;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000208BA-0001-0000-C000-000000000046")
    ILegendEntry : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Font( 
            /* [retval][out] */ Font	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Index( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LegendKey( 
            /* [retval][out] */ LegendKey	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_AutoScaleFont( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_AutoScaleFont( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Left( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Top( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Width( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Height( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Format( 
            /* [retval][out] */ ChartFormat	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ILegendEntryVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ILegendEntry * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ILegendEntry * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ILegendEntry * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ILegendEntry * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ILegendEntry * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ILegendEntry * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ILegendEntry * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ILegendEntry * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ILegendEntry * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ILegendEntry * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            ILegendEntry * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Font )( 
            ILegendEntry * This,
            /* [retval][out] */ Font	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Index )( 
            ILegendEntry * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LegendKey )( 
            ILegendEntry * This,
            /* [retval][out] */ LegendKey	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            ILegendEntry * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_AutoScaleFont )( 
            ILegendEntry * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_AutoScaleFont )( 
            ILegendEntry * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Left )( 
            ILegendEntry * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Top )( 
            ILegendEntry * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Width )( 
            ILegendEntry * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Height )( 
            ILegendEntry * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Format )( 
            ILegendEntry * This,
            /* [retval][out] */ ChartFormat	**RHS);
        
        END_INTERFACE
    } ILegendEntryVtbl;

    interface ILegendEntry
    {
        CONST_VTBL struct ILegendEntryVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ILegendEntry_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ILegendEntry_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ILegendEntry_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ILegendEntry_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ILegendEntry_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ILegendEntry_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ILegendEntry_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ILegendEntry_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ILegendEntry_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ILegendEntry_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ILegendEntry_Delete(This,RHS)	\
    ( (This)->lpVtbl -> Delete(This,RHS) ) 

#define ILegendEntry_get_Font(This,RHS)	\
    ( (This)->lpVtbl -> get_Font(This,RHS) ) 

#define ILegendEntry_get_Index(This,RHS)	\
    ( (This)->lpVtbl -> get_Index(This,RHS) ) 

#define ILegendEntry_get_LegendKey(This,RHS)	\
    ( (This)->lpVtbl -> get_LegendKey(This,RHS) ) 

#define ILegendEntry_Select(This,RHS)	\
    ( (This)->lpVtbl -> Select(This,RHS) ) 

#define ILegendEntry_get_AutoScaleFont(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoScaleFont(This,RHS) ) 

#define ILegendEntry_put_AutoScaleFont(This,RHS)	\
    ( (This)->lpVtbl -> put_AutoScaleFont(This,RHS) ) 

#define ILegendEntry_get_Left(This,RHS)	\
    ( (This)->lpVtbl -> get_Left(This,RHS) ) 

#define ILegendEntry_get_Top(This,RHS)	\
    ( (This)->lpVtbl -> get_Top(This,RHS) ) 

#define ILegendEntry_get_Width(This,RHS)	\
    ( (This)->lpVtbl -> get_Width(This,RHS) ) 

#define ILegendEntry_get_Height(This,RHS)	\
    ( (This)->lpVtbl -> get_Height(This,RHS) ) 

#define ILegendEntry_get_Format(This,RHS)	\
    ( (This)->lpVtbl -> get_Format(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ILegendEntry_INTERFACE_DEFINED__ */


#ifndef __ILegendEntries_INTERFACE_DEFINED__
#define __ILegendEntries_INTERFACE_DEFINED__

/* interface ILegendEntries */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ILegendEntries;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000208BB-0001-0000-C000-000000000046")
    ILegendEntries : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ LegendEntry	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall _NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall _Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ LegendEntry	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ILegendEntriesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ILegendEntries * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ILegendEntries * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ILegendEntries * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ILegendEntries * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ILegendEntries * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ILegendEntries * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ILegendEntries * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ILegendEntries * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ILegendEntries * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ILegendEntries * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            ILegendEntries * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Item )( 
            ILegendEntries * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ LegendEntry	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *_NewEnum )( 
            ILegendEntries * This,
            /* [retval][out] */ IUnknown **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *_Default )( 
            ILegendEntries * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ LegendEntry	**RHS);
        
        END_INTERFACE
    } ILegendEntriesVtbl;

    interface ILegendEntries
    {
        CONST_VTBL struct ILegendEntriesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ILegendEntries_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ILegendEntries_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ILegendEntries_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ILegendEntries_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ILegendEntries_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ILegendEntries_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ILegendEntries_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ILegendEntries_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ILegendEntries_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ILegendEntries_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ILegendEntries_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define ILegendEntries_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> Item(This,Index,RHS) ) 

#define ILegendEntries__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> _NewEnum(This,RHS) ) 

#define ILegendEntries__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> _Default(This,Index,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ILegendEntries_INTERFACE_DEFINED__ */


#ifndef __ILegendKey_INTERFACE_DEFINED__
#define __ILegendKey_INTERFACE_DEFINED__

/* interface ILegendKey */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ILegendKey;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000208BC-0001-0000-C000-000000000046")
    ILegendKey : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Border( 
            /* [retval][out] */ Border	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ClearFormats( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Interior( 
            /* [retval][out] */ Interior	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Fill( 
            /* [retval][out] */ ChartFillFormat	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_InvertIfNegative( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_InvertIfNegative( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MarkerBackgroundColor( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_MarkerBackgroundColor( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MarkerBackgroundColorIndex( 
            /* [retval][out] */ XlColorIndex *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_MarkerBackgroundColorIndex( 
            /* [in] */ XlColorIndex RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MarkerForegroundColor( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_MarkerForegroundColor( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MarkerForegroundColorIndex( 
            /* [retval][out] */ XlColorIndex *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_MarkerForegroundColorIndex( 
            /* [in] */ XlColorIndex RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MarkerSize( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_MarkerSize( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MarkerStyle( 
            /* [retval][out] */ XlMarkerStyle *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_MarkerStyle( 
            /* [in] */ XlMarkerStyle RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PictureType( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PictureType( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_PictureUnit( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_PictureUnit( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall Select( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Smooth( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Smooth( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Left( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Top( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Width( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Height( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Shadow( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Shadow( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PictureUnit2( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PictureUnit2( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Format( 
            /* [retval][out] */ ChartFormat	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ILegendKeyVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ILegendKey * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ILegendKey * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ILegendKey * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ILegendKey * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ILegendKey * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ILegendKey * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ILegendKey * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ILegendKey * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ILegendKey * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ILegendKey * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Border )( 
            ILegendKey * This,
            /* [retval][out] */ Border	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ClearFormats )( 
            ILegendKey * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            ILegendKey * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Interior )( 
            ILegendKey * This,
            /* [retval][out] */ Interior	**RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Fill )( 
            ILegendKey * This,
            /* [retval][out] */ ChartFillFormat	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_InvertIfNegative )( 
            ILegendKey * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_InvertIfNegative )( 
            ILegendKey * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MarkerBackgroundColor )( 
            ILegendKey * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_MarkerBackgroundColor )( 
            ILegendKey * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MarkerBackgroundColorIndex )( 
            ILegendKey * This,
            /* [retval][out] */ XlColorIndex *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_MarkerBackgroundColorIndex )( 
            ILegendKey * This,
            /* [in] */ XlColorIndex RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MarkerForegroundColor )( 
            ILegendKey * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_MarkerForegroundColor )( 
            ILegendKey * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MarkerForegroundColorIndex )( 
            ILegendKey * This,
            /* [retval][out] */ XlColorIndex *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_MarkerForegroundColorIndex )( 
            ILegendKey * This,
            /* [in] */ XlColorIndex RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MarkerSize )( 
            ILegendKey * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_MarkerSize )( 
            ILegendKey * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MarkerStyle )( 
            ILegendKey * This,
            /* [retval][out] */ XlMarkerStyle *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_MarkerStyle )( 
            ILegendKey * This,
            /* [in] */ XlMarkerStyle RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PictureType )( 
            ILegendKey * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PictureType )( 
            ILegendKey * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_PictureUnit )( 
            ILegendKey * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_PictureUnit )( 
            ILegendKey * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *Select )( 
            ILegendKey * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Smooth )( 
            ILegendKey * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Smooth )( 
            ILegendKey * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Left )( 
            ILegendKey * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Top )( 
            ILegendKey * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Width )( 
            ILegendKey * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Height )( 
            ILegendKey * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Shadow )( 
            ILegendKey * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Shadow )( 
            ILegendKey * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PictureUnit2 )( 
            ILegendKey * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PictureUnit2 )( 
            ILegendKey * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Format )( 
            ILegendKey * This,
            /* [retval][out] */ ChartFormat	**RHS);
        
        END_INTERFACE
    } ILegendKeyVtbl;

    interface ILegendKey
    {
        CONST_VTBL struct ILegendKeyVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ILegendKey_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ILegendKey_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ILegendKey_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ILegendKey_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ILegendKey_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ILegendKey_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ILegendKey_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ILegendKey_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ILegendKey_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ILegendKey_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ILegendKey_get_Border(This,RHS)	\
    ( (This)->lpVtbl -> get_Border(This,RHS) ) 

#define ILegendKey_ClearFormats(This,RHS)	\
    ( (This)->lpVtbl -> ClearFormats(This,RHS) ) 

#define ILegendKey_Delete(This,RHS)	\
    ( (This)->lpVtbl -> Delete(This,RHS) ) 

#define ILegendKey_get_Interior(This,RHS)	\
    ( (This)->lpVtbl -> get_Interior(This,RHS) ) 

#define ILegendKey_get_Fill(This,RHS)	\
    ( (This)->lpVtbl -> get_Fill(This,RHS) ) 

#define ILegendKey_get_InvertIfNegative(This,RHS)	\
    ( (This)->lpVtbl -> get_InvertIfNegative(This,RHS) ) 

#define ILegendKey_put_InvertIfNegative(This,RHS)	\
    ( (This)->lpVtbl -> put_InvertIfNegative(This,RHS) ) 

#define ILegendKey_get_MarkerBackgroundColor(This,RHS)	\
    ( (This)->lpVtbl -> get_MarkerBackgroundColor(This,RHS) ) 

#define ILegendKey_put_MarkerBackgroundColor(This,RHS)	\
    ( (This)->lpVtbl -> put_MarkerBackgroundColor(This,RHS) ) 

#define ILegendKey_get_MarkerBackgroundColorIndex(This,RHS)	\
    ( (This)->lpVtbl -> get_MarkerBackgroundColorIndex(This,RHS) ) 

#define ILegendKey_put_MarkerBackgroundColorIndex(This,RHS)	\
    ( (This)->lpVtbl -> put_MarkerBackgroundColorIndex(This,RHS) ) 

#define ILegendKey_get_MarkerForegroundColor(This,RHS)	\
    ( (This)->lpVtbl -> get_MarkerForegroundColor(This,RHS) ) 

#define ILegendKey_put_MarkerForegroundColor(This,RHS)	\
    ( (This)->lpVtbl -> put_MarkerForegroundColor(This,RHS) ) 

#define ILegendKey_get_MarkerForegroundColorIndex(This,RHS)	\
    ( (This)->lpVtbl -> get_MarkerForegroundColorIndex(This,RHS) ) 

#define ILegendKey_put_MarkerForegroundColorIndex(This,RHS)	\
    ( (This)->lpVtbl -> put_MarkerForegroundColorIndex(This,RHS) ) 

#define ILegendKey_get_MarkerSize(This,RHS)	\
    ( (This)->lpVtbl -> get_MarkerSize(This,RHS) ) 

#define ILegendKey_put_MarkerSize(This,RHS)	\
    ( (This)->lpVtbl -> put_MarkerSize(This,RHS) ) 

#define ILegendKey_get_MarkerStyle(This,RHS)	\
    ( (This)->lpVtbl -> get_MarkerStyle(This,RHS) ) 

#define ILegendKey_put_MarkerStyle(This,RHS)	\
    ( (This)->lpVtbl -> put_MarkerStyle(This,RHS) ) 

#define ILegendKey_get_PictureType(This,RHS)	\
    ( (This)->lpVtbl -> get_PictureType(This,RHS) ) 

#define ILegendKey_put_PictureType(This,RHS)	\
    ( (This)->lpVtbl -> put_PictureType(This,RHS) ) 

#define ILegendKey_get_PictureUnit(This,RHS)	\
    ( (This)->lpVtbl -> get_PictureUnit(This,RHS) ) 

#define ILegendKey_put_PictureUnit(This,RHS)	\
    ( (This)->lpVtbl -> put_PictureUnit(This,RHS) ) 

#define ILegendKey_Select(This,RHS)	\
    ( (This)->lpVtbl -> Select(This,RHS) ) 

#define ILegendKey_get_Smooth(This,RHS)	\
    ( (This)->lpVtbl -> get_Smooth(This,RHS) ) 

#define ILegendKey_put_Smooth(This,RHS)	\
    ( (This)->lpVtbl -> put_Smooth(This,RHS) ) 

#define ILegendKey_get_Left(This,RHS)	\
    ( (This)->lpVtbl -> get_Left(This,RHS) ) 

#define ILegendKey_get_Top(This,RHS)	\
    ( (This)->lpVtbl -> get_Top(This,RHS) ) 

#define ILegendKey_get_Width(This,RHS)	\
    ( (This)->lpVtbl -> get_Width(This,RHS) ) 

#define ILegendKey_get_Height(This,RHS)	\
    ( (This)->lpVtbl -> get_Height(This,RHS) ) 

#define ILegendKey_get_Shadow(This,RHS)	\
    ( (This)->lpVtbl -> get_Shadow(This,RHS) ) 

#define ILegendKey_put_Shadow(This,RHS)	\
    ( (This)->lpVtbl -> put_Shadow(This,RHS) ) 

#define ILegendKey_get_PictureUnit2(This,RHS)	\
    ( (This)->lpVtbl -> get_PictureUnit2(This,RHS) ) 

#define ILegendKey_put_PictureUnit2(This,RHS)	\
    ( (This)->lpVtbl -> put_PictureUnit2(This,RHS) ) 

#define ILegendKey_get_Format(This,RHS)	\
    ( (This)->lpVtbl -> get_Format(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ILegendKey_INTERFACE_DEFINED__ */


#ifndef __ITrendlines_INTERFACE_DEFINED__
#define __ITrendlines_INTERFACE_DEFINED__

/* interface ITrendlines */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ITrendlines;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000208BD-0001-0000-C000-000000000046")
    ITrendlines : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add( 
            /* [defaultvalue][optional][in] */ XlTrendlineType Type,
            /* [optional][in] */ VARIANT Order,
            /* [optional][in] */ VARIANT Period,
            /* [optional][in] */ VARIANT Forward,
            /* [optional][in] */ VARIANT Backward,
            /* [optional][in] */ VARIANT Intercept,
            /* [optional][in] */ VARIANT DisplayEquation,
            /* [optional][in] */ VARIANT DisplayRSquared,
            /* [optional][in] */ VARIANT Name,
            /* [retval][out] */ Trendline	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Item( 
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ Trendline	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall _NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall _Default( 
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ Trendline	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ITrendlinesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ITrendlines * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ITrendlines * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ITrendlines * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ITrendlines * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ITrendlines * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ITrendlines * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ITrendlines * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ITrendlines * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ITrendlines * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ITrendlines * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add )( 
            ITrendlines * This,
            /* [defaultvalue][optional][in] */ XlTrendlineType Type,
            /* [optional][in] */ VARIANT Order,
            /* [optional][in] */ VARIANT Period,
            /* [optional][in] */ VARIANT Forward,
            /* [optional][in] */ VARIANT Backward,
            /* [optional][in] */ VARIANT Intercept,
            /* [optional][in] */ VARIANT DisplayEquation,
            /* [optional][in] */ VARIANT DisplayRSquared,
            /* [optional][in] */ VARIANT Name,
            /* [retval][out] */ Trendline	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            ITrendlines * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Item )( 
            ITrendlines * This,
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ Trendline	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *_NewEnum )( 
            ITrendlines * This,
            /* [retval][out] */ IUnknown **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *_Default )( 
            ITrendlines * This,
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ Trendline	**RHS);
        
        END_INTERFACE
    } ITrendlinesVtbl;

    interface ITrendlines
    {
        CONST_VTBL struct ITrendlinesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ITrendlines_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ITrendlines_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ITrendlines_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ITrendlines_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ITrendlines_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ITrendlines_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ITrendlines_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ITrendlines_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ITrendlines_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ITrendlines_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ITrendlines_Add(This,Type,Order,Period,Forward,Backward,Intercept,DisplayEquation,DisplayRSquared,Name,RHS)	\
    ( (This)->lpVtbl -> Add(This,Type,Order,Period,Forward,Backward,Intercept,DisplayEquation,DisplayRSquared,Name,RHS) ) 

#define ITrendlines_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define ITrendlines_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> Item(This,Index,RHS) ) 

#define ITrendlines__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> _NewEnum(This,RHS) ) 

#define ITrendlines__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> _Default(This,Index,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ITrendlines_INTERFACE_DEFINED__ */


#ifndef __ITrendline_INTERFACE_DEFINED__
#define __ITrendline_INTERFACE_DEFINED__

/* interface ITrendline */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ITrendline;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000208BE-0001-0000-C000-000000000046")
    ITrendline : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Backward( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_Backward( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Border( 
            /* [retval][out] */ Border	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ClearFormats( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DataLabel( 
            /* [retval][out] */ DataLabel	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DisplayEquation( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DisplayEquation( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DisplayRSquared( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DisplayRSquared( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Forward( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_Forward( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Index( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Intercept( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Intercept( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_InterceptIsAuto( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_InterceptIsAuto( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Name( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_NameIsAuto( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_NameIsAuto( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Order( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Order( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Period( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Period( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Type( 
            /* [retval][out] */ XlTrendlineType *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Type( 
            /* [in] */ XlTrendlineType RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Backward2( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Backward2( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Forward2( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Forward2( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Format( 
            /* [retval][out] */ ChartFormat	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ITrendlineVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ITrendline * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ITrendline * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ITrendline * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ITrendline * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ITrendline * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ITrendline * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ITrendline * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ITrendline * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ITrendline * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ITrendline * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Backward )( 
            ITrendline * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_Backward )( 
            ITrendline * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Border )( 
            ITrendline * This,
            /* [retval][out] */ Border	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ClearFormats )( 
            ITrendline * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DataLabel )( 
            ITrendline * This,
            /* [retval][out] */ DataLabel	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            ITrendline * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DisplayEquation )( 
            ITrendline * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DisplayEquation )( 
            ITrendline * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DisplayRSquared )( 
            ITrendline * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DisplayRSquared )( 
            ITrendline * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Forward )( 
            ITrendline * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_Forward )( 
            ITrendline * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Index )( 
            ITrendline * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Intercept )( 
            ITrendline * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Intercept )( 
            ITrendline * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_InterceptIsAuto )( 
            ITrendline * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_InterceptIsAuto )( 
            ITrendline * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            ITrendline * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Name )( 
            ITrendline * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_NameIsAuto )( 
            ITrendline * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_NameIsAuto )( 
            ITrendline * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Order )( 
            ITrendline * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Order )( 
            ITrendline * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Period )( 
            ITrendline * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Period )( 
            ITrendline * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            ITrendline * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Type )( 
            ITrendline * This,
            /* [retval][out] */ XlTrendlineType *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Type )( 
            ITrendline * This,
            /* [in] */ XlTrendlineType RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Backward2 )( 
            ITrendline * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Backward2 )( 
            ITrendline * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Forward2 )( 
            ITrendline * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Forward2 )( 
            ITrendline * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Format )( 
            ITrendline * This,
            /* [retval][out] */ ChartFormat	**RHS);
        
        END_INTERFACE
    } ITrendlineVtbl;

    interface ITrendline
    {
        CONST_VTBL struct ITrendlineVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ITrendline_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ITrendline_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ITrendline_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ITrendline_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ITrendline_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ITrendline_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ITrendline_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ITrendline_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ITrendline_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ITrendline_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ITrendline_get_Backward(This,RHS)	\
    ( (This)->lpVtbl -> get_Backward(This,RHS) ) 

#define ITrendline_put_Backward(This,RHS)	\
    ( (This)->lpVtbl -> put_Backward(This,RHS) ) 

#define ITrendline_get_Border(This,RHS)	\
    ( (This)->lpVtbl -> get_Border(This,RHS) ) 

#define ITrendline_ClearFormats(This,RHS)	\
    ( (This)->lpVtbl -> ClearFormats(This,RHS) ) 

#define ITrendline_get_DataLabel(This,RHS)	\
    ( (This)->lpVtbl -> get_DataLabel(This,RHS) ) 

#define ITrendline_Delete(This,RHS)	\
    ( (This)->lpVtbl -> Delete(This,RHS) ) 

#define ITrendline_get_DisplayEquation(This,RHS)	\
    ( (This)->lpVtbl -> get_DisplayEquation(This,RHS) ) 

#define ITrendline_put_DisplayEquation(This,RHS)	\
    ( (This)->lpVtbl -> put_DisplayEquation(This,RHS) ) 

#define ITrendline_get_DisplayRSquared(This,RHS)	\
    ( (This)->lpVtbl -> get_DisplayRSquared(This,RHS) ) 

#define ITrendline_put_DisplayRSquared(This,RHS)	\
    ( (This)->lpVtbl -> put_DisplayRSquared(This,RHS) ) 

#define ITrendline_get_Forward(This,RHS)	\
    ( (This)->lpVtbl -> get_Forward(This,RHS) ) 

#define ITrendline_put_Forward(This,RHS)	\
    ( (This)->lpVtbl -> put_Forward(This,RHS) ) 

#define ITrendline_get_Index(This,RHS)	\
    ( (This)->lpVtbl -> get_Index(This,RHS) ) 

#define ITrendline_get_Intercept(This,RHS)	\
    ( (This)->lpVtbl -> get_Intercept(This,RHS) ) 

#define ITrendline_put_Intercept(This,RHS)	\
    ( (This)->lpVtbl -> put_Intercept(This,RHS) ) 

#define ITrendline_get_InterceptIsAuto(This,RHS)	\
    ( (This)->lpVtbl -> get_InterceptIsAuto(This,RHS) ) 

#define ITrendline_put_InterceptIsAuto(This,RHS)	\
    ( (This)->lpVtbl -> put_InterceptIsAuto(This,RHS) ) 

#define ITrendline_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define ITrendline_put_Name(This,RHS)	\
    ( (This)->lpVtbl -> put_Name(This,RHS) ) 

#define ITrendline_get_NameIsAuto(This,RHS)	\
    ( (This)->lpVtbl -> get_NameIsAuto(This,RHS) ) 

#define ITrendline_put_NameIsAuto(This,RHS)	\
    ( (This)->lpVtbl -> put_NameIsAuto(This,RHS) ) 

#define ITrendline_get_Order(This,RHS)	\
    ( (This)->lpVtbl -> get_Order(This,RHS) ) 

#define ITrendline_put_Order(This,RHS)	\
    ( (This)->lpVtbl -> put_Order(This,RHS) ) 

#define ITrendline_get_Period(This,RHS)	\
    ( (This)->lpVtbl -> get_Period(This,RHS) ) 

#define ITrendline_put_Period(This,RHS)	\
    ( (This)->lpVtbl -> put_Period(This,RHS) ) 

#define ITrendline_Select(This,RHS)	\
    ( (This)->lpVtbl -> Select(This,RHS) ) 

#define ITrendline_get_Type(This,RHS)	\
    ( (This)->lpVtbl -> get_Type(This,RHS) ) 

#define ITrendline_put_Type(This,RHS)	\
    ( (This)->lpVtbl -> put_Type(This,RHS) ) 

#define ITrendline_get_Backward2(This,RHS)	\
    ( (This)->lpVtbl -> get_Backward2(This,RHS) ) 

#define ITrendline_put_Backward2(This,RHS)	\
    ( (This)->lpVtbl -> put_Backward2(This,RHS) ) 

#define ITrendline_get_Forward2(This,RHS)	\
    ( (This)->lpVtbl -> get_Forward2(This,RHS) ) 

#define ITrendline_put_Forward2(This,RHS)	\
    ( (This)->lpVtbl -> put_Forward2(This,RHS) ) 

#define ITrendline_get_Format(This,RHS)	\
    ( (This)->lpVtbl -> get_Format(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ITrendline_INTERFACE_DEFINED__ */


#ifndef __ICorners_INTERFACE_DEFINED__
#define __ICorners_INTERFACE_DEFINED__

/* interface ICorners */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ICorners;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000208C0-0001-0000-C000-000000000046")
    ICorners : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall Select( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ICornersVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ICorners * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ICorners * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ICorners * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ICorners * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ICorners * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ICorners * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ICorners * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ICorners * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ICorners * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ICorners * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            ICorners * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *Select )( 
            ICorners * This,
            /* [retval][out] */ VARIANT *RHS);
        
        END_INTERFACE
    } ICornersVtbl;

    interface ICorners
    {
        CONST_VTBL struct ICornersVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ICorners_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ICorners_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ICorners_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ICorners_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ICorners_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ICorners_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ICorners_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ICorners_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ICorners_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ICorners_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ICorners_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define ICorners_Select(This,RHS)	\
    ( (This)->lpVtbl -> Select(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ICorners_INTERFACE_DEFINED__ */


#ifndef __ISeriesLines_INTERFACE_DEFINED__
#define __ISeriesLines_INTERFACE_DEFINED__

/* interface ISeriesLines */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ISeriesLines;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000208C1-0001-0000-C000-000000000046")
    ISeriesLines : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Border( 
            /* [retval][out] */ Border	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Format( 
            /* [retval][out] */ ChartFormat	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ISeriesLinesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ISeriesLines * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ISeriesLines * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ISeriesLines * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ISeriesLines * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ISeriesLines * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ISeriesLines * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ISeriesLines * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ISeriesLines * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ISeriesLines * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ISeriesLines * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            ISeriesLines * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            ISeriesLines * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Border )( 
            ISeriesLines * This,
            /* [retval][out] */ Border	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            ISeriesLines * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Format )( 
            ISeriesLines * This,
            /* [retval][out] */ ChartFormat	**RHS);
        
        END_INTERFACE
    } ISeriesLinesVtbl;

    interface ISeriesLines
    {
        CONST_VTBL struct ISeriesLinesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ISeriesLines_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ISeriesLines_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ISeriesLines_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ISeriesLines_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ISeriesLines_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ISeriesLines_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ISeriesLines_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ISeriesLines_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ISeriesLines_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ISeriesLines_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ISeriesLines_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define ISeriesLines_Select(This,RHS)	\
    ( (This)->lpVtbl -> Select(This,RHS) ) 

#define ISeriesLines_get_Border(This,RHS)	\
    ( (This)->lpVtbl -> get_Border(This,RHS) ) 

#define ISeriesLines_Delete(This,RHS)	\
    ( (This)->lpVtbl -> Delete(This,RHS) ) 

#define ISeriesLines_get_Format(This,RHS)	\
    ( (This)->lpVtbl -> get_Format(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ISeriesLines_INTERFACE_DEFINED__ */


#ifndef __IHiLoLines_INTERFACE_DEFINED__
#define __IHiLoLines_INTERFACE_DEFINED__

/* interface IHiLoLines */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IHiLoLines;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000208C2-0001-0000-C000-000000000046")
    IHiLoLines : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Border( 
            /* [retval][out] */ Border	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Format( 
            /* [retval][out] */ ChartFormat	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IHiLoLinesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IHiLoLines * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IHiLoLines * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IHiLoLines * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IHiLoLines * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IHiLoLines * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IHiLoLines * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IHiLoLines * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IHiLoLines * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IHiLoLines * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IHiLoLines * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            IHiLoLines * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            IHiLoLines * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Border )( 
            IHiLoLines * This,
            /* [retval][out] */ Border	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IHiLoLines * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Format )( 
            IHiLoLines * This,
            /* [retval][out] */ ChartFormat	**RHS);
        
        END_INTERFACE
    } IHiLoLinesVtbl;

    interface IHiLoLines
    {
        CONST_VTBL struct IHiLoLinesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IHiLoLines_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IHiLoLines_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IHiLoLines_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IHiLoLines_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IHiLoLines_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IHiLoLines_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IHiLoLines_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IHiLoLines_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IHiLoLines_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IHiLoLines_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IHiLoLines_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define IHiLoLines_Select(This,RHS)	\
    ( (This)->lpVtbl -> Select(This,RHS) ) 

#define IHiLoLines_get_Border(This,RHS)	\
    ( (This)->lpVtbl -> get_Border(This,RHS) ) 

#define IHiLoLines_Delete(This,RHS)	\
    ( (This)->lpVtbl -> Delete(This,RHS) ) 

#define IHiLoLines_get_Format(This,RHS)	\
    ( (This)->lpVtbl -> get_Format(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IHiLoLines_INTERFACE_DEFINED__ */


#ifndef __IGridlines_INTERFACE_DEFINED__
#define __IGridlines_INTERFACE_DEFINED__

/* interface IGridlines */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IGridlines;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000208C3-0001-0000-C000-000000000046")
    IGridlines : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Border( 
            /* [retval][out] */ Border	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Format( 
            /* [retval][out] */ ChartFormat	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IGridlinesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IGridlines * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IGridlines * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IGridlines * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IGridlines * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IGridlines * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IGridlines * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IGridlines * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IGridlines * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IGridlines * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IGridlines * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            IGridlines * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            IGridlines * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Border )( 
            IGridlines * This,
            /* [retval][out] */ Border	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IGridlines * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Format )( 
            IGridlines * This,
            /* [retval][out] */ ChartFormat	**RHS);
        
        END_INTERFACE
    } IGridlinesVtbl;

    interface IGridlines
    {
        CONST_VTBL struct IGridlinesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IGridlines_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IGridlines_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IGridlines_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IGridlines_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IGridlines_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IGridlines_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IGridlines_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IGridlines_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IGridlines_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IGridlines_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IGridlines_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define IGridlines_Select(This,RHS)	\
    ( (This)->lpVtbl -> Select(This,RHS) ) 

#define IGridlines_get_Border(This,RHS)	\
    ( (This)->lpVtbl -> get_Border(This,RHS) ) 

#define IGridlines_Delete(This,RHS)	\
    ( (This)->lpVtbl -> Delete(This,RHS) ) 

#define IGridlines_get_Format(This,RHS)	\
    ( (This)->lpVtbl -> get_Format(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IGridlines_INTERFACE_DEFINED__ */


#ifndef __IDropLines_INTERFACE_DEFINED__
#define __IDropLines_INTERFACE_DEFINED__

/* interface IDropLines */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IDropLines;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000208C4-0001-0000-C000-000000000046")
    IDropLines : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Border( 
            /* [retval][out] */ Border	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Format( 
            /* [retval][out] */ ChartFormat	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IDropLinesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IDropLines * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IDropLines * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IDropLines * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IDropLines * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IDropLines * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IDropLines * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IDropLines * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IDropLines * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IDropLines * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IDropLines * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            IDropLines * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            IDropLines * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Border )( 
            IDropLines * This,
            /* [retval][out] */ Border	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IDropLines * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Format )( 
            IDropLines * This,
            /* [retval][out] */ ChartFormat	**RHS);
        
        END_INTERFACE
    } IDropLinesVtbl;

    interface IDropLines
    {
        CONST_VTBL struct IDropLinesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IDropLines_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IDropLines_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IDropLines_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IDropLines_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IDropLines_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IDropLines_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IDropLines_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IDropLines_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IDropLines_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IDropLines_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IDropLines_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define IDropLines_Select(This,RHS)	\
    ( (This)->lpVtbl -> Select(This,RHS) ) 

#define IDropLines_get_Border(This,RHS)	\
    ( (This)->lpVtbl -> get_Border(This,RHS) ) 

#define IDropLines_Delete(This,RHS)	\
    ( (This)->lpVtbl -> Delete(This,RHS) ) 

#define IDropLines_get_Format(This,RHS)	\
    ( (This)->lpVtbl -> get_Format(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IDropLines_INTERFACE_DEFINED__ */


#ifndef __ILeaderLines_INTERFACE_DEFINED__
#define __ILeaderLines_INTERFACE_DEFINED__

/* interface ILeaderLines */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ILeaderLines;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024437-0001-0000-C000-000000000046")
    ILeaderLines : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Border( 
            /* [retval][out] */ Border	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Format( 
            /* [retval][out] */ ChartFormat	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ILeaderLinesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ILeaderLines * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ILeaderLines * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ILeaderLines * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ILeaderLines * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ILeaderLines * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ILeaderLines * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ILeaderLines * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ILeaderLines * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ILeaderLines * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ILeaderLines * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Border )( 
            ILeaderLines * This,
            /* [retval][out] */ Border	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            ILeaderLines * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            ILeaderLines * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Format )( 
            ILeaderLines * This,
            /* [retval][out] */ ChartFormat	**RHS);
        
        END_INTERFACE
    } ILeaderLinesVtbl;

    interface ILeaderLines
    {
        CONST_VTBL struct ILeaderLinesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ILeaderLines_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ILeaderLines_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ILeaderLines_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ILeaderLines_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ILeaderLines_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ILeaderLines_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ILeaderLines_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ILeaderLines_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ILeaderLines_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ILeaderLines_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ILeaderLines_get_Border(This,RHS)	\
    ( (This)->lpVtbl -> get_Border(This,RHS) ) 

#define ILeaderLines_Delete(This)	\
    ( (This)->lpVtbl -> Delete(This) ) 

#define ILeaderLines_Select(This)	\
    ( (This)->lpVtbl -> Select(This) ) 

#define ILeaderLines_get_Format(This,RHS)	\
    ( (This)->lpVtbl -> get_Format(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ILeaderLines_INTERFACE_DEFINED__ */


#ifndef __IUpBars_INTERFACE_DEFINED__
#define __IUpBars_INTERFACE_DEFINED__

/* interface IUpBars */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IUpBars;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000208C5-0001-0000-C000-000000000046")
    IUpBars : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Border( 
            /* [retval][out] */ Border	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Interior( 
            /* [retval][out] */ Interior	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Fill( 
            /* [retval][out] */ ChartFillFormat	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Format( 
            /* [retval][out] */ ChartFormat	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IUpBarsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IUpBars * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IUpBars * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IUpBars * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IUpBars * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IUpBars * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IUpBars * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IUpBars * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IUpBars * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IUpBars * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IUpBars * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            IUpBars * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            IUpBars * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Border )( 
            IUpBars * This,
            /* [retval][out] */ Border	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IUpBars * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Interior )( 
            IUpBars * This,
            /* [retval][out] */ Interior	**RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Fill )( 
            IUpBars * This,
            /* [retval][out] */ ChartFillFormat	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Format )( 
            IUpBars * This,
            /* [retval][out] */ ChartFormat	**RHS);
        
        END_INTERFACE
    } IUpBarsVtbl;

    interface IUpBars
    {
        CONST_VTBL struct IUpBarsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IUpBars_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IUpBars_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IUpBars_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IUpBars_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IUpBars_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IUpBars_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IUpBars_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IUpBars_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IUpBars_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IUpBars_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IUpBars_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define IUpBars_Select(This,RHS)	\
    ( (This)->lpVtbl -> Select(This,RHS) ) 

#define IUpBars_get_Border(This,RHS)	\
    ( (This)->lpVtbl -> get_Border(This,RHS) ) 

#define IUpBars_Delete(This,RHS)	\
    ( (This)->lpVtbl -> Delete(This,RHS) ) 

#define IUpBars_get_Interior(This,RHS)	\
    ( (This)->lpVtbl -> get_Interior(This,RHS) ) 

#define IUpBars_get_Fill(This,RHS)	\
    ( (This)->lpVtbl -> get_Fill(This,RHS) ) 

#define IUpBars_get_Format(This,RHS)	\
    ( (This)->lpVtbl -> get_Format(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IUpBars_INTERFACE_DEFINED__ */


#ifndef __IDownBars_INTERFACE_DEFINED__
#define __IDownBars_INTERFACE_DEFINED__

/* interface IDownBars */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IDownBars;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000208C6-0001-0000-C000-000000000046")
    IDownBars : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Border( 
            /* [retval][out] */ Border	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Interior( 
            /* [retval][out] */ Interior	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Fill( 
            /* [retval][out] */ ChartFillFormat	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Format( 
            /* [retval][out] */ ChartFormat	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IDownBarsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IDownBars * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IDownBars * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IDownBars * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IDownBars * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IDownBars * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IDownBars * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IDownBars * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IDownBars * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IDownBars * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IDownBars * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            IDownBars * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            IDownBars * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Border )( 
            IDownBars * This,
            /* [retval][out] */ Border	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IDownBars * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Interior )( 
            IDownBars * This,
            /* [retval][out] */ Interior	**RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Fill )( 
            IDownBars * This,
            /* [retval][out] */ ChartFillFormat	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Format )( 
            IDownBars * This,
            /* [retval][out] */ ChartFormat	**RHS);
        
        END_INTERFACE
    } IDownBarsVtbl;

    interface IDownBars
    {
        CONST_VTBL struct IDownBarsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IDownBars_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IDownBars_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IDownBars_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IDownBars_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IDownBars_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IDownBars_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IDownBars_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IDownBars_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IDownBars_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IDownBars_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IDownBars_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define IDownBars_Select(This,RHS)	\
    ( (This)->lpVtbl -> Select(This,RHS) ) 

#define IDownBars_get_Border(This,RHS)	\
    ( (This)->lpVtbl -> get_Border(This,RHS) ) 

#define IDownBars_Delete(This,RHS)	\
    ( (This)->lpVtbl -> Delete(This,RHS) ) 

#define IDownBars_get_Interior(This,RHS)	\
    ( (This)->lpVtbl -> get_Interior(This,RHS) ) 

#define IDownBars_get_Fill(This,RHS)	\
    ( (This)->lpVtbl -> get_Fill(This,RHS) ) 

#define IDownBars_get_Format(This,RHS)	\
    ( (This)->lpVtbl -> get_Format(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IDownBars_INTERFACE_DEFINED__ */


#ifndef __IFloor_INTERFACE_DEFINED__
#define __IFloor_INTERFACE_DEFINED__

/* interface IFloor */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IFloor;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000208C7-0001-0000-C000-000000000046")
    IFloor : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Border( 
            /* [retval][out] */ Border	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ClearFormats( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Interior( 
            /* [retval][out] */ Interior	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Fill( 
            /* [retval][out] */ ChartFillFormat	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PictureType( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PictureType( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Paste( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Thickness( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Thickness( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Format( 
            /* [retval][out] */ ChartFormat	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IFloorVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IFloor * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IFloor * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IFloor * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IFloor * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IFloor * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IFloor * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IFloor * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IFloor * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IFloor * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IFloor * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            IFloor * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            IFloor * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Border )( 
            IFloor * This,
            /* [retval][out] */ Border	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ClearFormats )( 
            IFloor * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Interior )( 
            IFloor * This,
            /* [retval][out] */ Interior	**RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Fill )( 
            IFloor * This,
            /* [retval][out] */ ChartFillFormat	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PictureType )( 
            IFloor * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PictureType )( 
            IFloor * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Paste )( 
            IFloor * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Thickness )( 
            IFloor * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Thickness )( 
            IFloor * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Format )( 
            IFloor * This,
            /* [retval][out] */ ChartFormat	**RHS);
        
        END_INTERFACE
    } IFloorVtbl;

    interface IFloor
    {
        CONST_VTBL struct IFloorVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IFloor_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IFloor_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IFloor_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IFloor_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IFloor_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IFloor_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IFloor_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IFloor_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IFloor_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IFloor_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IFloor_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define IFloor_Select(This,RHS)	\
    ( (This)->lpVtbl -> Select(This,RHS) ) 

#define IFloor_get_Border(This,RHS)	\
    ( (This)->lpVtbl -> get_Border(This,RHS) ) 

#define IFloor_ClearFormats(This,RHS)	\
    ( (This)->lpVtbl -> ClearFormats(This,RHS) ) 

#define IFloor_get_Interior(This,RHS)	\
    ( (This)->lpVtbl -> get_Interior(This,RHS) ) 

#define IFloor_get_Fill(This,RHS)	\
    ( (This)->lpVtbl -> get_Fill(This,RHS) ) 

#define IFloor_get_PictureType(This,RHS)	\
    ( (This)->lpVtbl -> get_PictureType(This,RHS) ) 

#define IFloor_put_PictureType(This,RHS)	\
    ( (This)->lpVtbl -> put_PictureType(This,RHS) ) 

#define IFloor_Paste(This)	\
    ( (This)->lpVtbl -> Paste(This) ) 

#define IFloor_get_Thickness(This,RHS)	\
    ( (This)->lpVtbl -> get_Thickness(This,RHS) ) 

#define IFloor_put_Thickness(This,RHS)	\
    ( (This)->lpVtbl -> put_Thickness(This,RHS) ) 

#define IFloor_get_Format(This,RHS)	\
    ( (This)->lpVtbl -> get_Format(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IFloor_INTERFACE_DEFINED__ */


#ifndef __IWalls_INTERFACE_DEFINED__
#define __IWalls_INTERFACE_DEFINED__

/* interface IWalls */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IWalls;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000208C8-0001-0000-C000-000000000046")
    IWalls : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Border( 
            /* [retval][out] */ Border	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ClearFormats( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Interior( 
            /* [retval][out] */ Interior	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Fill( 
            /* [retval][out] */ ChartFillFormat	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PictureType( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PictureType( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Paste( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PictureUnit( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PictureUnit( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Thickness( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Thickness( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Format( 
            /* [retval][out] */ ChartFormat	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IWallsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IWalls * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IWalls * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IWalls * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IWalls * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IWalls * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IWalls * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IWalls * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IWalls * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IWalls * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IWalls * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            IWalls * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            IWalls * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Border )( 
            IWalls * This,
            /* [retval][out] */ Border	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ClearFormats )( 
            IWalls * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Interior )( 
            IWalls * This,
            /* [retval][out] */ Interior	**RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Fill )( 
            IWalls * This,
            /* [retval][out] */ ChartFillFormat	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PictureType )( 
            IWalls * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PictureType )( 
            IWalls * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Paste )( 
            IWalls * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PictureUnit )( 
            IWalls * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PictureUnit )( 
            IWalls * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Thickness )( 
            IWalls * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Thickness )( 
            IWalls * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Format )( 
            IWalls * This,
            /* [retval][out] */ ChartFormat	**RHS);
        
        END_INTERFACE
    } IWallsVtbl;

    interface IWalls
    {
        CONST_VTBL struct IWallsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IWalls_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IWalls_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IWalls_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IWalls_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IWalls_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IWalls_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IWalls_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IWalls_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IWalls_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IWalls_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IWalls_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define IWalls_Select(This,RHS)	\
    ( (This)->lpVtbl -> Select(This,RHS) ) 

#define IWalls_get_Border(This,RHS)	\
    ( (This)->lpVtbl -> get_Border(This,RHS) ) 

#define IWalls_ClearFormats(This,RHS)	\
    ( (This)->lpVtbl -> ClearFormats(This,RHS) ) 

#define IWalls_get_Interior(This,RHS)	\
    ( (This)->lpVtbl -> get_Interior(This,RHS) ) 

#define IWalls_get_Fill(This,RHS)	\
    ( (This)->lpVtbl -> get_Fill(This,RHS) ) 

#define IWalls_get_PictureType(This,RHS)	\
    ( (This)->lpVtbl -> get_PictureType(This,RHS) ) 

#define IWalls_put_PictureType(This,RHS)	\
    ( (This)->lpVtbl -> put_PictureType(This,RHS) ) 

#define IWalls_Paste(This)	\
    ( (This)->lpVtbl -> Paste(This) ) 

#define IWalls_get_PictureUnit(This,RHS)	\
    ( (This)->lpVtbl -> get_PictureUnit(This,RHS) ) 

#define IWalls_put_PictureUnit(This,RHS)	\
    ( (This)->lpVtbl -> put_PictureUnit(This,RHS) ) 

#define IWalls_get_Thickness(This,RHS)	\
    ( (This)->lpVtbl -> get_Thickness(This,RHS) ) 

#define IWalls_put_Thickness(This,RHS)	\
    ( (This)->lpVtbl -> put_Thickness(This,RHS) ) 

#define IWalls_get_Format(This,RHS)	\
    ( (This)->lpVtbl -> get_Format(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IWalls_INTERFACE_DEFINED__ */


#ifndef __ITickLabels_INTERFACE_DEFINED__
#define __ITickLabels_INTERFACE_DEFINED__

/* interface ITickLabels */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ITickLabels;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000208C9-0001-0000-C000-000000000046")
    ITickLabels : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Font( 
            /* [retval][out] */ Font	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_NumberFormat( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_NumberFormat( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_NumberFormatLinked( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_NumberFormatLinked( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_NumberFormatLocal( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_NumberFormatLocal( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Orientation( 
            /* [retval][out] */ XlTickLabelOrientation *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Orientation( 
            /* [in] */ XlTickLabelOrientation RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ReadingOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ReadingOrder( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_AutoScaleFont( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_AutoScaleFont( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Depth( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Offset( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Offset( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Alignment( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Alignment( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MultiLevel( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_MultiLevel( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Format( 
            /* [retval][out] */ ChartFormat	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ITickLabelsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ITickLabels * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ITickLabels * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ITickLabels * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ITickLabels * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ITickLabels * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ITickLabels * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ITickLabels * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ITickLabels * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ITickLabels * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ITickLabels * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            ITickLabels * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Font )( 
            ITickLabels * This,
            /* [retval][out] */ Font	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            ITickLabels * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_NumberFormat )( 
            ITickLabels * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_NumberFormat )( 
            ITickLabels * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_NumberFormatLinked )( 
            ITickLabels * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_NumberFormatLinked )( 
            ITickLabels * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_NumberFormatLocal )( 
            ITickLabels * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_NumberFormatLocal )( 
            ITickLabels * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Orientation )( 
            ITickLabels * This,
            /* [retval][out] */ XlTickLabelOrientation *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Orientation )( 
            ITickLabels * This,
            /* [in] */ XlTickLabelOrientation RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            ITickLabels * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ReadingOrder )( 
            ITickLabels * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ReadingOrder )( 
            ITickLabels * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_AutoScaleFont )( 
            ITickLabels * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_AutoScaleFont )( 
            ITickLabels * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Depth )( 
            ITickLabels * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Offset )( 
            ITickLabels * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Offset )( 
            ITickLabels * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Alignment )( 
            ITickLabels * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Alignment )( 
            ITickLabels * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MultiLevel )( 
            ITickLabels * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_MultiLevel )( 
            ITickLabels * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Format )( 
            ITickLabels * This,
            /* [retval][out] */ ChartFormat	**RHS);
        
        END_INTERFACE
    } ITickLabelsVtbl;

    interface ITickLabels
    {
        CONST_VTBL struct ITickLabelsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ITickLabels_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ITickLabels_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ITickLabels_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ITickLabels_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ITickLabels_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ITickLabels_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ITickLabels_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ITickLabels_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ITickLabels_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ITickLabels_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ITickLabels_Delete(This,RHS)	\
    ( (This)->lpVtbl -> Delete(This,RHS) ) 

#define ITickLabels_get_Font(This,RHS)	\
    ( (This)->lpVtbl -> get_Font(This,RHS) ) 

#define ITickLabels_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define ITickLabels_get_NumberFormat(This,RHS)	\
    ( (This)->lpVtbl -> get_NumberFormat(This,RHS) ) 

#define ITickLabels_put_NumberFormat(This,RHS)	\
    ( (This)->lpVtbl -> put_NumberFormat(This,RHS) ) 

#define ITickLabels_get_NumberFormatLinked(This,RHS)	\
    ( (This)->lpVtbl -> get_NumberFormatLinked(This,RHS) ) 

#define ITickLabels_put_NumberFormatLinked(This,RHS)	\
    ( (This)->lpVtbl -> put_NumberFormatLinked(This,RHS) ) 

#define ITickLabels_get_NumberFormatLocal(This,RHS)	\
    ( (This)->lpVtbl -> get_NumberFormatLocal(This,RHS) ) 

#define ITickLabels_put_NumberFormatLocal(This,RHS)	\
    ( (This)->lpVtbl -> put_NumberFormatLocal(This,RHS) ) 

#define ITickLabels_get_Orientation(This,RHS)	\
    ( (This)->lpVtbl -> get_Orientation(This,RHS) ) 

#define ITickLabels_put_Orientation(This,RHS)	\
    ( (This)->lpVtbl -> put_Orientation(This,RHS) ) 

#define ITickLabels_Select(This,RHS)	\
    ( (This)->lpVtbl -> Select(This,RHS) ) 

#define ITickLabels_get_ReadingOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_ReadingOrder(This,RHS) ) 

#define ITickLabels_put_ReadingOrder(This,RHS)	\
    ( (This)->lpVtbl -> put_ReadingOrder(This,RHS) ) 

#define ITickLabels_get_AutoScaleFont(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoScaleFont(This,RHS) ) 

#define ITickLabels_put_AutoScaleFont(This,RHS)	\
    ( (This)->lpVtbl -> put_AutoScaleFont(This,RHS) ) 

#define ITickLabels_get_Depth(This,RHS)	\
    ( (This)->lpVtbl -> get_Depth(This,RHS) ) 

#define ITickLabels_get_Offset(This,RHS)	\
    ( (This)->lpVtbl -> get_Offset(This,RHS) ) 

#define ITickLabels_put_Offset(This,RHS)	\
    ( (This)->lpVtbl -> put_Offset(This,RHS) ) 

#define ITickLabels_get_Alignment(This,RHS)	\
    ( (This)->lpVtbl -> get_Alignment(This,RHS) ) 

#define ITickLabels_put_Alignment(This,RHS)	\
    ( (This)->lpVtbl -> put_Alignment(This,RHS) ) 

#define ITickLabels_get_MultiLevel(This,RHS)	\
    ( (This)->lpVtbl -> get_MultiLevel(This,RHS) ) 

#define ITickLabels_put_MultiLevel(This,RHS)	\
    ( (This)->lpVtbl -> put_MultiLevel(This,RHS) ) 

#define ITickLabels_get_Format(This,RHS)	\
    ( (This)->lpVtbl -> get_Format(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ITickLabels_INTERFACE_DEFINED__ */


#ifndef __IPlotArea_INTERFACE_DEFINED__
#define __IPlotArea_INTERFACE_DEFINED__

/* interface IPlotArea */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IPlotArea;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000208CB-0001-0000-C000-000000000046")
    IPlotArea : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Border( 
            /* [retval][out] */ Border	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ClearFormats( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Height( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Height( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Interior( 
            /* [retval][out] */ Interior	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Fill( 
            /* [retval][out] */ ChartFillFormat	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Left( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Left( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Top( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Top( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Width( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Width( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get__InsideLeft( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get__InsideTop( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get__InsideWidth( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get__InsideHeight( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_InsideLeft( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_InsideLeft( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_InsideTop( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_InsideTop( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_InsideWidth( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_InsideWidth( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_InsideHeight( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_InsideHeight( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Position( 
            /* [retval][out] */ XlChartElementPosition *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Position( 
            /* [in] */ XlChartElementPosition RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Format( 
            /* [retval][out] */ ChartFormat	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IPlotAreaVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IPlotArea * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IPlotArea * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IPlotArea * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IPlotArea * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IPlotArea * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IPlotArea * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IPlotArea * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IPlotArea * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IPlotArea * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IPlotArea * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            IPlotArea * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            IPlotArea * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Border )( 
            IPlotArea * This,
            /* [retval][out] */ Border	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ClearFormats )( 
            IPlotArea * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Height )( 
            IPlotArea * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Height )( 
            IPlotArea * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Interior )( 
            IPlotArea * This,
            /* [retval][out] */ Interior	**RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Fill )( 
            IPlotArea * This,
            /* [retval][out] */ ChartFillFormat	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Left )( 
            IPlotArea * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Left )( 
            IPlotArea * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Top )( 
            IPlotArea * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Top )( 
            IPlotArea * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Width )( 
            IPlotArea * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Width )( 
            IPlotArea * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get__InsideLeft )( 
            IPlotArea * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get__InsideTop )( 
            IPlotArea * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get__InsideWidth )( 
            IPlotArea * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get__InsideHeight )( 
            IPlotArea * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_InsideLeft )( 
            IPlotArea * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_InsideLeft )( 
            IPlotArea * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_InsideTop )( 
            IPlotArea * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_InsideTop )( 
            IPlotArea * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_InsideWidth )( 
            IPlotArea * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_InsideWidth )( 
            IPlotArea * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_InsideHeight )( 
            IPlotArea * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_InsideHeight )( 
            IPlotArea * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Position )( 
            IPlotArea * This,
            /* [retval][out] */ XlChartElementPosition *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Position )( 
            IPlotArea * This,
            /* [in] */ XlChartElementPosition RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Format )( 
            IPlotArea * This,
            /* [retval][out] */ ChartFormat	**RHS);
        
        END_INTERFACE
    } IPlotAreaVtbl;

    interface IPlotArea
    {
        CONST_VTBL struct IPlotAreaVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IPlotArea_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IPlotArea_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IPlotArea_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IPlotArea_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IPlotArea_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IPlotArea_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IPlotArea_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IPlotArea_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IPlotArea_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IPlotArea_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IPlotArea_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define IPlotArea_Select(This,RHS)	\
    ( (This)->lpVtbl -> Select(This,RHS) ) 

#define IPlotArea_get_Border(This,RHS)	\
    ( (This)->lpVtbl -> get_Border(This,RHS) ) 

#define IPlotArea_ClearFormats(This,RHS)	\
    ( (This)->lpVtbl -> ClearFormats(This,RHS) ) 

#define IPlotArea_get_Height(This,RHS)	\
    ( (This)->lpVtbl -> get_Height(This,RHS) ) 

#define IPlotArea_put_Height(This,RHS)	\
    ( (This)->lpVtbl -> put_Height(This,RHS) ) 

#define IPlotArea_get_Interior(This,RHS)	\
    ( (This)->lpVtbl -> get_Interior(This,RHS) ) 

#define IPlotArea_get_Fill(This,RHS)	\
    ( (This)->lpVtbl -> get_Fill(This,RHS) ) 

#define IPlotArea_get_Left(This,RHS)	\
    ( (This)->lpVtbl -> get_Left(This,RHS) ) 

#define IPlotArea_put_Left(This,RHS)	\
    ( (This)->lpVtbl -> put_Left(This,RHS) ) 

#define IPlotArea_get_Top(This,RHS)	\
    ( (This)->lpVtbl -> get_Top(This,RHS) ) 

#define IPlotArea_put_Top(This,RHS)	\
    ( (This)->lpVtbl -> put_Top(This,RHS) ) 

#define IPlotArea_get_Width(This,RHS)	\
    ( (This)->lpVtbl -> get_Width(This,RHS) ) 

#define IPlotArea_put_Width(This,RHS)	\
    ( (This)->lpVtbl -> put_Width(This,RHS) ) 

#define IPlotArea_get__InsideLeft(This,RHS)	\
    ( (This)->lpVtbl -> get__InsideLeft(This,RHS) ) 

#define IPlotArea_get__InsideTop(This,RHS)	\
    ( (This)->lpVtbl -> get__InsideTop(This,RHS) ) 

#define IPlotArea_get__InsideWidth(This,RHS)	\
    ( (This)->lpVtbl -> get__InsideWidth(This,RHS) ) 

#define IPlotArea_get__InsideHeight(This,RHS)	\
    ( (This)->lpVtbl -> get__InsideHeight(This,RHS) ) 

#define IPlotArea_get_InsideLeft(This,RHS)	\
    ( (This)->lpVtbl -> get_InsideLeft(This,RHS) ) 

#define IPlotArea_put_InsideLeft(This,RHS)	\
    ( (This)->lpVtbl -> put_InsideLeft(This,RHS) ) 

#define IPlotArea_get_InsideTop(This,RHS)	\
    ( (This)->lpVtbl -> get_InsideTop(This,RHS) ) 

#define IPlotArea_put_InsideTop(This,RHS)	\
    ( (This)->lpVtbl -> put_InsideTop(This,RHS) ) 

#define IPlotArea_get_InsideWidth(This,RHS)	\
    ( (This)->lpVtbl -> get_InsideWidth(This,RHS) ) 

#define IPlotArea_put_InsideWidth(This,RHS)	\
    ( (This)->lpVtbl -> put_InsideWidth(This,RHS) ) 

#define IPlotArea_get_InsideHeight(This,RHS)	\
    ( (This)->lpVtbl -> get_InsideHeight(This,RHS) ) 

#define IPlotArea_put_InsideHeight(This,RHS)	\
    ( (This)->lpVtbl -> put_InsideHeight(This,RHS) ) 

#define IPlotArea_get_Position(This,RHS)	\
    ( (This)->lpVtbl -> get_Position(This,RHS) ) 

#define IPlotArea_put_Position(This,RHS)	\
    ( (This)->lpVtbl -> put_Position(This,RHS) ) 

#define IPlotArea_get_Format(This,RHS)	\
    ( (This)->lpVtbl -> get_Format(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IPlotArea_INTERFACE_DEFINED__ */


#ifndef __IChartArea_INTERFACE_DEFINED__
#define __IChartArea_INTERFACE_DEFINED__

/* interface IChartArea */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IChartArea;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000208CC-0001-0000-C000-000000000046")
    IChartArea : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Border( 
            /* [retval][out] */ Border	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Clear( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ClearContents( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Copy( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Font( 
            /* [retval][out] */ Font	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Shadow( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Shadow( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ClearFormats( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Height( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Height( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Interior( 
            /* [retval][out] */ Interior	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Fill( 
            /* [retval][out] */ ChartFillFormat	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Left( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Left( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Top( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Top( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Width( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Width( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_AutoScaleFont( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_AutoScaleFont( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Format( 
            /* [retval][out] */ ChartFormat	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RoundedCorners( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_RoundedCorners( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IChartAreaVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IChartArea * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IChartArea * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IChartArea * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IChartArea * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IChartArea * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IChartArea * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IChartArea * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IChartArea * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IChartArea * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IChartArea * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            IChartArea * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            IChartArea * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Border )( 
            IChartArea * This,
            /* [retval][out] */ Border	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Clear )( 
            IChartArea * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ClearContents )( 
            IChartArea * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Copy )( 
            IChartArea * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Font )( 
            IChartArea * This,
            /* [retval][out] */ Font	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Shadow )( 
            IChartArea * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Shadow )( 
            IChartArea * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ClearFormats )( 
            IChartArea * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Height )( 
            IChartArea * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Height )( 
            IChartArea * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Interior )( 
            IChartArea * This,
            /* [retval][out] */ Interior	**RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Fill )( 
            IChartArea * This,
            /* [retval][out] */ ChartFillFormat	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Left )( 
            IChartArea * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Left )( 
            IChartArea * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Top )( 
            IChartArea * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Top )( 
            IChartArea * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Width )( 
            IChartArea * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Width )( 
            IChartArea * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_AutoScaleFont )( 
            IChartArea * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_AutoScaleFont )( 
            IChartArea * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Format )( 
            IChartArea * This,
            /* [retval][out] */ ChartFormat	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RoundedCorners )( 
            IChartArea * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_RoundedCorners )( 
            IChartArea * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        END_INTERFACE
    } IChartAreaVtbl;

    interface IChartArea
    {
        CONST_VTBL struct IChartAreaVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IChartArea_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IChartArea_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IChartArea_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IChartArea_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IChartArea_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IChartArea_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IChartArea_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IChartArea_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IChartArea_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IChartArea_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IChartArea_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define IChartArea_Select(This,RHS)	\
    ( (This)->lpVtbl -> Select(This,RHS) ) 

#define IChartArea_get_Border(This,RHS)	\
    ( (This)->lpVtbl -> get_Border(This,RHS) ) 

#define IChartArea_Clear(This,RHS)	\
    ( (This)->lpVtbl -> Clear(This,RHS) ) 

#define IChartArea_ClearContents(This,RHS)	\
    ( (This)->lpVtbl -> ClearContents(This,RHS) ) 

#define IChartArea_Copy(This,RHS)	\
    ( (This)->lpVtbl -> Copy(This,RHS) ) 

#define IChartArea_get_Font(This,RHS)	\
    ( (This)->lpVtbl -> get_Font(This,RHS) ) 

#define IChartArea_get_Shadow(This,RHS)	\
    ( (This)->lpVtbl -> get_Shadow(This,RHS) ) 

#define IChartArea_put_Shadow(This,RHS)	\
    ( (This)->lpVtbl -> put_Shadow(This,RHS) ) 

#define IChartArea_ClearFormats(This,RHS)	\
    ( (This)->lpVtbl -> ClearFormats(This,RHS) ) 

#define IChartArea_get_Height(This,RHS)	\
    ( (This)->lpVtbl -> get_Height(This,RHS) ) 

#define IChartArea_put_Height(This,RHS)	\
    ( (This)->lpVtbl -> put_Height(This,RHS) ) 

#define IChartArea_get_Interior(This,RHS)	\
    ( (This)->lpVtbl -> get_Interior(This,RHS) ) 

#define IChartArea_get_Fill(This,RHS)	\
    ( (This)->lpVtbl -> get_Fill(This,RHS) ) 

#define IChartArea_get_Left(This,RHS)	\
    ( (This)->lpVtbl -> get_Left(This,RHS) ) 

#define IChartArea_put_Left(This,RHS)	\
    ( (This)->lpVtbl -> put_Left(This,RHS) ) 

#define IChartArea_get_Top(This,RHS)	\
    ( (This)->lpVtbl -> get_Top(This,RHS) ) 

#define IChartArea_put_Top(This,RHS)	\
    ( (This)->lpVtbl -> put_Top(This,RHS) ) 

#define IChartArea_get_Width(This,RHS)	\
    ( (This)->lpVtbl -> get_Width(This,RHS) ) 

#define IChartArea_put_Width(This,RHS)	\
    ( (This)->lpVtbl -> put_Width(This,RHS) ) 

#define IChartArea_get_AutoScaleFont(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoScaleFont(This,RHS) ) 

#define IChartArea_put_AutoScaleFont(This,RHS)	\
    ( (This)->lpVtbl -> put_AutoScaleFont(This,RHS) ) 

#define IChartArea_get_Format(This,RHS)	\
    ( (This)->lpVtbl -> get_Format(This,RHS) ) 

#define IChartArea_get_RoundedCorners(This,RHS)	\
    ( (This)->lpVtbl -> get_RoundedCorners(This,RHS) ) 

#define IChartArea_put_RoundedCorners(This,RHS)	\
    ( (This)->lpVtbl -> put_RoundedCorners(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IChartArea_INTERFACE_DEFINED__ */


#ifndef __ILegend_INTERFACE_DEFINED__
#define __ILegend_INTERFACE_DEFINED__

/* interface ILegend */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ILegend;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000208CD-0001-0000-C000-000000000046")
    ILegend : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Border( 
            /* [retval][out] */ Border	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Font( 
            /* [retval][out] */ Font	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall LegendEntries( 
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Position( 
            /* [retval][out] */ XlLegendPosition *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Position( 
            /* [in] */ XlLegendPosition RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Shadow( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Shadow( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Clear( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Height( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Height( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Interior( 
            /* [retval][out] */ Interior	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Fill( 
            /* [retval][out] */ ChartFillFormat	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Left( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Left( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Top( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Top( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Width( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Width( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_AutoScaleFont( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_AutoScaleFont( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_IncludeInLayout( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_IncludeInLayout( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Format( 
            /* [retval][out] */ ChartFormat	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ILegendVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ILegend * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ILegend * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ILegend * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ILegend * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ILegend * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ILegend * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ILegend * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ILegend * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ILegend * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ILegend * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            ILegend * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            ILegend * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Border )( 
            ILegend * This,
            /* [retval][out] */ Border	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            ILegend * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Font )( 
            ILegend * This,
            /* [retval][out] */ Font	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *LegendEntries )( 
            ILegend * This,
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Position )( 
            ILegend * This,
            /* [retval][out] */ XlLegendPosition *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Position )( 
            ILegend * This,
            /* [in] */ XlLegendPosition RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Shadow )( 
            ILegend * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Shadow )( 
            ILegend * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Clear )( 
            ILegend * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Height )( 
            ILegend * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Height )( 
            ILegend * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Interior )( 
            ILegend * This,
            /* [retval][out] */ Interior	**RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Fill )( 
            ILegend * This,
            /* [retval][out] */ ChartFillFormat	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Left )( 
            ILegend * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Left )( 
            ILegend * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Top )( 
            ILegend * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Top )( 
            ILegend * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Width )( 
            ILegend * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Width )( 
            ILegend * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_AutoScaleFont )( 
            ILegend * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_AutoScaleFont )( 
            ILegend * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_IncludeInLayout )( 
            ILegend * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_IncludeInLayout )( 
            ILegend * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Format )( 
            ILegend * This,
            /* [retval][out] */ ChartFormat	**RHS);
        
        END_INTERFACE
    } ILegendVtbl;

    interface ILegend
    {
        CONST_VTBL struct ILegendVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ILegend_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ILegend_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ILegend_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ILegend_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ILegend_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ILegend_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ILegend_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ILegend_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ILegend_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ILegend_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ILegend_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define ILegend_Select(This,RHS)	\
    ( (This)->lpVtbl -> Select(This,RHS) ) 

#define ILegend_get_Border(This,RHS)	\
    ( (This)->lpVtbl -> get_Border(This,RHS) ) 

#define ILegend_Delete(This,RHS)	\
    ( (This)->lpVtbl -> Delete(This,RHS) ) 

#define ILegend_get_Font(This,RHS)	\
    ( (This)->lpVtbl -> get_Font(This,RHS) ) 

#define ILegend_LegendEntries(This,Index,RHS)	\
    ( (This)->lpVtbl -> LegendEntries(This,Index,RHS) ) 

#define ILegend_get_Position(This,RHS)	\
    ( (This)->lpVtbl -> get_Position(This,RHS) ) 

#define ILegend_put_Position(This,RHS)	\
    ( (This)->lpVtbl -> put_Position(This,RHS) ) 

#define ILegend_get_Shadow(This,RHS)	\
    ( (This)->lpVtbl -> get_Shadow(This,RHS) ) 

#define ILegend_put_Shadow(This,RHS)	\
    ( (This)->lpVtbl -> put_Shadow(This,RHS) ) 

#define ILegend_Clear(This,RHS)	\
    ( (This)->lpVtbl -> Clear(This,RHS) ) 

#define ILegend_get_Height(This,RHS)	\
    ( (This)->lpVtbl -> get_Height(This,RHS) ) 

#define ILegend_put_Height(This,RHS)	\
    ( (This)->lpVtbl -> put_Height(This,RHS) ) 

#define ILegend_get_Interior(This,RHS)	\
    ( (This)->lpVtbl -> get_Interior(This,RHS) ) 

#define ILegend_get_Fill(This,RHS)	\
    ( (This)->lpVtbl -> get_Fill(This,RHS) ) 

#define ILegend_get_Left(This,RHS)	\
    ( (This)->lpVtbl -> get_Left(This,RHS) ) 

#define ILegend_put_Left(This,RHS)	\
    ( (This)->lpVtbl -> put_Left(This,RHS) ) 

#define ILegend_get_Top(This,RHS)	\
    ( (This)->lpVtbl -> get_Top(This,RHS) ) 

#define ILegend_put_Top(This,RHS)	\
    ( (This)->lpVtbl -> put_Top(This,RHS) ) 

#define ILegend_get_Width(This,RHS)	\
    ( (This)->lpVtbl -> get_Width(This,RHS) ) 

#define ILegend_put_Width(This,RHS)	\
    ( (This)->lpVtbl -> put_Width(This,RHS) ) 

#define ILegend_get_AutoScaleFont(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoScaleFont(This,RHS) ) 

#define ILegend_put_AutoScaleFont(This,RHS)	\
    ( (This)->lpVtbl -> put_AutoScaleFont(This,RHS) ) 

#define ILegend_get_IncludeInLayout(This,RHS)	\
    ( (This)->lpVtbl -> get_IncludeInLayout(This,RHS) ) 

#define ILegend_put_IncludeInLayout(This,RHS)	\
    ( (This)->lpVtbl -> put_IncludeInLayout(This,RHS) ) 

#define ILegend_get_Format(This,RHS)	\
    ( (This)->lpVtbl -> get_Format(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ILegend_INTERFACE_DEFINED__ */


#ifndef __IErrorBars_INTERFACE_DEFINED__
#define __IErrorBars_INTERFACE_DEFINED__

/* interface IErrorBars */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IErrorBars;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000208CE-0001-0000-C000-000000000046")
    IErrorBars : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Border( 
            /* [retval][out] */ Border	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ClearFormats( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_EndStyle( 
            /* [retval][out] */ XlEndStyleCap *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_EndStyle( 
            /* [in] */ XlEndStyleCap RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Format( 
            /* [retval][out] */ ChartFormat	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IErrorBarsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IErrorBars * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IErrorBars * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IErrorBars * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IErrorBars * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IErrorBars * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IErrorBars * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IErrorBars * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IErrorBars * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IErrorBars * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IErrorBars * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            IErrorBars * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            IErrorBars * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Border )( 
            IErrorBars * This,
            /* [retval][out] */ Border	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IErrorBars * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ClearFormats )( 
            IErrorBars * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_EndStyle )( 
            IErrorBars * This,
            /* [retval][out] */ XlEndStyleCap *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_EndStyle )( 
            IErrorBars * This,
            /* [in] */ XlEndStyleCap RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Format )( 
            IErrorBars * This,
            /* [retval][out] */ ChartFormat	**RHS);
        
        END_INTERFACE
    } IErrorBarsVtbl;

    interface IErrorBars
    {
        CONST_VTBL struct IErrorBarsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IErrorBars_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IErrorBars_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IErrorBars_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IErrorBars_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IErrorBars_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IErrorBars_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IErrorBars_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IErrorBars_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IErrorBars_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IErrorBars_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IErrorBars_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define IErrorBars_Select(This,RHS)	\
    ( (This)->lpVtbl -> Select(This,RHS) ) 

#define IErrorBars_get_Border(This,RHS)	\
    ( (This)->lpVtbl -> get_Border(This,RHS) ) 

#define IErrorBars_Delete(This,RHS)	\
    ( (This)->lpVtbl -> Delete(This,RHS) ) 

#define IErrorBars_ClearFormats(This,RHS)	\
    ( (This)->lpVtbl -> ClearFormats(This,RHS) ) 

#define IErrorBars_get_EndStyle(This,RHS)	\
    ( (This)->lpVtbl -> get_EndStyle(This,RHS) ) 

#define IErrorBars_put_EndStyle(This,RHS)	\
    ( (This)->lpVtbl -> put_EndStyle(This,RHS) ) 

#define IErrorBars_get_Format(This,RHS)	\
    ( (This)->lpVtbl -> get_Format(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IErrorBars_INTERFACE_DEFINED__ */


#ifndef __IDataTable_INTERFACE_DEFINED__
#define __IDataTable_INTERFACE_DEFINED__

/* interface IDataTable */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IDataTable;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00020843-0001-0000-C000-000000000046")
    IDataTable : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShowLegendKey( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ShowLegendKey( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HasBorderHorizontal( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_HasBorderHorizontal( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HasBorderVertical( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_HasBorderVertical( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HasBorderOutline( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_HasBorderOutline( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Border( 
            /* [retval][out] */ Border	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Font( 
            /* [retval][out] */ Font	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( void) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_AutoScaleFont( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_AutoScaleFont( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Format( 
            /* [retval][out] */ ChartFormat	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IDataTableVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IDataTable * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IDataTable * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IDataTable * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IDataTable * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IDataTable * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IDataTable * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IDataTable * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IDataTable * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IDataTable * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IDataTable * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShowLegendKey )( 
            IDataTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ShowLegendKey )( 
            IDataTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HasBorderHorizontal )( 
            IDataTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_HasBorderHorizontal )( 
            IDataTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HasBorderVertical )( 
            IDataTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_HasBorderVertical )( 
            IDataTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HasBorderOutline )( 
            IDataTable * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_HasBorderOutline )( 
            IDataTable * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Border )( 
            IDataTable * This,
            /* [retval][out] */ Border	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Font )( 
            IDataTable * This,
            /* [retval][out] */ Font	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            IDataTable * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IDataTable * This);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_AutoScaleFont )( 
            IDataTable * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_AutoScaleFont )( 
            IDataTable * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Format )( 
            IDataTable * This,
            /* [retval][out] */ ChartFormat	**RHS);
        
        END_INTERFACE
    } IDataTableVtbl;

    interface IDataTable
    {
        CONST_VTBL struct IDataTableVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IDataTable_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IDataTable_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IDataTable_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IDataTable_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IDataTable_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IDataTable_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IDataTable_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IDataTable_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IDataTable_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IDataTable_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IDataTable_get_ShowLegendKey(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowLegendKey(This,RHS) ) 

#define IDataTable_put_ShowLegendKey(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowLegendKey(This,RHS) ) 

#define IDataTable_get_HasBorderHorizontal(This,RHS)	\
    ( (This)->lpVtbl -> get_HasBorderHorizontal(This,RHS) ) 

#define IDataTable_put_HasBorderHorizontal(This,RHS)	\
    ( (This)->lpVtbl -> put_HasBorderHorizontal(This,RHS) ) 

#define IDataTable_get_HasBorderVertical(This,RHS)	\
    ( (This)->lpVtbl -> get_HasBorderVertical(This,RHS) ) 

#define IDataTable_put_HasBorderVertical(This,RHS)	\
    ( (This)->lpVtbl -> put_HasBorderVertical(This,RHS) ) 

#define IDataTable_get_HasBorderOutline(This,RHS)	\
    ( (This)->lpVtbl -> get_HasBorderOutline(This,RHS) ) 

#define IDataTable_put_HasBorderOutline(This,RHS)	\
    ( (This)->lpVtbl -> put_HasBorderOutline(This,RHS) ) 

#define IDataTable_get_Border(This,RHS)	\
    ( (This)->lpVtbl -> get_Border(This,RHS) ) 

#define IDataTable_get_Font(This,RHS)	\
    ( (This)->lpVtbl -> get_Font(This,RHS) ) 

#define IDataTable_Select(This)	\
    ( (This)->lpVtbl -> Select(This) ) 

#define IDataTable_Delete(This)	\
    ( (This)->lpVtbl -> Delete(This) ) 

#define IDataTable_get_AutoScaleFont(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoScaleFont(This,RHS) ) 

#define IDataTable_put_AutoScaleFont(This,RHS)	\
    ( (This)->lpVtbl -> put_AutoScaleFont(This,RHS) ) 

#define IDataTable_get_Format(This,RHS)	\
    ( (This)->lpVtbl -> get_Format(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IDataTable_INTERFACE_DEFINED__ */


#ifndef __IPhonetic_INTERFACE_DEFINED__
#define __IPhonetic_INTERFACE_DEFINED__

/* interface IPhonetic */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IPhonetic;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024438-0001-0000-C000-000000000046")
    IPhonetic : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Visible( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Visible( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CharacterType( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_CharacterType( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Alignment( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Alignment( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Font( 
            /* [retval][out] */ Font	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Text( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Text( 
            /* [in] */ BSTR RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IPhoneticVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IPhonetic * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IPhonetic * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IPhonetic * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IPhonetic * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IPhonetic * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IPhonetic * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IPhonetic * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IPhonetic * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IPhonetic * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IPhonetic * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Visible )( 
            IPhonetic * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Visible )( 
            IPhonetic * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CharacterType )( 
            IPhonetic * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_CharacterType )( 
            IPhonetic * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Alignment )( 
            IPhonetic * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Alignment )( 
            IPhonetic * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Font )( 
            IPhonetic * This,
            /* [retval][out] */ Font	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Text )( 
            IPhonetic * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Text )( 
            IPhonetic * This,
            /* [in] */ BSTR RHS);
        
        END_INTERFACE
    } IPhoneticVtbl;

    interface IPhonetic
    {
        CONST_VTBL struct IPhoneticVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IPhonetic_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IPhonetic_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IPhonetic_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IPhonetic_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IPhonetic_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IPhonetic_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IPhonetic_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IPhonetic_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IPhonetic_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IPhonetic_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IPhonetic_get_Visible(This,RHS)	\
    ( (This)->lpVtbl -> get_Visible(This,RHS) ) 

#define IPhonetic_put_Visible(This,RHS)	\
    ( (This)->lpVtbl -> put_Visible(This,RHS) ) 

#define IPhonetic_get_CharacterType(This,RHS)	\
    ( (This)->lpVtbl -> get_CharacterType(This,RHS) ) 

#define IPhonetic_put_CharacterType(This,RHS)	\
    ( (This)->lpVtbl -> put_CharacterType(This,RHS) ) 

#define IPhonetic_get_Alignment(This,RHS)	\
    ( (This)->lpVtbl -> get_Alignment(This,RHS) ) 

#define IPhonetic_put_Alignment(This,RHS)	\
    ( (This)->lpVtbl -> put_Alignment(This,RHS) ) 

#define IPhonetic_get_Font(This,RHS)	\
    ( (This)->lpVtbl -> get_Font(This,RHS) ) 

#define IPhonetic_get_Text(This,RHS)	\
    ( (This)->lpVtbl -> get_Text(This,RHS) ) 

#define IPhonetic_put_Text(This,RHS)	\
    ( (This)->lpVtbl -> put_Text(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IPhonetic_INTERFACE_DEFINED__ */


#ifndef __IShape_INTERFACE_DEFINED__
#define __IShape_INTERFACE_DEFINED__

/* interface IShape */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IShape;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024439-0001-0000-C000-000000000046")
    IShape : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Apply( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Duplicate( 
            /* [retval][out] */ Shape	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Flip( 
            /* [in] */ MsoFlipCmd FlipCmd) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall IncrementLeft( 
            /* [in] */ single Increment) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall IncrementRotation( 
            /* [in] */ single Increment) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall IncrementTop( 
            /* [in] */ single Increment) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall PickUp( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall RerouteConnections( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ScaleHeight( 
            /* [in] */ single Factor,
            /* [in] */ MsoTriState RelativeToOriginalSize,
            /* [optional][in] */ VARIANT Scale) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ScaleWidth( 
            /* [in] */ single Factor,
            /* [in] */ MsoTriState RelativeToOriginalSize,
            /* [optional][in] */ VARIANT Scale) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [optional][in] */ VARIANT Replace) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SetShapesDefaultProperties( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Ungroup( 
            /* [retval][out] */ ShapeRange	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ZOrder( 
            /* [in] */ MsoZOrderCmd ZOrderCmd) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Adjustments( 
            /* [retval][out] */ Adjustments **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TextFrame( 
            /* [retval][out] */ TextFrame	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AutoShapeType( 
            /* [retval][out] */ MsoAutoShapeType *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AutoShapeType( 
            /* [in] */ MsoAutoShapeType RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Callout( 
            /* [retval][out] */ CalloutFormat **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ConnectionSiteCount( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Connector( 
            /* [retval][out] */ MsoTriState *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ConnectorFormat( 
            /* [retval][out] */ ConnectorFormat	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Fill( 
            /* [retval][out] */ FillFormat **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_GroupItems( 
            /* [retval][out] */ GroupShapes	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Height( 
            /* [retval][out] */ single *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Height( 
            /* [in] */ single RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HorizontalFlip( 
            /* [retval][out] */ MsoTriState *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Left( 
            /* [retval][out] */ single *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Left( 
            /* [in] */ single RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Line( 
            /* [retval][out] */ LineFormat **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LockAspectRatio( 
            /* [retval][out] */ MsoTriState *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_LockAspectRatio( 
            /* [in] */ MsoTriState RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Name( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Nodes( 
            /* [retval][out] */ ShapeNodes **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Rotation( 
            /* [retval][out] */ single *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Rotation( 
            /* [in] */ single RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PictureFormat( 
            /* [retval][out] */ PictureFormat **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Shadow( 
            /* [retval][out] */ ShadowFormat **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TextEffect( 
            /* [retval][out] */ TextEffectFormat **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ThreeD( 
            /* [retval][out] */ ThreeDFormat **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Top( 
            /* [retval][out] */ single *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Top( 
            /* [in] */ single RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Type( 
            /* [retval][out] */ MsoShapeType *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_VerticalFlip( 
            /* [retval][out] */ MsoTriState *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Vertices( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Visible( 
            /* [retval][out] */ MsoTriState *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Visible( 
            /* [in] */ MsoTriState RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Width( 
            /* [retval][out] */ single *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Width( 
            /* [in] */ single RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ZOrderPosition( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Hyperlink( 
            /* [retval][out] */ Hyperlink	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_BlackWhiteMode( 
            /* [retval][out] */ MsoBlackWhiteMode *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_BlackWhiteMode( 
            /* [in] */ MsoBlackWhiteMode RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_DrawingObject( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_OnAction( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_OnAction( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Locked( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Locked( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TopLeftCell( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_BottomRightCell( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Placement( 
            /* [retval][out] */ XlPlacement *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Placement( 
            /* [in] */ XlPlacement RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Copy( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Cut( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CopyPicture( 
            /* [optional][in] */ VARIANT Appearance,
            /* [optional][in] */ VARIANT Format) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ControlFormat( 
            /* [retval][out] */ ControlFormat	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LinkFormat( 
            /* [retval][out] */ LinkFormat	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_OLEFormat( 
            /* [retval][out] */ OLEFormat	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_FormControlType( 
            /* [retval][out] */ XlFormControl *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AlternativeText( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AlternativeText( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Script( 
            /* [retval][out] */ /* external definition not present */ Script **RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_DiagramNode( 
            /* [retval][out] */ DiagramNode **RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_HasDiagramNode( 
            /* [retval][out] */ MsoTriState *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Diagram( 
            /* [retval][out] */ Diagram	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_HasDiagram( 
            /* [retval][out] */ MsoTriState *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Child( 
            /* [retval][out] */ MsoTriState *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ParentGroup( 
            /* [retval][out] */ Shape	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_CanvasItems( 
            /* [retval][out] */ /* external definition not present */ CanvasShapes **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ID( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall CanvasCropLeft( 
            /* [in] */ single Increment) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall CanvasCropTop( 
            /* [in] */ single Increment) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall CanvasCropRight( 
            /* [in] */ single Increment) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall CanvasCropBottom( 
            /* [in] */ single Increment) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Chart( 
            /* [retval][out] */ Chart	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HasChart( 
            /* [retval][out] */ MsoTriState *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TextFrame2( 
            /* [retval][out] */ TextFrame2 **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShapeStyle( 
            /* [retval][out] */ MsoShapeStyleIndex *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ShapeStyle( 
            /* [in] */ MsoShapeStyleIndex RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_BackgroundStyle( 
            /* [retval][out] */ MsoBackgroundStyleIndex *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_BackgroundStyle( 
            /* [in] */ MsoBackgroundStyleIndex RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SoftEdge( 
            /* [retval][out] */ /* external definition not present */ SoftEdgeFormat **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Glow( 
            /* [retval][out] */ /* external definition not present */ GlowFormat **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Reflection( 
            /* [retval][out] */ /* external definition not present */ ReflectionFormat **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HasSmartArt( 
            /* [retval][out] */ MsoTriState *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SmartArt( 
            /* [retval][out] */ /* external definition not present */ SmartArt **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Title( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Title( 
            /* [in] */ BSTR RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IShapeVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IShape * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IShape * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IShape * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IShape * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IShape * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IShape * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IShape * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IShape * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IShape * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IShape * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Apply )( 
            IShape * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IShape * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Duplicate )( 
            IShape * This,
            /* [retval][out] */ Shape	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Flip )( 
            IShape * This,
            /* [in] */ MsoFlipCmd FlipCmd);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *IncrementLeft )( 
            IShape * This,
            /* [in] */ single Increment);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *IncrementRotation )( 
            IShape * This,
            /* [in] */ single Increment);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *IncrementTop )( 
            IShape * This,
            /* [in] */ single Increment);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *PickUp )( 
            IShape * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *RerouteConnections )( 
            IShape * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ScaleHeight )( 
            IShape * This,
            /* [in] */ single Factor,
            /* [in] */ MsoTriState RelativeToOriginalSize,
            /* [optional][in] */ VARIANT Scale);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ScaleWidth )( 
            IShape * This,
            /* [in] */ single Factor,
            /* [in] */ MsoTriState RelativeToOriginalSize,
            /* [optional][in] */ VARIANT Scale);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            IShape * This,
            /* [optional][in] */ VARIANT Replace);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SetShapesDefaultProperties )( 
            IShape * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Ungroup )( 
            IShape * This,
            /* [retval][out] */ ShapeRange	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ZOrder )( 
            IShape * This,
            /* [in] */ MsoZOrderCmd ZOrderCmd);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Adjustments )( 
            IShape * This,
            /* [retval][out] */ Adjustments **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TextFrame )( 
            IShape * This,
            /* [retval][out] */ TextFrame	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AutoShapeType )( 
            IShape * This,
            /* [retval][out] */ MsoAutoShapeType *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AutoShapeType )( 
            IShape * This,
            /* [in] */ MsoAutoShapeType RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Callout )( 
            IShape * This,
            /* [retval][out] */ CalloutFormat **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ConnectionSiteCount )( 
            IShape * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Connector )( 
            IShape * This,
            /* [retval][out] */ MsoTriState *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ConnectorFormat )( 
            IShape * This,
            /* [retval][out] */ ConnectorFormat	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Fill )( 
            IShape * This,
            /* [retval][out] */ FillFormat **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_GroupItems )( 
            IShape * This,
            /* [retval][out] */ GroupShapes	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Height )( 
            IShape * This,
            /* [retval][out] */ single *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Height )( 
            IShape * This,
            /* [in] */ single RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HorizontalFlip )( 
            IShape * This,
            /* [retval][out] */ MsoTriState *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Left )( 
            IShape * This,
            /* [retval][out] */ single *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Left )( 
            IShape * This,
            /* [in] */ single RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Line )( 
            IShape * This,
            /* [retval][out] */ LineFormat **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LockAspectRatio )( 
            IShape * This,
            /* [retval][out] */ MsoTriState *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_LockAspectRatio )( 
            IShape * This,
            /* [in] */ MsoTriState RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            IShape * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Name )( 
            IShape * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Nodes )( 
            IShape * This,
            /* [retval][out] */ ShapeNodes **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Rotation )( 
            IShape * This,
            /* [retval][out] */ single *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Rotation )( 
            IShape * This,
            /* [in] */ single RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PictureFormat )( 
            IShape * This,
            /* [retval][out] */ PictureFormat **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Shadow )( 
            IShape * This,
            /* [retval][out] */ ShadowFormat **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TextEffect )( 
            IShape * This,
            /* [retval][out] */ TextEffectFormat **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ThreeD )( 
            IShape * This,
            /* [retval][out] */ ThreeDFormat **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Top )( 
            IShape * This,
            /* [retval][out] */ single *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Top )( 
            IShape * This,
            /* [in] */ single RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Type )( 
            IShape * This,
            /* [retval][out] */ MsoShapeType *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_VerticalFlip )( 
            IShape * This,
            /* [retval][out] */ MsoTriState *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Vertices )( 
            IShape * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Visible )( 
            IShape * This,
            /* [retval][out] */ MsoTriState *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Visible )( 
            IShape * This,
            /* [in] */ MsoTriState RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Width )( 
            IShape * This,
            /* [retval][out] */ single *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Width )( 
            IShape * This,
            /* [in] */ single RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ZOrderPosition )( 
            IShape * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Hyperlink )( 
            IShape * This,
            /* [retval][out] */ Hyperlink	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_BlackWhiteMode )( 
            IShape * This,
            /* [retval][out] */ MsoBlackWhiteMode *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_BlackWhiteMode )( 
            IShape * This,
            /* [in] */ MsoBlackWhiteMode RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_DrawingObject )( 
            IShape * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_OnAction )( 
            IShape * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_OnAction )( 
            IShape * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Locked )( 
            IShape * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Locked )( 
            IShape * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TopLeftCell )( 
            IShape * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_BottomRightCell )( 
            IShape * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Placement )( 
            IShape * This,
            /* [retval][out] */ XlPlacement *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Placement )( 
            IShape * This,
            /* [in] */ XlPlacement RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Copy )( 
            IShape * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Cut )( 
            IShape * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CopyPicture )( 
            IShape * This,
            /* [optional][in] */ VARIANT Appearance,
            /* [optional][in] */ VARIANT Format);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ControlFormat )( 
            IShape * This,
            /* [retval][out] */ ControlFormat	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LinkFormat )( 
            IShape * This,
            /* [retval][out] */ LinkFormat	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_OLEFormat )( 
            IShape * This,
            /* [retval][out] */ OLEFormat	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_FormControlType )( 
            IShape * This,
            /* [retval][out] */ XlFormControl *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AlternativeText )( 
            IShape * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AlternativeText )( 
            IShape * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Script )( 
            IShape * This,
            /* [retval][out] */ /* external definition not present */ Script **RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_DiagramNode )( 
            IShape * This,
            /* [retval][out] */ DiagramNode **RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_HasDiagramNode )( 
            IShape * This,
            /* [retval][out] */ MsoTriState *RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Diagram )( 
            IShape * This,
            /* [retval][out] */ Diagram	**RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_HasDiagram )( 
            IShape * This,
            /* [retval][out] */ MsoTriState *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Child )( 
            IShape * This,
            /* [retval][out] */ MsoTriState *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ParentGroup )( 
            IShape * This,
            /* [retval][out] */ Shape	**RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_CanvasItems )( 
            IShape * This,
            /* [retval][out] */ /* external definition not present */ CanvasShapes **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ID )( 
            IShape * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *CanvasCropLeft )( 
            IShape * This,
            /* [in] */ single Increment);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *CanvasCropTop )( 
            IShape * This,
            /* [in] */ single Increment);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *CanvasCropRight )( 
            IShape * This,
            /* [in] */ single Increment);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *CanvasCropBottom )( 
            IShape * This,
            /* [in] */ single Increment);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Chart )( 
            IShape * This,
            /* [retval][out] */ Chart	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HasChart )( 
            IShape * This,
            /* [retval][out] */ MsoTriState *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TextFrame2 )( 
            IShape * This,
            /* [retval][out] */ TextFrame2 **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShapeStyle )( 
            IShape * This,
            /* [retval][out] */ MsoShapeStyleIndex *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ShapeStyle )( 
            IShape * This,
            /* [in] */ MsoShapeStyleIndex RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_BackgroundStyle )( 
            IShape * This,
            /* [retval][out] */ MsoBackgroundStyleIndex *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_BackgroundStyle )( 
            IShape * This,
            /* [in] */ MsoBackgroundStyleIndex RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SoftEdge )( 
            IShape * This,
            /* [retval][out] */ /* external definition not present */ SoftEdgeFormat **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Glow )( 
            IShape * This,
            /* [retval][out] */ /* external definition not present */ GlowFormat **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Reflection )( 
            IShape * This,
            /* [retval][out] */ /* external definition not present */ ReflectionFormat **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HasSmartArt )( 
            IShape * This,
            /* [retval][out] */ MsoTriState *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SmartArt )( 
            IShape * This,
            /* [retval][out] */ /* external definition not present */ SmartArt **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Title )( 
            IShape * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Title )( 
            IShape * This,
            /* [in] */ BSTR RHS);
        
        END_INTERFACE
    } IShapeVtbl;

    interface IShape
    {
        CONST_VTBL struct IShapeVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IShape_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IShape_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IShape_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IShape_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IShape_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IShape_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IShape_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IShape_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IShape_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IShape_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IShape_Apply(This)	\
    ( (This)->lpVtbl -> Apply(This) ) 

#define IShape_Delete(This)	\
    ( (This)->lpVtbl -> Delete(This) ) 

#define IShape_Duplicate(This,RHS)	\
    ( (This)->lpVtbl -> Duplicate(This,RHS) ) 

#define IShape_Flip(This,FlipCmd)	\
    ( (This)->lpVtbl -> Flip(This,FlipCmd) ) 

#define IShape_IncrementLeft(This,Increment)	\
    ( (This)->lpVtbl -> IncrementLeft(This,Increment) ) 

#define IShape_IncrementRotation(This,Increment)	\
    ( (This)->lpVtbl -> IncrementRotation(This,Increment) ) 

#define IShape_IncrementTop(This,Increment)	\
    ( (This)->lpVtbl -> IncrementTop(This,Increment) ) 

#define IShape_PickUp(This)	\
    ( (This)->lpVtbl -> PickUp(This) ) 

#define IShape_RerouteConnections(This)	\
    ( (This)->lpVtbl -> RerouteConnections(This) ) 

#define IShape_ScaleHeight(This,Factor,RelativeToOriginalSize,Scale)	\
    ( (This)->lpVtbl -> ScaleHeight(This,Factor,RelativeToOriginalSize,Scale) ) 

#define IShape_ScaleWidth(This,Factor,RelativeToOriginalSize,Scale)	\
    ( (This)->lpVtbl -> ScaleWidth(This,Factor,RelativeToOriginalSize,Scale) ) 

#define IShape_Select(This,Replace)	\
    ( (This)->lpVtbl -> Select(This,Replace) ) 

#define IShape_SetShapesDefaultProperties(This)	\
    ( (This)->lpVtbl -> SetShapesDefaultProperties(This) ) 

#define IShape_Ungroup(This,RHS)	\
    ( (This)->lpVtbl -> Ungroup(This,RHS) ) 

#define IShape_ZOrder(This,ZOrderCmd)	\
    ( (This)->lpVtbl -> ZOrder(This,ZOrderCmd) ) 

#define IShape_get_Adjustments(This,RHS)	\
    ( (This)->lpVtbl -> get_Adjustments(This,RHS) ) 

#define IShape_get_TextFrame(This,RHS)	\
    ( (This)->lpVtbl -> get_TextFrame(This,RHS) ) 

#define IShape_get_AutoShapeType(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoShapeType(This,RHS) ) 

#define IShape_put_AutoShapeType(This,RHS)	\
    ( (This)->lpVtbl -> put_AutoShapeType(This,RHS) ) 

#define IShape_get_Callout(This,RHS)	\
    ( (This)->lpVtbl -> get_Callout(This,RHS) ) 

#define IShape_get_ConnectionSiteCount(This,RHS)	\
    ( (This)->lpVtbl -> get_ConnectionSiteCount(This,RHS) ) 

#define IShape_get_Connector(This,RHS)	\
    ( (This)->lpVtbl -> get_Connector(This,RHS) ) 

#define IShape_get_ConnectorFormat(This,RHS)	\
    ( (This)->lpVtbl -> get_ConnectorFormat(This,RHS) ) 

#define IShape_get_Fill(This,RHS)	\
    ( (This)->lpVtbl -> get_Fill(This,RHS) ) 

#define IShape_get_GroupItems(This,RHS)	\
    ( (This)->lpVtbl -> get_GroupItems(This,RHS) ) 

#define IShape_get_Height(This,RHS)	\
    ( (This)->lpVtbl -> get_Height(This,RHS) ) 

#define IShape_put_Height(This,RHS)	\
    ( (This)->lpVtbl -> put_Height(This,RHS) ) 

#define IShape_get_HorizontalFlip(This,RHS)	\
    ( (This)->lpVtbl -> get_HorizontalFlip(This,RHS) ) 

#define IShape_get_Left(This,RHS)	\
    ( (This)->lpVtbl -> get_Left(This,RHS) ) 

#define IShape_put_Left(This,RHS)	\
    ( (This)->lpVtbl -> put_Left(This,RHS) ) 

#define IShape_get_Line(This,RHS)	\
    ( (This)->lpVtbl -> get_Line(This,RHS) ) 

#define IShape_get_LockAspectRatio(This,RHS)	\
    ( (This)->lpVtbl -> get_LockAspectRatio(This,RHS) ) 

#define IShape_put_LockAspectRatio(This,RHS)	\
    ( (This)->lpVtbl -> put_LockAspectRatio(This,RHS) ) 

#define IShape_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define IShape_put_Name(This,RHS)	\
    ( (This)->lpVtbl -> put_Name(This,RHS) ) 

#define IShape_get_Nodes(This,RHS)	\
    ( (This)->lpVtbl -> get_Nodes(This,RHS) ) 

#define IShape_get_Rotation(This,RHS)	\
    ( (This)->lpVtbl -> get_Rotation(This,RHS) ) 

#define IShape_put_Rotation(This,RHS)	\
    ( (This)->lpVtbl -> put_Rotation(This,RHS) ) 

#define IShape_get_PictureFormat(This,RHS)	\
    ( (This)->lpVtbl -> get_PictureFormat(This,RHS) ) 

#define IShape_get_Shadow(This,RHS)	\
    ( (This)->lpVtbl -> get_Shadow(This,RHS) ) 

#define IShape_get_TextEffect(This,RHS)	\
    ( (This)->lpVtbl -> get_TextEffect(This,RHS) ) 

#define IShape_get_ThreeD(This,RHS)	\
    ( (This)->lpVtbl -> get_ThreeD(This,RHS) ) 

#define IShape_get_Top(This,RHS)	\
    ( (This)->lpVtbl -> get_Top(This,RHS) ) 

#define IShape_put_Top(This,RHS)	\
    ( (This)->lpVtbl -> put_Top(This,RHS) ) 

#define IShape_get_Type(This,RHS)	\
    ( (This)->lpVtbl -> get_Type(This,RHS) ) 

#define IShape_get_VerticalFlip(This,RHS)	\
    ( (This)->lpVtbl -> get_VerticalFlip(This,RHS) ) 

#define IShape_get_Vertices(This,RHS)	\
    ( (This)->lpVtbl -> get_Vertices(This,RHS) ) 

#define IShape_get_Visible(This,RHS)	\
    ( (This)->lpVtbl -> get_Visible(This,RHS) ) 

#define IShape_put_Visible(This,RHS)	\
    ( (This)->lpVtbl -> put_Visible(This,RHS) ) 

#define IShape_get_Width(This,RHS)	\
    ( (This)->lpVtbl -> get_Width(This,RHS) ) 

#define IShape_put_Width(This,RHS)	\
    ( (This)->lpVtbl -> put_Width(This,RHS) ) 

#define IShape_get_ZOrderPosition(This,RHS)	\
    ( (This)->lpVtbl -> get_ZOrderPosition(This,RHS) ) 

#define IShape_get_Hyperlink(This,RHS)	\
    ( (This)->lpVtbl -> get_Hyperlink(This,RHS) ) 

#define IShape_get_BlackWhiteMode(This,RHS)	\
    ( (This)->lpVtbl -> get_BlackWhiteMode(This,RHS) ) 

#define IShape_put_BlackWhiteMode(This,RHS)	\
    ( (This)->lpVtbl -> put_BlackWhiteMode(This,RHS) ) 

#define IShape_get_DrawingObject(This,RHS)	\
    ( (This)->lpVtbl -> get_DrawingObject(This,RHS) ) 

#define IShape_get_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> get_OnAction(This,RHS) ) 

#define IShape_put_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> put_OnAction(This,RHS) ) 

#define IShape_get_Locked(This,RHS)	\
    ( (This)->lpVtbl -> get_Locked(This,RHS) ) 

#define IShape_put_Locked(This,RHS)	\
    ( (This)->lpVtbl -> put_Locked(This,RHS) ) 

#define IShape_get_TopLeftCell(This,RHS)	\
    ( (This)->lpVtbl -> get_TopLeftCell(This,RHS) ) 

#define IShape_get_BottomRightCell(This,RHS)	\
    ( (This)->lpVtbl -> get_BottomRightCell(This,RHS) ) 

#define IShape_get_Placement(This,RHS)	\
    ( (This)->lpVtbl -> get_Placement(This,RHS) ) 

#define IShape_put_Placement(This,RHS)	\
    ( (This)->lpVtbl -> put_Placement(This,RHS) ) 

#define IShape_Copy(This)	\
    ( (This)->lpVtbl -> Copy(This) ) 

#define IShape_Cut(This)	\
    ( (This)->lpVtbl -> Cut(This) ) 

#define IShape_CopyPicture(This,Appearance,Format)	\
    ( (This)->lpVtbl -> CopyPicture(This,Appearance,Format) ) 

#define IShape_get_ControlFormat(This,RHS)	\
    ( (This)->lpVtbl -> get_ControlFormat(This,RHS) ) 

#define IShape_get_LinkFormat(This,RHS)	\
    ( (This)->lpVtbl -> get_LinkFormat(This,RHS) ) 

#define IShape_get_OLEFormat(This,RHS)	\
    ( (This)->lpVtbl -> get_OLEFormat(This,RHS) ) 

#define IShape_get_FormControlType(This,RHS)	\
    ( (This)->lpVtbl -> get_FormControlType(This,RHS) ) 

#define IShape_get_AlternativeText(This,RHS)	\
    ( (This)->lpVtbl -> get_AlternativeText(This,RHS) ) 

#define IShape_put_AlternativeText(This,RHS)	\
    ( (This)->lpVtbl -> put_AlternativeText(This,RHS) ) 

#define IShape_get_Script(This,RHS)	\
    ( (This)->lpVtbl -> get_Script(This,RHS) ) 

#define IShape_get_DiagramNode(This,RHS)	\
    ( (This)->lpVtbl -> get_DiagramNode(This,RHS) ) 

#define IShape_get_HasDiagramNode(This,RHS)	\
    ( (This)->lpVtbl -> get_HasDiagramNode(This,RHS) ) 

#define IShape_get_Diagram(This,RHS)	\
    ( (This)->lpVtbl -> get_Diagram(This,RHS) ) 

#define IShape_get_HasDiagram(This,RHS)	\
    ( (This)->lpVtbl -> get_HasDiagram(This,RHS) ) 

#define IShape_get_Child(This,RHS)	\
    ( (This)->lpVtbl -> get_Child(This,RHS) ) 

#define IShape_get_ParentGroup(This,RHS)	\
    ( (This)->lpVtbl -> get_ParentGroup(This,RHS) ) 

#define IShape_get_CanvasItems(This,RHS)	\
    ( (This)->lpVtbl -> get_CanvasItems(This,RHS) ) 

#define IShape_get_ID(This,RHS)	\
    ( (This)->lpVtbl -> get_ID(This,RHS) ) 

#define IShape_CanvasCropLeft(This,Increment)	\
    ( (This)->lpVtbl -> CanvasCropLeft(This,Increment) ) 

#define IShape_CanvasCropTop(This,Increment)	\
    ( (This)->lpVtbl -> CanvasCropTop(This,Increment) ) 

#define IShape_CanvasCropRight(This,Increment)	\
    ( (This)->lpVtbl -> CanvasCropRight(This,Increment) ) 

#define IShape_CanvasCropBottom(This,Increment)	\
    ( (This)->lpVtbl -> CanvasCropBottom(This,Increment) ) 

#define IShape_get_Chart(This,RHS)	\
    ( (This)->lpVtbl -> get_Chart(This,RHS) ) 

#define IShape_get_HasChart(This,RHS)	\
    ( (This)->lpVtbl -> get_HasChart(This,RHS) ) 

#define IShape_get_TextFrame2(This,RHS)	\
    ( (This)->lpVtbl -> get_TextFrame2(This,RHS) ) 

#define IShape_get_ShapeStyle(This,RHS)	\
    ( (This)->lpVtbl -> get_ShapeStyle(This,RHS) ) 

#define IShape_put_ShapeStyle(This,RHS)	\
    ( (This)->lpVtbl -> put_ShapeStyle(This,RHS) ) 

#define IShape_get_BackgroundStyle(This,RHS)	\
    ( (This)->lpVtbl -> get_BackgroundStyle(This,RHS) ) 

#define IShape_put_BackgroundStyle(This,RHS)	\
    ( (This)->lpVtbl -> put_BackgroundStyle(This,RHS) ) 

#define IShape_get_SoftEdge(This,RHS)	\
    ( (This)->lpVtbl -> get_SoftEdge(This,RHS) ) 

#define IShape_get_Glow(This,RHS)	\
    ( (This)->lpVtbl -> get_Glow(This,RHS) ) 

#define IShape_get_Reflection(This,RHS)	\
    ( (This)->lpVtbl -> get_Reflection(This,RHS) ) 

#define IShape_get_HasSmartArt(This,RHS)	\
    ( (This)->lpVtbl -> get_HasSmartArt(This,RHS) ) 

#define IShape_get_SmartArt(This,RHS)	\
    ( (This)->lpVtbl -> get_SmartArt(This,RHS) ) 

#define IShape_get_Title(This,RHS)	\
    ( (This)->lpVtbl -> get_Title(This,RHS) ) 

#define IShape_put_Title(This,RHS)	\
    ( (This)->lpVtbl -> put_Title(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IShape_INTERFACE_DEFINED__ */


#ifndef __IShapes_INTERFACE_DEFINED__
#define __IShapes_INTERFACE_DEFINED__

/* interface IShapes */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IShapes;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002443A-0001-0000-C000-000000000046")
    IShapes : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Shape	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall _Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Shape	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall AddCallout( 
            /* [in] */ MsoCalloutType Type,
            /* [in] */ single Left,
            /* [in] */ single Top,
            /* [in] */ single Width,
            /* [in] */ single Height,
            /* [retval][out] */ Shape	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall AddConnector( 
            /* [in] */ MsoConnectorType Type,
            /* [in] */ single BeginX,
            /* [in] */ single BeginY,
            /* [in] */ single EndX,
            /* [in] */ single EndY,
            /* [retval][out] */ Shape	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall AddCurve( 
            /* [in] */ VARIANT SafeArrayOfPoints,
            /* [retval][out] */ Shape	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall AddLabel( 
            /* [in] */ MsoTextOrientation Orientation,
            /* [in] */ single Left,
            /* [in] */ single Top,
            /* [in] */ single Width,
            /* [in] */ single Height,
            /* [retval][out] */ Shape	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall AddLine( 
            /* [in] */ single BeginX,
            /* [in] */ single BeginY,
            /* [in] */ single EndX,
            /* [in] */ single EndY,
            /* [retval][out] */ Shape	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall AddPicture( 
            /* [in] */ BSTR Filename,
            /* [in] */ MsoTriState LinkToFile,
            /* [in] */ MsoTriState SaveWithDocument,
            /* [in] */ single Left,
            /* [in] */ single Top,
            /* [in] */ single Width,
            /* [in] */ single Height,
            /* [retval][out] */ Shape	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall AddPolyline( 
            /* [in] */ VARIANT SafeArrayOfPoints,
            /* [retval][out] */ Shape	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall AddShape( 
            /* [in] */ MsoAutoShapeType Type,
            /* [in] */ single Left,
            /* [in] */ single Top,
            /* [in] */ single Width,
            /* [in] */ single Height,
            /* [retval][out] */ Shape	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall AddTextEffect( 
            /* [in] */ MsoPresetTextEffect PresetTextEffect,
            /* [in] */ BSTR Text,
            /* [in] */ BSTR FontName,
            /* [in] */ single FontSize,
            /* [in] */ MsoTriState FontBold,
            /* [in] */ MsoTriState FontItalic,
            /* [in] */ single Left,
            /* [in] */ single Top,
            /* [retval][out] */ Shape	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall AddTextbox( 
            /* [in] */ MsoTextOrientation Orientation,
            /* [in] */ single Left,
            /* [in] */ single Top,
            /* [in] */ single Width,
            /* [in] */ single Height,
            /* [retval][out] */ Shape	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall BuildFreeform( 
            /* [in] */ MsoEditingType EditingType,
            /* [in] */ single X1,
            /* [in] */ single Y1,
            /* [retval][out] */ FreeformBuilder	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Range( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ ShapeRange	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SelectAll( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall AddFormControl( 
            /* [in] */ XlFormControl Type,
            /* [in] */ long Left,
            /* [in] */ long Top,
            /* [in] */ long Width,
            /* [in] */ long Height,
            /* [retval][out] */ Shape	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall AddOLEObject( 
            /* [optional][in] */ VARIANT ClassType,
            /* [optional][in] */ VARIANT Filename,
            /* [optional][in] */ VARIANT Link,
            /* [optional][in] */ VARIANT DisplayAsIcon,
            /* [optional][in] */ VARIANT IconFileName,
            /* [optional][in] */ VARIANT IconIndex,
            /* [optional][in] */ VARIANT IconLabel,
            /* [optional][in] */ VARIANT Left,
            /* [optional][in] */ VARIANT Top,
            /* [optional][in] */ VARIANT Width,
            /* [optional][in] */ VARIANT Height,
            /* [retval][out] */ Shape	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall AddDiagram( 
            /* [in] */ MsoDiagramType Type,
            /* [in] */ single Left,
            /* [in] */ single Top,
            /* [in] */ single Width,
            /* [in] */ single Height,
            /* [retval][out] */ Shape	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall AddCanvas( 
            /* [in] */ single Left,
            /* [in] */ single Top,
            /* [in] */ single Width,
            /* [in] */ single Height,
            /* [retval][out] */ Shape	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall AddChart( 
            /* [optional][in] */ VARIANT XlChartType,
            /* [optional][in] */ VARIANT Left,
            /* [optional][in] */ VARIANT Top,
            /* [optional][in] */ VARIANT Width,
            /* [optional][in] */ VARIANT Height,
            /* [retval][out] */ Shape	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall AddSmartArt( 
            /* [in] */ /* external definition not present */ SmartArtLayout *Layout,
            /* [optional][in] */ VARIANT Left,
            /* [optional][in] */ VARIANT Top,
            /* [optional][in] */ VARIANT Width,
            /* [optional][in] */ VARIANT Height,
            /* [retval][out] */ Shape	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall AddChart2( 
            /* [optional][in] */ VARIANT Style,
            /* [optional][in] */ VARIANT XlChartType,
            /* [optional][in] */ VARIANT Left,
            /* [optional][in] */ VARIANT Top,
            /* [optional][in] */ VARIANT Width,
            /* [optional][in] */ VARIANT Height,
            /* [optional][in] */ VARIANT NewLayout,
            /* [retval][out] */ Shape	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall AddPicture2( 
            /* [in] */ BSTR Filename,
            /* [in] */ MsoTriState LinkToFile,
            /* [in] */ MsoTriState SaveWithDocument,
            /* [in] */ single Left,
            /* [in] */ single Top,
            /* [in] */ single Width,
            /* [in] */ single Height,
            /* [in] */ MsoPictureCompress Compress,
            /* [retval][out] */ Shape	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IShapesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IShapes * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IShapes * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IShapes * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IShapes * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IShapes * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IShapes * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IShapes * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IShapes * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IShapes * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IShapes * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IShapes * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Item )( 
            IShapes * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Shape	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *_Default )( 
            IShapes * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Shape	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            IShapes * This,
            /* [retval][out] */ IUnknown **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *AddCallout )( 
            IShapes * This,
            /* [in] */ MsoCalloutType Type,
            /* [in] */ single Left,
            /* [in] */ single Top,
            /* [in] */ single Width,
            /* [in] */ single Height,
            /* [retval][out] */ Shape	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *AddConnector )( 
            IShapes * This,
            /* [in] */ MsoConnectorType Type,
            /* [in] */ single BeginX,
            /* [in] */ single BeginY,
            /* [in] */ single EndX,
            /* [in] */ single EndY,
            /* [retval][out] */ Shape	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *AddCurve )( 
            IShapes * This,
            /* [in] */ VARIANT SafeArrayOfPoints,
            /* [retval][out] */ Shape	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *AddLabel )( 
            IShapes * This,
            /* [in] */ MsoTextOrientation Orientation,
            /* [in] */ single Left,
            /* [in] */ single Top,
            /* [in] */ single Width,
            /* [in] */ single Height,
            /* [retval][out] */ Shape	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *AddLine )( 
            IShapes * This,
            /* [in] */ single BeginX,
            /* [in] */ single BeginY,
            /* [in] */ single EndX,
            /* [in] */ single EndY,
            /* [retval][out] */ Shape	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *AddPicture )( 
            IShapes * This,
            /* [in] */ BSTR Filename,
            /* [in] */ MsoTriState LinkToFile,
            /* [in] */ MsoTriState SaveWithDocument,
            /* [in] */ single Left,
            /* [in] */ single Top,
            /* [in] */ single Width,
            /* [in] */ single Height,
            /* [retval][out] */ Shape	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *AddPolyline )( 
            IShapes * This,
            /* [in] */ VARIANT SafeArrayOfPoints,
            /* [retval][out] */ Shape	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *AddShape )( 
            IShapes * This,
            /* [in] */ MsoAutoShapeType Type,
            /* [in] */ single Left,
            /* [in] */ single Top,
            /* [in] */ single Width,
            /* [in] */ single Height,
            /* [retval][out] */ Shape	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *AddTextEffect )( 
            IShapes * This,
            /* [in] */ MsoPresetTextEffect PresetTextEffect,
            /* [in] */ BSTR Text,
            /* [in] */ BSTR FontName,
            /* [in] */ single FontSize,
            /* [in] */ MsoTriState FontBold,
            /* [in] */ MsoTriState FontItalic,
            /* [in] */ single Left,
            /* [in] */ single Top,
            /* [retval][out] */ Shape	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *AddTextbox )( 
            IShapes * This,
            /* [in] */ MsoTextOrientation Orientation,
            /* [in] */ single Left,
            /* [in] */ single Top,
            /* [in] */ single Width,
            /* [in] */ single Height,
            /* [retval][out] */ Shape	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *BuildFreeform )( 
            IShapes * This,
            /* [in] */ MsoEditingType EditingType,
            /* [in] */ single X1,
            /* [in] */ single Y1,
            /* [retval][out] */ FreeformBuilder	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Range )( 
            IShapes * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ ShapeRange	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SelectAll )( 
            IShapes * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *AddFormControl )( 
            IShapes * This,
            /* [in] */ XlFormControl Type,
            /* [in] */ long Left,
            /* [in] */ long Top,
            /* [in] */ long Width,
            /* [in] */ long Height,
            /* [retval][out] */ Shape	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *AddOLEObject )( 
            IShapes * This,
            /* [optional][in] */ VARIANT ClassType,
            /* [optional][in] */ VARIANT Filename,
            /* [optional][in] */ VARIANT Link,
            /* [optional][in] */ VARIANT DisplayAsIcon,
            /* [optional][in] */ VARIANT IconFileName,
            /* [optional][in] */ VARIANT IconIndex,
            /* [optional][in] */ VARIANT IconLabel,
            /* [optional][in] */ VARIANT Left,
            /* [optional][in] */ VARIANT Top,
            /* [optional][in] */ VARIANT Width,
            /* [optional][in] */ VARIANT Height,
            /* [retval][out] */ Shape	**RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *AddDiagram )( 
            IShapes * This,
            /* [in] */ MsoDiagramType Type,
            /* [in] */ single Left,
            /* [in] */ single Top,
            /* [in] */ single Width,
            /* [in] */ single Height,
            /* [retval][out] */ Shape	**RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *AddCanvas )( 
            IShapes * This,
            /* [in] */ single Left,
            /* [in] */ single Top,
            /* [in] */ single Width,
            /* [in] */ single Height,
            /* [retval][out] */ Shape	**RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *AddChart )( 
            IShapes * This,
            /* [optional][in] */ VARIANT XlChartType,
            /* [optional][in] */ VARIANT Left,
            /* [optional][in] */ VARIANT Top,
            /* [optional][in] */ VARIANT Width,
            /* [optional][in] */ VARIANT Height,
            /* [retval][out] */ Shape	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *AddSmartArt )( 
            IShapes * This,
            /* [in] */ /* external definition not present */ SmartArtLayout *Layout,
            /* [optional][in] */ VARIANT Left,
            /* [optional][in] */ VARIANT Top,
            /* [optional][in] */ VARIANT Width,
            /* [optional][in] */ VARIANT Height,
            /* [retval][out] */ Shape	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *AddChart2 )( 
            IShapes * This,
            /* [optional][in] */ VARIANT Style,
            /* [optional][in] */ VARIANT XlChartType,
            /* [optional][in] */ VARIANT Left,
            /* [optional][in] */ VARIANT Top,
            /* [optional][in] */ VARIANT Width,
            /* [optional][in] */ VARIANT Height,
            /* [optional][in] */ VARIANT NewLayout,
            /* [retval][out] */ Shape	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *AddPicture2 )( 
            IShapes * This,
            /* [in] */ BSTR Filename,
            /* [in] */ MsoTriState LinkToFile,
            /* [in] */ MsoTriState SaveWithDocument,
            /* [in] */ single Left,
            /* [in] */ single Top,
            /* [in] */ single Width,
            /* [in] */ single Height,
            /* [in] */ MsoPictureCompress Compress,
            /* [retval][out] */ Shape	**RHS);
        
        END_INTERFACE
    } IShapesVtbl;

    interface IShapes
    {
        CONST_VTBL struct IShapesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IShapes_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IShapes_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IShapes_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IShapes_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IShapes_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IShapes_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IShapes_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IShapes_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IShapes_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IShapes_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IShapes_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IShapes_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> Item(This,Index,RHS) ) 

#define IShapes__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> _Default(This,Index,RHS) ) 

#define IShapes_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#define IShapes_AddCallout(This,Type,Left,Top,Width,Height,RHS)	\
    ( (This)->lpVtbl -> AddCallout(This,Type,Left,Top,Width,Height,RHS) ) 

#define IShapes_AddConnector(This,Type,BeginX,BeginY,EndX,EndY,RHS)	\
    ( (This)->lpVtbl -> AddConnector(This,Type,BeginX,BeginY,EndX,EndY,RHS) ) 

#define IShapes_AddCurve(This,SafeArrayOfPoints,RHS)	\
    ( (This)->lpVtbl -> AddCurve(This,SafeArrayOfPoints,RHS) ) 

#define IShapes_AddLabel(This,Orientation,Left,Top,Width,Height,RHS)	\
    ( (This)->lpVtbl -> AddLabel(This,Orientation,Left,Top,Width,Height,RHS) ) 

#define IShapes_AddLine(This,BeginX,BeginY,EndX,EndY,RHS)	\
    ( (This)->lpVtbl -> AddLine(This,BeginX,BeginY,EndX,EndY,RHS) ) 

#define IShapes_AddPicture(This,Filename,LinkToFile,SaveWithDocument,Left,Top,Width,Height,RHS)	\
    ( (This)->lpVtbl -> AddPicture(This,Filename,LinkToFile,SaveWithDocument,Left,Top,Width,Height,RHS) ) 

#define IShapes_AddPolyline(This,SafeArrayOfPoints,RHS)	\
    ( (This)->lpVtbl -> AddPolyline(This,SafeArrayOfPoints,RHS) ) 

#define IShapes_AddShape(This,Type,Left,Top,Width,Height,RHS)	\
    ( (This)->lpVtbl -> AddShape(This,Type,Left,Top,Width,Height,RHS) ) 

#define IShapes_AddTextEffect(This,PresetTextEffect,Text,FontName,FontSize,FontBold,FontItalic,Left,Top,RHS)	\
    ( (This)->lpVtbl -> AddTextEffect(This,PresetTextEffect,Text,FontName,FontSize,FontBold,FontItalic,Left,Top,RHS) ) 

#define IShapes_AddTextbox(This,Orientation,Left,Top,Width,Height,RHS)	\
    ( (This)->lpVtbl -> AddTextbox(This,Orientation,Left,Top,Width,Height,RHS) ) 

#define IShapes_BuildFreeform(This,EditingType,X1,Y1,RHS)	\
    ( (This)->lpVtbl -> BuildFreeform(This,EditingType,X1,Y1,RHS) ) 

#define IShapes_get_Range(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Range(This,Index,RHS) ) 

#define IShapes_SelectAll(This)	\
    ( (This)->lpVtbl -> SelectAll(This) ) 

#define IShapes_AddFormControl(This,Type,Left,Top,Width,Height,RHS)	\
    ( (This)->lpVtbl -> AddFormControl(This,Type,Left,Top,Width,Height,RHS) ) 

#define IShapes_AddOLEObject(This,ClassType,Filename,Link,DisplayAsIcon,IconFileName,IconIndex,IconLabel,Left,Top,Width,Height,RHS)	\
    ( (This)->lpVtbl -> AddOLEObject(This,ClassType,Filename,Link,DisplayAsIcon,IconFileName,IconIndex,IconLabel,Left,Top,Width,Height,RHS) ) 

#define IShapes_AddDiagram(This,Type,Left,Top,Width,Height,RHS)	\
    ( (This)->lpVtbl -> AddDiagram(This,Type,Left,Top,Width,Height,RHS) ) 

#define IShapes_AddCanvas(This,Left,Top,Width,Height,RHS)	\
    ( (This)->lpVtbl -> AddCanvas(This,Left,Top,Width,Height,RHS) ) 

#define IShapes_AddChart(This,XlChartType,Left,Top,Width,Height,RHS)	\
    ( (This)->lpVtbl -> AddChart(This,XlChartType,Left,Top,Width,Height,RHS) ) 

#define IShapes_AddSmartArt(This,Layout,Left,Top,Width,Height,RHS)	\
    ( (This)->lpVtbl -> AddSmartArt(This,Layout,Left,Top,Width,Height,RHS) ) 

#define IShapes_AddChart2(This,Style,XlChartType,Left,Top,Width,Height,NewLayout,RHS)	\
    ( (This)->lpVtbl -> AddChart2(This,Style,XlChartType,Left,Top,Width,Height,NewLayout,RHS) ) 

#define IShapes_AddPicture2(This,Filename,LinkToFile,SaveWithDocument,Left,Top,Width,Height,Compress,RHS)	\
    ( (This)->lpVtbl -> AddPicture2(This,Filename,LinkToFile,SaveWithDocument,Left,Top,Width,Height,Compress,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IShapes_INTERFACE_DEFINED__ */


#ifndef __IShapeRange_INTERFACE_DEFINED__
#define __IShapeRange_INTERFACE_DEFINED__

/* interface IShapeRange */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IShapeRange;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002443B-0001-0000-C000-000000000046")
    IShapeRange : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Shape	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall _Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Shape	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Align( 
            /* [in] */ MsoAlignCmd AlignCmd,
            /* [in] */ MsoTriState RelativeTo) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Apply( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Distribute( 
            /* [in] */ MsoDistributeCmd DistributeCmd,
            /* [in] */ MsoTriState RelativeTo) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Duplicate( 
            /* [retval][out] */ ShapeRange	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Flip( 
            /* [in] */ MsoFlipCmd FlipCmd) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall IncrementLeft( 
            /* [in] */ single Increment) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall IncrementRotation( 
            /* [in] */ single Increment) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall IncrementTop( 
            /* [in] */ single Increment) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Group( 
            /* [retval][out] */ Shape	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall PickUp( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall RerouteConnections( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Regroup( 
            /* [retval][out] */ Shape	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ScaleHeight( 
            /* [in] */ single Factor,
            /* [in] */ MsoTriState RelativeToOriginalSize,
            /* [optional][in] */ VARIANT Scale) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ScaleWidth( 
            /* [in] */ single Factor,
            /* [in] */ MsoTriState RelativeToOriginalSize,
            /* [optional][in] */ VARIANT Scale) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [optional][in] */ VARIANT Replace) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SetShapesDefaultProperties( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Ungroup( 
            /* [retval][out] */ ShapeRange	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ZOrder( 
            /* [in] */ MsoZOrderCmd ZOrderCmd) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Adjustments( 
            /* [retval][out] */ Adjustments **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TextFrame( 
            /* [retval][out] */ TextFrame	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AutoShapeType( 
            /* [retval][out] */ MsoAutoShapeType *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AutoShapeType( 
            /* [in] */ MsoAutoShapeType RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Callout( 
            /* [retval][out] */ CalloutFormat **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ConnectionSiteCount( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Connector( 
            /* [retval][out] */ MsoTriState *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ConnectorFormat( 
            /* [retval][out] */ ConnectorFormat	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Fill( 
            /* [retval][out] */ FillFormat **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_GroupItems( 
            /* [retval][out] */ GroupShapes	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Height( 
            /* [retval][out] */ single *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Height( 
            /* [in] */ single RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HorizontalFlip( 
            /* [retval][out] */ MsoTriState *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Left( 
            /* [retval][out] */ single *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Left( 
            /* [in] */ single RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Line( 
            /* [retval][out] */ LineFormat **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LockAspectRatio( 
            /* [retval][out] */ MsoTriState *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_LockAspectRatio( 
            /* [in] */ MsoTriState RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Name( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Nodes( 
            /* [retval][out] */ ShapeNodes **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Rotation( 
            /* [retval][out] */ single *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Rotation( 
            /* [in] */ single RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PictureFormat( 
            /* [retval][out] */ PictureFormat **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Shadow( 
            /* [retval][out] */ ShadowFormat **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TextEffect( 
            /* [retval][out] */ TextEffectFormat **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ThreeD( 
            /* [retval][out] */ ThreeDFormat **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Top( 
            /* [retval][out] */ single *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Top( 
            /* [in] */ single RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Type( 
            /* [retval][out] */ MsoShapeType *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_VerticalFlip( 
            /* [retval][out] */ MsoTriState *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Vertices( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Visible( 
            /* [retval][out] */ MsoTriState *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Visible( 
            /* [in] */ MsoTriState RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Width( 
            /* [retval][out] */ single *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Width( 
            /* [in] */ single RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ZOrderPosition( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_BlackWhiteMode( 
            /* [retval][out] */ MsoBlackWhiteMode *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_BlackWhiteMode( 
            /* [in] */ MsoBlackWhiteMode RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AlternativeText( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AlternativeText( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_DiagramNode( 
            /* [retval][out] */ DiagramNode **RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_HasDiagramNode( 
            /* [retval][out] */ MsoTriState *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Diagram( 
            /* [retval][out] */ Diagram	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_HasDiagram( 
            /* [retval][out] */ MsoTriState *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Child( 
            /* [retval][out] */ MsoTriState *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ParentGroup( 
            /* [retval][out] */ Shape	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_CanvasItems( 
            /* [retval][out] */ /* external definition not present */ CanvasShapes **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ID( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall CanvasCropLeft( 
            /* [in] */ single Increment) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall CanvasCropTop( 
            /* [in] */ single Increment) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall CanvasCropRight( 
            /* [in] */ single Increment) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall CanvasCropBottom( 
            /* [in] */ single Increment) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Chart( 
            /* [retval][out] */ Chart	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HasChart( 
            /* [retval][out] */ MsoTriState *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TextFrame2( 
            /* [retval][out] */ TextFrame2 **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShapeStyle( 
            /* [retval][out] */ MsoShapeStyleIndex *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ShapeStyle( 
            /* [in] */ MsoShapeStyleIndex RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_BackgroundStyle( 
            /* [retval][out] */ MsoBackgroundStyleIndex *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_BackgroundStyle( 
            /* [in] */ MsoBackgroundStyleIndex RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SoftEdge( 
            /* [retval][out] */ /* external definition not present */ SoftEdgeFormat **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Glow( 
            /* [retval][out] */ /* external definition not present */ GlowFormat **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Reflection( 
            /* [retval][out] */ /* external definition not present */ ReflectionFormat **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Title( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Title( 
            /* [in] */ BSTR RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IShapeRangeVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IShapeRange * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IShapeRange * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IShapeRange * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IShapeRange * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IShapeRange * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IShapeRange * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IShapeRange * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IShapeRange * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IShapeRange * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IShapeRange * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IShapeRange * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Item )( 
            IShapeRange * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Shape	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *_Default )( 
            IShapeRange * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Shape	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            IShapeRange * This,
            /* [retval][out] */ IUnknown **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Align )( 
            IShapeRange * This,
            /* [in] */ MsoAlignCmd AlignCmd,
            /* [in] */ MsoTriState RelativeTo);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Apply )( 
            IShapeRange * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IShapeRange * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Distribute )( 
            IShapeRange * This,
            /* [in] */ MsoDistributeCmd DistributeCmd,
            /* [in] */ MsoTriState RelativeTo);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Duplicate )( 
            IShapeRange * This,
            /* [retval][out] */ ShapeRange	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Flip )( 
            IShapeRange * This,
            /* [in] */ MsoFlipCmd FlipCmd);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *IncrementLeft )( 
            IShapeRange * This,
            /* [in] */ single Increment);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *IncrementRotation )( 
            IShapeRange * This,
            /* [in] */ single Increment);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *IncrementTop )( 
            IShapeRange * This,
            /* [in] */ single Increment);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Group )( 
            IShapeRange * This,
            /* [retval][out] */ Shape	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *PickUp )( 
            IShapeRange * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *RerouteConnections )( 
            IShapeRange * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Regroup )( 
            IShapeRange * This,
            /* [retval][out] */ Shape	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ScaleHeight )( 
            IShapeRange * This,
            /* [in] */ single Factor,
            /* [in] */ MsoTriState RelativeToOriginalSize,
            /* [optional][in] */ VARIANT Scale);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ScaleWidth )( 
            IShapeRange * This,
            /* [in] */ single Factor,
            /* [in] */ MsoTriState RelativeToOriginalSize,
            /* [optional][in] */ VARIANT Scale);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            IShapeRange * This,
            /* [optional][in] */ VARIANT Replace);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SetShapesDefaultProperties )( 
            IShapeRange * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Ungroup )( 
            IShapeRange * This,
            /* [retval][out] */ ShapeRange	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ZOrder )( 
            IShapeRange * This,
            /* [in] */ MsoZOrderCmd ZOrderCmd);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Adjustments )( 
            IShapeRange * This,
            /* [retval][out] */ Adjustments **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TextFrame )( 
            IShapeRange * This,
            /* [retval][out] */ TextFrame	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AutoShapeType )( 
            IShapeRange * This,
            /* [retval][out] */ MsoAutoShapeType *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AutoShapeType )( 
            IShapeRange * This,
            /* [in] */ MsoAutoShapeType RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Callout )( 
            IShapeRange * This,
            /* [retval][out] */ CalloutFormat **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ConnectionSiteCount )( 
            IShapeRange * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Connector )( 
            IShapeRange * This,
            /* [retval][out] */ MsoTriState *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ConnectorFormat )( 
            IShapeRange * This,
            /* [retval][out] */ ConnectorFormat	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Fill )( 
            IShapeRange * This,
            /* [retval][out] */ FillFormat **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_GroupItems )( 
            IShapeRange * This,
            /* [retval][out] */ GroupShapes	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Height )( 
            IShapeRange * This,
            /* [retval][out] */ single *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Height )( 
            IShapeRange * This,
            /* [in] */ single RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HorizontalFlip )( 
            IShapeRange * This,
            /* [retval][out] */ MsoTriState *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Left )( 
            IShapeRange * This,
            /* [retval][out] */ single *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Left )( 
            IShapeRange * This,
            /* [in] */ single RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Line )( 
            IShapeRange * This,
            /* [retval][out] */ LineFormat **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LockAspectRatio )( 
            IShapeRange * This,
            /* [retval][out] */ MsoTriState *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_LockAspectRatio )( 
            IShapeRange * This,
            /* [in] */ MsoTriState RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            IShapeRange * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Name )( 
            IShapeRange * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Nodes )( 
            IShapeRange * This,
            /* [retval][out] */ ShapeNodes **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Rotation )( 
            IShapeRange * This,
            /* [retval][out] */ single *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Rotation )( 
            IShapeRange * This,
            /* [in] */ single RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PictureFormat )( 
            IShapeRange * This,
            /* [retval][out] */ PictureFormat **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Shadow )( 
            IShapeRange * This,
            /* [retval][out] */ ShadowFormat **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TextEffect )( 
            IShapeRange * This,
            /* [retval][out] */ TextEffectFormat **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ThreeD )( 
            IShapeRange * This,
            /* [retval][out] */ ThreeDFormat **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Top )( 
            IShapeRange * This,
            /* [retval][out] */ single *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Top )( 
            IShapeRange * This,
            /* [in] */ single RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Type )( 
            IShapeRange * This,
            /* [retval][out] */ MsoShapeType *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_VerticalFlip )( 
            IShapeRange * This,
            /* [retval][out] */ MsoTriState *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Vertices )( 
            IShapeRange * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Visible )( 
            IShapeRange * This,
            /* [retval][out] */ MsoTriState *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Visible )( 
            IShapeRange * This,
            /* [in] */ MsoTriState RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Width )( 
            IShapeRange * This,
            /* [retval][out] */ single *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Width )( 
            IShapeRange * This,
            /* [in] */ single RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ZOrderPosition )( 
            IShapeRange * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_BlackWhiteMode )( 
            IShapeRange * This,
            /* [retval][out] */ MsoBlackWhiteMode *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_BlackWhiteMode )( 
            IShapeRange * This,
            /* [in] */ MsoBlackWhiteMode RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AlternativeText )( 
            IShapeRange * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AlternativeText )( 
            IShapeRange * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_DiagramNode )( 
            IShapeRange * This,
            /* [retval][out] */ DiagramNode **RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_HasDiagramNode )( 
            IShapeRange * This,
            /* [retval][out] */ MsoTriState *RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Diagram )( 
            IShapeRange * This,
            /* [retval][out] */ Diagram	**RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_HasDiagram )( 
            IShapeRange * This,
            /* [retval][out] */ MsoTriState *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Child )( 
            IShapeRange * This,
            /* [retval][out] */ MsoTriState *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ParentGroup )( 
            IShapeRange * This,
            /* [retval][out] */ Shape	**RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_CanvasItems )( 
            IShapeRange * This,
            /* [retval][out] */ /* external definition not present */ CanvasShapes **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ID )( 
            IShapeRange * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *CanvasCropLeft )( 
            IShapeRange * This,
            /* [in] */ single Increment);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *CanvasCropTop )( 
            IShapeRange * This,
            /* [in] */ single Increment);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *CanvasCropRight )( 
            IShapeRange * This,
            /* [in] */ single Increment);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *CanvasCropBottom )( 
            IShapeRange * This,
            /* [in] */ single Increment);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Chart )( 
            IShapeRange * This,
            /* [retval][out] */ Chart	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HasChart )( 
            IShapeRange * This,
            /* [retval][out] */ MsoTriState *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TextFrame2 )( 
            IShapeRange * This,
            /* [retval][out] */ TextFrame2 **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShapeStyle )( 
            IShapeRange * This,
            /* [retval][out] */ MsoShapeStyleIndex *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ShapeStyle )( 
            IShapeRange * This,
            /* [in] */ MsoShapeStyleIndex RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_BackgroundStyle )( 
            IShapeRange * This,
            /* [retval][out] */ MsoBackgroundStyleIndex *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_BackgroundStyle )( 
            IShapeRange * This,
            /* [in] */ MsoBackgroundStyleIndex RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SoftEdge )( 
            IShapeRange * This,
            /* [retval][out] */ /* external definition not present */ SoftEdgeFormat **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Glow )( 
            IShapeRange * This,
            /* [retval][out] */ /* external definition not present */ GlowFormat **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Reflection )( 
            IShapeRange * This,
            /* [retval][out] */ /* external definition not present */ ReflectionFormat **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Title )( 
            IShapeRange * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Title )( 
            IShapeRange * This,
            /* [in] */ BSTR RHS);
        
        END_INTERFACE
    } IShapeRangeVtbl;

    interface IShapeRange
    {
        CONST_VTBL struct IShapeRangeVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IShapeRange_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IShapeRange_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IShapeRange_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IShapeRange_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IShapeRange_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IShapeRange_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IShapeRange_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IShapeRange_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IShapeRange_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IShapeRange_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IShapeRange_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IShapeRange_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> Item(This,Index,RHS) ) 

#define IShapeRange__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> _Default(This,Index,RHS) ) 

#define IShapeRange_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#define IShapeRange_Align(This,AlignCmd,RelativeTo)	\
    ( (This)->lpVtbl -> Align(This,AlignCmd,RelativeTo) ) 

#define IShapeRange_Apply(This)	\
    ( (This)->lpVtbl -> Apply(This) ) 

#define IShapeRange_Delete(This)	\
    ( (This)->lpVtbl -> Delete(This) ) 

#define IShapeRange_Distribute(This,DistributeCmd,RelativeTo)	\
    ( (This)->lpVtbl -> Distribute(This,DistributeCmd,RelativeTo) ) 

#define IShapeRange_Duplicate(This,RHS)	\
    ( (This)->lpVtbl -> Duplicate(This,RHS) ) 

#define IShapeRange_Flip(This,FlipCmd)	\
    ( (This)->lpVtbl -> Flip(This,FlipCmd) ) 

#define IShapeRange_IncrementLeft(This,Increment)	\
    ( (This)->lpVtbl -> IncrementLeft(This,Increment) ) 

#define IShapeRange_IncrementRotation(This,Increment)	\
    ( (This)->lpVtbl -> IncrementRotation(This,Increment) ) 

#define IShapeRange_IncrementTop(This,Increment)	\
    ( (This)->lpVtbl -> IncrementTop(This,Increment) ) 

#define IShapeRange_Group(This,RHS)	\
    ( (This)->lpVtbl -> Group(This,RHS) ) 

#define IShapeRange_PickUp(This)	\
    ( (This)->lpVtbl -> PickUp(This) ) 

#define IShapeRange_RerouteConnections(This)	\
    ( (This)->lpVtbl -> RerouteConnections(This) ) 

#define IShapeRange_Regroup(This,RHS)	\
    ( (This)->lpVtbl -> Regroup(This,RHS) ) 

#define IShapeRange_ScaleHeight(This,Factor,RelativeToOriginalSize,Scale)	\
    ( (This)->lpVtbl -> ScaleHeight(This,Factor,RelativeToOriginalSize,Scale) ) 

#define IShapeRange_ScaleWidth(This,Factor,RelativeToOriginalSize,Scale)	\
    ( (This)->lpVtbl -> ScaleWidth(This,Factor,RelativeToOriginalSize,Scale) ) 

#define IShapeRange_Select(This,Replace)	\
    ( (This)->lpVtbl -> Select(This,Replace) ) 

#define IShapeRange_SetShapesDefaultProperties(This)	\
    ( (This)->lpVtbl -> SetShapesDefaultProperties(This) ) 

#define IShapeRange_Ungroup(This,RHS)	\
    ( (This)->lpVtbl -> Ungroup(This,RHS) ) 

#define IShapeRange_ZOrder(This,ZOrderCmd)	\
    ( (This)->lpVtbl -> ZOrder(This,ZOrderCmd) ) 

#define IShapeRange_get_Adjustments(This,RHS)	\
    ( (This)->lpVtbl -> get_Adjustments(This,RHS) ) 

#define IShapeRange_get_TextFrame(This,RHS)	\
    ( (This)->lpVtbl -> get_TextFrame(This,RHS) ) 

#define IShapeRange_get_AutoShapeType(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoShapeType(This,RHS) ) 

#define IShapeRange_put_AutoShapeType(This,RHS)	\
    ( (This)->lpVtbl -> put_AutoShapeType(This,RHS) ) 

#define IShapeRange_get_Callout(This,RHS)	\
    ( (This)->lpVtbl -> get_Callout(This,RHS) ) 

#define IShapeRange_get_ConnectionSiteCount(This,RHS)	\
    ( (This)->lpVtbl -> get_ConnectionSiteCount(This,RHS) ) 

#define IShapeRange_get_Connector(This,RHS)	\
    ( (This)->lpVtbl -> get_Connector(This,RHS) ) 

#define IShapeRange_get_ConnectorFormat(This,RHS)	\
    ( (This)->lpVtbl -> get_ConnectorFormat(This,RHS) ) 

#define IShapeRange_get_Fill(This,RHS)	\
    ( (This)->lpVtbl -> get_Fill(This,RHS) ) 

#define IShapeRange_get_GroupItems(This,RHS)	\
    ( (This)->lpVtbl -> get_GroupItems(This,RHS) ) 

#define IShapeRange_get_Height(This,RHS)	\
    ( (This)->lpVtbl -> get_Height(This,RHS) ) 

#define IShapeRange_put_Height(This,RHS)	\
    ( (This)->lpVtbl -> put_Height(This,RHS) ) 

#define IShapeRange_get_HorizontalFlip(This,RHS)	\
    ( (This)->lpVtbl -> get_HorizontalFlip(This,RHS) ) 

#define IShapeRange_get_Left(This,RHS)	\
    ( (This)->lpVtbl -> get_Left(This,RHS) ) 

#define IShapeRange_put_Left(This,RHS)	\
    ( (This)->lpVtbl -> put_Left(This,RHS) ) 

#define IShapeRange_get_Line(This,RHS)	\
    ( (This)->lpVtbl -> get_Line(This,RHS) ) 

#define IShapeRange_get_LockAspectRatio(This,RHS)	\
    ( (This)->lpVtbl -> get_LockAspectRatio(This,RHS) ) 

#define IShapeRange_put_LockAspectRatio(This,RHS)	\
    ( (This)->lpVtbl -> put_LockAspectRatio(This,RHS) ) 

#define IShapeRange_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define IShapeRange_put_Name(This,RHS)	\
    ( (This)->lpVtbl -> put_Name(This,RHS) ) 

#define IShapeRange_get_Nodes(This,RHS)	\
    ( (This)->lpVtbl -> get_Nodes(This,RHS) ) 

#define IShapeRange_get_Rotation(This,RHS)	\
    ( (This)->lpVtbl -> get_Rotation(This,RHS) ) 

#define IShapeRange_put_Rotation(This,RHS)	\
    ( (This)->lpVtbl -> put_Rotation(This,RHS) ) 

#define IShapeRange_get_PictureFormat(This,RHS)	\
    ( (This)->lpVtbl -> get_PictureFormat(This,RHS) ) 

#define IShapeRange_get_Shadow(This,RHS)	\
    ( (This)->lpVtbl -> get_Shadow(This,RHS) ) 

#define IShapeRange_get_TextEffect(This,RHS)	\
    ( (This)->lpVtbl -> get_TextEffect(This,RHS) ) 

#define IShapeRange_get_ThreeD(This,RHS)	\
    ( (This)->lpVtbl -> get_ThreeD(This,RHS) ) 

#define IShapeRange_get_Top(This,RHS)	\
    ( (This)->lpVtbl -> get_Top(This,RHS) ) 

#define IShapeRange_put_Top(This,RHS)	\
    ( (This)->lpVtbl -> put_Top(This,RHS) ) 

#define IShapeRange_get_Type(This,RHS)	\
    ( (This)->lpVtbl -> get_Type(This,RHS) ) 

#define IShapeRange_get_VerticalFlip(This,RHS)	\
    ( (This)->lpVtbl -> get_VerticalFlip(This,RHS) ) 

#define IShapeRange_get_Vertices(This,RHS)	\
    ( (This)->lpVtbl -> get_Vertices(This,RHS) ) 

#define IShapeRange_get_Visible(This,RHS)	\
    ( (This)->lpVtbl -> get_Visible(This,RHS) ) 

#define IShapeRange_put_Visible(This,RHS)	\
    ( (This)->lpVtbl -> put_Visible(This,RHS) ) 

#define IShapeRange_get_Width(This,RHS)	\
    ( (This)->lpVtbl -> get_Width(This,RHS) ) 

#define IShapeRange_put_Width(This,RHS)	\
    ( (This)->lpVtbl -> put_Width(This,RHS) ) 

#define IShapeRange_get_ZOrderPosition(This,RHS)	\
    ( (This)->lpVtbl -> get_ZOrderPosition(This,RHS) ) 

#define IShapeRange_get_BlackWhiteMode(This,RHS)	\
    ( (This)->lpVtbl -> get_BlackWhiteMode(This,RHS) ) 

#define IShapeRange_put_BlackWhiteMode(This,RHS)	\
    ( (This)->lpVtbl -> put_BlackWhiteMode(This,RHS) ) 

#define IShapeRange_get_AlternativeText(This,RHS)	\
    ( (This)->lpVtbl -> get_AlternativeText(This,RHS) ) 

#define IShapeRange_put_AlternativeText(This,RHS)	\
    ( (This)->lpVtbl -> put_AlternativeText(This,RHS) ) 

#define IShapeRange_get_DiagramNode(This,RHS)	\
    ( (This)->lpVtbl -> get_DiagramNode(This,RHS) ) 

#define IShapeRange_get_HasDiagramNode(This,RHS)	\
    ( (This)->lpVtbl -> get_HasDiagramNode(This,RHS) ) 

#define IShapeRange_get_Diagram(This,RHS)	\
    ( (This)->lpVtbl -> get_Diagram(This,RHS) ) 

#define IShapeRange_get_HasDiagram(This,RHS)	\
    ( (This)->lpVtbl -> get_HasDiagram(This,RHS) ) 

#define IShapeRange_get_Child(This,RHS)	\
    ( (This)->lpVtbl -> get_Child(This,RHS) ) 

#define IShapeRange_get_ParentGroup(This,RHS)	\
    ( (This)->lpVtbl -> get_ParentGroup(This,RHS) ) 

#define IShapeRange_get_CanvasItems(This,RHS)	\
    ( (This)->lpVtbl -> get_CanvasItems(This,RHS) ) 

#define IShapeRange_get_ID(This,RHS)	\
    ( (This)->lpVtbl -> get_ID(This,RHS) ) 

#define IShapeRange_CanvasCropLeft(This,Increment)	\
    ( (This)->lpVtbl -> CanvasCropLeft(This,Increment) ) 

#define IShapeRange_CanvasCropTop(This,Increment)	\
    ( (This)->lpVtbl -> CanvasCropTop(This,Increment) ) 

#define IShapeRange_CanvasCropRight(This,Increment)	\
    ( (This)->lpVtbl -> CanvasCropRight(This,Increment) ) 

#define IShapeRange_CanvasCropBottom(This,Increment)	\
    ( (This)->lpVtbl -> CanvasCropBottom(This,Increment) ) 

#define IShapeRange_get_Chart(This,RHS)	\
    ( (This)->lpVtbl -> get_Chart(This,RHS) ) 

#define IShapeRange_get_HasChart(This,RHS)	\
    ( (This)->lpVtbl -> get_HasChart(This,RHS) ) 

#define IShapeRange_get_TextFrame2(This,RHS)	\
    ( (This)->lpVtbl -> get_TextFrame2(This,RHS) ) 

#define IShapeRange_get_ShapeStyle(This,RHS)	\
    ( (This)->lpVtbl -> get_ShapeStyle(This,RHS) ) 

#define IShapeRange_put_ShapeStyle(This,RHS)	\
    ( (This)->lpVtbl -> put_ShapeStyle(This,RHS) ) 

#define IShapeRange_get_BackgroundStyle(This,RHS)	\
    ( (This)->lpVtbl -> get_BackgroundStyle(This,RHS) ) 

#define IShapeRange_put_BackgroundStyle(This,RHS)	\
    ( (This)->lpVtbl -> put_BackgroundStyle(This,RHS) ) 

#define IShapeRange_get_SoftEdge(This,RHS)	\
    ( (This)->lpVtbl -> get_SoftEdge(This,RHS) ) 

#define IShapeRange_get_Glow(This,RHS)	\
    ( (This)->lpVtbl -> get_Glow(This,RHS) ) 

#define IShapeRange_get_Reflection(This,RHS)	\
    ( (This)->lpVtbl -> get_Reflection(This,RHS) ) 

#define IShapeRange_get_Title(This,RHS)	\
    ( (This)->lpVtbl -> get_Title(This,RHS) ) 

#define IShapeRange_put_Title(This,RHS)	\
    ( (This)->lpVtbl -> put_Title(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IShapeRange_INTERFACE_DEFINED__ */


#ifndef __IGroupShapes_INTERFACE_DEFINED__
#define __IGroupShapes_INTERFACE_DEFINED__

/* interface IGroupShapes */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IGroupShapes;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002443C-0001-0000-C000-000000000046")
    IGroupShapes : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Shape	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall _Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Shape	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Range( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ ShapeRange	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IGroupShapesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IGroupShapes * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IGroupShapes * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IGroupShapes * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IGroupShapes * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IGroupShapes * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IGroupShapes * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IGroupShapes * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IGroupShapes * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IGroupShapes * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IGroupShapes * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IGroupShapes * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Item )( 
            IGroupShapes * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Shape	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *_Default )( 
            IGroupShapes * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Shape	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            IGroupShapes * This,
            /* [retval][out] */ IUnknown **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Range )( 
            IGroupShapes * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ ShapeRange	**RHS);
        
        END_INTERFACE
    } IGroupShapesVtbl;

    interface IGroupShapes
    {
        CONST_VTBL struct IGroupShapesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IGroupShapes_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IGroupShapes_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IGroupShapes_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IGroupShapes_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IGroupShapes_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IGroupShapes_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IGroupShapes_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IGroupShapes_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IGroupShapes_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IGroupShapes_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IGroupShapes_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IGroupShapes_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> Item(This,Index,RHS) ) 

#define IGroupShapes__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> _Default(This,Index,RHS) ) 

#define IGroupShapes_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#define IGroupShapes_get_Range(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Range(This,Index,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IGroupShapes_INTERFACE_DEFINED__ */


#ifndef __ITextFrame_INTERFACE_DEFINED__
#define __ITextFrame_INTERFACE_DEFINED__

/* interface ITextFrame */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ITextFrame;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002443D-0001-0000-C000-000000000046")
    ITextFrame : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MarginBottom( 
            /* [retval][out] */ single *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_MarginBottom( 
            /* [in] */ single RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MarginLeft( 
            /* [retval][out] */ single *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_MarginLeft( 
            /* [in] */ single RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MarginRight( 
            /* [retval][out] */ single *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_MarginRight( 
            /* [in] */ single RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MarginTop( 
            /* [retval][out] */ single *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_MarginTop( 
            /* [in] */ single RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Orientation( 
            /* [retval][out] */ MsoTextOrientation *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Orientation( 
            /* [in] */ MsoTextOrientation RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Characters( 
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Length,
            /* [retval][out] */ Characters	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HorizontalAlignment( 
            /* [retval][out] */ XlHAlign *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_HorizontalAlignment( 
            /* [in] */ XlHAlign RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_VerticalAlignment( 
            /* [retval][out] */ XlVAlign *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_VerticalAlignment( 
            /* [in] */ XlVAlign RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AutoSize( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AutoSize( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ReadingOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ReadingOrder( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AutoMargins( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AutoMargins( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_VerticalOverflow( 
            /* [retval][out] */ XlOartVerticalOverflow *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_VerticalOverflow( 
            /* [in] */ XlOartVerticalOverflow RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HorizontalOverflow( 
            /* [retval][out] */ XlOartHorizontalOverflow *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_HorizontalOverflow( 
            /* [in] */ XlOartHorizontalOverflow RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ITextFrameVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ITextFrame * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ITextFrame * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ITextFrame * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ITextFrame * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ITextFrame * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ITextFrame * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ITextFrame * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ITextFrame * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ITextFrame * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ITextFrame * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MarginBottom )( 
            ITextFrame * This,
            /* [retval][out] */ single *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_MarginBottom )( 
            ITextFrame * This,
            /* [in] */ single RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MarginLeft )( 
            ITextFrame * This,
            /* [retval][out] */ single *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_MarginLeft )( 
            ITextFrame * This,
            /* [in] */ single RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MarginRight )( 
            ITextFrame * This,
            /* [retval][out] */ single *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_MarginRight )( 
            ITextFrame * This,
            /* [in] */ single RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MarginTop )( 
            ITextFrame * This,
            /* [retval][out] */ single *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_MarginTop )( 
            ITextFrame * This,
            /* [in] */ single RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Orientation )( 
            ITextFrame * This,
            /* [retval][out] */ MsoTextOrientation *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Orientation )( 
            ITextFrame * This,
            /* [in] */ MsoTextOrientation RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Characters )( 
            ITextFrame * This,
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Length,
            /* [retval][out] */ Characters	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HorizontalAlignment )( 
            ITextFrame * This,
            /* [retval][out] */ XlHAlign *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_HorizontalAlignment )( 
            ITextFrame * This,
            /* [in] */ XlHAlign RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_VerticalAlignment )( 
            ITextFrame * This,
            /* [retval][out] */ XlVAlign *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_VerticalAlignment )( 
            ITextFrame * This,
            /* [in] */ XlVAlign RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AutoSize )( 
            ITextFrame * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AutoSize )( 
            ITextFrame * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ReadingOrder )( 
            ITextFrame * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ReadingOrder )( 
            ITextFrame * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AutoMargins )( 
            ITextFrame * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AutoMargins )( 
            ITextFrame * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_VerticalOverflow )( 
            ITextFrame * This,
            /* [retval][out] */ XlOartVerticalOverflow *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_VerticalOverflow )( 
            ITextFrame * This,
            /* [in] */ XlOartVerticalOverflow RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HorizontalOverflow )( 
            ITextFrame * This,
            /* [retval][out] */ XlOartHorizontalOverflow *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_HorizontalOverflow )( 
            ITextFrame * This,
            /* [in] */ XlOartHorizontalOverflow RHS);
        
        END_INTERFACE
    } ITextFrameVtbl;

    interface ITextFrame
    {
        CONST_VTBL struct ITextFrameVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ITextFrame_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ITextFrame_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ITextFrame_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ITextFrame_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ITextFrame_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ITextFrame_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ITextFrame_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ITextFrame_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ITextFrame_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ITextFrame_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ITextFrame_get_MarginBottom(This,RHS)	\
    ( (This)->lpVtbl -> get_MarginBottom(This,RHS) ) 

#define ITextFrame_put_MarginBottom(This,RHS)	\
    ( (This)->lpVtbl -> put_MarginBottom(This,RHS) ) 

#define ITextFrame_get_MarginLeft(This,RHS)	\
    ( (This)->lpVtbl -> get_MarginLeft(This,RHS) ) 

#define ITextFrame_put_MarginLeft(This,RHS)	\
    ( (This)->lpVtbl -> put_MarginLeft(This,RHS) ) 

#define ITextFrame_get_MarginRight(This,RHS)	\
    ( (This)->lpVtbl -> get_MarginRight(This,RHS) ) 

#define ITextFrame_put_MarginRight(This,RHS)	\
    ( (This)->lpVtbl -> put_MarginRight(This,RHS) ) 

#define ITextFrame_get_MarginTop(This,RHS)	\
    ( (This)->lpVtbl -> get_MarginTop(This,RHS) ) 

#define ITextFrame_put_MarginTop(This,RHS)	\
    ( (This)->lpVtbl -> put_MarginTop(This,RHS) ) 

#define ITextFrame_get_Orientation(This,RHS)	\
    ( (This)->lpVtbl -> get_Orientation(This,RHS) ) 

#define ITextFrame_put_Orientation(This,RHS)	\
    ( (This)->lpVtbl -> put_Orientation(This,RHS) ) 

#define ITextFrame_Characters(This,Start,Length,RHS)	\
    ( (This)->lpVtbl -> Characters(This,Start,Length,RHS) ) 

#define ITextFrame_get_HorizontalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> get_HorizontalAlignment(This,RHS) ) 

#define ITextFrame_put_HorizontalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> put_HorizontalAlignment(This,RHS) ) 

#define ITextFrame_get_VerticalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> get_VerticalAlignment(This,RHS) ) 

#define ITextFrame_put_VerticalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> put_VerticalAlignment(This,RHS) ) 

#define ITextFrame_get_AutoSize(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoSize(This,RHS) ) 

#define ITextFrame_put_AutoSize(This,RHS)	\
    ( (This)->lpVtbl -> put_AutoSize(This,RHS) ) 

#define ITextFrame_get_ReadingOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_ReadingOrder(This,RHS) ) 

#define ITextFrame_put_ReadingOrder(This,RHS)	\
    ( (This)->lpVtbl -> put_ReadingOrder(This,RHS) ) 

#define ITextFrame_get_AutoMargins(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoMargins(This,RHS) ) 

#define ITextFrame_put_AutoMargins(This,RHS)	\
    ( (This)->lpVtbl -> put_AutoMargins(This,RHS) ) 

#define ITextFrame_get_VerticalOverflow(This,RHS)	\
    ( (This)->lpVtbl -> get_VerticalOverflow(This,RHS) ) 

#define ITextFrame_put_VerticalOverflow(This,RHS)	\
    ( (This)->lpVtbl -> put_VerticalOverflow(This,RHS) ) 

#define ITextFrame_get_HorizontalOverflow(This,RHS)	\
    ( (This)->lpVtbl -> get_HorizontalOverflow(This,RHS) ) 

#define ITextFrame_put_HorizontalOverflow(This,RHS)	\
    ( (This)->lpVtbl -> put_HorizontalOverflow(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ITextFrame_INTERFACE_DEFINED__ */


#ifndef __IConnectorFormat_INTERFACE_DEFINED__
#define __IConnectorFormat_INTERFACE_DEFINED__

/* interface IConnectorFormat */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IConnectorFormat;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002443E-0001-0000-C000-000000000046")
    IConnectorFormat : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall BeginConnect( 
            /* [in] */ Shape	*ConnectedShape,
            /* [in] */ long ConnectionSite) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall BeginDisconnect( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall EndConnect( 
            /* [in] */ Shape	*ConnectedShape,
            /* [in] */ long ConnectionSite) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall EndDisconnect( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_BeginConnected( 
            /* [retval][out] */ MsoTriState *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_BeginConnectedShape( 
            /* [retval][out] */ Shape	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_BeginConnectionSite( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_EndConnected( 
            /* [retval][out] */ MsoTriState *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_EndConnectedShape( 
            /* [retval][out] */ Shape	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_EndConnectionSite( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Type( 
            /* [retval][out] */ MsoConnectorType *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Type( 
            /* [in] */ MsoConnectorType RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IConnectorFormatVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IConnectorFormat * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IConnectorFormat * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IConnectorFormat * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IConnectorFormat * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IConnectorFormat * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IConnectorFormat * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IConnectorFormat * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IConnectorFormat * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IConnectorFormat * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IConnectorFormat * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *BeginConnect )( 
            IConnectorFormat * This,
            /* [in] */ Shape	*ConnectedShape,
            /* [in] */ long ConnectionSite);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *BeginDisconnect )( 
            IConnectorFormat * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *EndConnect )( 
            IConnectorFormat * This,
            /* [in] */ Shape	*ConnectedShape,
            /* [in] */ long ConnectionSite);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *EndDisconnect )( 
            IConnectorFormat * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_BeginConnected )( 
            IConnectorFormat * This,
            /* [retval][out] */ MsoTriState *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_BeginConnectedShape )( 
            IConnectorFormat * This,
            /* [retval][out] */ Shape	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_BeginConnectionSite )( 
            IConnectorFormat * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_EndConnected )( 
            IConnectorFormat * This,
            /* [retval][out] */ MsoTriState *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_EndConnectedShape )( 
            IConnectorFormat * This,
            /* [retval][out] */ Shape	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_EndConnectionSite )( 
            IConnectorFormat * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Type )( 
            IConnectorFormat * This,
            /* [retval][out] */ MsoConnectorType *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Type )( 
            IConnectorFormat * This,
            /* [in] */ MsoConnectorType RHS);
        
        END_INTERFACE
    } IConnectorFormatVtbl;

    interface IConnectorFormat
    {
        CONST_VTBL struct IConnectorFormatVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IConnectorFormat_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IConnectorFormat_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IConnectorFormat_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IConnectorFormat_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IConnectorFormat_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IConnectorFormat_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IConnectorFormat_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IConnectorFormat_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IConnectorFormat_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IConnectorFormat_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IConnectorFormat_BeginConnect(This,ConnectedShape,ConnectionSite)	\
    ( (This)->lpVtbl -> BeginConnect(This,ConnectedShape,ConnectionSite) ) 

#define IConnectorFormat_BeginDisconnect(This)	\
    ( (This)->lpVtbl -> BeginDisconnect(This) ) 

#define IConnectorFormat_EndConnect(This,ConnectedShape,ConnectionSite)	\
    ( (This)->lpVtbl -> EndConnect(This,ConnectedShape,ConnectionSite) ) 

#define IConnectorFormat_EndDisconnect(This)	\
    ( (This)->lpVtbl -> EndDisconnect(This) ) 

#define IConnectorFormat_get_BeginConnected(This,RHS)	\
    ( (This)->lpVtbl -> get_BeginConnected(This,RHS) ) 

#define IConnectorFormat_get_BeginConnectedShape(This,RHS)	\
    ( (This)->lpVtbl -> get_BeginConnectedShape(This,RHS) ) 

#define IConnectorFormat_get_BeginConnectionSite(This,RHS)	\
    ( (This)->lpVtbl -> get_BeginConnectionSite(This,RHS) ) 

#define IConnectorFormat_get_EndConnected(This,RHS)	\
    ( (This)->lpVtbl -> get_EndConnected(This,RHS) ) 

#define IConnectorFormat_get_EndConnectedShape(This,RHS)	\
    ( (This)->lpVtbl -> get_EndConnectedShape(This,RHS) ) 

#define IConnectorFormat_get_EndConnectionSite(This,RHS)	\
    ( (This)->lpVtbl -> get_EndConnectionSite(This,RHS) ) 

#define IConnectorFormat_get_Type(This,RHS)	\
    ( (This)->lpVtbl -> get_Type(This,RHS) ) 

#define IConnectorFormat_put_Type(This,RHS)	\
    ( (This)->lpVtbl -> put_Type(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IConnectorFormat_INTERFACE_DEFINED__ */


#ifndef __IFreeformBuilder_INTERFACE_DEFINED__
#define __IFreeformBuilder_INTERFACE_DEFINED__

/* interface IFreeformBuilder */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IFreeformBuilder;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002443F-0001-0000-C000-000000000046")
    IFreeformBuilder : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall AddNodes( 
            /* [in] */ MsoSegmentType SegmentType,
            /* [in] */ MsoEditingType EditingType,
            /* [in] */ single X1,
            /* [in] */ single Y1,
            /* [optional][in] */ VARIANT X2,
            /* [optional][in] */ VARIANT Y2,
            /* [optional][in] */ VARIANT X3,
            /* [optional][in] */ VARIANT Y3) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ConvertToShape( 
            /* [retval][out] */ Shape	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IFreeformBuilderVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IFreeformBuilder * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IFreeformBuilder * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IFreeformBuilder * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IFreeformBuilder * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IFreeformBuilder * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IFreeformBuilder * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IFreeformBuilder * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IFreeformBuilder * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IFreeformBuilder * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IFreeformBuilder * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *AddNodes )( 
            IFreeformBuilder * This,
            /* [in] */ MsoSegmentType SegmentType,
            /* [in] */ MsoEditingType EditingType,
            /* [in] */ single X1,
            /* [in] */ single Y1,
            /* [optional][in] */ VARIANT X2,
            /* [optional][in] */ VARIANT Y2,
            /* [optional][in] */ VARIANT X3,
            /* [optional][in] */ VARIANT Y3);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ConvertToShape )( 
            IFreeformBuilder * This,
            /* [retval][out] */ Shape	**RHS);
        
        END_INTERFACE
    } IFreeformBuilderVtbl;

    interface IFreeformBuilder
    {
        CONST_VTBL struct IFreeformBuilderVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IFreeformBuilder_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IFreeformBuilder_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IFreeformBuilder_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IFreeformBuilder_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IFreeformBuilder_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IFreeformBuilder_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IFreeformBuilder_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IFreeformBuilder_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IFreeformBuilder_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IFreeformBuilder_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IFreeformBuilder_AddNodes(This,SegmentType,EditingType,X1,Y1,X2,Y2,X3,Y3)	\
    ( (This)->lpVtbl -> AddNodes(This,SegmentType,EditingType,X1,Y1,X2,Y2,X3,Y3) ) 

#define IFreeformBuilder_ConvertToShape(This,RHS)	\
    ( (This)->lpVtbl -> ConvertToShape(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IFreeformBuilder_INTERFACE_DEFINED__ */


#ifndef __IControlFormat_INTERFACE_DEFINED__
#define __IControlFormat_INTERFACE_DEFINED__

/* interface IControlFormat */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IControlFormat;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024440-0001-0000-C000-000000000046")
    IControlFormat : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall AddItem( 
            /* [in] */ BSTR Text,
            /* [optional][in] */ VARIANT Index) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall RemoveAllItems( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall RemoveItem( 
            /* [in] */ long Index,
            /* [optional][in] */ VARIANT Count) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DropDownLines( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DropDownLines( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Enabled( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Enabled( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LargeChange( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_LargeChange( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LinkedCell( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_LinkedCell( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [custom][helpcontext][id] */ HRESULT __stdcall List( 
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ListCount( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ListCount( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ListFillRange( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ListFillRange( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ListIndex( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ListIndex( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LockedText( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_LockedText( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Max( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Max( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Min( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Min( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MultiSelect( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_MultiSelect( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PrintObject( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PrintObject( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SmallChange( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_SmallChange( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put__Default( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Value( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Value( 
            /* [in] */ long RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IControlFormatVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IControlFormat * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IControlFormat * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IControlFormat * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IControlFormat * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IControlFormat * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IControlFormat * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IControlFormat * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IControlFormat * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IControlFormat * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IControlFormat * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *AddItem )( 
            IControlFormat * This,
            /* [in] */ BSTR Text,
            /* [optional][in] */ VARIANT Index);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *RemoveAllItems )( 
            IControlFormat * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *RemoveItem )( 
            IControlFormat * This,
            /* [in] */ long Index,
            /* [optional][in] */ VARIANT Count);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DropDownLines )( 
            IControlFormat * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DropDownLines )( 
            IControlFormat * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Enabled )( 
            IControlFormat * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Enabled )( 
            IControlFormat * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LargeChange )( 
            IControlFormat * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_LargeChange )( 
            IControlFormat * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LinkedCell )( 
            IControlFormat * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_LinkedCell )( 
            IControlFormat * This,
            /* [in] */ BSTR RHS);
        
        /* [custom][helpcontext][id] */ HRESULT ( __stdcall *List )( 
            IControlFormat * This,
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ListCount )( 
            IControlFormat * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ListCount )( 
            IControlFormat * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ListFillRange )( 
            IControlFormat * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ListFillRange )( 
            IControlFormat * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ListIndex )( 
            IControlFormat * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ListIndex )( 
            IControlFormat * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LockedText )( 
            IControlFormat * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_LockedText )( 
            IControlFormat * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Max )( 
            IControlFormat * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Max )( 
            IControlFormat * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Min )( 
            IControlFormat * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Min )( 
            IControlFormat * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MultiSelect )( 
            IControlFormat * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_MultiSelect )( 
            IControlFormat * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PrintObject )( 
            IControlFormat * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PrintObject )( 
            IControlFormat * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SmallChange )( 
            IControlFormat * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_SmallChange )( 
            IControlFormat * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IControlFormat * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put__Default )( 
            IControlFormat * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Value )( 
            IControlFormat * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Value )( 
            IControlFormat * This,
            /* [in] */ long RHS);
        
        END_INTERFACE
    } IControlFormatVtbl;

    interface IControlFormat
    {
        CONST_VTBL struct IControlFormatVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IControlFormat_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IControlFormat_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IControlFormat_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IControlFormat_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IControlFormat_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IControlFormat_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IControlFormat_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IControlFormat_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IControlFormat_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IControlFormat_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IControlFormat_AddItem(This,Text,Index)	\
    ( (This)->lpVtbl -> AddItem(This,Text,Index) ) 

#define IControlFormat_RemoveAllItems(This)	\
    ( (This)->lpVtbl -> RemoveAllItems(This) ) 

#define IControlFormat_RemoveItem(This,Index,Count)	\
    ( (This)->lpVtbl -> RemoveItem(This,Index,Count) ) 

#define IControlFormat_get_DropDownLines(This,RHS)	\
    ( (This)->lpVtbl -> get_DropDownLines(This,RHS) ) 

#define IControlFormat_put_DropDownLines(This,RHS)	\
    ( (This)->lpVtbl -> put_DropDownLines(This,RHS) ) 

#define IControlFormat_get_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> get_Enabled(This,RHS) ) 

#define IControlFormat_put_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> put_Enabled(This,RHS) ) 

#define IControlFormat_get_LargeChange(This,RHS)	\
    ( (This)->lpVtbl -> get_LargeChange(This,RHS) ) 

#define IControlFormat_put_LargeChange(This,RHS)	\
    ( (This)->lpVtbl -> put_LargeChange(This,RHS) ) 

#define IControlFormat_get_LinkedCell(This,RHS)	\
    ( (This)->lpVtbl -> get_LinkedCell(This,RHS) ) 

#define IControlFormat_put_LinkedCell(This,RHS)	\
    ( (This)->lpVtbl -> put_LinkedCell(This,RHS) ) 

#define IControlFormat_List(This,Index,RHS)	\
    ( (This)->lpVtbl -> List(This,Index,RHS) ) 

#define IControlFormat_get_ListCount(This,RHS)	\
    ( (This)->lpVtbl -> get_ListCount(This,RHS) ) 

#define IControlFormat_put_ListCount(This,RHS)	\
    ( (This)->lpVtbl -> put_ListCount(This,RHS) ) 

#define IControlFormat_get_ListFillRange(This,RHS)	\
    ( (This)->lpVtbl -> get_ListFillRange(This,RHS) ) 

#define IControlFormat_put_ListFillRange(This,RHS)	\
    ( (This)->lpVtbl -> put_ListFillRange(This,RHS) ) 

#define IControlFormat_get_ListIndex(This,RHS)	\
    ( (This)->lpVtbl -> get_ListIndex(This,RHS) ) 

#define IControlFormat_put_ListIndex(This,RHS)	\
    ( (This)->lpVtbl -> put_ListIndex(This,RHS) ) 

#define IControlFormat_get_LockedText(This,RHS)	\
    ( (This)->lpVtbl -> get_LockedText(This,RHS) ) 

#define IControlFormat_put_LockedText(This,RHS)	\
    ( (This)->lpVtbl -> put_LockedText(This,RHS) ) 

#define IControlFormat_get_Max(This,RHS)	\
    ( (This)->lpVtbl -> get_Max(This,RHS) ) 

#define IControlFormat_put_Max(This,RHS)	\
    ( (This)->lpVtbl -> put_Max(This,RHS) ) 

#define IControlFormat_get_Min(This,RHS)	\
    ( (This)->lpVtbl -> get_Min(This,RHS) ) 

#define IControlFormat_put_Min(This,RHS)	\
    ( (This)->lpVtbl -> put_Min(This,RHS) ) 

#define IControlFormat_get_MultiSelect(This,RHS)	\
    ( (This)->lpVtbl -> get_MultiSelect(This,RHS) ) 

#define IControlFormat_put_MultiSelect(This,RHS)	\
    ( (This)->lpVtbl -> put_MultiSelect(This,RHS) ) 

#define IControlFormat_get_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> get_PrintObject(This,RHS) ) 

#define IControlFormat_put_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> put_PrintObject(This,RHS) ) 

#define IControlFormat_get_SmallChange(This,RHS)	\
    ( (This)->lpVtbl -> get_SmallChange(This,RHS) ) 

#define IControlFormat_put_SmallChange(This,RHS)	\
    ( (This)->lpVtbl -> put_SmallChange(This,RHS) ) 

#define IControlFormat_get__Default(This,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,RHS) ) 

#define IControlFormat_put__Default(This,RHS)	\
    ( (This)->lpVtbl -> put__Default(This,RHS) ) 

#define IControlFormat_get_Value(This,RHS)	\
    ( (This)->lpVtbl -> get_Value(This,RHS) ) 

#define IControlFormat_put_Value(This,RHS)	\
    ( (This)->lpVtbl -> put_Value(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IControlFormat_INTERFACE_DEFINED__ */


#ifndef __IOLEFormat_INTERFACE_DEFINED__
#define __IOLEFormat_INTERFACE_DEFINED__

/* interface IOLEFormat */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IOLEFormat;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024441-0001-0000-C000-000000000046")
    IOLEFormat : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Activate( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Object( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_progID( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Verb( 
            /* [optional][in] */ VARIANT Verb) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IOLEFormatVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IOLEFormat * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IOLEFormat * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IOLEFormat * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IOLEFormat * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IOLEFormat * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IOLEFormat * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IOLEFormat * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IOLEFormat * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IOLEFormat * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IOLEFormat * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Activate )( 
            IOLEFormat * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Object )( 
            IOLEFormat * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_progID )( 
            IOLEFormat * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Verb )( 
            IOLEFormat * This,
            /* [optional][in] */ VARIANT Verb);
        
        END_INTERFACE
    } IOLEFormatVtbl;

    interface IOLEFormat
    {
        CONST_VTBL struct IOLEFormatVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IOLEFormat_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IOLEFormat_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IOLEFormat_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IOLEFormat_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IOLEFormat_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IOLEFormat_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IOLEFormat_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IOLEFormat_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IOLEFormat_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IOLEFormat_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IOLEFormat_Activate(This)	\
    ( (This)->lpVtbl -> Activate(This) ) 

#define IOLEFormat_get_Object(This,RHS)	\
    ( (This)->lpVtbl -> get_Object(This,RHS) ) 

#define IOLEFormat_get_progID(This,RHS)	\
    ( (This)->lpVtbl -> get_progID(This,RHS) ) 

#define IOLEFormat_Verb(This,Verb)	\
    ( (This)->lpVtbl -> Verb(This,Verb) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IOLEFormat_INTERFACE_DEFINED__ */


#ifndef __ILinkFormat_INTERFACE_DEFINED__
#define __ILinkFormat_INTERFACE_DEFINED__

/* interface ILinkFormat */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ILinkFormat;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024442-0001-0000-C000-000000000046")
    ILinkFormat : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AutoUpdate( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AutoUpdate( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Locked( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Locked( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Update( void) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ILinkFormatVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ILinkFormat * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ILinkFormat * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ILinkFormat * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ILinkFormat * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ILinkFormat * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ILinkFormat * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ILinkFormat * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ILinkFormat * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ILinkFormat * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ILinkFormat * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AutoUpdate )( 
            ILinkFormat * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AutoUpdate )( 
            ILinkFormat * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Locked )( 
            ILinkFormat * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Locked )( 
            ILinkFormat * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Update )( 
            ILinkFormat * This);
        
        END_INTERFACE
    } ILinkFormatVtbl;

    interface ILinkFormat
    {
        CONST_VTBL struct ILinkFormatVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ILinkFormat_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ILinkFormat_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ILinkFormat_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ILinkFormat_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ILinkFormat_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ILinkFormat_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ILinkFormat_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ILinkFormat_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ILinkFormat_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ILinkFormat_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ILinkFormat_get_AutoUpdate(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoUpdate(This,RHS) ) 

#define ILinkFormat_put_AutoUpdate(This,RHS)	\
    ( (This)->lpVtbl -> put_AutoUpdate(This,RHS) ) 

#define ILinkFormat_get_Locked(This,RHS)	\
    ( (This)->lpVtbl -> get_Locked(This,RHS) ) 

#define ILinkFormat_put_Locked(This,RHS)	\
    ( (This)->lpVtbl -> put_Locked(This,RHS) ) 

#define ILinkFormat_Update(This)	\
    ( (This)->lpVtbl -> Update(This) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ILinkFormat_INTERFACE_DEFINED__ */


#ifndef __IPublishObjects_INTERFACE_DEFINED__
#define __IPublishObjects_INTERFACE_DEFINED__

/* interface IPublishObjects */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IPublishObjects;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024443-0001-0000-C000-000000000046")
    IPublishObjects : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add( 
            /* [in] */ XlSourceType SourceType,
            /* [in] */ BSTR Filename,
            /* [optional][in] */ VARIANT Sheet,
            /* [optional][in] */ VARIANT Source,
            /* [optional][in] */ VARIANT HtmlType,
            /* [optional][in] */ VARIANT DivID,
            /* [optional][in] */ VARIANT Title,
            /* [retval][out] */ PublishObject **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ PublishObject **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ PublishObject **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Publish( void) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IPublishObjectsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IPublishObjects * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IPublishObjects * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IPublishObjects * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IPublishObjects * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IPublishObjects * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IPublishObjects * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IPublishObjects * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IPublishObjects * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IPublishObjects * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IPublishObjects * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add )( 
            IPublishObjects * This,
            /* [in] */ XlSourceType SourceType,
            /* [in] */ BSTR Filename,
            /* [optional][in] */ VARIANT Sheet,
            /* [optional][in] */ VARIANT Source,
            /* [optional][in] */ VARIANT HtmlType,
            /* [optional][in] */ VARIANT DivID,
            /* [optional][in] */ VARIANT Title,
            /* [retval][out] */ PublishObject **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IPublishObjects * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Item )( 
            IPublishObjects * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ PublishObject **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IPublishObjects * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ PublishObject **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            IPublishObjects * This,
            /* [retval][out] */ IUnknown **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IPublishObjects * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Publish )( 
            IPublishObjects * This);
        
        END_INTERFACE
    } IPublishObjectsVtbl;

    interface IPublishObjects
    {
        CONST_VTBL struct IPublishObjectsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IPublishObjects_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IPublishObjects_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IPublishObjects_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IPublishObjects_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IPublishObjects_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IPublishObjects_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IPublishObjects_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IPublishObjects_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IPublishObjects_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IPublishObjects_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IPublishObjects_Add(This,SourceType,Filename,Sheet,Source,HtmlType,DivID,Title,RHS)	\
    ( (This)->lpVtbl -> Add(This,SourceType,Filename,Sheet,Source,HtmlType,DivID,Title,RHS) ) 

#define IPublishObjects_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IPublishObjects_get_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Item(This,Index,RHS) ) 

#define IPublishObjects_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define IPublishObjects_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#define IPublishObjects_Delete(This)	\
    ( (This)->lpVtbl -> Delete(This) ) 

#define IPublishObjects_Publish(This)	\
    ( (This)->lpVtbl -> Publish(This) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IPublishObjects_INTERFACE_DEFINED__ */


#ifndef __PublishObject_INTERFACE_DEFINED__
#define __PublishObject_INTERFACE_DEFINED__

/* interface PublishObject */
/* [object][oleautomation][nonextensible][dual][helpcontext][uuid] */ 


EXTERN_C const IID IID_PublishObject;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024444-0000-0000-C000-000000000046")
    PublishObject : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Delete( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Publish( 
            /* [optional][in] */ VARIANT Create) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_DivID( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Sheet( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_SourceType( 
            /* [retval][out] */ XlSourceType *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Source( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_HtmlType( 
            /* [retval][out] */ XlHtmlType *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_HtmlType( 
            /* [in] */ XlHtmlType RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Title( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_Title( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Filename( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_Filename( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_AutoRepublish( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_AutoRepublish( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct PublishObjectVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            PublishObject * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            PublishObject * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            PublishObject * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            PublishObject * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            PublishObject * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            PublishObject * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            PublishObject * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Application )( 
            PublishObject * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Creator )( 
            PublishObject * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Parent )( 
            PublishObject * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Delete )( 
            PublishObject * This);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Publish )( 
            PublishObject * This,
            /* [optional][in] */ VARIANT Create);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_DivID )( 
            PublishObject * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Sheet )( 
            PublishObject * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_SourceType )( 
            PublishObject * This,
            /* [retval][out] */ XlSourceType *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Source )( 
            PublishObject * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_HtmlType )( 
            PublishObject * This,
            /* [retval][out] */ XlHtmlType *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_HtmlType )( 
            PublishObject * This,
            /* [in] */ XlHtmlType RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Title )( 
            PublishObject * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Title )( 
            PublishObject * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Filename )( 
            PublishObject * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Filename )( 
            PublishObject * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_AutoRepublish )( 
            PublishObject * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_AutoRepublish )( 
            PublishObject * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        END_INTERFACE
    } PublishObjectVtbl;

    interface PublishObject
    {
        CONST_VTBL struct PublishObjectVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define PublishObject_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define PublishObject_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define PublishObject_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define PublishObject_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define PublishObject_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define PublishObject_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define PublishObject_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define PublishObject_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define PublishObject_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define PublishObject_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define PublishObject_Delete(This)	\
    ( (This)->lpVtbl -> Delete(This) ) 

#define PublishObject_Publish(This,Create)	\
    ( (This)->lpVtbl -> Publish(This,Create) ) 

#define PublishObject_get_DivID(This,RHS)	\
    ( (This)->lpVtbl -> get_DivID(This,RHS) ) 

#define PublishObject_get_Sheet(This,RHS)	\
    ( (This)->lpVtbl -> get_Sheet(This,RHS) ) 

#define PublishObject_get_SourceType(This,RHS)	\
    ( (This)->lpVtbl -> get_SourceType(This,RHS) ) 

#define PublishObject_get_Source(This,RHS)	\
    ( (This)->lpVtbl -> get_Source(This,RHS) ) 

#define PublishObject_get_HtmlType(This,RHS)	\
    ( (This)->lpVtbl -> get_HtmlType(This,RHS) ) 

#define PublishObject_put_HtmlType(This,RHS)	\
    ( (This)->lpVtbl -> put_HtmlType(This,RHS) ) 

#define PublishObject_get_Title(This,RHS)	\
    ( (This)->lpVtbl -> get_Title(This,RHS) ) 

#define PublishObject_put_Title(This,RHS)	\
    ( (This)->lpVtbl -> put_Title(This,RHS) ) 

#define PublishObject_get_Filename(This,RHS)	\
    ( (This)->lpVtbl -> get_Filename(This,RHS) ) 

#define PublishObject_put_Filename(This,RHS)	\
    ( (This)->lpVtbl -> put_Filename(This,RHS) ) 

#define PublishObject_get_AutoRepublish(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoRepublish(This,RHS) ) 

#define PublishObject_put_AutoRepublish(This,RHS)	\
    ( (This)->lpVtbl -> put_AutoRepublish(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __PublishObject_INTERFACE_DEFINED__ */


#ifndef __IOLEDBError_INTERFACE_DEFINED__
#define __IOLEDBError_INTERFACE_DEFINED__

/* interface IOLEDBError */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IOLEDBError;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024445-0001-0000-C000-000000000046")
    IOLEDBError : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SqlState( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ErrorString( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Native( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Number( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Stage( 
            /* [retval][out] */ long *RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IOLEDBErrorVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IOLEDBError * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IOLEDBError * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IOLEDBError * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IOLEDBError * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IOLEDBError * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IOLEDBError * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IOLEDBError * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IOLEDBError * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IOLEDBError * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IOLEDBError * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SqlState )( 
            IOLEDBError * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ErrorString )( 
            IOLEDBError * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Native )( 
            IOLEDBError * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Number )( 
            IOLEDBError * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Stage )( 
            IOLEDBError * This,
            /* [retval][out] */ long *RHS);
        
        END_INTERFACE
    } IOLEDBErrorVtbl;

    interface IOLEDBError
    {
        CONST_VTBL struct IOLEDBErrorVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IOLEDBError_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IOLEDBError_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IOLEDBError_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IOLEDBError_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IOLEDBError_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IOLEDBError_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IOLEDBError_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IOLEDBError_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IOLEDBError_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IOLEDBError_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IOLEDBError_get_SqlState(This,RHS)	\
    ( (This)->lpVtbl -> get_SqlState(This,RHS) ) 

#define IOLEDBError_get_ErrorString(This,RHS)	\
    ( (This)->lpVtbl -> get_ErrorString(This,RHS) ) 

#define IOLEDBError_get_Native(This,RHS)	\
    ( (This)->lpVtbl -> get_Native(This,RHS) ) 

#define IOLEDBError_get_Number(This,RHS)	\
    ( (This)->lpVtbl -> get_Number(This,RHS) ) 

#define IOLEDBError_get_Stage(This,RHS)	\
    ( (This)->lpVtbl -> get_Stage(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IOLEDBError_INTERFACE_DEFINED__ */


#ifndef __IOLEDBErrors_INTERFACE_DEFINED__
#define __IOLEDBErrors_INTERFACE_DEFINED__

/* interface IOLEDBErrors */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IOLEDBErrors;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024446-0001-0000-C000-000000000046")
    IOLEDBErrors : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Item( 
            /* [in] */ long Index,
            /* [retval][out] */ OLEDBError	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ long Index,
            /* [retval][out] */ OLEDBError	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall _NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IOLEDBErrorsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IOLEDBErrors * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IOLEDBErrors * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IOLEDBErrors * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IOLEDBErrors * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IOLEDBErrors * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IOLEDBErrors * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IOLEDBErrors * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IOLEDBErrors * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IOLEDBErrors * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IOLEDBErrors * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IOLEDBErrors * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Item )( 
            IOLEDBErrors * This,
            /* [in] */ long Index,
            /* [retval][out] */ OLEDBError	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IOLEDBErrors * This,
            /* [in] */ long Index,
            /* [retval][out] */ OLEDBError	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *_NewEnum )( 
            IOLEDBErrors * This,
            /* [retval][out] */ IUnknown **RHS);
        
        END_INTERFACE
    } IOLEDBErrorsVtbl;

    interface IOLEDBErrors
    {
        CONST_VTBL struct IOLEDBErrorsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IOLEDBErrors_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IOLEDBErrors_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IOLEDBErrors_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IOLEDBErrors_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IOLEDBErrors_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IOLEDBErrors_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IOLEDBErrors_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IOLEDBErrors_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IOLEDBErrors_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IOLEDBErrors_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IOLEDBErrors_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IOLEDBErrors_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> Item(This,Index,RHS) ) 

#define IOLEDBErrors_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define IOLEDBErrors__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> _NewEnum(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IOLEDBErrors_INTERFACE_DEFINED__ */


#ifndef __IPhonetics_INTERFACE_DEFINED__
#define __IPhonetics_INTERFACE_DEFINED__

/* interface IPhonetics */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IPhonetics;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024447-0001-0000-C000-000000000046")
    IPhonetics : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Start( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Length( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Visible( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Visible( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CharacterType( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_CharacterType( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Alignment( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Alignment( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Font( 
            /* [retval][out] */ Font	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Item( 
            /* [in] */ long Index,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add( 
            /* [in] */ long Start,
            /* [in] */ long Length,
            /* [in] */ BSTR Text) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Text( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Text( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ long Index,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IPhoneticsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IPhonetics * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IPhonetics * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IPhonetics * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IPhonetics * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IPhonetics * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IPhonetics * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IPhonetics * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IPhonetics * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IPhonetics * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IPhonetics * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IPhonetics * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Start )( 
            IPhonetics * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Length )( 
            IPhonetics * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Visible )( 
            IPhonetics * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Visible )( 
            IPhonetics * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CharacterType )( 
            IPhonetics * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_CharacterType )( 
            IPhonetics * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Alignment )( 
            IPhonetics * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Alignment )( 
            IPhonetics * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Font )( 
            IPhonetics * This,
            /* [retval][out] */ Font	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Item )( 
            IPhonetics * This,
            /* [in] */ long Index,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IPhonetics * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add )( 
            IPhonetics * This,
            /* [in] */ long Start,
            /* [in] */ long Length,
            /* [in] */ BSTR Text);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Text )( 
            IPhonetics * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Text )( 
            IPhonetics * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IPhonetics * This,
            /* [in] */ long Index,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            IPhonetics * This,
            /* [retval][out] */ IUnknown **RHS);
        
        END_INTERFACE
    } IPhoneticsVtbl;

    interface IPhonetics
    {
        CONST_VTBL struct IPhoneticsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IPhonetics_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IPhonetics_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IPhonetics_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IPhonetics_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IPhonetics_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IPhonetics_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IPhonetics_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IPhonetics_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IPhonetics_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IPhonetics_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IPhonetics_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IPhonetics_get_Start(This,RHS)	\
    ( (This)->lpVtbl -> get_Start(This,RHS) ) 

#define IPhonetics_get_Length(This,RHS)	\
    ( (This)->lpVtbl -> get_Length(This,RHS) ) 

#define IPhonetics_get_Visible(This,RHS)	\
    ( (This)->lpVtbl -> get_Visible(This,RHS) ) 

#define IPhonetics_put_Visible(This,RHS)	\
    ( (This)->lpVtbl -> put_Visible(This,RHS) ) 

#define IPhonetics_get_CharacterType(This,RHS)	\
    ( (This)->lpVtbl -> get_CharacterType(This,RHS) ) 

#define IPhonetics_put_CharacterType(This,RHS)	\
    ( (This)->lpVtbl -> put_CharacterType(This,RHS) ) 

#define IPhonetics_get_Alignment(This,RHS)	\
    ( (This)->lpVtbl -> get_Alignment(This,RHS) ) 

#define IPhonetics_put_Alignment(This,RHS)	\
    ( (This)->lpVtbl -> put_Alignment(This,RHS) ) 

#define IPhonetics_get_Font(This,RHS)	\
    ( (This)->lpVtbl -> get_Font(This,RHS) ) 

#define IPhonetics_get_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Item(This,Index,RHS) ) 

#define IPhonetics_Delete(This)	\
    ( (This)->lpVtbl -> Delete(This) ) 

#define IPhonetics_Add(This,Start,Length,Text)	\
    ( (This)->lpVtbl -> Add(This,Start,Length,Text) ) 

#define IPhonetics_get_Text(This,RHS)	\
    ( (This)->lpVtbl -> get_Text(This,RHS) ) 

#define IPhonetics_put_Text(This,RHS)	\
    ( (This)->lpVtbl -> put_Text(This,RHS) ) 

#define IPhonetics_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define IPhonetics_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IPhonetics_INTERFACE_DEFINED__ */


#ifndef __DefaultWebOptions_INTERFACE_DEFINED__
#define __DefaultWebOptions_INTERFACE_DEFINED__

/* interface DefaultWebOptions */
/* [object][oleautomation][nonextensible][dual][helpcontext][uuid] */ 


EXTERN_C const IID IID_DefaultWebOptions;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024448-0000-0000-C000-000000000046")
    DefaultWebOptions : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_RelyOnCSS( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_RelyOnCSS( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_SaveHiddenData( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_SaveHiddenData( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_LoadPictures( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_LoadPictures( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_OrganizeInFolder( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_OrganizeInFolder( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_UpdateLinksOnSave( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_UpdateLinksOnSave( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_UseLongFileNames( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_UseLongFileNames( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_CheckIfOfficeIsHTMLEditor( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_CheckIfOfficeIsHTMLEditor( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_DownloadComponents( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_DownloadComponents( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_RelyOnVML( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_RelyOnVML( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_AllowPNG( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_AllowPNG( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ScreenSize( 
            /* [retval][out] */ MsoScreenSize *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_ScreenSize( 
            /* [in] */ MsoScreenSize RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_PixelsPerInch( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_PixelsPerInch( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_LocationOfComponents( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_LocationOfComponents( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Encoding( 
            /* [retval][out] */ MsoEncoding *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_Encoding( 
            /* [in] */ MsoEncoding RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_AlwaysSaveInDefaultEncoding( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_AlwaysSaveInDefaultEncoding( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Fonts( 
            /* [retval][out] */ /* external definition not present */ WebPageFonts **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_FolderSuffix( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_TargetBrowser( 
            /* [retval][out] */ MsoTargetBrowser *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_TargetBrowser( 
            /* [in] */ MsoTargetBrowser RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_SaveNewWebPagesAsWebArchives( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_SaveNewWebPagesAsWebArchives( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct DefaultWebOptionsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            DefaultWebOptions * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            DefaultWebOptions * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            DefaultWebOptions * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            DefaultWebOptions * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            DefaultWebOptions * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            DefaultWebOptions * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            DefaultWebOptions * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Application )( 
            DefaultWebOptions * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Creator )( 
            DefaultWebOptions * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Parent )( 
            DefaultWebOptions * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_RelyOnCSS )( 
            DefaultWebOptions * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_RelyOnCSS )( 
            DefaultWebOptions * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_SaveHiddenData )( 
            DefaultWebOptions * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_SaveHiddenData )( 
            DefaultWebOptions * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_LoadPictures )( 
            DefaultWebOptions * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_LoadPictures )( 
            DefaultWebOptions * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_OrganizeInFolder )( 
            DefaultWebOptions * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_OrganizeInFolder )( 
            DefaultWebOptions * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_UpdateLinksOnSave )( 
            DefaultWebOptions * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_UpdateLinksOnSave )( 
            DefaultWebOptions * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_UseLongFileNames )( 
            DefaultWebOptions * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_UseLongFileNames )( 
            DefaultWebOptions * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_CheckIfOfficeIsHTMLEditor )( 
            DefaultWebOptions * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_CheckIfOfficeIsHTMLEditor )( 
            DefaultWebOptions * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_DownloadComponents )( 
            DefaultWebOptions * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_DownloadComponents )( 
            DefaultWebOptions * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_RelyOnVML )( 
            DefaultWebOptions * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_RelyOnVML )( 
            DefaultWebOptions * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_AllowPNG )( 
            DefaultWebOptions * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_AllowPNG )( 
            DefaultWebOptions * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ScreenSize )( 
            DefaultWebOptions * This,
            /* [retval][out] */ MsoScreenSize *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_ScreenSize )( 
            DefaultWebOptions * This,
            /* [in] */ MsoScreenSize RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_PixelsPerInch )( 
            DefaultWebOptions * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_PixelsPerInch )( 
            DefaultWebOptions * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_LocationOfComponents )( 
            DefaultWebOptions * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_LocationOfComponents )( 
            DefaultWebOptions * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Encoding )( 
            DefaultWebOptions * This,
            /* [retval][out] */ MsoEncoding *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Encoding )( 
            DefaultWebOptions * This,
            /* [in] */ MsoEncoding RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_AlwaysSaveInDefaultEncoding )( 
            DefaultWebOptions * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_AlwaysSaveInDefaultEncoding )( 
            DefaultWebOptions * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Fonts )( 
            DefaultWebOptions * This,
            /* [retval][out] */ /* external definition not present */ WebPageFonts **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_FolderSuffix )( 
            DefaultWebOptions * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_TargetBrowser )( 
            DefaultWebOptions * This,
            /* [retval][out] */ MsoTargetBrowser *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_TargetBrowser )( 
            DefaultWebOptions * This,
            /* [in] */ MsoTargetBrowser RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_SaveNewWebPagesAsWebArchives )( 
            DefaultWebOptions * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_SaveNewWebPagesAsWebArchives )( 
            DefaultWebOptions * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        END_INTERFACE
    } DefaultWebOptionsVtbl;

    interface DefaultWebOptions
    {
        CONST_VTBL struct DefaultWebOptionsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define DefaultWebOptions_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define DefaultWebOptions_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define DefaultWebOptions_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define DefaultWebOptions_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define DefaultWebOptions_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define DefaultWebOptions_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define DefaultWebOptions_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define DefaultWebOptions_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define DefaultWebOptions_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define DefaultWebOptions_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define DefaultWebOptions_get_RelyOnCSS(This,RHS)	\
    ( (This)->lpVtbl -> get_RelyOnCSS(This,RHS) ) 

#define DefaultWebOptions_put_RelyOnCSS(This,RHS)	\
    ( (This)->lpVtbl -> put_RelyOnCSS(This,RHS) ) 

#define DefaultWebOptions_get_SaveHiddenData(This,RHS)	\
    ( (This)->lpVtbl -> get_SaveHiddenData(This,RHS) ) 

#define DefaultWebOptions_put_SaveHiddenData(This,RHS)	\
    ( (This)->lpVtbl -> put_SaveHiddenData(This,RHS) ) 

#define DefaultWebOptions_get_LoadPictures(This,RHS)	\
    ( (This)->lpVtbl -> get_LoadPictures(This,RHS) ) 

#define DefaultWebOptions_put_LoadPictures(This,RHS)	\
    ( (This)->lpVtbl -> put_LoadPictures(This,RHS) ) 

#define DefaultWebOptions_get_OrganizeInFolder(This,RHS)	\
    ( (This)->lpVtbl -> get_OrganizeInFolder(This,RHS) ) 

#define DefaultWebOptions_put_OrganizeInFolder(This,RHS)	\
    ( (This)->lpVtbl -> put_OrganizeInFolder(This,RHS) ) 

#define DefaultWebOptions_get_UpdateLinksOnSave(This,RHS)	\
    ( (This)->lpVtbl -> get_UpdateLinksOnSave(This,RHS) ) 

#define DefaultWebOptions_put_UpdateLinksOnSave(This,RHS)	\
    ( (This)->lpVtbl -> put_UpdateLinksOnSave(This,RHS) ) 

#define DefaultWebOptions_get_UseLongFileNames(This,RHS)	\
    ( (This)->lpVtbl -> get_UseLongFileNames(This,RHS) ) 

#define DefaultWebOptions_put_UseLongFileNames(This,RHS)	\
    ( (This)->lpVtbl -> put_UseLongFileNames(This,RHS) ) 

#define DefaultWebOptions_get_CheckIfOfficeIsHTMLEditor(This,RHS)	\
    ( (This)->lpVtbl -> get_CheckIfOfficeIsHTMLEditor(This,RHS) ) 

#define DefaultWebOptions_put_CheckIfOfficeIsHTMLEditor(This,RHS)	\
    ( (This)->lpVtbl -> put_CheckIfOfficeIsHTMLEditor(This,RHS) ) 

#define DefaultWebOptions_get_DownloadComponents(This,RHS)	\
    ( (This)->lpVtbl -> get_DownloadComponents(This,RHS) ) 

#define DefaultWebOptions_put_DownloadComponents(This,RHS)	\
    ( (This)->lpVtbl -> put_DownloadComponents(This,RHS) ) 

#define DefaultWebOptions_get_RelyOnVML(This,RHS)	\
    ( (This)->lpVtbl -> get_RelyOnVML(This,RHS) ) 

#define DefaultWebOptions_put_RelyOnVML(This,RHS)	\
    ( (This)->lpVtbl -> put_RelyOnVML(This,RHS) ) 

#define DefaultWebOptions_get_AllowPNG(This,RHS)	\
    ( (This)->lpVtbl -> get_AllowPNG(This,RHS) ) 

#define DefaultWebOptions_put_AllowPNG(This,RHS)	\
    ( (This)->lpVtbl -> put_AllowPNG(This,RHS) ) 

#define DefaultWebOptions_get_ScreenSize(This,RHS)	\
    ( (This)->lpVtbl -> get_ScreenSize(This,RHS) ) 

#define DefaultWebOptions_put_ScreenSize(This,RHS)	\
    ( (This)->lpVtbl -> put_ScreenSize(This,RHS) ) 

#define DefaultWebOptions_get_PixelsPerInch(This,RHS)	\
    ( (This)->lpVtbl -> get_PixelsPerInch(This,RHS) ) 

#define DefaultWebOptions_put_PixelsPerInch(This,RHS)	\
    ( (This)->lpVtbl -> put_PixelsPerInch(This,RHS) ) 

#define DefaultWebOptions_get_LocationOfComponents(This,RHS)	\
    ( (This)->lpVtbl -> get_LocationOfComponents(This,RHS) ) 

#define DefaultWebOptions_put_LocationOfComponents(This,RHS)	\
    ( (This)->lpVtbl -> put_LocationOfComponents(This,RHS) ) 

#define DefaultWebOptions_get_Encoding(This,RHS)	\
    ( (This)->lpVtbl -> get_Encoding(This,RHS) ) 

#define DefaultWebOptions_put_Encoding(This,RHS)	\
    ( (This)->lpVtbl -> put_Encoding(This,RHS) ) 

#define DefaultWebOptions_get_AlwaysSaveInDefaultEncoding(This,RHS)	\
    ( (This)->lpVtbl -> get_AlwaysSaveInDefaultEncoding(This,RHS) ) 

#define DefaultWebOptions_put_AlwaysSaveInDefaultEncoding(This,RHS)	\
    ( (This)->lpVtbl -> put_AlwaysSaveInDefaultEncoding(This,RHS) ) 

#define DefaultWebOptions_get_Fonts(This,RHS)	\
    ( (This)->lpVtbl -> get_Fonts(This,RHS) ) 

#define DefaultWebOptions_get_FolderSuffix(This,RHS)	\
    ( (This)->lpVtbl -> get_FolderSuffix(This,RHS) ) 

#define DefaultWebOptions_get_TargetBrowser(This,RHS)	\
    ( (This)->lpVtbl -> get_TargetBrowser(This,RHS) ) 

#define DefaultWebOptions_put_TargetBrowser(This,RHS)	\
    ( (This)->lpVtbl -> put_TargetBrowser(This,RHS) ) 

#define DefaultWebOptions_get_SaveNewWebPagesAsWebArchives(This,RHS)	\
    ( (This)->lpVtbl -> get_SaveNewWebPagesAsWebArchives(This,RHS) ) 

#define DefaultWebOptions_put_SaveNewWebPagesAsWebArchives(This,RHS)	\
    ( (This)->lpVtbl -> put_SaveNewWebPagesAsWebArchives(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __DefaultWebOptions_INTERFACE_DEFINED__ */


#ifndef __WebOptions_INTERFACE_DEFINED__
#define __WebOptions_INTERFACE_DEFINED__

/* interface WebOptions */
/* [object][oleautomation][nonextensible][dual][helpcontext][uuid] */ 


EXTERN_C const IID IID_WebOptions;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024449-0000-0000-C000-000000000046")
    WebOptions : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_RelyOnCSS( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_RelyOnCSS( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_OrganizeInFolder( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_OrganizeInFolder( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_UseLongFileNames( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_UseLongFileNames( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_DownloadComponents( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_DownloadComponents( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_RelyOnVML( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_RelyOnVML( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_AllowPNG( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_AllowPNG( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ScreenSize( 
            /* [retval][out] */ MsoScreenSize *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_ScreenSize( 
            /* [in] */ MsoScreenSize RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_PixelsPerInch( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_PixelsPerInch( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_LocationOfComponents( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_LocationOfComponents( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Encoding( 
            /* [retval][out] */ MsoEncoding *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_Encoding( 
            /* [in] */ MsoEncoding RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_FolderSuffix( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE UseDefaultFolderSuffix( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_TargetBrowser( 
            /* [retval][out] */ MsoTargetBrowser *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_TargetBrowser( 
            /* [in] */ MsoTargetBrowser RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct WebOptionsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            WebOptions * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            WebOptions * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            WebOptions * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            WebOptions * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            WebOptions * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            WebOptions * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            WebOptions * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Application )( 
            WebOptions * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Creator )( 
            WebOptions * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Parent )( 
            WebOptions * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_RelyOnCSS )( 
            WebOptions * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_RelyOnCSS )( 
            WebOptions * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_OrganizeInFolder )( 
            WebOptions * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_OrganizeInFolder )( 
            WebOptions * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_UseLongFileNames )( 
            WebOptions * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_UseLongFileNames )( 
            WebOptions * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_DownloadComponents )( 
            WebOptions * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_DownloadComponents )( 
            WebOptions * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_RelyOnVML )( 
            WebOptions * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_RelyOnVML )( 
            WebOptions * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_AllowPNG )( 
            WebOptions * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_AllowPNG )( 
            WebOptions * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ScreenSize )( 
            WebOptions * This,
            /* [retval][out] */ MsoScreenSize *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_ScreenSize )( 
            WebOptions * This,
            /* [in] */ MsoScreenSize RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_PixelsPerInch )( 
            WebOptions * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_PixelsPerInch )( 
            WebOptions * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_LocationOfComponents )( 
            WebOptions * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_LocationOfComponents )( 
            WebOptions * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Encoding )( 
            WebOptions * This,
            /* [retval][out] */ MsoEncoding *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Encoding )( 
            WebOptions * This,
            /* [in] */ MsoEncoding RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_FolderSuffix )( 
            WebOptions * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *UseDefaultFolderSuffix )( 
            WebOptions * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_TargetBrowser )( 
            WebOptions * This,
            /* [retval][out] */ MsoTargetBrowser *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_TargetBrowser )( 
            WebOptions * This,
            /* [in] */ MsoTargetBrowser RHS);
        
        END_INTERFACE
    } WebOptionsVtbl;

    interface WebOptions
    {
        CONST_VTBL struct WebOptionsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define WebOptions_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define WebOptions_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define WebOptions_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define WebOptions_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define WebOptions_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define WebOptions_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define WebOptions_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define WebOptions_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define WebOptions_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define WebOptions_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define WebOptions_get_RelyOnCSS(This,RHS)	\
    ( (This)->lpVtbl -> get_RelyOnCSS(This,RHS) ) 

#define WebOptions_put_RelyOnCSS(This,RHS)	\
    ( (This)->lpVtbl -> put_RelyOnCSS(This,RHS) ) 

#define WebOptions_get_OrganizeInFolder(This,RHS)	\
    ( (This)->lpVtbl -> get_OrganizeInFolder(This,RHS) ) 

#define WebOptions_put_OrganizeInFolder(This,RHS)	\
    ( (This)->lpVtbl -> put_OrganizeInFolder(This,RHS) ) 

#define WebOptions_get_UseLongFileNames(This,RHS)	\
    ( (This)->lpVtbl -> get_UseLongFileNames(This,RHS) ) 

#define WebOptions_put_UseLongFileNames(This,RHS)	\
    ( (This)->lpVtbl -> put_UseLongFileNames(This,RHS) ) 

#define WebOptions_get_DownloadComponents(This,RHS)	\
    ( (This)->lpVtbl -> get_DownloadComponents(This,RHS) ) 

#define WebOptions_put_DownloadComponents(This,RHS)	\
    ( (This)->lpVtbl -> put_DownloadComponents(This,RHS) ) 

#define WebOptions_get_RelyOnVML(This,RHS)	\
    ( (This)->lpVtbl -> get_RelyOnVML(This,RHS) ) 

#define WebOptions_put_RelyOnVML(This,RHS)	\
    ( (This)->lpVtbl -> put_RelyOnVML(This,RHS) ) 

#define WebOptions_get_AllowPNG(This,RHS)	\
    ( (This)->lpVtbl -> get_AllowPNG(This,RHS) ) 

#define WebOptions_put_AllowPNG(This,RHS)	\
    ( (This)->lpVtbl -> put_AllowPNG(This,RHS) ) 

#define WebOptions_get_ScreenSize(This,RHS)	\
    ( (This)->lpVtbl -> get_ScreenSize(This,RHS) ) 

#define WebOptions_put_ScreenSize(This,RHS)	\
    ( (This)->lpVtbl -> put_ScreenSize(This,RHS) ) 

#define WebOptions_get_PixelsPerInch(This,RHS)	\
    ( (This)->lpVtbl -> get_PixelsPerInch(This,RHS) ) 

#define WebOptions_put_PixelsPerInch(This,RHS)	\
    ( (This)->lpVtbl -> put_PixelsPerInch(This,RHS) ) 

#define WebOptions_get_LocationOfComponents(This,RHS)	\
    ( (This)->lpVtbl -> get_LocationOfComponents(This,RHS) ) 

#define WebOptions_put_LocationOfComponents(This,RHS)	\
    ( (This)->lpVtbl -> put_LocationOfComponents(This,RHS) ) 

#define WebOptions_get_Encoding(This,RHS)	\
    ( (This)->lpVtbl -> get_Encoding(This,RHS) ) 

#define WebOptions_put_Encoding(This,RHS)	\
    ( (This)->lpVtbl -> put_Encoding(This,RHS) ) 

#define WebOptions_get_FolderSuffix(This,RHS)	\
    ( (This)->lpVtbl -> get_FolderSuffix(This,RHS) ) 

#define WebOptions_UseDefaultFolderSuffix(This)	\
    ( (This)->lpVtbl -> UseDefaultFolderSuffix(This) ) 

#define WebOptions_get_TargetBrowser(This,RHS)	\
    ( (This)->lpVtbl -> get_TargetBrowser(This,RHS) ) 

#define WebOptions_put_TargetBrowser(This,RHS)	\
    ( (This)->lpVtbl -> put_TargetBrowser(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __WebOptions_INTERFACE_DEFINED__ */


#ifndef __IPivotLayout_INTERFACE_DEFINED__
#define __IPivotLayout_INTERFACE_DEFINED__

/* interface IPivotLayout */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IPivotLayout;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002444A-0001-0000-C000-000000000046")
    IPivotLayout : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_ColumnFields( 
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_DataFields( 
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_PageFields( 
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_RowFields( 
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_HiddenFields( 
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_VisibleFields( 
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_PivotFields( 
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_CubeFields( 
            /* [retval][out] */ CubeFields **RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_PivotCache( 
            /* [retval][out] */ PivotCache	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PivotTable( 
            /* [retval][out] */ PivotTable	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_InnerDetail( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_InnerDetail( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall AddFields( 
            /* [optional][in] */ VARIANT RowFields,
            /* [optional][in] */ VARIANT ColumnFields,
            /* [optional][in] */ VARIANT PageFields,
            /* [optional][in] */ VARIANT AppendField) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IPivotLayoutVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IPivotLayout * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IPivotLayout * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IPivotLayout * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IPivotLayout * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IPivotLayout * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IPivotLayout * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IPivotLayout * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IPivotLayout * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IPivotLayout * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IPivotLayout * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_ColumnFields )( 
            IPivotLayout * This,
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_DataFields )( 
            IPivotLayout * This,
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_PageFields )( 
            IPivotLayout * This,
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_RowFields )( 
            IPivotLayout * This,
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_HiddenFields )( 
            IPivotLayout * This,
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_VisibleFields )( 
            IPivotLayout * This,
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_PivotFields )( 
            IPivotLayout * This,
            /* [optional][in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_CubeFields )( 
            IPivotLayout * This,
            /* [retval][out] */ CubeFields **RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_PivotCache )( 
            IPivotLayout * This,
            /* [retval][out] */ PivotCache	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PivotTable )( 
            IPivotLayout * This,
            /* [retval][out] */ PivotTable	**RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_InnerDetail )( 
            IPivotLayout * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_InnerDetail )( 
            IPivotLayout * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *AddFields )( 
            IPivotLayout * This,
            /* [optional][in] */ VARIANT RowFields,
            /* [optional][in] */ VARIANT ColumnFields,
            /* [optional][in] */ VARIANT PageFields,
            /* [optional][in] */ VARIANT AppendField);
        
        END_INTERFACE
    } IPivotLayoutVtbl;

    interface IPivotLayout
    {
        CONST_VTBL struct IPivotLayoutVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IPivotLayout_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IPivotLayout_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IPivotLayout_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IPivotLayout_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IPivotLayout_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IPivotLayout_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IPivotLayout_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IPivotLayout_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IPivotLayout_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IPivotLayout_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IPivotLayout_get_ColumnFields(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_ColumnFields(This,Index,RHS) ) 

#define IPivotLayout_get_DataFields(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_DataFields(This,Index,RHS) ) 

#define IPivotLayout_get_PageFields(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_PageFields(This,Index,RHS) ) 

#define IPivotLayout_get_RowFields(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_RowFields(This,Index,RHS) ) 

#define IPivotLayout_get_HiddenFields(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_HiddenFields(This,Index,RHS) ) 

#define IPivotLayout_get_VisibleFields(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_VisibleFields(This,Index,RHS) ) 

#define IPivotLayout_get_PivotFields(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_PivotFields(This,Index,RHS) ) 

#define IPivotLayout_get_CubeFields(This,RHS)	\
    ( (This)->lpVtbl -> get_CubeFields(This,RHS) ) 

#define IPivotLayout_get_PivotCache(This,RHS)	\
    ( (This)->lpVtbl -> get_PivotCache(This,RHS) ) 

#define IPivotLayout_get_PivotTable(This,RHS)	\
    ( (This)->lpVtbl -> get_PivotTable(This,RHS) ) 

#define IPivotLayout_get_InnerDetail(This,RHS)	\
    ( (This)->lpVtbl -> get_InnerDetail(This,RHS) ) 

#define IPivotLayout_put_InnerDetail(This,RHS)	\
    ( (This)->lpVtbl -> put_InnerDetail(This,RHS) ) 

#define IPivotLayout_AddFields(This,RowFields,ColumnFields,PageFields,AppendField)	\
    ( (This)->lpVtbl -> AddFields(This,RowFields,ColumnFields,PageFields,AppendField) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IPivotLayout_INTERFACE_DEFINED__ */


#ifndef __TreeviewControl_INTERFACE_DEFINED__
#define __TreeviewControl_INTERFACE_DEFINED__

/* interface TreeviewControl */
/* [object][oleautomation][nonextensible][dual][helpcontext][uuid] */ 


EXTERN_C const IID IID_TreeviewControl;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002444B-0000-0000-C000-000000000046")
    TreeviewControl : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Hidden( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_Hidden( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Drilled( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_Drilled( 
            /* [in] */ VARIANT RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct TreeviewControlVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            TreeviewControl * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            TreeviewControl * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            TreeviewControl * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            TreeviewControl * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            TreeviewControl * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            TreeviewControl * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            TreeviewControl * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Application )( 
            TreeviewControl * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Creator )( 
            TreeviewControl * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Parent )( 
            TreeviewControl * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Hidden )( 
            TreeviewControl * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Hidden )( 
            TreeviewControl * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Drilled )( 
            TreeviewControl * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Drilled )( 
            TreeviewControl * This,
            /* [in] */ VARIANT RHS);
        
        END_INTERFACE
    } TreeviewControlVtbl;

    interface TreeviewControl
    {
        CONST_VTBL struct TreeviewControlVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define TreeviewControl_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define TreeviewControl_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define TreeviewControl_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define TreeviewControl_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define TreeviewControl_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define TreeviewControl_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define TreeviewControl_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define TreeviewControl_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define TreeviewControl_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define TreeviewControl_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define TreeviewControl_get_Hidden(This,RHS)	\
    ( (This)->lpVtbl -> get_Hidden(This,RHS) ) 

#define TreeviewControl_put_Hidden(This,RHS)	\
    ( (This)->lpVtbl -> put_Hidden(This,RHS) ) 

#define TreeviewControl_get_Drilled(This,RHS)	\
    ( (This)->lpVtbl -> get_Drilled(This,RHS) ) 

#define TreeviewControl_put_Drilled(This,RHS)	\
    ( (This)->lpVtbl -> put_Drilled(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __TreeviewControl_INTERFACE_DEFINED__ */


#ifndef __CubeField_INTERFACE_DEFINED__
#define __CubeField_INTERFACE_DEFINED__

/* interface CubeField */
/* [object][oleautomation][nonextensible][dual][helpcontext][uuid] */ 


EXTERN_C const IID IID_CubeField;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002444C-0000-0000-C000-000000000046")
    CubeField : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_CubeFieldType( 
            /* [retval][out] */ XlCubeFieldType *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get__Caption( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Value( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Orientation( 
            /* [retval][out] */ XlPivotFieldOrientation *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_Orientation( 
            /* [in] */ XlPivotFieldOrientation RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Position( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_Position( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_TreeviewControl( 
            /* [retval][out] */ TreeviewControl **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_DragToColumn( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_DragToColumn( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_DragToHide( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_DragToHide( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_DragToPage( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_DragToPage( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_DragToRow( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_DragToRow( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_DragToData( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_DragToData( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT STDMETHODCALLTYPE get_HiddenLevels( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT STDMETHODCALLTYPE put_HiddenLevels( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_HasMemberProperties( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_LayoutForm( 
            /* [retval][out] */ XlLayoutFormType *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_LayoutForm( 
            /* [in] */ XlLayoutFormType RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_PivotFields( 
            /* [retval][out] */ PivotFields	**RHS) = 0;
        
        virtual /* [custom][helpcontext][hidden][id] */ HRESULT STDMETHODCALLTYPE _AddMemberPropertyField( 
            /* [in] */ BSTR Property,
            /* [optional][in] */ VARIANT PropertyOrder) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_EnableMultiplePageItems( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_EnableMultiplePageItems( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_LayoutSubtotalLocation( 
            /* [retval][out] */ XlSubtototalLocationType *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_LayoutSubtotalLocation( 
            /* [in] */ XlSubtototalLocationType RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_ShowInFieldList( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_ShowInFieldList( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE Delete( void) = 0;
        
        virtual /* [custom][helpcontext][id] */ HRESULT STDMETHODCALLTYPE AddMemberPropertyField( 
            /* [in] */ BSTR Property,
            /* [optional][in] */ VARIANT PropertyOrder,
            /* [optional][in] */ VARIANT PropertyDisplayedIn) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_IncludeNewItemsInFilter( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_IncludeNewItemsInFilter( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_CubeFieldSubType( 
            /* [retval][out] */ XlCubeFieldSubType *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_AllItemsVisible( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE ClearManualFilter( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE CreatePivotFields( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_CurrentPageName( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_CurrentPageName( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_IsDate( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Caption( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_Caption( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_FlattenHierarchies( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_FlattenHierarchies( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_HierarchizeDistinct( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT STDMETHODCALLTYPE put_HierarchizeDistinct( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct CubeFieldVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            CubeField * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            CubeField * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            CubeField * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            CubeField * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            CubeField * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            CubeField * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            CubeField * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Application )( 
            CubeField * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Creator )( 
            CubeField * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Parent )( 
            CubeField * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_CubeFieldType )( 
            CubeField * This,
            /* [retval][out] */ XlCubeFieldType *RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get__Caption )( 
            CubeField * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Name )( 
            CubeField * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Value )( 
            CubeField * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Orientation )( 
            CubeField * This,
            /* [retval][out] */ XlPivotFieldOrientation *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Orientation )( 
            CubeField * This,
            /* [in] */ XlPivotFieldOrientation RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Position )( 
            CubeField * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Position )( 
            CubeField * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_TreeviewControl )( 
            CubeField * This,
            /* [retval][out] */ TreeviewControl **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_DragToColumn )( 
            CubeField * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_DragToColumn )( 
            CubeField * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_DragToHide )( 
            CubeField * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_DragToHide )( 
            CubeField * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_DragToPage )( 
            CubeField * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_DragToPage )( 
            CubeField * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_DragToRow )( 
            CubeField * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_DragToRow )( 
            CubeField * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_DragToData )( 
            CubeField * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_DragToData )( 
            CubeField * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_HiddenLevels )( 
            CubeField * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_HiddenLevels )( 
            CubeField * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_HasMemberProperties )( 
            CubeField * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_LayoutForm )( 
            CubeField * This,
            /* [retval][out] */ XlLayoutFormType *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_LayoutForm )( 
            CubeField * This,
            /* [in] */ XlLayoutFormType RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_PivotFields )( 
            CubeField * This,
            /* [retval][out] */ PivotFields	**RHS);
        
        /* [custom][helpcontext][hidden][id] */ HRESULT ( STDMETHODCALLTYPE *_AddMemberPropertyField )( 
            CubeField * This,
            /* [in] */ BSTR Property,
            /* [optional][in] */ VARIANT PropertyOrder);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_EnableMultiplePageItems )( 
            CubeField * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_EnableMultiplePageItems )( 
            CubeField * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_LayoutSubtotalLocation )( 
            CubeField * This,
            /* [retval][out] */ XlSubtototalLocationType *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_LayoutSubtotalLocation )( 
            CubeField * This,
            /* [in] */ XlSubtototalLocationType RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_ShowInFieldList )( 
            CubeField * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_ShowInFieldList )( 
            CubeField * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *Delete )( 
            CubeField * This);
        
        /* [custom][helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *AddMemberPropertyField )( 
            CubeField * This,
            /* [in] */ BSTR Property,
            /* [optional][in] */ VARIANT PropertyOrder,
            /* [optional][in] */ VARIANT PropertyDisplayedIn);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_IncludeNewItemsInFilter )( 
            CubeField * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_IncludeNewItemsInFilter )( 
            CubeField * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_CubeFieldSubType )( 
            CubeField * This,
            /* [retval][out] */ XlCubeFieldSubType *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_AllItemsVisible )( 
            CubeField * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *ClearManualFilter )( 
            CubeField * This);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *CreatePivotFields )( 
            CubeField * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_CurrentPageName )( 
            CubeField * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_CurrentPageName )( 
            CubeField * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_IsDate )( 
            CubeField * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Caption )( 
            CubeField * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_Caption )( 
            CubeField * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_FlattenHierarchies )( 
            CubeField * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_FlattenHierarchies )( 
            CubeField * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_HierarchizeDistinct )( 
            CubeField * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( STDMETHODCALLTYPE *put_HierarchizeDistinct )( 
            CubeField * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        END_INTERFACE
    } CubeFieldVtbl;

    interface CubeField
    {
        CONST_VTBL struct CubeFieldVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define CubeField_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define CubeField_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define CubeField_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define CubeField_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define CubeField_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define CubeField_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define CubeField_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define CubeField_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define CubeField_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define CubeField_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define CubeField_get_CubeFieldType(This,RHS)	\
    ( (This)->lpVtbl -> get_CubeFieldType(This,RHS) ) 

#define CubeField_get__Caption(This,RHS)	\
    ( (This)->lpVtbl -> get__Caption(This,RHS) ) 

#define CubeField_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define CubeField_get_Value(This,RHS)	\
    ( (This)->lpVtbl -> get_Value(This,RHS) ) 

#define CubeField_get_Orientation(This,RHS)	\
    ( (This)->lpVtbl -> get_Orientation(This,RHS) ) 

#define CubeField_put_Orientation(This,RHS)	\
    ( (This)->lpVtbl -> put_Orientation(This,RHS) ) 

#define CubeField_get_Position(This,RHS)	\
    ( (This)->lpVtbl -> get_Position(This,RHS) ) 

#define CubeField_put_Position(This,RHS)	\
    ( (This)->lpVtbl -> put_Position(This,RHS) ) 

#define CubeField_get_TreeviewControl(This,RHS)	\
    ( (This)->lpVtbl -> get_TreeviewControl(This,RHS) ) 

#define CubeField_get_DragToColumn(This,RHS)	\
    ( (This)->lpVtbl -> get_DragToColumn(This,RHS) ) 

#define CubeField_put_DragToColumn(This,RHS)	\
    ( (This)->lpVtbl -> put_DragToColumn(This,RHS) ) 

#define CubeField_get_DragToHide(This,RHS)	\
    ( (This)->lpVtbl -> get_DragToHide(This,RHS) ) 

#define CubeField_put_DragToHide(This,RHS)	\
    ( (This)->lpVtbl -> put_DragToHide(This,RHS) ) 

#define CubeField_get_DragToPage(This,RHS)	\
    ( (This)->lpVtbl -> get_DragToPage(This,RHS) ) 

#define CubeField_put_DragToPage(This,RHS)	\
    ( (This)->lpVtbl -> put_DragToPage(This,RHS) ) 

#define CubeField_get_DragToRow(This,RHS)	\
    ( (This)->lpVtbl -> get_DragToRow(This,RHS) ) 

#define CubeField_put_DragToRow(This,RHS)	\
    ( (This)->lpVtbl -> put_DragToRow(This,RHS) ) 

#define CubeField_get_DragToData(This,RHS)	\
    ( (This)->lpVtbl -> get_DragToData(This,RHS) ) 

#define CubeField_put_DragToData(This,RHS)	\
    ( (This)->lpVtbl -> put_DragToData(This,RHS) ) 

#define CubeField_get_HiddenLevels(This,RHS)	\
    ( (This)->lpVtbl -> get_HiddenLevels(This,RHS) ) 

#define CubeField_put_HiddenLevels(This,RHS)	\
    ( (This)->lpVtbl -> put_HiddenLevels(This,RHS) ) 

#define CubeField_get_HasMemberProperties(This,RHS)	\
    ( (This)->lpVtbl -> get_HasMemberProperties(This,RHS) ) 

#define CubeField_get_LayoutForm(This,RHS)	\
    ( (This)->lpVtbl -> get_LayoutForm(This,RHS) ) 

#define CubeField_put_LayoutForm(This,RHS)	\
    ( (This)->lpVtbl -> put_LayoutForm(This,RHS) ) 

#define CubeField_get_PivotFields(This,RHS)	\
    ( (This)->lpVtbl -> get_PivotFields(This,RHS) ) 

#define CubeField__AddMemberPropertyField(This,Property,PropertyOrder)	\
    ( (This)->lpVtbl -> _AddMemberPropertyField(This,Property,PropertyOrder) ) 

#define CubeField_get_EnableMultiplePageItems(This,RHS)	\
    ( (This)->lpVtbl -> get_EnableMultiplePageItems(This,RHS) ) 

#define CubeField_put_EnableMultiplePageItems(This,RHS)	\
    ( (This)->lpVtbl -> put_EnableMultiplePageItems(This,RHS) ) 

#define CubeField_get_LayoutSubtotalLocation(This,RHS)	\
    ( (This)->lpVtbl -> get_LayoutSubtotalLocation(This,RHS) ) 

#define CubeField_put_LayoutSubtotalLocation(This,RHS)	\
    ( (This)->lpVtbl -> put_LayoutSubtotalLocation(This,RHS) ) 

#define CubeField_get_ShowInFieldList(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowInFieldList(This,RHS) ) 

#define CubeField_put_ShowInFieldList(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowInFieldList(This,RHS) ) 

#define CubeField_Delete(This)	\
    ( (This)->lpVtbl -> Delete(This) ) 

#define CubeField_AddMemberPropertyField(This,Property,PropertyOrder,PropertyDisplayedIn)	\
    ( (This)->lpVtbl -> AddMemberPropertyField(This,Property,PropertyOrder,PropertyDisplayedIn) ) 

#define CubeField_get_IncludeNewItemsInFilter(This,RHS)	\
    ( (This)->lpVtbl -> get_IncludeNewItemsInFilter(This,RHS) ) 

#define CubeField_put_IncludeNewItemsInFilter(This,RHS)	\
    ( (This)->lpVtbl -> put_IncludeNewItemsInFilter(This,RHS) ) 

#define CubeField_get_CubeFieldSubType(This,RHS)	\
    ( (This)->lpVtbl -> get_CubeFieldSubType(This,RHS) ) 

#define CubeField_get_AllItemsVisible(This,RHS)	\
    ( (This)->lpVtbl -> get_AllItemsVisible(This,RHS) ) 

#define CubeField_ClearManualFilter(This)	\
    ( (This)->lpVtbl -> ClearManualFilter(This) ) 

#define CubeField_CreatePivotFields(This)	\
    ( (This)->lpVtbl -> CreatePivotFields(This) ) 

#define CubeField_get_CurrentPageName(This,RHS)	\
    ( (This)->lpVtbl -> get_CurrentPageName(This,RHS) ) 

#define CubeField_put_CurrentPageName(This,RHS)	\
    ( (This)->lpVtbl -> put_CurrentPageName(This,RHS) ) 

#define CubeField_get_IsDate(This,RHS)	\
    ( (This)->lpVtbl -> get_IsDate(This,RHS) ) 

#define CubeField_get_Caption(This,RHS)	\
    ( (This)->lpVtbl -> get_Caption(This,RHS) ) 

#define CubeField_put_Caption(This,RHS)	\
    ( (This)->lpVtbl -> put_Caption(This,RHS) ) 

#define CubeField_get_FlattenHierarchies(This,RHS)	\
    ( (This)->lpVtbl -> get_FlattenHierarchies(This,RHS) ) 

#define CubeField_put_FlattenHierarchies(This,RHS)	\
    ( (This)->lpVtbl -> put_FlattenHierarchies(This,RHS) ) 

#define CubeField_get_HierarchizeDistinct(This,RHS)	\
    ( (This)->lpVtbl -> get_HierarchizeDistinct(This,RHS) ) 

#define CubeField_put_HierarchizeDistinct(This,RHS)	\
    ( (This)->lpVtbl -> put_HierarchizeDistinct(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __CubeField_INTERFACE_DEFINED__ */


#ifndef __CubeFields_INTERFACE_DEFINED__
#define __CubeFields_INTERFACE_DEFINED__

/* interface CubeFields */
/* [object][oleautomation][nonextensible][dual][helpcontext][uuid] */ 


EXTERN_C const IID IID_CubeFields;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002444D-0000-0000-C000-000000000046")
    CubeFields : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get_Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ CubeField **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ CubeField **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT STDMETHODCALLTYPE get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE AddSet( 
            /* [in] */ BSTR Name,
            /* [in] */ BSTR Caption,
            /* [retval][out] */ CubeField **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE GetMeasure( 
            /* [in] */ VARIANT AttributeHierarchy,
            /* [in] */ XlConsolidationFunction Function,
            /* [optional][in] */ VARIANT Caption,
            /* [retval][out] */ CubeField **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct CubeFieldsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            CubeFields * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            CubeFields * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            CubeFields * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            CubeFields * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            CubeFields * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            CubeFields * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            CubeFields * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Application )( 
            CubeFields * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Creator )( 
            CubeFields * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Parent )( 
            CubeFields * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Count )( 
            CubeFields * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get_Item )( 
            CubeFields * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ CubeField **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get__Default )( 
            CubeFields * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ CubeField **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( STDMETHODCALLTYPE *get__NewEnum )( 
            CubeFields * This,
            /* [retval][out] */ IUnknown **RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *AddSet )( 
            CubeFields * This,
            /* [in] */ BSTR Name,
            /* [in] */ BSTR Caption,
            /* [retval][out] */ CubeField **RHS);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *GetMeasure )( 
            CubeFields * This,
            /* [in] */ VARIANT AttributeHierarchy,
            /* [in] */ XlConsolidationFunction Function,
            /* [optional][in] */ VARIANT Caption,
            /* [retval][out] */ CubeField **RHS);
        
        END_INTERFACE
    } CubeFieldsVtbl;

    interface CubeFields
    {
        CONST_VTBL struct CubeFieldsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define CubeFields_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define CubeFields_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define CubeFields_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define CubeFields_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define CubeFields_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define CubeFields_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define CubeFields_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define CubeFields_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define CubeFields_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define CubeFields_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define CubeFields_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define CubeFields_get_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Item(This,Index,RHS) ) 

#define CubeFields_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define CubeFields_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#define CubeFields_AddSet(This,Name,Caption,RHS)	\
    ( (This)->lpVtbl -> AddSet(This,Name,Caption,RHS) ) 

#define CubeFields_GetMeasure(This,AttributeHierarchy,Function,Caption,RHS)	\
    ( (This)->lpVtbl -> GetMeasure(This,AttributeHierarchy,Function,Caption,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __CubeFields_INTERFACE_DEFINED__ */


#ifndef __IDisplayUnitLabel_INTERFACE_DEFINED__
#define __IDisplayUnitLabel_INTERFACE_DEFINED__

/* interface IDisplayUnitLabel */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IDisplayUnitLabel;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002084C-0001-0000-C000-000000000046")
    IDisplayUnitLabel : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Border( 
            /* [retval][out] */ Border	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Interior( 
            /* [retval][out] */ Interior	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Fill( 
            /* [retval][out] */ ChartFillFormat	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Caption( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Caption( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Characters( 
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Length,
            /* [retval][out] */ Characters	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Font( 
            /* [retval][out] */ Font	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HorizontalAlignment( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_HorizontalAlignment( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Left( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Left( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Orientation( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Orientation( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Shadow( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Shadow( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Text( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Text( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Top( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Top( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_VerticalAlignment( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_VerticalAlignment( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ReadingOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ReadingOrder( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_AutoScaleFont( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_AutoScaleFont( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy21( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Position( 
            /* [retval][out] */ XlChartElementPosition *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Position( 
            /* [in] */ XlChartElementPosition RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Format( 
            /* [retval][out] */ ChartFormat	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Height( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Width( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Formula( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Formula( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_FormulaR1C1( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_FormulaR1C1( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_FormulaLocal( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_FormulaLocal( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_FormulaR1C1Local( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_FormulaR1C1Local( 
            /* [in] */ BSTR RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IDisplayUnitLabelVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IDisplayUnitLabel * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IDisplayUnitLabel * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IDisplayUnitLabel * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IDisplayUnitLabel * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IDisplayUnitLabel * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IDisplayUnitLabel * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IDisplayUnitLabel * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IDisplayUnitLabel * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IDisplayUnitLabel * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IDisplayUnitLabel * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            IDisplayUnitLabel * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            IDisplayUnitLabel * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Border )( 
            IDisplayUnitLabel * This,
            /* [retval][out] */ Border	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IDisplayUnitLabel * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Interior )( 
            IDisplayUnitLabel * This,
            /* [retval][out] */ Interior	**RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Fill )( 
            IDisplayUnitLabel * This,
            /* [retval][out] */ ChartFillFormat	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Caption )( 
            IDisplayUnitLabel * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Caption )( 
            IDisplayUnitLabel * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Characters )( 
            IDisplayUnitLabel * This,
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Length,
            /* [retval][out] */ Characters	**RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Font )( 
            IDisplayUnitLabel * This,
            /* [retval][out] */ Font	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HorizontalAlignment )( 
            IDisplayUnitLabel * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_HorizontalAlignment )( 
            IDisplayUnitLabel * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Left )( 
            IDisplayUnitLabel * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Left )( 
            IDisplayUnitLabel * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Orientation )( 
            IDisplayUnitLabel * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Orientation )( 
            IDisplayUnitLabel * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Shadow )( 
            IDisplayUnitLabel * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Shadow )( 
            IDisplayUnitLabel * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Text )( 
            IDisplayUnitLabel * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Text )( 
            IDisplayUnitLabel * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Top )( 
            IDisplayUnitLabel * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Top )( 
            IDisplayUnitLabel * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_VerticalAlignment )( 
            IDisplayUnitLabel * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_VerticalAlignment )( 
            IDisplayUnitLabel * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ReadingOrder )( 
            IDisplayUnitLabel * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ReadingOrder )( 
            IDisplayUnitLabel * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_AutoScaleFont )( 
            IDisplayUnitLabel * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_AutoScaleFont )( 
            IDisplayUnitLabel * This,
            /* [in] */ VARIANT RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy21 )( 
            IDisplayUnitLabel * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Position )( 
            IDisplayUnitLabel * This,
            /* [retval][out] */ XlChartElementPosition *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Position )( 
            IDisplayUnitLabel * This,
            /* [in] */ XlChartElementPosition RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Format )( 
            IDisplayUnitLabel * This,
            /* [retval][out] */ ChartFormat	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Height )( 
            IDisplayUnitLabel * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Width )( 
            IDisplayUnitLabel * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Formula )( 
            IDisplayUnitLabel * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Formula )( 
            IDisplayUnitLabel * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_FormulaR1C1 )( 
            IDisplayUnitLabel * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_FormulaR1C1 )( 
            IDisplayUnitLabel * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_FormulaLocal )( 
            IDisplayUnitLabel * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_FormulaLocal )( 
            IDisplayUnitLabel * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_FormulaR1C1Local )( 
            IDisplayUnitLabel * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_FormulaR1C1Local )( 
            IDisplayUnitLabel * This,
            /* [in] */ BSTR RHS);
        
        END_INTERFACE
    } IDisplayUnitLabelVtbl;

    interface IDisplayUnitLabel
    {
        CONST_VTBL struct IDisplayUnitLabelVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IDisplayUnitLabel_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IDisplayUnitLabel_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IDisplayUnitLabel_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IDisplayUnitLabel_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IDisplayUnitLabel_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IDisplayUnitLabel_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IDisplayUnitLabel_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IDisplayUnitLabel_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IDisplayUnitLabel_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IDisplayUnitLabel_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IDisplayUnitLabel_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define IDisplayUnitLabel_Select(This,RHS)	\
    ( (This)->lpVtbl -> Select(This,RHS) ) 

#define IDisplayUnitLabel_get_Border(This,RHS)	\
    ( (This)->lpVtbl -> get_Border(This,RHS) ) 

#define IDisplayUnitLabel_Delete(This,RHS)	\
    ( (This)->lpVtbl -> Delete(This,RHS) ) 

#define IDisplayUnitLabel_get_Interior(This,RHS)	\
    ( (This)->lpVtbl -> get_Interior(This,RHS) ) 

#define IDisplayUnitLabel_get_Fill(This,RHS)	\
    ( (This)->lpVtbl -> get_Fill(This,RHS) ) 

#define IDisplayUnitLabel_get_Caption(This,RHS)	\
    ( (This)->lpVtbl -> get_Caption(This,RHS) ) 

#define IDisplayUnitLabel_put_Caption(This,RHS)	\
    ( (This)->lpVtbl -> put_Caption(This,RHS) ) 

#define IDisplayUnitLabel_get_Characters(This,Start,Length,RHS)	\
    ( (This)->lpVtbl -> get_Characters(This,Start,Length,RHS) ) 

#define IDisplayUnitLabel_get_Font(This,RHS)	\
    ( (This)->lpVtbl -> get_Font(This,RHS) ) 

#define IDisplayUnitLabel_get_HorizontalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> get_HorizontalAlignment(This,RHS) ) 

#define IDisplayUnitLabel_put_HorizontalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> put_HorizontalAlignment(This,RHS) ) 

#define IDisplayUnitLabel_get_Left(This,RHS)	\
    ( (This)->lpVtbl -> get_Left(This,RHS) ) 

#define IDisplayUnitLabel_put_Left(This,RHS)	\
    ( (This)->lpVtbl -> put_Left(This,RHS) ) 

#define IDisplayUnitLabel_get_Orientation(This,RHS)	\
    ( (This)->lpVtbl -> get_Orientation(This,RHS) ) 

#define IDisplayUnitLabel_put_Orientation(This,RHS)	\
    ( (This)->lpVtbl -> put_Orientation(This,RHS) ) 

#define IDisplayUnitLabel_get_Shadow(This,RHS)	\
    ( (This)->lpVtbl -> get_Shadow(This,RHS) ) 

#define IDisplayUnitLabel_put_Shadow(This,RHS)	\
    ( (This)->lpVtbl -> put_Shadow(This,RHS) ) 

#define IDisplayUnitLabel_get_Text(This,RHS)	\
    ( (This)->lpVtbl -> get_Text(This,RHS) ) 

#define IDisplayUnitLabel_put_Text(This,RHS)	\
    ( (This)->lpVtbl -> put_Text(This,RHS) ) 

#define IDisplayUnitLabel_get_Top(This,RHS)	\
    ( (This)->lpVtbl -> get_Top(This,RHS) ) 

#define IDisplayUnitLabel_put_Top(This,RHS)	\
    ( (This)->lpVtbl -> put_Top(This,RHS) ) 

#define IDisplayUnitLabel_get_VerticalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> get_VerticalAlignment(This,RHS) ) 

#define IDisplayUnitLabel_put_VerticalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> put_VerticalAlignment(This,RHS) ) 

#define IDisplayUnitLabel_get_ReadingOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_ReadingOrder(This,RHS) ) 

#define IDisplayUnitLabel_put_ReadingOrder(This,RHS)	\
    ( (This)->lpVtbl -> put_ReadingOrder(This,RHS) ) 

#define IDisplayUnitLabel_get_AutoScaleFont(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoScaleFont(This,RHS) ) 

#define IDisplayUnitLabel_put_AutoScaleFont(This,RHS)	\
    ( (This)->lpVtbl -> put_AutoScaleFont(This,RHS) ) 

#define IDisplayUnitLabel__Dummy21(This)	\
    ( (This)->lpVtbl -> _Dummy21(This) ) 

#define IDisplayUnitLabel_get_Position(This,RHS)	\
    ( (This)->lpVtbl -> get_Position(This,RHS) ) 

#define IDisplayUnitLabel_put_Position(This,RHS)	\
    ( (This)->lpVtbl -> put_Position(This,RHS) ) 

#define IDisplayUnitLabel_get_Format(This,RHS)	\
    ( (This)->lpVtbl -> get_Format(This,RHS) ) 

#define IDisplayUnitLabel_get_Height(This,RHS)	\
    ( (This)->lpVtbl -> get_Height(This,RHS) ) 

#define IDisplayUnitLabel_get_Width(This,RHS)	\
    ( (This)->lpVtbl -> get_Width(This,RHS) ) 

#define IDisplayUnitLabel_get_Formula(This,RHS)	\
    ( (This)->lpVtbl -> get_Formula(This,RHS) ) 

#define IDisplayUnitLabel_put_Formula(This,RHS)	\
    ( (This)->lpVtbl -> put_Formula(This,RHS) ) 

#define IDisplayUnitLabel_get_FormulaR1C1(This,RHS)	\
    ( (This)->lpVtbl -> get_FormulaR1C1(This,RHS) ) 

#define IDisplayUnitLabel_put_FormulaR1C1(This,RHS)	\
    ( (This)->lpVtbl -> put_FormulaR1C1(This,RHS) ) 

#define IDisplayUnitLabel_get_FormulaLocal(This,RHS)	\
    ( (This)->lpVtbl -> get_FormulaLocal(This,RHS) ) 

#define IDisplayUnitLabel_put_FormulaLocal(This,RHS)	\
    ( (This)->lpVtbl -> put_FormulaLocal(This,RHS) ) 

#define IDisplayUnitLabel_get_FormulaR1C1Local(This,RHS)	\
    ( (This)->lpVtbl -> get_FormulaR1C1Local(This,RHS) ) 

#define IDisplayUnitLabel_put_FormulaR1C1Local(This,RHS)	\
    ( (This)->lpVtbl -> put_FormulaR1C1Local(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IDisplayUnitLabel_INTERFACE_DEFINED__ */


#ifndef __ICellFormat_INTERFACE_DEFINED__
#define __ICellFormat_INTERFACE_DEFINED__

/* interface ICellFormat */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ICellFormat;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024450-0001-0000-C000-000000000046")
    ICellFormat : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Borders( 
            /* [retval][out] */ Borders	**RHS) = 0;
        
        virtual /* [helpcontext][propputref][id] */ HRESULT __stdcall putref_Borders( 
            /* [in] */ Borders	*RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Font( 
            /* [retval][out] */ Font	**RHS) = 0;
        
        virtual /* [helpcontext][propputref][id] */ HRESULT __stdcall putref_Font( 
            /* [in] */ Font	*RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Interior( 
            /* [retval][out] */ Interior	**RHS) = 0;
        
        virtual /* [helpcontext][propputref][id] */ HRESULT __stdcall putref_Interior( 
            /* [in] */ Interior	*RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_NumberFormat( 
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_NumberFormat( 
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_NumberFormatLocal( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_NumberFormatLocal( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AddIndent( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AddIndent( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_IndentLevel( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_IndentLevel( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HorizontalAlignment( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_HorizontalAlignment( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_VerticalAlignment( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_VerticalAlignment( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Orientation( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Orientation( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShrinkToFit( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ShrinkToFit( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_WrapText( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_WrapText( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Locked( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Locked( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_FormulaHidden( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_FormulaHidden( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MergeCells( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_MergeCells( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Clear( void) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ICellFormatVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ICellFormat * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ICellFormat * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ICellFormat * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ICellFormat * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ICellFormat * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ICellFormat * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ICellFormat * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ICellFormat * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ICellFormat * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ICellFormat * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Borders )( 
            ICellFormat * This,
            /* [retval][out] */ Borders	**RHS);
        
        /* [helpcontext][propputref][id] */ HRESULT ( __stdcall *putref_Borders )( 
            ICellFormat * This,
            /* [in] */ Borders	*RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Font )( 
            ICellFormat * This,
            /* [retval][out] */ Font	**RHS);
        
        /* [helpcontext][propputref][id] */ HRESULT ( __stdcall *putref_Font )( 
            ICellFormat * This,
            /* [in] */ Font	*RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Interior )( 
            ICellFormat * This,
            /* [retval][out] */ Interior	**RHS);
        
        /* [helpcontext][propputref][id] */ HRESULT ( __stdcall *putref_Interior )( 
            ICellFormat * This,
            /* [in] */ Interior	*RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_NumberFormat )( 
            ICellFormat * This,
            /* [lcid][in] */ long lcid,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_NumberFormat )( 
            ICellFormat * This,
            /* [lcid][in] */ long lcid,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_NumberFormatLocal )( 
            ICellFormat * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_NumberFormatLocal )( 
            ICellFormat * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AddIndent )( 
            ICellFormat * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AddIndent )( 
            ICellFormat * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_IndentLevel )( 
            ICellFormat * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_IndentLevel )( 
            ICellFormat * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HorizontalAlignment )( 
            ICellFormat * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_HorizontalAlignment )( 
            ICellFormat * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_VerticalAlignment )( 
            ICellFormat * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_VerticalAlignment )( 
            ICellFormat * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Orientation )( 
            ICellFormat * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Orientation )( 
            ICellFormat * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShrinkToFit )( 
            ICellFormat * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ShrinkToFit )( 
            ICellFormat * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_WrapText )( 
            ICellFormat * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_WrapText )( 
            ICellFormat * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Locked )( 
            ICellFormat * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Locked )( 
            ICellFormat * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_FormulaHidden )( 
            ICellFormat * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_FormulaHidden )( 
            ICellFormat * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MergeCells )( 
            ICellFormat * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_MergeCells )( 
            ICellFormat * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Clear )( 
            ICellFormat * This);
        
        END_INTERFACE
    } ICellFormatVtbl;

    interface ICellFormat
    {
        CONST_VTBL struct ICellFormatVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ICellFormat_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ICellFormat_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ICellFormat_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ICellFormat_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ICellFormat_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ICellFormat_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ICellFormat_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ICellFormat_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ICellFormat_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ICellFormat_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ICellFormat_get_Borders(This,RHS)	\
    ( (This)->lpVtbl -> get_Borders(This,RHS) ) 

#define ICellFormat_putref_Borders(This,RHS)	\
    ( (This)->lpVtbl -> putref_Borders(This,RHS) ) 

#define ICellFormat_get_Font(This,RHS)	\
    ( (This)->lpVtbl -> get_Font(This,RHS) ) 

#define ICellFormat_putref_Font(This,RHS)	\
    ( (This)->lpVtbl -> putref_Font(This,RHS) ) 

#define ICellFormat_get_Interior(This,RHS)	\
    ( (This)->lpVtbl -> get_Interior(This,RHS) ) 

#define ICellFormat_putref_Interior(This,RHS)	\
    ( (This)->lpVtbl -> putref_Interior(This,RHS) ) 

#define ICellFormat_get_NumberFormat(This,lcid,RHS)	\
    ( (This)->lpVtbl -> get_NumberFormat(This,lcid,RHS) ) 

#define ICellFormat_put_NumberFormat(This,lcid,RHS)	\
    ( (This)->lpVtbl -> put_NumberFormat(This,lcid,RHS) ) 

#define ICellFormat_get_NumberFormatLocal(This,RHS)	\
    ( (This)->lpVtbl -> get_NumberFormatLocal(This,RHS) ) 

#define ICellFormat_put_NumberFormatLocal(This,RHS)	\
    ( (This)->lpVtbl -> put_NumberFormatLocal(This,RHS) ) 

#define ICellFormat_get_AddIndent(This,RHS)	\
    ( (This)->lpVtbl -> get_AddIndent(This,RHS) ) 

#define ICellFormat_put_AddIndent(This,RHS)	\
    ( (This)->lpVtbl -> put_AddIndent(This,RHS) ) 

#define ICellFormat_get_IndentLevel(This,RHS)	\
    ( (This)->lpVtbl -> get_IndentLevel(This,RHS) ) 

#define ICellFormat_put_IndentLevel(This,RHS)	\
    ( (This)->lpVtbl -> put_IndentLevel(This,RHS) ) 

#define ICellFormat_get_HorizontalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> get_HorizontalAlignment(This,RHS) ) 

#define ICellFormat_put_HorizontalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> put_HorizontalAlignment(This,RHS) ) 

#define ICellFormat_get_VerticalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> get_VerticalAlignment(This,RHS) ) 

#define ICellFormat_put_VerticalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> put_VerticalAlignment(This,RHS) ) 

#define ICellFormat_get_Orientation(This,RHS)	\
    ( (This)->lpVtbl -> get_Orientation(This,RHS) ) 

#define ICellFormat_put_Orientation(This,RHS)	\
    ( (This)->lpVtbl -> put_Orientation(This,RHS) ) 

#define ICellFormat_get_ShrinkToFit(This,RHS)	\
    ( (This)->lpVtbl -> get_ShrinkToFit(This,RHS) ) 

#define ICellFormat_put_ShrinkToFit(This,RHS)	\
    ( (This)->lpVtbl -> put_ShrinkToFit(This,RHS) ) 

#define ICellFormat_get_WrapText(This,RHS)	\
    ( (This)->lpVtbl -> get_WrapText(This,RHS) ) 

#define ICellFormat_put_WrapText(This,RHS)	\
    ( (This)->lpVtbl -> put_WrapText(This,RHS) ) 

#define ICellFormat_get_Locked(This,RHS)	\
    ( (This)->lpVtbl -> get_Locked(This,RHS) ) 

#define ICellFormat_put_Locked(This,RHS)	\
    ( (This)->lpVtbl -> put_Locked(This,RHS) ) 

#define ICellFormat_get_FormulaHidden(This,RHS)	\
    ( (This)->lpVtbl -> get_FormulaHidden(This,RHS) ) 

#define ICellFormat_put_FormulaHidden(This,RHS)	\
    ( (This)->lpVtbl -> put_FormulaHidden(This,RHS) ) 

#define ICellFormat_get_MergeCells(This,RHS)	\
    ( (This)->lpVtbl -> get_MergeCells(This,RHS) ) 

#define ICellFormat_put_MergeCells(This,RHS)	\
    ( (This)->lpVtbl -> put_MergeCells(This,RHS) ) 

#define ICellFormat_Clear(This)	\
    ( (This)->lpVtbl -> Clear(This) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ICellFormat_INTERFACE_DEFINED__ */


#ifndef __IUsedObjects_INTERFACE_DEFINED__
#define __IUsedObjects_INTERFACE_DEFINED__

/* interface IUsedObjects */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IUsedObjects;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024451-0001-0000-C000-000000000046")
    IUsedObjects : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IUsedObjectsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IUsedObjects * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IUsedObjects * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IUsedObjects * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IUsedObjects * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IUsedObjects * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IUsedObjects * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IUsedObjects * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IUsedObjects * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IUsedObjects * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IUsedObjects * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IUsedObjects * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            IUsedObjects * This,
            /* [retval][out] */ IUnknown **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IUsedObjects * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Item )( 
            IUsedObjects * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS);
        
        END_INTERFACE
    } IUsedObjectsVtbl;

    interface IUsedObjects
    {
        CONST_VTBL struct IUsedObjectsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IUsedObjects_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IUsedObjects_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IUsedObjects_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IUsedObjects_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IUsedObjects_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IUsedObjects_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IUsedObjects_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IUsedObjects_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IUsedObjects_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IUsedObjects_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IUsedObjects_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IUsedObjects_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#define IUsedObjects_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define IUsedObjects_get_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Item(This,Index,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IUsedObjects_INTERFACE_DEFINED__ */


#ifndef __ICustomProperties_INTERFACE_DEFINED__
#define __ICustomProperties_INTERFACE_DEFINED__

/* interface ICustomProperties */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ICustomProperties;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024452-0001-0000-C000-000000000046")
    ICustomProperties : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add( 
            /* [in] */ BSTR Name,
            /* [in] */ VARIANT Value,
            /* [retval][out] */ CustomProperty	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ CustomProperty	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ CustomProperty	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ICustomPropertiesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ICustomProperties * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ICustomProperties * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ICustomProperties * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ICustomProperties * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ICustomProperties * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ICustomProperties * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ICustomProperties * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ICustomProperties * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ICustomProperties * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ICustomProperties * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add )( 
            ICustomProperties * This,
            /* [in] */ BSTR Name,
            /* [in] */ VARIANT Value,
            /* [retval][out] */ CustomProperty	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            ICustomProperties * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            ICustomProperties * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ CustomProperty	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Item )( 
            ICustomProperties * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ CustomProperty	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            ICustomProperties * This,
            /* [retval][out] */ IUnknown **RHS);
        
        END_INTERFACE
    } ICustomPropertiesVtbl;

    interface ICustomProperties
    {
        CONST_VTBL struct ICustomPropertiesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ICustomProperties_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ICustomProperties_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ICustomProperties_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ICustomProperties_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ICustomProperties_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ICustomProperties_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ICustomProperties_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ICustomProperties_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ICustomProperties_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ICustomProperties_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ICustomProperties_Add(This,Name,Value,RHS)	\
    ( (This)->lpVtbl -> Add(This,Name,Value,RHS) ) 

#define ICustomProperties_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define ICustomProperties_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define ICustomProperties_get_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Item(This,Index,RHS) ) 

#define ICustomProperties_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ICustomProperties_INTERFACE_DEFINED__ */


#ifndef __ICustomProperty_INTERFACE_DEFINED__
#define __ICustomProperty_INTERFACE_DEFINED__

/* interface ICustomProperty */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ICustomProperty;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024453-0001-0000-C000-000000000046")
    ICustomProperty : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Name( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Value( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Value( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( void) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ICustomPropertyVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ICustomProperty * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ICustomProperty * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ICustomProperty * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ICustomProperty * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ICustomProperty * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ICustomProperty * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ICustomProperty * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ICustomProperty * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ICustomProperty * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ICustomProperty * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            ICustomProperty * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Name )( 
            ICustomProperty * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Value )( 
            ICustomProperty * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Value )( 
            ICustomProperty * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            ICustomProperty * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            ICustomProperty * This);
        
        END_INTERFACE
    } ICustomPropertyVtbl;

    interface ICustomProperty
    {
        CONST_VTBL struct ICustomPropertyVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ICustomProperty_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ICustomProperty_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ICustomProperty_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ICustomProperty_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ICustomProperty_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ICustomProperty_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ICustomProperty_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ICustomProperty_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ICustomProperty_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ICustomProperty_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ICustomProperty_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define ICustomProperty_put_Name(This,RHS)	\
    ( (This)->lpVtbl -> put_Name(This,RHS) ) 

#define ICustomProperty_get_Value(This,RHS)	\
    ( (This)->lpVtbl -> get_Value(This,RHS) ) 

#define ICustomProperty_put_Value(This,RHS)	\
    ( (This)->lpVtbl -> put_Value(This,RHS) ) 

#define ICustomProperty_get__Default(This,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,RHS) ) 

#define ICustomProperty_Delete(This)	\
    ( (This)->lpVtbl -> Delete(This) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ICustomProperty_INTERFACE_DEFINED__ */


#ifndef __ICalculatedMembers_INTERFACE_DEFINED__
#define __ICalculatedMembers_INTERFACE_DEFINED__

/* interface ICalculatedMembers */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ICalculatedMembers;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024454-0001-0000-C000-000000000046")
    ICalculatedMembers : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ CalculatedMember	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ CalculatedMember	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
        virtual /* [custom][helpcontext][hidden][id] */ HRESULT __stdcall _Add( 
            /* [in] */ BSTR Name,
            /* [in] */ BSTR Formula,
            /* [optional][in] */ VARIANT SolveOrder,
            /* [optional][in] */ VARIANT Type,
            /* [retval][out] */ CalculatedMember	**RHS) = 0;
        
        virtual /* [custom][helpcontext][id] */ HRESULT __stdcall Add( 
            /* [in] */ BSTR Name,
            /* [in] */ VARIANT Formula,
            /* [optional][in] */ VARIANT SolveOrder,
            /* [optional][in] */ VARIANT Type,
            /* [optional][in] */ VARIANT Dynamic,
            /* [optional][in] */ VARIANT DisplayFolder,
            /* [optional][in] */ VARIANT HierarchizeDistinct,
            /* [retval][out] */ CalculatedMember	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall AddCalculatedMember( 
            /* [in] */ BSTR Name,
            /* [in] */ VARIANT Formula,
            /* [optional][in] */ VARIANT SolveOrder,
            /* [optional][in] */ VARIANT Type,
            /* [optional][in] */ VARIANT DisplayFolder,
            /* [optional][in] */ VARIANT MeasureGroup,
            /* [optional][in] */ VARIANT ParentHierarchy,
            /* [optional][in] */ VARIANT ParentMember,
            /* [optional][in] */ VARIANT NumberFormat,
            /* [retval][out] */ CalculatedMember	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ICalculatedMembersVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ICalculatedMembers * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ICalculatedMembers * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ICalculatedMembers * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ICalculatedMembers * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ICalculatedMembers * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ICalculatedMembers * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ICalculatedMembers * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ICalculatedMembers * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ICalculatedMembers * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ICalculatedMembers * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            ICalculatedMembers * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Item )( 
            ICalculatedMembers * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ CalculatedMember	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            ICalculatedMembers * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ CalculatedMember	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            ICalculatedMembers * This,
            /* [retval][out] */ IUnknown **RHS);
        
        /* [custom][helpcontext][hidden][id] */ HRESULT ( __stdcall *_Add )( 
            ICalculatedMembers * This,
            /* [in] */ BSTR Name,
            /* [in] */ BSTR Formula,
            /* [optional][in] */ VARIANT SolveOrder,
            /* [optional][in] */ VARIANT Type,
            /* [retval][out] */ CalculatedMember	**RHS);
        
        /* [custom][helpcontext][id] */ HRESULT ( __stdcall *Add )( 
            ICalculatedMembers * This,
            /* [in] */ BSTR Name,
            /* [in] */ VARIANT Formula,
            /* [optional][in] */ VARIANT SolveOrder,
            /* [optional][in] */ VARIANT Type,
            /* [optional][in] */ VARIANT Dynamic,
            /* [optional][in] */ VARIANT DisplayFolder,
            /* [optional][in] */ VARIANT HierarchizeDistinct,
            /* [retval][out] */ CalculatedMember	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *AddCalculatedMember )( 
            ICalculatedMembers * This,
            /* [in] */ BSTR Name,
            /* [in] */ VARIANT Formula,
            /* [optional][in] */ VARIANT SolveOrder,
            /* [optional][in] */ VARIANT Type,
            /* [optional][in] */ VARIANT DisplayFolder,
            /* [optional][in] */ VARIANT MeasureGroup,
            /* [optional][in] */ VARIANT ParentHierarchy,
            /* [optional][in] */ VARIANT ParentMember,
            /* [optional][in] */ VARIANT NumberFormat,
            /* [retval][out] */ CalculatedMember	**RHS);
        
        END_INTERFACE
    } ICalculatedMembersVtbl;

    interface ICalculatedMembers
    {
        CONST_VTBL struct ICalculatedMembersVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ICalculatedMembers_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ICalculatedMembers_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ICalculatedMembers_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ICalculatedMembers_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ICalculatedMembers_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ICalculatedMembers_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ICalculatedMembers_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ICalculatedMembers_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ICalculatedMembers_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ICalculatedMembers_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ICalculatedMembers_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define ICalculatedMembers_get_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Item(This,Index,RHS) ) 

#define ICalculatedMembers_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define ICalculatedMembers_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#define ICalculatedMembers__Add(This,Name,Formula,SolveOrder,Type,RHS)	\
    ( (This)->lpVtbl -> _Add(This,Name,Formula,SolveOrder,Type,RHS) ) 

#define ICalculatedMembers_Add(This,Name,Formula,SolveOrder,Type,Dynamic,DisplayFolder,HierarchizeDistinct,RHS)	\
    ( (This)->lpVtbl -> Add(This,Name,Formula,SolveOrder,Type,Dynamic,DisplayFolder,HierarchizeDistinct,RHS) ) 

#define ICalculatedMembers_AddCalculatedMember(This,Name,Formula,SolveOrder,Type,DisplayFolder,MeasureGroup,ParentHierarchy,ParentMember,NumberFormat,RHS)	\
    ( (This)->lpVtbl -> AddCalculatedMember(This,Name,Formula,SolveOrder,Type,DisplayFolder,MeasureGroup,ParentHierarchy,ParentMember,NumberFormat,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ICalculatedMembers_INTERFACE_DEFINED__ */


#ifndef __ICalculatedMember_INTERFACE_DEFINED__
#define __ICalculatedMember_INTERFACE_DEFINED__

/* interface ICalculatedMember */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ICalculatedMember;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024455-0001-0000-C000-000000000046")
    ICalculatedMember : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Formula( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SourceName( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SolveOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_IsValid( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Type( 
            /* [retval][out] */ XlCalculatedMemberType *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Dynamic( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DisplayFolder( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HierarchizeDistinct( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_HierarchizeDistinct( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_FlattenHierarchies( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_FlattenHierarchies( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MeasureGroup( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ParentHierarchy( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ParentMember( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_NumberFormat( 
            /* [retval][out] */ XlCalcMemNumberFormatType *RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ICalculatedMemberVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ICalculatedMember * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ICalculatedMember * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ICalculatedMember * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ICalculatedMember * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ICalculatedMember * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ICalculatedMember * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ICalculatedMember * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ICalculatedMember * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ICalculatedMember * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ICalculatedMember * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            ICalculatedMember * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Formula )( 
            ICalculatedMember * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SourceName )( 
            ICalculatedMember * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SolveOrder )( 
            ICalculatedMember * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_IsValid )( 
            ICalculatedMember * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            ICalculatedMember * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            ICalculatedMember * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Type )( 
            ICalculatedMember * This,
            /* [retval][out] */ XlCalculatedMemberType *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Dynamic )( 
            ICalculatedMember * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DisplayFolder )( 
            ICalculatedMember * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HierarchizeDistinct )( 
            ICalculatedMember * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_HierarchizeDistinct )( 
            ICalculatedMember * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_FlattenHierarchies )( 
            ICalculatedMember * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_FlattenHierarchies )( 
            ICalculatedMember * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MeasureGroup )( 
            ICalculatedMember * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ParentHierarchy )( 
            ICalculatedMember * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ParentMember )( 
            ICalculatedMember * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_NumberFormat )( 
            ICalculatedMember * This,
            /* [retval][out] */ XlCalcMemNumberFormatType *RHS);
        
        END_INTERFACE
    } ICalculatedMemberVtbl;

    interface ICalculatedMember
    {
        CONST_VTBL struct ICalculatedMemberVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ICalculatedMember_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ICalculatedMember_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ICalculatedMember_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ICalculatedMember_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ICalculatedMember_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ICalculatedMember_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ICalculatedMember_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ICalculatedMember_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ICalculatedMember_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ICalculatedMember_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ICalculatedMember_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define ICalculatedMember_get_Formula(This,RHS)	\
    ( (This)->lpVtbl -> get_Formula(This,RHS) ) 

#define ICalculatedMember_get_SourceName(This,RHS)	\
    ( (This)->lpVtbl -> get_SourceName(This,RHS) ) 

#define ICalculatedMember_get_SolveOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_SolveOrder(This,RHS) ) 

#define ICalculatedMember_get_IsValid(This,RHS)	\
    ( (This)->lpVtbl -> get_IsValid(This,RHS) ) 

#define ICalculatedMember_get__Default(This,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,RHS) ) 

#define ICalculatedMember_Delete(This)	\
    ( (This)->lpVtbl -> Delete(This) ) 

#define ICalculatedMember_get_Type(This,RHS)	\
    ( (This)->lpVtbl -> get_Type(This,RHS) ) 

#define ICalculatedMember_get_Dynamic(This,RHS)	\
    ( (This)->lpVtbl -> get_Dynamic(This,RHS) ) 

#define ICalculatedMember_get_DisplayFolder(This,RHS)	\
    ( (This)->lpVtbl -> get_DisplayFolder(This,RHS) ) 

#define ICalculatedMember_get_HierarchizeDistinct(This,RHS)	\
    ( (This)->lpVtbl -> get_HierarchizeDistinct(This,RHS) ) 

#define ICalculatedMember_put_HierarchizeDistinct(This,RHS)	\
    ( (This)->lpVtbl -> put_HierarchizeDistinct(This,RHS) ) 

#define ICalculatedMember_get_FlattenHierarchies(This,RHS)	\
    ( (This)->lpVtbl -> get_FlattenHierarchies(This,RHS) ) 

#define ICalculatedMember_put_FlattenHierarchies(This,RHS)	\
    ( (This)->lpVtbl -> put_FlattenHierarchies(This,RHS) ) 

#define ICalculatedMember_get_MeasureGroup(This,RHS)	\
    ( (This)->lpVtbl -> get_MeasureGroup(This,RHS) ) 

#define ICalculatedMember_get_ParentHierarchy(This,RHS)	\
    ( (This)->lpVtbl -> get_ParentHierarchy(This,RHS) ) 

#define ICalculatedMember_get_ParentMember(This,RHS)	\
    ( (This)->lpVtbl -> get_ParentMember(This,RHS) ) 

#define ICalculatedMember_get_NumberFormat(This,RHS)	\
    ( (This)->lpVtbl -> get_NumberFormat(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ICalculatedMember_INTERFACE_DEFINED__ */


#ifndef __IWatches_INTERFACE_DEFINED__
#define __IWatches_INTERFACE_DEFINED__

/* interface IWatches */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IWatches;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024456-0001-0000-C000-000000000046")
    IWatches : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add( 
            /* [in] */ VARIANT Source,
            /* [retval][out] */ Watch	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Watch	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Watch	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( void) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IWatchesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IWatches * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IWatches * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IWatches * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IWatches * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IWatches * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IWatches * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IWatches * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IWatches * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IWatches * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IWatches * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add )( 
            IWatches * This,
            /* [in] */ VARIANT Source,
            /* [retval][out] */ Watch	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IWatches * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IWatches * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Watch	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Item )( 
            IWatches * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Watch	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            IWatches * This,
            /* [retval][out] */ IUnknown **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IWatches * This);
        
        END_INTERFACE
    } IWatchesVtbl;

    interface IWatches
    {
        CONST_VTBL struct IWatchesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IWatches_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IWatches_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IWatches_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IWatches_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IWatches_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IWatches_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IWatches_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IWatches_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IWatches_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IWatches_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IWatches_Add(This,Source,RHS)	\
    ( (This)->lpVtbl -> Add(This,Source,RHS) ) 

#define IWatches_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IWatches_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define IWatches_get_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Item(This,Index,RHS) ) 

#define IWatches_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#define IWatches_Delete(This)	\
    ( (This)->lpVtbl -> Delete(This) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IWatches_INTERFACE_DEFINED__ */


#ifndef __IWatch_INTERFACE_DEFINED__
#define __IWatch_INTERFACE_DEFINED__

/* interface IWatch */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IWatch;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024457-0001-0000-C000-000000000046")
    IWatch : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Source( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IWatchVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IWatch * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IWatch * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IWatch * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IWatch * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IWatch * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IWatch * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IWatch * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IWatch * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IWatch * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IWatch * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IWatch * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Source )( 
            IWatch * This,
            /* [retval][out] */ VARIANT *RHS);
        
        END_INTERFACE
    } IWatchVtbl;

    interface IWatch
    {
        CONST_VTBL struct IWatchVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IWatch_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IWatch_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IWatch_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IWatch_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IWatch_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IWatch_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IWatch_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IWatch_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IWatch_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IWatch_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IWatch_Delete(This)	\
    ( (This)->lpVtbl -> Delete(This) ) 

#define IWatch_get_Source(This,RHS)	\
    ( (This)->lpVtbl -> get_Source(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IWatch_INTERFACE_DEFINED__ */


#ifndef __IPivotCell_INTERFACE_DEFINED__
#define __IPivotCell_INTERFACE_DEFINED__

/* interface IPivotCell */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IPivotCell;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024458-0001-0000-C000-000000000046")
    IPivotCell : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PivotCellType( 
            /* [retval][out] */ XlPivotCellType *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PivotTable( 
            /* [retval][out] */ PivotTable	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DataField( 
            /* [retval][out] */ PivotField	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PivotField( 
            /* [retval][out] */ PivotField	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PivotItem( 
            /* [retval][out] */ PivotItem	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RowItems( 
            /* [retval][out] */ PivotItemList	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ColumnItems( 
            /* [retval][out] */ PivotItemList	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Range( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_Dummy18( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CustomSubtotalFunction( 
            /* [retval][out] */ XlConsolidationFunction *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PivotRowLine( 
            /* [retval][out] */ PivotLine	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PivotColumnLine( 
            /* [retval][out] */ PivotLine	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall AllocateChange( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall DiscardChange( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DataSourceValue( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CellChanged( 
            /* [retval][out] */ XlCellChangedState *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MDX( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ServerActions( 
            /* [retval][out] */ Actions	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IPivotCellVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IPivotCell * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IPivotCell * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IPivotCell * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IPivotCell * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IPivotCell * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IPivotCell * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IPivotCell * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IPivotCell * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IPivotCell * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IPivotCell * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PivotCellType )( 
            IPivotCell * This,
            /* [retval][out] */ XlPivotCellType *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PivotTable )( 
            IPivotCell * This,
            /* [retval][out] */ PivotTable	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DataField )( 
            IPivotCell * This,
            /* [retval][out] */ PivotField	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PivotField )( 
            IPivotCell * This,
            /* [retval][out] */ PivotField	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PivotItem )( 
            IPivotCell * This,
            /* [retval][out] */ PivotItem	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RowItems )( 
            IPivotCell * This,
            /* [retval][out] */ PivotItemList	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ColumnItems )( 
            IPivotCell * This,
            /* [retval][out] */ PivotItemList	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Range )( 
            IPivotCell * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_Dummy18 )( 
            IPivotCell * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CustomSubtotalFunction )( 
            IPivotCell * This,
            /* [retval][out] */ XlConsolidationFunction *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PivotRowLine )( 
            IPivotCell * This,
            /* [retval][out] */ PivotLine	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PivotColumnLine )( 
            IPivotCell * This,
            /* [retval][out] */ PivotLine	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *AllocateChange )( 
            IPivotCell * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *DiscardChange )( 
            IPivotCell * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DataSourceValue )( 
            IPivotCell * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CellChanged )( 
            IPivotCell * This,
            /* [retval][out] */ XlCellChangedState *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MDX )( 
            IPivotCell * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ServerActions )( 
            IPivotCell * This,
            /* [retval][out] */ Actions	**RHS);
        
        END_INTERFACE
    } IPivotCellVtbl;

    interface IPivotCell
    {
        CONST_VTBL struct IPivotCellVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IPivotCell_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IPivotCell_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IPivotCell_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IPivotCell_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IPivotCell_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IPivotCell_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IPivotCell_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IPivotCell_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IPivotCell_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IPivotCell_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IPivotCell_get_PivotCellType(This,RHS)	\
    ( (This)->lpVtbl -> get_PivotCellType(This,RHS) ) 

#define IPivotCell_get_PivotTable(This,RHS)	\
    ( (This)->lpVtbl -> get_PivotTable(This,RHS) ) 

#define IPivotCell_get_DataField(This,RHS)	\
    ( (This)->lpVtbl -> get_DataField(This,RHS) ) 

#define IPivotCell_get_PivotField(This,RHS)	\
    ( (This)->lpVtbl -> get_PivotField(This,RHS) ) 

#define IPivotCell_get_PivotItem(This,RHS)	\
    ( (This)->lpVtbl -> get_PivotItem(This,RHS) ) 

#define IPivotCell_get_RowItems(This,RHS)	\
    ( (This)->lpVtbl -> get_RowItems(This,RHS) ) 

#define IPivotCell_get_ColumnItems(This,RHS)	\
    ( (This)->lpVtbl -> get_ColumnItems(This,RHS) ) 

#define IPivotCell_get_Range(This,RHS)	\
    ( (This)->lpVtbl -> get_Range(This,RHS) ) 

#define IPivotCell_get_Dummy18(This,RHS)	\
    ( (This)->lpVtbl -> get_Dummy18(This,RHS) ) 

#define IPivotCell_get_CustomSubtotalFunction(This,RHS)	\
    ( (This)->lpVtbl -> get_CustomSubtotalFunction(This,RHS) ) 

#define IPivotCell_get_PivotRowLine(This,RHS)	\
    ( (This)->lpVtbl -> get_PivotRowLine(This,RHS) ) 

#define IPivotCell_get_PivotColumnLine(This,RHS)	\
    ( (This)->lpVtbl -> get_PivotColumnLine(This,RHS) ) 

#define IPivotCell_AllocateChange(This)	\
    ( (This)->lpVtbl -> AllocateChange(This) ) 

#define IPivotCell_DiscardChange(This)	\
    ( (This)->lpVtbl -> DiscardChange(This) ) 

#define IPivotCell_get_DataSourceValue(This,RHS)	\
    ( (This)->lpVtbl -> get_DataSourceValue(This,RHS) ) 

#define IPivotCell_get_CellChanged(This,RHS)	\
    ( (This)->lpVtbl -> get_CellChanged(This,RHS) ) 

#define IPivotCell_get_MDX(This,RHS)	\
    ( (This)->lpVtbl -> get_MDX(This,RHS) ) 

#define IPivotCell_get_ServerActions(This,RHS)	\
    ( (This)->lpVtbl -> get_ServerActions(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IPivotCell_INTERFACE_DEFINED__ */


#ifndef __IGraphic_INTERFACE_DEFINED__
#define __IGraphic_INTERFACE_DEFINED__

/* interface IGraphic */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IGraphic;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024459-0001-0000-C000-000000000046")
    IGraphic : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Brightness( 
            /* [retval][out] */ single *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Brightness( 
            /* [in] */ single RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ColorType( 
            /* [retval][out] */ MsoPictureColorType *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ColorType( 
            /* [in] */ MsoPictureColorType RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Contrast( 
            /* [retval][out] */ single *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Contrast( 
            /* [in] */ single RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CropBottom( 
            /* [retval][out] */ single *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_CropBottom( 
            /* [in] */ single RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CropLeft( 
            /* [retval][out] */ single *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_CropLeft( 
            /* [in] */ single RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CropRight( 
            /* [retval][out] */ single *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_CropRight( 
            /* [in] */ single RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CropTop( 
            /* [retval][out] */ single *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_CropTop( 
            /* [in] */ single RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Filename( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Filename( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Height( 
            /* [retval][out] */ single *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Height( 
            /* [in] */ single RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LockAspectRatio( 
            /* [retval][out] */ MsoTriState *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_LockAspectRatio( 
            /* [in] */ MsoTriState RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Width( 
            /* [retval][out] */ single *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Width( 
            /* [in] */ single RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IGraphicVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IGraphic * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IGraphic * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IGraphic * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IGraphic * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IGraphic * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IGraphic * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IGraphic * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IGraphic * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IGraphic * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IGraphic * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Brightness )( 
            IGraphic * This,
            /* [retval][out] */ single *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Brightness )( 
            IGraphic * This,
            /* [in] */ single RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ColorType )( 
            IGraphic * This,
            /* [retval][out] */ MsoPictureColorType *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ColorType )( 
            IGraphic * This,
            /* [in] */ MsoPictureColorType RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Contrast )( 
            IGraphic * This,
            /* [retval][out] */ single *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Contrast )( 
            IGraphic * This,
            /* [in] */ single RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CropBottom )( 
            IGraphic * This,
            /* [retval][out] */ single *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_CropBottom )( 
            IGraphic * This,
            /* [in] */ single RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CropLeft )( 
            IGraphic * This,
            /* [retval][out] */ single *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_CropLeft )( 
            IGraphic * This,
            /* [in] */ single RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CropRight )( 
            IGraphic * This,
            /* [retval][out] */ single *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_CropRight )( 
            IGraphic * This,
            /* [in] */ single RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CropTop )( 
            IGraphic * This,
            /* [retval][out] */ single *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_CropTop )( 
            IGraphic * This,
            /* [in] */ single RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Filename )( 
            IGraphic * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Filename )( 
            IGraphic * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Height )( 
            IGraphic * This,
            /* [retval][out] */ single *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Height )( 
            IGraphic * This,
            /* [in] */ single RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LockAspectRatio )( 
            IGraphic * This,
            /* [retval][out] */ MsoTriState *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_LockAspectRatio )( 
            IGraphic * This,
            /* [in] */ MsoTriState RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Width )( 
            IGraphic * This,
            /* [retval][out] */ single *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Width )( 
            IGraphic * This,
            /* [in] */ single RHS);
        
        END_INTERFACE
    } IGraphicVtbl;

    interface IGraphic
    {
        CONST_VTBL struct IGraphicVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IGraphic_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IGraphic_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IGraphic_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IGraphic_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IGraphic_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IGraphic_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IGraphic_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IGraphic_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IGraphic_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IGraphic_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IGraphic_get_Brightness(This,RHS)	\
    ( (This)->lpVtbl -> get_Brightness(This,RHS) ) 

#define IGraphic_put_Brightness(This,RHS)	\
    ( (This)->lpVtbl -> put_Brightness(This,RHS) ) 

#define IGraphic_get_ColorType(This,RHS)	\
    ( (This)->lpVtbl -> get_ColorType(This,RHS) ) 

#define IGraphic_put_ColorType(This,RHS)	\
    ( (This)->lpVtbl -> put_ColorType(This,RHS) ) 

#define IGraphic_get_Contrast(This,RHS)	\
    ( (This)->lpVtbl -> get_Contrast(This,RHS) ) 

#define IGraphic_put_Contrast(This,RHS)	\
    ( (This)->lpVtbl -> put_Contrast(This,RHS) ) 

#define IGraphic_get_CropBottom(This,RHS)	\
    ( (This)->lpVtbl -> get_CropBottom(This,RHS) ) 

#define IGraphic_put_CropBottom(This,RHS)	\
    ( (This)->lpVtbl -> put_CropBottom(This,RHS) ) 

#define IGraphic_get_CropLeft(This,RHS)	\
    ( (This)->lpVtbl -> get_CropLeft(This,RHS) ) 

#define IGraphic_put_CropLeft(This,RHS)	\
    ( (This)->lpVtbl -> put_CropLeft(This,RHS) ) 

#define IGraphic_get_CropRight(This,RHS)	\
    ( (This)->lpVtbl -> get_CropRight(This,RHS) ) 

#define IGraphic_put_CropRight(This,RHS)	\
    ( (This)->lpVtbl -> put_CropRight(This,RHS) ) 

#define IGraphic_get_CropTop(This,RHS)	\
    ( (This)->lpVtbl -> get_CropTop(This,RHS) ) 

#define IGraphic_put_CropTop(This,RHS)	\
    ( (This)->lpVtbl -> put_CropTop(This,RHS) ) 

#define IGraphic_get_Filename(This,RHS)	\
    ( (This)->lpVtbl -> get_Filename(This,RHS) ) 

#define IGraphic_put_Filename(This,RHS)	\
    ( (This)->lpVtbl -> put_Filename(This,RHS) ) 

#define IGraphic_get_Height(This,RHS)	\
    ( (This)->lpVtbl -> get_Height(This,RHS) ) 

#define IGraphic_put_Height(This,RHS)	\
    ( (This)->lpVtbl -> put_Height(This,RHS) ) 

#define IGraphic_get_LockAspectRatio(This,RHS)	\
    ( (This)->lpVtbl -> get_LockAspectRatio(This,RHS) ) 

#define IGraphic_put_LockAspectRatio(This,RHS)	\
    ( (This)->lpVtbl -> put_LockAspectRatio(This,RHS) ) 

#define IGraphic_get_Width(This,RHS)	\
    ( (This)->lpVtbl -> get_Width(This,RHS) ) 

#define IGraphic_put_Width(This,RHS)	\
    ( (This)->lpVtbl -> put_Width(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IGraphic_INTERFACE_DEFINED__ */


#ifndef __IAutoRecover_INTERFACE_DEFINED__
#define __IAutoRecover_INTERFACE_DEFINED__

/* interface IAutoRecover */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IAutoRecover;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002445A-0001-0000-C000-000000000046")
    IAutoRecover : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Enabled( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Enabled( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Time( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Time( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Path( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Path( 
            /* [in] */ BSTR RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IAutoRecoverVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IAutoRecover * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IAutoRecover * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IAutoRecover * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IAutoRecover * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IAutoRecover * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IAutoRecover * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IAutoRecover * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IAutoRecover * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IAutoRecover * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IAutoRecover * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Enabled )( 
            IAutoRecover * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Enabled )( 
            IAutoRecover * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Time )( 
            IAutoRecover * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Time )( 
            IAutoRecover * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Path )( 
            IAutoRecover * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Path )( 
            IAutoRecover * This,
            /* [in] */ BSTR RHS);
        
        END_INTERFACE
    } IAutoRecoverVtbl;

    interface IAutoRecover
    {
        CONST_VTBL struct IAutoRecoverVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IAutoRecover_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IAutoRecover_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IAutoRecover_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IAutoRecover_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IAutoRecover_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IAutoRecover_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IAutoRecover_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IAutoRecover_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IAutoRecover_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IAutoRecover_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IAutoRecover_get_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> get_Enabled(This,RHS) ) 

#define IAutoRecover_put_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> put_Enabled(This,RHS) ) 

#define IAutoRecover_get_Time(This,RHS)	\
    ( (This)->lpVtbl -> get_Time(This,RHS) ) 

#define IAutoRecover_put_Time(This,RHS)	\
    ( (This)->lpVtbl -> put_Time(This,RHS) ) 

#define IAutoRecover_get_Path(This,RHS)	\
    ( (This)->lpVtbl -> get_Path(This,RHS) ) 

#define IAutoRecover_put_Path(This,RHS)	\
    ( (This)->lpVtbl -> put_Path(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IAutoRecover_INTERFACE_DEFINED__ */


#ifndef __IErrorCheckingOptions_INTERFACE_DEFINED__
#define __IErrorCheckingOptions_INTERFACE_DEFINED__

/* interface IErrorCheckingOptions */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IErrorCheckingOptions;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002445B-0001-0000-C000-000000000046")
    IErrorCheckingOptions : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_BackgroundChecking( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_BackgroundChecking( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_IndicatorColorIndex( 
            /* [retval][out] */ XlColorIndex *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_IndicatorColorIndex( 
            /* [in] */ XlColorIndex RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_EvaluateToError( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_EvaluateToError( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TextDate( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_TextDate( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_NumberAsText( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_NumberAsText( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_InconsistentFormula( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_InconsistentFormula( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_OmittedCells( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_OmittedCells( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_UnlockedFormulaCells( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_UnlockedFormulaCells( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_EmptyCellReferences( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_EmptyCellReferences( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ListDataValidation( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ListDataValidation( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_InconsistentTableFormula( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_InconsistentTableFormula( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IErrorCheckingOptionsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IErrorCheckingOptions * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IErrorCheckingOptions * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IErrorCheckingOptions * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IErrorCheckingOptions * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IErrorCheckingOptions * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IErrorCheckingOptions * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IErrorCheckingOptions * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IErrorCheckingOptions * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IErrorCheckingOptions * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IErrorCheckingOptions * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_BackgroundChecking )( 
            IErrorCheckingOptions * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_BackgroundChecking )( 
            IErrorCheckingOptions * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_IndicatorColorIndex )( 
            IErrorCheckingOptions * This,
            /* [retval][out] */ XlColorIndex *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_IndicatorColorIndex )( 
            IErrorCheckingOptions * This,
            /* [in] */ XlColorIndex RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_EvaluateToError )( 
            IErrorCheckingOptions * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_EvaluateToError )( 
            IErrorCheckingOptions * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TextDate )( 
            IErrorCheckingOptions * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_TextDate )( 
            IErrorCheckingOptions * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_NumberAsText )( 
            IErrorCheckingOptions * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_NumberAsText )( 
            IErrorCheckingOptions * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_InconsistentFormula )( 
            IErrorCheckingOptions * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_InconsistentFormula )( 
            IErrorCheckingOptions * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_OmittedCells )( 
            IErrorCheckingOptions * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_OmittedCells )( 
            IErrorCheckingOptions * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_UnlockedFormulaCells )( 
            IErrorCheckingOptions * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_UnlockedFormulaCells )( 
            IErrorCheckingOptions * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_EmptyCellReferences )( 
            IErrorCheckingOptions * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_EmptyCellReferences )( 
            IErrorCheckingOptions * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ListDataValidation )( 
            IErrorCheckingOptions * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ListDataValidation )( 
            IErrorCheckingOptions * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_InconsistentTableFormula )( 
            IErrorCheckingOptions * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_InconsistentTableFormula )( 
            IErrorCheckingOptions * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        END_INTERFACE
    } IErrorCheckingOptionsVtbl;

    interface IErrorCheckingOptions
    {
        CONST_VTBL struct IErrorCheckingOptionsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IErrorCheckingOptions_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IErrorCheckingOptions_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IErrorCheckingOptions_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IErrorCheckingOptions_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IErrorCheckingOptions_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IErrorCheckingOptions_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IErrorCheckingOptions_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IErrorCheckingOptions_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IErrorCheckingOptions_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IErrorCheckingOptions_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IErrorCheckingOptions_get_BackgroundChecking(This,RHS)	\
    ( (This)->lpVtbl -> get_BackgroundChecking(This,RHS) ) 

#define IErrorCheckingOptions_put_BackgroundChecking(This,RHS)	\
    ( (This)->lpVtbl -> put_BackgroundChecking(This,RHS) ) 

#define IErrorCheckingOptions_get_IndicatorColorIndex(This,RHS)	\
    ( (This)->lpVtbl -> get_IndicatorColorIndex(This,RHS) ) 

#define IErrorCheckingOptions_put_IndicatorColorIndex(This,RHS)	\
    ( (This)->lpVtbl -> put_IndicatorColorIndex(This,RHS) ) 

#define IErrorCheckingOptions_get_EvaluateToError(This,RHS)	\
    ( (This)->lpVtbl -> get_EvaluateToError(This,RHS) ) 

#define IErrorCheckingOptions_put_EvaluateToError(This,RHS)	\
    ( (This)->lpVtbl -> put_EvaluateToError(This,RHS) ) 

#define IErrorCheckingOptions_get_TextDate(This,RHS)	\
    ( (This)->lpVtbl -> get_TextDate(This,RHS) ) 

#define IErrorCheckingOptions_put_TextDate(This,RHS)	\
    ( (This)->lpVtbl -> put_TextDate(This,RHS) ) 

#define IErrorCheckingOptions_get_NumberAsText(This,RHS)	\
    ( (This)->lpVtbl -> get_NumberAsText(This,RHS) ) 

#define IErrorCheckingOptions_put_NumberAsText(This,RHS)	\
    ( (This)->lpVtbl -> put_NumberAsText(This,RHS) ) 

#define IErrorCheckingOptions_get_InconsistentFormula(This,RHS)	\
    ( (This)->lpVtbl -> get_InconsistentFormula(This,RHS) ) 

#define IErrorCheckingOptions_put_InconsistentFormula(This,RHS)	\
    ( (This)->lpVtbl -> put_InconsistentFormula(This,RHS) ) 

#define IErrorCheckingOptions_get_OmittedCells(This,RHS)	\
    ( (This)->lpVtbl -> get_OmittedCells(This,RHS) ) 

#define IErrorCheckingOptions_put_OmittedCells(This,RHS)	\
    ( (This)->lpVtbl -> put_OmittedCells(This,RHS) ) 

#define IErrorCheckingOptions_get_UnlockedFormulaCells(This,RHS)	\
    ( (This)->lpVtbl -> get_UnlockedFormulaCells(This,RHS) ) 

#define IErrorCheckingOptions_put_UnlockedFormulaCells(This,RHS)	\
    ( (This)->lpVtbl -> put_UnlockedFormulaCells(This,RHS) ) 

#define IErrorCheckingOptions_get_EmptyCellReferences(This,RHS)	\
    ( (This)->lpVtbl -> get_EmptyCellReferences(This,RHS) ) 

#define IErrorCheckingOptions_put_EmptyCellReferences(This,RHS)	\
    ( (This)->lpVtbl -> put_EmptyCellReferences(This,RHS) ) 

#define IErrorCheckingOptions_get_ListDataValidation(This,RHS)	\
    ( (This)->lpVtbl -> get_ListDataValidation(This,RHS) ) 

#define IErrorCheckingOptions_put_ListDataValidation(This,RHS)	\
    ( (This)->lpVtbl -> put_ListDataValidation(This,RHS) ) 

#define IErrorCheckingOptions_get_InconsistentTableFormula(This,RHS)	\
    ( (This)->lpVtbl -> get_InconsistentTableFormula(This,RHS) ) 

#define IErrorCheckingOptions_put_InconsistentTableFormula(This,RHS)	\
    ( (This)->lpVtbl -> put_InconsistentTableFormula(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IErrorCheckingOptions_INTERFACE_DEFINED__ */


#ifndef __IErrors_INTERFACE_DEFINED__
#define __IErrors_INTERFACE_DEFINED__

/* interface IErrors */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IErrors;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002445C-0001-0000-C000-000000000046")
    IErrors : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Error	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Error	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IErrorsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IErrors * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IErrors * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IErrors * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IErrors * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IErrors * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IErrors * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IErrors * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IErrors * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IErrors * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IErrors * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Item )( 
            IErrors * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Error	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IErrors * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Error	**RHS);
        
        END_INTERFACE
    } IErrorsVtbl;

    interface IErrors
    {
        CONST_VTBL struct IErrorsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IErrors_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IErrors_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IErrors_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IErrors_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IErrors_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IErrors_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IErrors_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IErrors_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IErrors_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IErrors_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IErrors_get_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Item(This,Index,RHS) ) 

#define IErrors_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IErrors_INTERFACE_DEFINED__ */


#ifndef __IError_INTERFACE_DEFINED__
#define __IError_INTERFACE_DEFINED__

/* interface IError */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IError;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002445D-0001-0000-C000-000000000046")
    IError : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Value( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Ignore( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Ignore( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IErrorVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IError * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IError * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IError * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IError * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IError * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IError * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IError * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IError * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IError * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IError * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Value )( 
            IError * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Ignore )( 
            IError * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Ignore )( 
            IError * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        END_INTERFACE
    } IErrorVtbl;

    interface IError
    {
        CONST_VTBL struct IErrorVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IError_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IError_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IError_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IError_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IError_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IError_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IError_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IError_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IError_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IError_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IError_get_Value(This,RHS)	\
    ( (This)->lpVtbl -> get_Value(This,RHS) ) 

#define IError_get_Ignore(This,RHS)	\
    ( (This)->lpVtbl -> get_Ignore(This,RHS) ) 

#define IError_put_Ignore(This,RHS)	\
    ( (This)->lpVtbl -> put_Ignore(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IError_INTERFACE_DEFINED__ */


#ifndef __ISmartTagAction_INTERFACE_DEFINED__
#define __ISmartTagAction_INTERFACE_DEFINED__

/* interface ISmartTagAction */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ISmartTagAction;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002445E-0001-0000-C000-000000000046")
    ISmartTagAction : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Execute( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Type( 
            /* [retval][out] */ XlSmartTagControlType *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PresentInPane( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ExpandHelp( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ExpandHelp( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CheckboxState( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_CheckboxState( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TextboxText( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_TextboxText( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ListSelection( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ListSelection( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RadioGroupSelection( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_RadioGroupSelection( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ActiveXControl( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ISmartTagActionVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ISmartTagAction * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ISmartTagAction * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ISmartTagAction * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ISmartTagAction * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ISmartTagAction * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ISmartTagAction * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ISmartTagAction * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ISmartTagAction * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ISmartTagAction * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ISmartTagAction * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            ISmartTagAction * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Execute )( 
            ISmartTagAction * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            ISmartTagAction * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Type )( 
            ISmartTagAction * This,
            /* [retval][out] */ XlSmartTagControlType *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PresentInPane )( 
            ISmartTagAction * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ExpandHelp )( 
            ISmartTagAction * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ExpandHelp )( 
            ISmartTagAction * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CheckboxState )( 
            ISmartTagAction * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_CheckboxState )( 
            ISmartTagAction * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TextboxText )( 
            ISmartTagAction * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_TextboxText )( 
            ISmartTagAction * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ListSelection )( 
            ISmartTagAction * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ListSelection )( 
            ISmartTagAction * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RadioGroupSelection )( 
            ISmartTagAction * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_RadioGroupSelection )( 
            ISmartTagAction * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ActiveXControl )( 
            ISmartTagAction * This,
            /* [retval][out] */ IDispatch **RHS);
        
        END_INTERFACE
    } ISmartTagActionVtbl;

    interface ISmartTagAction
    {
        CONST_VTBL struct ISmartTagActionVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ISmartTagAction_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ISmartTagAction_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ISmartTagAction_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ISmartTagAction_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ISmartTagAction_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ISmartTagAction_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ISmartTagAction_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ISmartTagAction_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ISmartTagAction_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ISmartTagAction_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ISmartTagAction_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define ISmartTagAction_Execute(This)	\
    ( (This)->lpVtbl -> Execute(This) ) 

#define ISmartTagAction_get__Default(This,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,RHS) ) 

#define ISmartTagAction_get_Type(This,RHS)	\
    ( (This)->lpVtbl -> get_Type(This,RHS) ) 

#define ISmartTagAction_get_PresentInPane(This,RHS)	\
    ( (This)->lpVtbl -> get_PresentInPane(This,RHS) ) 

#define ISmartTagAction_get_ExpandHelp(This,RHS)	\
    ( (This)->lpVtbl -> get_ExpandHelp(This,RHS) ) 

#define ISmartTagAction_put_ExpandHelp(This,RHS)	\
    ( (This)->lpVtbl -> put_ExpandHelp(This,RHS) ) 

#define ISmartTagAction_get_CheckboxState(This,RHS)	\
    ( (This)->lpVtbl -> get_CheckboxState(This,RHS) ) 

#define ISmartTagAction_put_CheckboxState(This,RHS)	\
    ( (This)->lpVtbl -> put_CheckboxState(This,RHS) ) 

#define ISmartTagAction_get_TextboxText(This,RHS)	\
    ( (This)->lpVtbl -> get_TextboxText(This,RHS) ) 

#define ISmartTagAction_put_TextboxText(This,RHS)	\
    ( (This)->lpVtbl -> put_TextboxText(This,RHS) ) 

#define ISmartTagAction_get_ListSelection(This,RHS)	\
    ( (This)->lpVtbl -> get_ListSelection(This,RHS) ) 

#define ISmartTagAction_put_ListSelection(This,RHS)	\
    ( (This)->lpVtbl -> put_ListSelection(This,RHS) ) 

#define ISmartTagAction_get_RadioGroupSelection(This,RHS)	\
    ( (This)->lpVtbl -> get_RadioGroupSelection(This,RHS) ) 

#define ISmartTagAction_put_RadioGroupSelection(This,RHS)	\
    ( (This)->lpVtbl -> put_RadioGroupSelection(This,RHS) ) 

#define ISmartTagAction_get_ActiveXControl(This,RHS)	\
    ( (This)->lpVtbl -> get_ActiveXControl(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ISmartTagAction_INTERFACE_DEFINED__ */


#ifndef __ISmartTagActions_INTERFACE_DEFINED__
#define __ISmartTagActions_INTERFACE_DEFINED__

/* interface ISmartTagActions */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ISmartTagActions;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002445F-0001-0000-C000-000000000046")
    ISmartTagActions : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ SmartTagAction	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ SmartTagAction	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ISmartTagActionsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ISmartTagActions * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ISmartTagActions * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ISmartTagActions * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ISmartTagActions * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ISmartTagActions * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ISmartTagActions * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ISmartTagActions * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ISmartTagActions * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ISmartTagActions * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ISmartTagActions * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            ISmartTagActions * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            ISmartTagActions * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ SmartTagAction	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Item )( 
            ISmartTagActions * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ SmartTagAction	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            ISmartTagActions * This,
            /* [retval][out] */ IUnknown **RHS);
        
        END_INTERFACE
    } ISmartTagActionsVtbl;

    interface ISmartTagActions
    {
        CONST_VTBL struct ISmartTagActionsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ISmartTagActions_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ISmartTagActions_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ISmartTagActions_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ISmartTagActions_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ISmartTagActions_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ISmartTagActions_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ISmartTagActions_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ISmartTagActions_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ISmartTagActions_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ISmartTagActions_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ISmartTagActions_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define ISmartTagActions_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define ISmartTagActions_get_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Item(This,Index,RHS) ) 

#define ISmartTagActions_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ISmartTagActions_INTERFACE_DEFINED__ */


#ifndef __ISmartTag_INTERFACE_DEFINED__
#define __ISmartTag_INTERFACE_DEFINED__

/* interface ISmartTag */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ISmartTag;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024460-0001-0000-C000-000000000046")
    ISmartTag : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DownloadURL( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_XML( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Range( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SmartTagActions( 
            /* [retval][out] */ SmartTagActions	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Properties( 
            /* [retval][out] */ CustomProperties	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ISmartTagVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ISmartTag * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ISmartTag * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ISmartTag * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ISmartTag * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ISmartTag * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ISmartTag * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ISmartTag * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ISmartTag * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ISmartTag * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ISmartTag * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DownloadURL )( 
            ISmartTag * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            ISmartTag * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            ISmartTag * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_XML )( 
            ISmartTag * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Range )( 
            ISmartTag * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            ISmartTag * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SmartTagActions )( 
            ISmartTag * This,
            /* [retval][out] */ SmartTagActions	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Properties )( 
            ISmartTag * This,
            /* [retval][out] */ CustomProperties	**RHS);
        
        END_INTERFACE
    } ISmartTagVtbl;

    interface ISmartTag
    {
        CONST_VTBL struct ISmartTagVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ISmartTag_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ISmartTag_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ISmartTag_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ISmartTag_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ISmartTag_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ISmartTag_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ISmartTag_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ISmartTag_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ISmartTag_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ISmartTag_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ISmartTag_get_DownloadURL(This,RHS)	\
    ( (This)->lpVtbl -> get_DownloadURL(This,RHS) ) 

#define ISmartTag_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define ISmartTag_get__Default(This,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,RHS) ) 

#define ISmartTag_get_XML(This,RHS)	\
    ( (This)->lpVtbl -> get_XML(This,RHS) ) 

#define ISmartTag_get_Range(This,RHS)	\
    ( (This)->lpVtbl -> get_Range(This,RHS) ) 

#define ISmartTag_Delete(This)	\
    ( (This)->lpVtbl -> Delete(This) ) 

#define ISmartTag_get_SmartTagActions(This,RHS)	\
    ( (This)->lpVtbl -> get_SmartTagActions(This,RHS) ) 

#define ISmartTag_get_Properties(This,RHS)	\
    ( (This)->lpVtbl -> get_Properties(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ISmartTag_INTERFACE_DEFINED__ */


#ifndef __ISmartTags_INTERFACE_DEFINED__
#define __ISmartTags_INTERFACE_DEFINED__

/* interface ISmartTags */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ISmartTags;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024461-0001-0000-C000-000000000046")
    ISmartTags : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add( 
            /* [in] */ BSTR SmartTagType,
            /* [retval][out] */ SmartTag	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ SmartTag	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ISmartTagsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ISmartTags * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ISmartTags * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ISmartTags * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ISmartTags * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ISmartTags * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ISmartTags * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ISmartTags * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ISmartTags * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ISmartTags * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ISmartTags * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add )( 
            ISmartTags * This,
            /* [in] */ BSTR SmartTagType,
            /* [retval][out] */ SmartTag	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            ISmartTags * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            ISmartTags * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ SmartTag	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            ISmartTags * This,
            /* [retval][out] */ IUnknown **RHS);
        
        END_INTERFACE
    } ISmartTagsVtbl;

    interface ISmartTags
    {
        CONST_VTBL struct ISmartTagsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ISmartTags_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ISmartTags_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ISmartTags_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ISmartTags_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ISmartTags_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ISmartTags_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ISmartTags_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ISmartTags_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ISmartTags_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ISmartTags_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ISmartTags_Add(This,SmartTagType,RHS)	\
    ( (This)->lpVtbl -> Add(This,SmartTagType,RHS) ) 

#define ISmartTags_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define ISmartTags_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define ISmartTags_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ISmartTags_INTERFACE_DEFINED__ */


#ifndef __ISmartTagRecognizer_INTERFACE_DEFINED__
#define __ISmartTagRecognizer_INTERFACE_DEFINED__

/* interface ISmartTagRecognizer */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ISmartTagRecognizer;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024462-0001-0000-C000-000000000046")
    ISmartTagRecognizer : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Enabled( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Enabled( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_progID( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_FullName( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ISmartTagRecognizerVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ISmartTagRecognizer * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ISmartTagRecognizer * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ISmartTagRecognizer * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ISmartTagRecognizer * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ISmartTagRecognizer * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ISmartTagRecognizer * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ISmartTagRecognizer * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ISmartTagRecognizer * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ISmartTagRecognizer * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ISmartTagRecognizer * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Enabled )( 
            ISmartTagRecognizer * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Enabled )( 
            ISmartTagRecognizer * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_progID )( 
            ISmartTagRecognizer * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            ISmartTagRecognizer * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_FullName )( 
            ISmartTagRecognizer * This,
            /* [retval][out] */ BSTR *RHS);
        
        END_INTERFACE
    } ISmartTagRecognizerVtbl;

    interface ISmartTagRecognizer
    {
        CONST_VTBL struct ISmartTagRecognizerVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ISmartTagRecognizer_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ISmartTagRecognizer_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ISmartTagRecognizer_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ISmartTagRecognizer_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ISmartTagRecognizer_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ISmartTagRecognizer_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ISmartTagRecognizer_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ISmartTagRecognizer_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ISmartTagRecognizer_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ISmartTagRecognizer_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ISmartTagRecognizer_get_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> get_Enabled(This,RHS) ) 

#define ISmartTagRecognizer_put_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> put_Enabled(This,RHS) ) 

#define ISmartTagRecognizer_get_progID(This,RHS)	\
    ( (This)->lpVtbl -> get_progID(This,RHS) ) 

#define ISmartTagRecognizer_get__Default(This,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,RHS) ) 

#define ISmartTagRecognizer_get_FullName(This,RHS)	\
    ( (This)->lpVtbl -> get_FullName(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ISmartTagRecognizer_INTERFACE_DEFINED__ */


#ifndef __ISmartTagRecognizers_INTERFACE_DEFINED__
#define __ISmartTagRecognizers_INTERFACE_DEFINED__

/* interface ISmartTagRecognizers */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ISmartTagRecognizers;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024463-0001-0000-C000-000000000046")
    ISmartTagRecognizers : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ SmartTagRecognizer	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ SmartTagRecognizer	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Recognize( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Recognize( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ISmartTagRecognizersVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ISmartTagRecognizers * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ISmartTagRecognizers * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ISmartTagRecognizers * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ISmartTagRecognizers * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ISmartTagRecognizers * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ISmartTagRecognizers * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ISmartTagRecognizers * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ISmartTagRecognizers * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ISmartTagRecognizers * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ISmartTagRecognizers * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            ISmartTagRecognizers * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Item )( 
            ISmartTagRecognizers * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ SmartTagRecognizer	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            ISmartTagRecognizers * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ SmartTagRecognizer	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            ISmartTagRecognizers * This,
            /* [retval][out] */ IUnknown **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Recognize )( 
            ISmartTagRecognizers * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Recognize )( 
            ISmartTagRecognizers * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        END_INTERFACE
    } ISmartTagRecognizersVtbl;

    interface ISmartTagRecognizers
    {
        CONST_VTBL struct ISmartTagRecognizersVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ISmartTagRecognizers_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ISmartTagRecognizers_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ISmartTagRecognizers_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ISmartTagRecognizers_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ISmartTagRecognizers_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ISmartTagRecognizers_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ISmartTagRecognizers_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ISmartTagRecognizers_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ISmartTagRecognizers_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ISmartTagRecognizers_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ISmartTagRecognizers_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define ISmartTagRecognizers_get_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Item(This,Index,RHS) ) 

#define ISmartTagRecognizers_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define ISmartTagRecognizers_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#define ISmartTagRecognizers_get_Recognize(This,RHS)	\
    ( (This)->lpVtbl -> get_Recognize(This,RHS) ) 

#define ISmartTagRecognizers_put_Recognize(This,RHS)	\
    ( (This)->lpVtbl -> put_Recognize(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ISmartTagRecognizers_INTERFACE_DEFINED__ */


#ifndef __ISmartTagOptions_INTERFACE_DEFINED__
#define __ISmartTagOptions_INTERFACE_DEFINED__

/* interface ISmartTagOptions */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ISmartTagOptions;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024464-0001-0000-C000-000000000046")
    ISmartTagOptions : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DisplaySmartTags( 
            /* [retval][out] */ XlSmartTagDisplayMode *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DisplaySmartTags( 
            /* [in] */ XlSmartTagDisplayMode RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_EmbedSmartTags( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_EmbedSmartTags( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ISmartTagOptionsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ISmartTagOptions * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ISmartTagOptions * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ISmartTagOptions * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ISmartTagOptions * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ISmartTagOptions * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ISmartTagOptions * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ISmartTagOptions * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ISmartTagOptions * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ISmartTagOptions * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ISmartTagOptions * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DisplaySmartTags )( 
            ISmartTagOptions * This,
            /* [retval][out] */ XlSmartTagDisplayMode *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DisplaySmartTags )( 
            ISmartTagOptions * This,
            /* [in] */ XlSmartTagDisplayMode RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_EmbedSmartTags )( 
            ISmartTagOptions * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_EmbedSmartTags )( 
            ISmartTagOptions * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        END_INTERFACE
    } ISmartTagOptionsVtbl;

    interface ISmartTagOptions
    {
        CONST_VTBL struct ISmartTagOptionsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ISmartTagOptions_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ISmartTagOptions_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ISmartTagOptions_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ISmartTagOptions_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ISmartTagOptions_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ISmartTagOptions_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ISmartTagOptions_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ISmartTagOptions_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ISmartTagOptions_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ISmartTagOptions_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ISmartTagOptions_get_DisplaySmartTags(This,RHS)	\
    ( (This)->lpVtbl -> get_DisplaySmartTags(This,RHS) ) 

#define ISmartTagOptions_put_DisplaySmartTags(This,RHS)	\
    ( (This)->lpVtbl -> put_DisplaySmartTags(This,RHS) ) 

#define ISmartTagOptions_get_EmbedSmartTags(This,RHS)	\
    ( (This)->lpVtbl -> get_EmbedSmartTags(This,RHS) ) 

#define ISmartTagOptions_put_EmbedSmartTags(This,RHS)	\
    ( (This)->lpVtbl -> put_EmbedSmartTags(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ISmartTagOptions_INTERFACE_DEFINED__ */


#ifndef __ISpellingOptions_INTERFACE_DEFINED__
#define __ISpellingOptions_INTERFACE_DEFINED__

/* interface ISpellingOptions */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ISpellingOptions;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024465-0001-0000-C000-000000000046")
    ISpellingOptions : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DictLang( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DictLang( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_UserDict( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_UserDict( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_IgnoreCaps( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_IgnoreCaps( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SuggestMainOnly( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_SuggestMainOnly( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_IgnoreMixedDigits( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_IgnoreMixedDigits( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_IgnoreFileNames( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_IgnoreFileNames( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_GermanPostReform( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_GermanPostReform( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_KoreanCombineAux( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_KoreanCombineAux( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_KoreanUseAutoChangeList( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_KoreanUseAutoChangeList( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_KoreanProcessCompound( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_KoreanProcessCompound( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HebrewModes( 
            /* [retval][out] */ XlHebrewModes *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_HebrewModes( 
            /* [in] */ XlHebrewModes RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ArabicModes( 
            /* [retval][out] */ XlArabicModes *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ArabicModes( 
            /* [in] */ XlArabicModes RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ArabicStrictAlefHamza( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ArabicStrictAlefHamza( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ArabicStrictFinalYaa( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ArabicStrictFinalYaa( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ArabicStrictTaaMarboota( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ArabicStrictTaaMarboota( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RussianStrictE( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_RussianStrictE( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SpanishModes( 
            /* [retval][out] */ XlSpanishModes *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_SpanishModes( 
            /* [in] */ XlSpanishModes RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PortugalReform( 
            /* [retval][out] */ XlPortugueseReform *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PortugalReform( 
            /* [in] */ XlPortugueseReform RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_BrazilReform( 
            /* [retval][out] */ XlPortugueseReform *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_BrazilReform( 
            /* [in] */ XlPortugueseReform RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ISpellingOptionsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ISpellingOptions * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ISpellingOptions * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ISpellingOptions * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ISpellingOptions * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ISpellingOptions * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ISpellingOptions * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ISpellingOptions * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DictLang )( 
            ISpellingOptions * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DictLang )( 
            ISpellingOptions * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_UserDict )( 
            ISpellingOptions * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_UserDict )( 
            ISpellingOptions * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_IgnoreCaps )( 
            ISpellingOptions * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_IgnoreCaps )( 
            ISpellingOptions * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SuggestMainOnly )( 
            ISpellingOptions * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_SuggestMainOnly )( 
            ISpellingOptions * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_IgnoreMixedDigits )( 
            ISpellingOptions * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_IgnoreMixedDigits )( 
            ISpellingOptions * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_IgnoreFileNames )( 
            ISpellingOptions * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_IgnoreFileNames )( 
            ISpellingOptions * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_GermanPostReform )( 
            ISpellingOptions * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_GermanPostReform )( 
            ISpellingOptions * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_KoreanCombineAux )( 
            ISpellingOptions * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_KoreanCombineAux )( 
            ISpellingOptions * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_KoreanUseAutoChangeList )( 
            ISpellingOptions * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_KoreanUseAutoChangeList )( 
            ISpellingOptions * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_KoreanProcessCompound )( 
            ISpellingOptions * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_KoreanProcessCompound )( 
            ISpellingOptions * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HebrewModes )( 
            ISpellingOptions * This,
            /* [retval][out] */ XlHebrewModes *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_HebrewModes )( 
            ISpellingOptions * This,
            /* [in] */ XlHebrewModes RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ArabicModes )( 
            ISpellingOptions * This,
            /* [retval][out] */ XlArabicModes *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ArabicModes )( 
            ISpellingOptions * This,
            /* [in] */ XlArabicModes RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ArabicStrictAlefHamza )( 
            ISpellingOptions * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ArabicStrictAlefHamza )( 
            ISpellingOptions * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ArabicStrictFinalYaa )( 
            ISpellingOptions * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ArabicStrictFinalYaa )( 
            ISpellingOptions * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ArabicStrictTaaMarboota )( 
            ISpellingOptions * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ArabicStrictTaaMarboota )( 
            ISpellingOptions * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RussianStrictE )( 
            ISpellingOptions * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_RussianStrictE )( 
            ISpellingOptions * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SpanishModes )( 
            ISpellingOptions * This,
            /* [retval][out] */ XlSpanishModes *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_SpanishModes )( 
            ISpellingOptions * This,
            /* [in] */ XlSpanishModes RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PortugalReform )( 
            ISpellingOptions * This,
            /* [retval][out] */ XlPortugueseReform *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PortugalReform )( 
            ISpellingOptions * This,
            /* [in] */ XlPortugueseReform RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_BrazilReform )( 
            ISpellingOptions * This,
            /* [retval][out] */ XlPortugueseReform *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_BrazilReform )( 
            ISpellingOptions * This,
            /* [in] */ XlPortugueseReform RHS);
        
        END_INTERFACE
    } ISpellingOptionsVtbl;

    interface ISpellingOptions
    {
        CONST_VTBL struct ISpellingOptionsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ISpellingOptions_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ISpellingOptions_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ISpellingOptions_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ISpellingOptions_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ISpellingOptions_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ISpellingOptions_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ISpellingOptions_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ISpellingOptions_get_DictLang(This,RHS)	\
    ( (This)->lpVtbl -> get_DictLang(This,RHS) ) 

#define ISpellingOptions_put_DictLang(This,RHS)	\
    ( (This)->lpVtbl -> put_DictLang(This,RHS) ) 

#define ISpellingOptions_get_UserDict(This,RHS)	\
    ( (This)->lpVtbl -> get_UserDict(This,RHS) ) 

#define ISpellingOptions_put_UserDict(This,RHS)	\
    ( (This)->lpVtbl -> put_UserDict(This,RHS) ) 

#define ISpellingOptions_get_IgnoreCaps(This,RHS)	\
    ( (This)->lpVtbl -> get_IgnoreCaps(This,RHS) ) 

#define ISpellingOptions_put_IgnoreCaps(This,RHS)	\
    ( (This)->lpVtbl -> put_IgnoreCaps(This,RHS) ) 

#define ISpellingOptions_get_SuggestMainOnly(This,RHS)	\
    ( (This)->lpVtbl -> get_SuggestMainOnly(This,RHS) ) 

#define ISpellingOptions_put_SuggestMainOnly(This,RHS)	\
    ( (This)->lpVtbl -> put_SuggestMainOnly(This,RHS) ) 

#define ISpellingOptions_get_IgnoreMixedDigits(This,RHS)	\
    ( (This)->lpVtbl -> get_IgnoreMixedDigits(This,RHS) ) 

#define ISpellingOptions_put_IgnoreMixedDigits(This,RHS)	\
    ( (This)->lpVtbl -> put_IgnoreMixedDigits(This,RHS) ) 

#define ISpellingOptions_get_IgnoreFileNames(This,RHS)	\
    ( (This)->lpVtbl -> get_IgnoreFileNames(This,RHS) ) 

#define ISpellingOptions_put_IgnoreFileNames(This,RHS)	\
    ( (This)->lpVtbl -> put_IgnoreFileNames(This,RHS) ) 

#define ISpellingOptions_get_GermanPostReform(This,RHS)	\
    ( (This)->lpVtbl -> get_GermanPostReform(This,RHS) ) 

#define ISpellingOptions_put_GermanPostReform(This,RHS)	\
    ( (This)->lpVtbl -> put_GermanPostReform(This,RHS) ) 

#define ISpellingOptions_get_KoreanCombineAux(This,RHS)	\
    ( (This)->lpVtbl -> get_KoreanCombineAux(This,RHS) ) 

#define ISpellingOptions_put_KoreanCombineAux(This,RHS)	\
    ( (This)->lpVtbl -> put_KoreanCombineAux(This,RHS) ) 

#define ISpellingOptions_get_KoreanUseAutoChangeList(This,RHS)	\
    ( (This)->lpVtbl -> get_KoreanUseAutoChangeList(This,RHS) ) 

#define ISpellingOptions_put_KoreanUseAutoChangeList(This,RHS)	\
    ( (This)->lpVtbl -> put_KoreanUseAutoChangeList(This,RHS) ) 

#define ISpellingOptions_get_KoreanProcessCompound(This,RHS)	\
    ( (This)->lpVtbl -> get_KoreanProcessCompound(This,RHS) ) 

#define ISpellingOptions_put_KoreanProcessCompound(This,RHS)	\
    ( (This)->lpVtbl -> put_KoreanProcessCompound(This,RHS) ) 

#define ISpellingOptions_get_HebrewModes(This,RHS)	\
    ( (This)->lpVtbl -> get_HebrewModes(This,RHS) ) 

#define ISpellingOptions_put_HebrewModes(This,RHS)	\
    ( (This)->lpVtbl -> put_HebrewModes(This,RHS) ) 

#define ISpellingOptions_get_ArabicModes(This,RHS)	\
    ( (This)->lpVtbl -> get_ArabicModes(This,RHS) ) 

#define ISpellingOptions_put_ArabicModes(This,RHS)	\
    ( (This)->lpVtbl -> put_ArabicModes(This,RHS) ) 

#define ISpellingOptions_get_ArabicStrictAlefHamza(This,RHS)	\
    ( (This)->lpVtbl -> get_ArabicStrictAlefHamza(This,RHS) ) 

#define ISpellingOptions_put_ArabicStrictAlefHamza(This,RHS)	\
    ( (This)->lpVtbl -> put_ArabicStrictAlefHamza(This,RHS) ) 

#define ISpellingOptions_get_ArabicStrictFinalYaa(This,RHS)	\
    ( (This)->lpVtbl -> get_ArabicStrictFinalYaa(This,RHS) ) 

#define ISpellingOptions_put_ArabicStrictFinalYaa(This,RHS)	\
    ( (This)->lpVtbl -> put_ArabicStrictFinalYaa(This,RHS) ) 

#define ISpellingOptions_get_ArabicStrictTaaMarboota(This,RHS)	\
    ( (This)->lpVtbl -> get_ArabicStrictTaaMarboota(This,RHS) ) 

#define ISpellingOptions_put_ArabicStrictTaaMarboota(This,RHS)	\
    ( (This)->lpVtbl -> put_ArabicStrictTaaMarboota(This,RHS) ) 

#define ISpellingOptions_get_RussianStrictE(This,RHS)	\
    ( (This)->lpVtbl -> get_RussianStrictE(This,RHS) ) 

#define ISpellingOptions_put_RussianStrictE(This,RHS)	\
    ( (This)->lpVtbl -> put_RussianStrictE(This,RHS) ) 

#define ISpellingOptions_get_SpanishModes(This,RHS)	\
    ( (This)->lpVtbl -> get_SpanishModes(This,RHS) ) 

#define ISpellingOptions_put_SpanishModes(This,RHS)	\
    ( (This)->lpVtbl -> put_SpanishModes(This,RHS) ) 

#define ISpellingOptions_get_PortugalReform(This,RHS)	\
    ( (This)->lpVtbl -> get_PortugalReform(This,RHS) ) 

#define ISpellingOptions_put_PortugalReform(This,RHS)	\
    ( (This)->lpVtbl -> put_PortugalReform(This,RHS) ) 

#define ISpellingOptions_get_BrazilReform(This,RHS)	\
    ( (This)->lpVtbl -> get_BrazilReform(This,RHS) ) 

#define ISpellingOptions_put_BrazilReform(This,RHS)	\
    ( (This)->lpVtbl -> put_BrazilReform(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ISpellingOptions_INTERFACE_DEFINED__ */


#ifndef __ISpeech_INTERFACE_DEFINED__
#define __ISpeech_INTERFACE_DEFINED__

/* interface ISpeech */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ISpeech;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024466-0001-0000-C000-000000000046")
    ISpeech : public IDispatch
    {
    public:
        virtual /* [helpcontext][id] */ HRESULT __stdcall Speak( 
            /* [in] */ BSTR Text,
            /* [optional][in] */ VARIANT SpeakAsync,
            /* [optional][in] */ VARIANT SpeakXML,
            /* [optional][in] */ VARIANT Purge) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Direction( 
            /* [retval][out] */ XlSpeakDirection *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Direction( 
            /* [in] */ XlSpeakDirection RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SpeakCellOnEnter( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_SpeakCellOnEnter( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ISpeechVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ISpeech * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ISpeech * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ISpeech * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ISpeech * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ISpeech * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ISpeech * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ISpeech * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Speak )( 
            ISpeech * This,
            /* [in] */ BSTR Text,
            /* [optional][in] */ VARIANT SpeakAsync,
            /* [optional][in] */ VARIANT SpeakXML,
            /* [optional][in] */ VARIANT Purge);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Direction )( 
            ISpeech * This,
            /* [retval][out] */ XlSpeakDirection *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Direction )( 
            ISpeech * This,
            /* [in] */ XlSpeakDirection RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SpeakCellOnEnter )( 
            ISpeech * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_SpeakCellOnEnter )( 
            ISpeech * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        END_INTERFACE
    } ISpeechVtbl;

    interface ISpeech
    {
        CONST_VTBL struct ISpeechVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ISpeech_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ISpeech_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ISpeech_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ISpeech_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ISpeech_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ISpeech_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ISpeech_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ISpeech_Speak(This,Text,SpeakAsync,SpeakXML,Purge)	\
    ( (This)->lpVtbl -> Speak(This,Text,SpeakAsync,SpeakXML,Purge) ) 

#define ISpeech_get_Direction(This,RHS)	\
    ( (This)->lpVtbl -> get_Direction(This,RHS) ) 

#define ISpeech_put_Direction(This,RHS)	\
    ( (This)->lpVtbl -> put_Direction(This,RHS) ) 

#define ISpeech_get_SpeakCellOnEnter(This,RHS)	\
    ( (This)->lpVtbl -> get_SpeakCellOnEnter(This,RHS) ) 

#define ISpeech_put_SpeakCellOnEnter(This,RHS)	\
    ( (This)->lpVtbl -> put_SpeakCellOnEnter(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ISpeech_INTERFACE_DEFINED__ */


#ifndef __IProtection_INTERFACE_DEFINED__
#define __IProtection_INTERFACE_DEFINED__

/* interface IProtection */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IProtection;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024467-0001-0000-C000-000000000046")
    IProtection : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AllowFormattingCells( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AllowFormattingColumns( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AllowFormattingRows( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AllowInsertingColumns( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AllowInsertingRows( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AllowInsertingHyperlinks( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AllowDeletingColumns( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AllowDeletingRows( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AllowSorting( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AllowFiltering( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AllowUsingPivotTables( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AllowEditRanges( 
            /* [retval][out] */ AllowEditRanges	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IProtectionVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IProtection * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IProtection * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IProtection * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IProtection * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IProtection * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IProtection * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IProtection * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AllowFormattingCells )( 
            IProtection * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AllowFormattingColumns )( 
            IProtection * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AllowFormattingRows )( 
            IProtection * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AllowInsertingColumns )( 
            IProtection * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AllowInsertingRows )( 
            IProtection * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AllowInsertingHyperlinks )( 
            IProtection * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AllowDeletingColumns )( 
            IProtection * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AllowDeletingRows )( 
            IProtection * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AllowSorting )( 
            IProtection * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AllowFiltering )( 
            IProtection * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AllowUsingPivotTables )( 
            IProtection * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AllowEditRanges )( 
            IProtection * This,
            /* [retval][out] */ AllowEditRanges	**RHS);
        
        END_INTERFACE
    } IProtectionVtbl;

    interface IProtection
    {
        CONST_VTBL struct IProtectionVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IProtection_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IProtection_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IProtection_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IProtection_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IProtection_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IProtection_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IProtection_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IProtection_get_AllowFormattingCells(This,RHS)	\
    ( (This)->lpVtbl -> get_AllowFormattingCells(This,RHS) ) 

#define IProtection_get_AllowFormattingColumns(This,RHS)	\
    ( (This)->lpVtbl -> get_AllowFormattingColumns(This,RHS) ) 

#define IProtection_get_AllowFormattingRows(This,RHS)	\
    ( (This)->lpVtbl -> get_AllowFormattingRows(This,RHS) ) 

#define IProtection_get_AllowInsertingColumns(This,RHS)	\
    ( (This)->lpVtbl -> get_AllowInsertingColumns(This,RHS) ) 

#define IProtection_get_AllowInsertingRows(This,RHS)	\
    ( (This)->lpVtbl -> get_AllowInsertingRows(This,RHS) ) 

#define IProtection_get_AllowInsertingHyperlinks(This,RHS)	\
    ( (This)->lpVtbl -> get_AllowInsertingHyperlinks(This,RHS) ) 

#define IProtection_get_AllowDeletingColumns(This,RHS)	\
    ( (This)->lpVtbl -> get_AllowDeletingColumns(This,RHS) ) 

#define IProtection_get_AllowDeletingRows(This,RHS)	\
    ( (This)->lpVtbl -> get_AllowDeletingRows(This,RHS) ) 

#define IProtection_get_AllowSorting(This,RHS)	\
    ( (This)->lpVtbl -> get_AllowSorting(This,RHS) ) 

#define IProtection_get_AllowFiltering(This,RHS)	\
    ( (This)->lpVtbl -> get_AllowFiltering(This,RHS) ) 

#define IProtection_get_AllowUsingPivotTables(This,RHS)	\
    ( (This)->lpVtbl -> get_AllowUsingPivotTables(This,RHS) ) 

#define IProtection_get_AllowEditRanges(This,RHS)	\
    ( (This)->lpVtbl -> get_AllowEditRanges(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IProtection_INTERFACE_DEFINED__ */


#ifndef __IPivotItemList_INTERFACE_DEFINED__
#define __IPivotItemList_INTERFACE_DEFINED__

/* interface IPivotItemList */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IPivotItemList;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024468-0001-0000-C000-000000000046")
    IPivotItemList : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ PivotItem	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Field,
            /* [retval][out] */ PivotItem	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall _NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IPivotItemListVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IPivotItemList * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IPivotItemList * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IPivotItemList * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IPivotItemList * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IPivotItemList * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IPivotItemList * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IPivotItemList * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IPivotItemList * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IPivotItemList * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IPivotItemList * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IPivotItemList * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Item )( 
            IPivotItemList * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ PivotItem	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IPivotItemList * This,
            /* [in] */ VARIANT Field,
            /* [retval][out] */ PivotItem	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *_NewEnum )( 
            IPivotItemList * This,
            /* [retval][out] */ IUnknown **RHS);
        
        END_INTERFACE
    } IPivotItemListVtbl;

    interface IPivotItemList
    {
        CONST_VTBL struct IPivotItemListVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IPivotItemList_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IPivotItemList_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IPivotItemList_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IPivotItemList_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IPivotItemList_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IPivotItemList_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IPivotItemList_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IPivotItemList_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IPivotItemList_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IPivotItemList_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IPivotItemList_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IPivotItemList_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> Item(This,Index,RHS) ) 

#define IPivotItemList_get__Default(This,Field,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Field,RHS) ) 

#define IPivotItemList__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> _NewEnum(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IPivotItemList_INTERFACE_DEFINED__ */


#ifndef __ITab_INTERFACE_DEFINED__
#define __ITab_INTERFACE_DEFINED__

/* interface ITab */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ITab;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024469-0001-0000-C000-000000000046")
    ITab : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Color( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Color( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ColorIndex( 
            /* [retval][out] */ XlColorIndex *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ColorIndex( 
            /* [in] */ XlColorIndex RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ThemeColor( 
            /* [retval][out] */ XlThemeColor *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ThemeColor( 
            /* [in] */ XlThemeColor RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TintAndShade( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_TintAndShade( 
            /* [in] */ VARIANT RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ITabVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ITab * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ITab * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ITab * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ITab * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ITab * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ITab * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ITab * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ITab * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ITab * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ITab * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Color )( 
            ITab * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Color )( 
            ITab * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ColorIndex )( 
            ITab * This,
            /* [retval][out] */ XlColorIndex *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ColorIndex )( 
            ITab * This,
            /* [in] */ XlColorIndex RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ThemeColor )( 
            ITab * This,
            /* [retval][out] */ XlThemeColor *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ThemeColor )( 
            ITab * This,
            /* [in] */ XlThemeColor RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TintAndShade )( 
            ITab * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_TintAndShade )( 
            ITab * This,
            /* [in] */ VARIANT RHS);
        
        END_INTERFACE
    } ITabVtbl;

    interface ITab
    {
        CONST_VTBL struct ITabVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ITab_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ITab_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ITab_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ITab_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ITab_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ITab_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ITab_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ITab_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ITab_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ITab_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ITab_get_Color(This,RHS)	\
    ( (This)->lpVtbl -> get_Color(This,RHS) ) 

#define ITab_put_Color(This,RHS)	\
    ( (This)->lpVtbl -> put_Color(This,RHS) ) 

#define ITab_get_ColorIndex(This,RHS)	\
    ( (This)->lpVtbl -> get_ColorIndex(This,RHS) ) 

#define ITab_put_ColorIndex(This,RHS)	\
    ( (This)->lpVtbl -> put_ColorIndex(This,RHS) ) 

#define ITab_get_ThemeColor(This,RHS)	\
    ( (This)->lpVtbl -> get_ThemeColor(This,RHS) ) 

#define ITab_put_ThemeColor(This,RHS)	\
    ( (This)->lpVtbl -> put_ThemeColor(This,RHS) ) 

#define ITab_get_TintAndShade(This,RHS)	\
    ( (This)->lpVtbl -> get_TintAndShade(This,RHS) ) 

#define ITab_put_TintAndShade(This,RHS)	\
    ( (This)->lpVtbl -> put_TintAndShade(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ITab_INTERFACE_DEFINED__ */


#ifndef __IAllowEditRanges_INTERFACE_DEFINED__
#define __IAllowEditRanges_INTERFACE_DEFINED__

/* interface IAllowEditRanges */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IAllowEditRanges;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002446A-0001-0000-C000-000000000046")
    IAllowEditRanges : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ AllowEditRange	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add( 
            /* [in] */ BSTR Title,
            /* [in] */ Range	*Range,
            /* [optional][in] */ VARIANT Password,
            /* [retval][out] */ AllowEditRange	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ AllowEditRange	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IAllowEditRangesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IAllowEditRanges * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IAllowEditRanges * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IAllowEditRanges * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IAllowEditRanges * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IAllowEditRanges * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IAllowEditRanges * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IAllowEditRanges * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IAllowEditRanges * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Item )( 
            IAllowEditRanges * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ AllowEditRange	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add )( 
            IAllowEditRanges * This,
            /* [in] */ BSTR Title,
            /* [in] */ Range	*Range,
            /* [optional][in] */ VARIANT Password,
            /* [retval][out] */ AllowEditRange	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IAllowEditRanges * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ AllowEditRange	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            IAllowEditRanges * This,
            /* [retval][out] */ IUnknown **RHS);
        
        END_INTERFACE
    } IAllowEditRangesVtbl;

    interface IAllowEditRanges
    {
        CONST_VTBL struct IAllowEditRangesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IAllowEditRanges_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IAllowEditRanges_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IAllowEditRanges_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IAllowEditRanges_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IAllowEditRanges_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IAllowEditRanges_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IAllowEditRanges_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IAllowEditRanges_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IAllowEditRanges_get_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Item(This,Index,RHS) ) 

#define IAllowEditRanges_Add(This,Title,Range,Password,RHS)	\
    ( (This)->lpVtbl -> Add(This,Title,Range,Password,RHS) ) 

#define IAllowEditRanges_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define IAllowEditRanges_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IAllowEditRanges_INTERFACE_DEFINED__ */


#ifndef __IAllowEditRange_INTERFACE_DEFINED__
#define __IAllowEditRange_INTERFACE_DEFINED__

/* interface IAllowEditRange */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IAllowEditRange;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002446B-0001-0000-C000-000000000046")
    IAllowEditRange : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Title( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Title( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Range( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propputref][id] */ HRESULT __stdcall putref_Range( 
            /* [in] */ Range	*RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ChangePassword( 
            /* [in] */ BSTR Password) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Unprotect( 
            /* [optional][in] */ VARIANT Password) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Users( 
            /* [retval][out] */ UserAccessList	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IAllowEditRangeVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IAllowEditRange * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IAllowEditRange * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IAllowEditRange * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IAllowEditRange * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IAllowEditRange * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IAllowEditRange * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IAllowEditRange * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Title )( 
            IAllowEditRange * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Title )( 
            IAllowEditRange * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Range )( 
            IAllowEditRange * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propputref][id] */ HRESULT ( __stdcall *putref_Range )( 
            IAllowEditRange * This,
            /* [in] */ Range	*RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ChangePassword )( 
            IAllowEditRange * This,
            /* [in] */ BSTR Password);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IAllowEditRange * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Unprotect )( 
            IAllowEditRange * This,
            /* [optional][in] */ VARIANT Password);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Users )( 
            IAllowEditRange * This,
            /* [retval][out] */ UserAccessList	**RHS);
        
        END_INTERFACE
    } IAllowEditRangeVtbl;

    interface IAllowEditRange
    {
        CONST_VTBL struct IAllowEditRangeVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IAllowEditRange_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IAllowEditRange_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IAllowEditRange_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IAllowEditRange_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IAllowEditRange_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IAllowEditRange_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IAllowEditRange_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IAllowEditRange_get_Title(This,RHS)	\
    ( (This)->lpVtbl -> get_Title(This,RHS) ) 

#define IAllowEditRange_put_Title(This,RHS)	\
    ( (This)->lpVtbl -> put_Title(This,RHS) ) 

#define IAllowEditRange_get_Range(This,RHS)	\
    ( (This)->lpVtbl -> get_Range(This,RHS) ) 

#define IAllowEditRange_putref_Range(This,RHS)	\
    ( (This)->lpVtbl -> putref_Range(This,RHS) ) 

#define IAllowEditRange_ChangePassword(This,Password)	\
    ( (This)->lpVtbl -> ChangePassword(This,Password) ) 

#define IAllowEditRange_Delete(This)	\
    ( (This)->lpVtbl -> Delete(This) ) 

#define IAllowEditRange_Unprotect(This,Password)	\
    ( (This)->lpVtbl -> Unprotect(This,Password) ) 

#define IAllowEditRange_get_Users(This,RHS)	\
    ( (This)->lpVtbl -> get_Users(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IAllowEditRange_INTERFACE_DEFINED__ */


#ifndef __IUserAccessList_INTERFACE_DEFINED__
#define __IUserAccessList_INTERFACE_DEFINED__

/* interface IUserAccessList */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IUserAccessList;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002446C-0001-0000-C000-000000000046")
    IUserAccessList : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ UserAccess	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add( 
            /* [in] */ BSTR Name,
            /* [in] */ VARIANT_BOOL AllowEdit,
            /* [retval][out] */ UserAccess	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall DeleteAll( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ UserAccess	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IUserAccessListVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IUserAccessList * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IUserAccessList * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IUserAccessList * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IUserAccessList * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IUserAccessList * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IUserAccessList * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IUserAccessList * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IUserAccessList * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Item )( 
            IUserAccessList * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ UserAccess	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add )( 
            IUserAccessList * This,
            /* [in] */ BSTR Name,
            /* [in] */ VARIANT_BOOL AllowEdit,
            /* [retval][out] */ UserAccess	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *DeleteAll )( 
            IUserAccessList * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IUserAccessList * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ UserAccess	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            IUserAccessList * This,
            /* [retval][out] */ IUnknown **RHS);
        
        END_INTERFACE
    } IUserAccessListVtbl;

    interface IUserAccessList
    {
        CONST_VTBL struct IUserAccessListVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IUserAccessList_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IUserAccessList_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IUserAccessList_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IUserAccessList_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IUserAccessList_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IUserAccessList_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IUserAccessList_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IUserAccessList_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IUserAccessList_get_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Item(This,Index,RHS) ) 

#define IUserAccessList_Add(This,Name,AllowEdit,RHS)	\
    ( (This)->lpVtbl -> Add(This,Name,AllowEdit,RHS) ) 

#define IUserAccessList_DeleteAll(This)	\
    ( (This)->lpVtbl -> DeleteAll(This) ) 

#define IUserAccessList_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define IUserAccessList_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IUserAccessList_INTERFACE_DEFINED__ */


#ifndef __IUserAccess_INTERFACE_DEFINED__
#define __IUserAccess_INTERFACE_DEFINED__

/* interface IUserAccess */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IUserAccess;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002446D-0001-0000-C000-000000000046")
    IUserAccess : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AllowEdit( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AllowEdit( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( void) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IUserAccessVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IUserAccess * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IUserAccess * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IUserAccess * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IUserAccess * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IUserAccess * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IUserAccess * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IUserAccess * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            IUserAccess * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AllowEdit )( 
            IUserAccess * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AllowEdit )( 
            IUserAccess * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IUserAccess * This);
        
        END_INTERFACE
    } IUserAccessVtbl;

    interface IUserAccess
    {
        CONST_VTBL struct IUserAccessVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IUserAccess_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IUserAccess_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IUserAccess_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IUserAccess_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IUserAccess_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IUserAccess_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IUserAccess_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IUserAccess_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define IUserAccess_get_AllowEdit(This,RHS)	\
    ( (This)->lpVtbl -> get_AllowEdit(This,RHS) ) 

#define IUserAccess_put_AllowEdit(This,RHS)	\
    ( (This)->lpVtbl -> put_AllowEdit(This,RHS) ) 

#define IUserAccess_Delete(This)	\
    ( (This)->lpVtbl -> Delete(This) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IUserAccess_INTERFACE_DEFINED__ */


#ifndef __IRTD_INTERFACE_DEFINED__
#define __IRTD_INTERFACE_DEFINED__

/* interface IRTD */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IRTD;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002446E-0001-0000-C000-000000000046")
    IRTD : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ThrottleInterval( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ThrottleInterval( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall RefreshData( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall RestartServers( void) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IRTDVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IRTD * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IRTD * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IRTD * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IRTD * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IRTD * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IRTD * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IRTD * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ThrottleInterval )( 
            IRTD * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ThrottleInterval )( 
            IRTD * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *RefreshData )( 
            IRTD * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *RestartServers )( 
            IRTD * This);
        
        END_INTERFACE
    } IRTDVtbl;

    interface IRTD
    {
        CONST_VTBL struct IRTDVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IRTD_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IRTD_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IRTD_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IRTD_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IRTD_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IRTD_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IRTD_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IRTD_get_ThrottleInterval(This,RHS)	\
    ( (This)->lpVtbl -> get_ThrottleInterval(This,RHS) ) 

#define IRTD_put_ThrottleInterval(This,RHS)	\
    ( (This)->lpVtbl -> put_ThrottleInterval(This,RHS) ) 

#define IRTD_RefreshData(This)	\
    ( (This)->lpVtbl -> RefreshData(This) ) 

#define IRTD_RestartServers(This)	\
    ( (This)->lpVtbl -> RestartServers(This) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IRTD_INTERFACE_DEFINED__ */


#ifndef __IDiagram_INTERFACE_DEFINED__
#define __IDiagram_INTERFACE_DEFINED__

/* interface IDiagram */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IDiagram;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002446F-0001-0000-C000-000000000046")
    IDiagram : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Nodes( 
            /* [retval][out] */ DiagramNodes **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Type( 
            /* [retval][out] */ MsoDiagramType *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AutoLayout( 
            /* [retval][out] */ MsoTriState *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AutoLayout( 
            /* [in] */ MsoTriState RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Reverse( 
            /* [retval][out] */ MsoTriState *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Reverse( 
            /* [in] */ MsoTriState RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AutoFormat( 
            /* [retval][out] */ MsoTriState *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AutoFormat( 
            /* [in] */ MsoTriState RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Convert( 
            /* [in] */ MsoDiagramType Type) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall FitText( void) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IDiagramVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IDiagram * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IDiagram * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IDiagram * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IDiagram * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IDiagram * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IDiagram * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IDiagram * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IDiagram * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IDiagram * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IDiagram * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Nodes )( 
            IDiagram * This,
            /* [retval][out] */ DiagramNodes **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Type )( 
            IDiagram * This,
            /* [retval][out] */ MsoDiagramType *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AutoLayout )( 
            IDiagram * This,
            /* [retval][out] */ MsoTriState *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AutoLayout )( 
            IDiagram * This,
            /* [in] */ MsoTriState RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Reverse )( 
            IDiagram * This,
            /* [retval][out] */ MsoTriState *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Reverse )( 
            IDiagram * This,
            /* [in] */ MsoTriState RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AutoFormat )( 
            IDiagram * This,
            /* [retval][out] */ MsoTriState *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AutoFormat )( 
            IDiagram * This,
            /* [in] */ MsoTriState RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Convert )( 
            IDiagram * This,
            /* [in] */ MsoDiagramType Type);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *FitText )( 
            IDiagram * This);
        
        END_INTERFACE
    } IDiagramVtbl;

    interface IDiagram
    {
        CONST_VTBL struct IDiagramVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IDiagram_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IDiagram_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IDiagram_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IDiagram_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IDiagram_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IDiagram_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IDiagram_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IDiagram_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IDiagram_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IDiagram_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IDiagram_get_Nodes(This,RHS)	\
    ( (This)->lpVtbl -> get_Nodes(This,RHS) ) 

#define IDiagram_get_Type(This,RHS)	\
    ( (This)->lpVtbl -> get_Type(This,RHS) ) 

#define IDiagram_get_AutoLayout(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoLayout(This,RHS) ) 

#define IDiagram_put_AutoLayout(This,RHS)	\
    ( (This)->lpVtbl -> put_AutoLayout(This,RHS) ) 

#define IDiagram_get_Reverse(This,RHS)	\
    ( (This)->lpVtbl -> get_Reverse(This,RHS) ) 

#define IDiagram_put_Reverse(This,RHS)	\
    ( (This)->lpVtbl -> put_Reverse(This,RHS) ) 

#define IDiagram_get_AutoFormat(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoFormat(This,RHS) ) 

#define IDiagram_put_AutoFormat(This,RHS)	\
    ( (This)->lpVtbl -> put_AutoFormat(This,RHS) ) 

#define IDiagram_Convert(This,Type)	\
    ( (This)->lpVtbl -> Convert(This,Type) ) 

#define IDiagram_FitText(This)	\
    ( (This)->lpVtbl -> FitText(This) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IDiagram_INTERFACE_DEFINED__ */


#ifndef __IListObjects_INTERFACE_DEFINED__
#define __IListObjects_INTERFACE_DEFINED__

/* interface IListObjects */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IListObjects;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024470-0001-0000-C000-000000000046")
    IListObjects : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [custom][helpcontext][hidden][id] */ HRESULT __stdcall _Add( 
            /* [defaultvalue][optional][in] */ XlListObjectSourceType SourceType,
            /* [optional][in] */ VARIANT Source,
            /* [optional][in] */ VARIANT LinkSource,
            /* [defaultvalue][optional][in] */ XlYesNoGuess XlListObjectHasHeaders,
            /* [optional][in] */ VARIANT Destination,
            /* [retval][out] */ ListObject	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ ListObject	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ ListObject	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [custom][helpcontext][id] */ HRESULT __stdcall Add( 
            /* [defaultvalue][optional][in] */ XlListObjectSourceType SourceType,
            /* [optional][in] */ VARIANT Source,
            /* [optional][in] */ VARIANT LinkSource,
            /* [defaultvalue][optional][in] */ XlYesNoGuess XlListObjectHasHeaders,
            /* [optional][in] */ VARIANT Destination,
            /* [optional][in] */ VARIANT TableStyleName,
            /* [retval][out] */ ListObject	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IListObjectsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IListObjects * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IListObjects * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IListObjects * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IListObjects * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IListObjects * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IListObjects * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IListObjects * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IListObjects * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IListObjects * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IListObjects * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [custom][helpcontext][hidden][id] */ HRESULT ( __stdcall *_Add )( 
            IListObjects * This,
            /* [defaultvalue][optional][in] */ XlListObjectSourceType SourceType,
            /* [optional][in] */ VARIANT Source,
            /* [optional][in] */ VARIANT LinkSource,
            /* [defaultvalue][optional][in] */ XlYesNoGuess XlListObjectHasHeaders,
            /* [optional][in] */ VARIANT Destination,
            /* [retval][out] */ ListObject	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IListObjects * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ ListObject	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            IListObjects * This,
            /* [retval][out] */ IUnknown **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Item )( 
            IListObjects * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ ListObject	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IListObjects * This,
            /* [retval][out] */ long *RHS);
        
        /* [custom][helpcontext][id] */ HRESULT ( __stdcall *Add )( 
            IListObjects * This,
            /* [defaultvalue][optional][in] */ XlListObjectSourceType SourceType,
            /* [optional][in] */ VARIANT Source,
            /* [optional][in] */ VARIANT LinkSource,
            /* [defaultvalue][optional][in] */ XlYesNoGuess XlListObjectHasHeaders,
            /* [optional][in] */ VARIANT Destination,
            /* [optional][in] */ VARIANT TableStyleName,
            /* [retval][out] */ ListObject	**RHS);
        
        END_INTERFACE
    } IListObjectsVtbl;

    interface IListObjects
    {
        CONST_VTBL struct IListObjectsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IListObjects_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IListObjects_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IListObjects_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IListObjects_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IListObjects_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IListObjects_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IListObjects_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IListObjects_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IListObjects_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IListObjects_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IListObjects__Add(This,SourceType,Source,LinkSource,XlListObjectHasHeaders,Destination,RHS)	\
    ( (This)->lpVtbl -> _Add(This,SourceType,Source,LinkSource,XlListObjectHasHeaders,Destination,RHS) ) 

#define IListObjects_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define IListObjects_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#define IListObjects_get_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Item(This,Index,RHS) ) 

#define IListObjects_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IListObjects_Add(This,SourceType,Source,LinkSource,XlListObjectHasHeaders,Destination,TableStyleName,RHS)	\
    ( (This)->lpVtbl -> Add(This,SourceType,Source,LinkSource,XlListObjectHasHeaders,Destination,TableStyleName,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IListObjects_INTERFACE_DEFINED__ */


#ifndef __IListObject_INTERFACE_DEFINED__
#define __IListObject_INTERFACE_DEFINED__

/* interface IListObject */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IListObject;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024471-0001-0000-C000-000000000046")
    IListObject : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Publish( 
            /* [in] */ VARIANT Target,
            /* [in] */ VARIANT_BOOL LinkSource,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Refresh( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Unlink( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Unlist( void) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall UpdateChanges( 
            /* [defaultvalue][optional][in] */ XlListConflict iConflictType = xlListConflictDialog) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Resize( 
            /* [in] */ Range	*Range) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Active( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DataBodyRange( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DisplayRightToLeft( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HeaderRowRange( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_InsertRowRange( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ListColumns( 
            /* [retval][out] */ ListColumns	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ListRows( 
            /* [retval][out] */ ListRows	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Name( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_QueryTable( 
            /* [retval][out] */ QueryTable	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Range( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShowAutoFilter( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ShowAutoFilter( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShowTotals( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ShowTotals( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SourceType( 
            /* [retval][out] */ XlListObjectSourceType *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TotalsRowRange( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SharePointURL( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_XmlMap( 
            /* [retval][out] */ XmlMap	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DisplayName( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DisplayName( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShowHeaders( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ShowHeaders( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AutoFilter( 
            /* [retval][out] */ AutoFilter	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TableStyle( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_TableStyle( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShowTableStyleFirstColumn( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ShowTableStyleFirstColumn( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShowTableStyleLastColumn( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ShowTableStyleLastColumn( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShowTableStyleRowStripes( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ShowTableStyleRowStripes( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShowTableStyleColumnStripes( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ShowTableStyleColumnStripes( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Sort( 
            /* [retval][out] */ Sort	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Comment( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Comment( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ExportToVisio( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AlternativeText( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AlternativeText( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Summary( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Summary( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TableObject( 
            /* [retval][out] */ TableObject	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Slicers( 
            /* [retval][out] */ Slicers	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShowAutoFilterDropDown( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ShowAutoFilterDropDown( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IListObjectVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IListObject * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IListObject * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IListObject * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IListObject * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IListObject * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IListObject * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IListObject * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IListObject * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IListObject * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IListObject * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IListObject * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Publish )( 
            IListObject * This,
            /* [in] */ VARIANT Target,
            /* [in] */ VARIANT_BOOL LinkSource,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Refresh )( 
            IListObject * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Unlink )( 
            IListObject * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Unlist )( 
            IListObject * This);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *UpdateChanges )( 
            IListObject * This,
            /* [defaultvalue][optional][in] */ XlListConflict iConflictType);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Resize )( 
            IListObject * This,
            /* [in] */ Range	*Range);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IListObject * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Active )( 
            IListObject * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DataBodyRange )( 
            IListObject * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DisplayRightToLeft )( 
            IListObject * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HeaderRowRange )( 
            IListObject * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_InsertRowRange )( 
            IListObject * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ListColumns )( 
            IListObject * This,
            /* [retval][out] */ ListColumns	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ListRows )( 
            IListObject * This,
            /* [retval][out] */ ListRows	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            IListObject * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Name )( 
            IListObject * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_QueryTable )( 
            IListObject * This,
            /* [retval][out] */ QueryTable	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Range )( 
            IListObject * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShowAutoFilter )( 
            IListObject * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ShowAutoFilter )( 
            IListObject * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShowTotals )( 
            IListObject * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ShowTotals )( 
            IListObject * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SourceType )( 
            IListObject * This,
            /* [retval][out] */ XlListObjectSourceType *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TotalsRowRange )( 
            IListObject * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SharePointURL )( 
            IListObject * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_XmlMap )( 
            IListObject * This,
            /* [retval][out] */ XmlMap	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DisplayName )( 
            IListObject * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DisplayName )( 
            IListObject * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShowHeaders )( 
            IListObject * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ShowHeaders )( 
            IListObject * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AutoFilter )( 
            IListObject * This,
            /* [retval][out] */ AutoFilter	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TableStyle )( 
            IListObject * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_TableStyle )( 
            IListObject * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShowTableStyleFirstColumn )( 
            IListObject * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ShowTableStyleFirstColumn )( 
            IListObject * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShowTableStyleLastColumn )( 
            IListObject * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ShowTableStyleLastColumn )( 
            IListObject * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShowTableStyleRowStripes )( 
            IListObject * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ShowTableStyleRowStripes )( 
            IListObject * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShowTableStyleColumnStripes )( 
            IListObject * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ShowTableStyleColumnStripes )( 
            IListObject * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Sort )( 
            IListObject * This,
            /* [retval][out] */ Sort	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Comment )( 
            IListObject * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Comment )( 
            IListObject * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ExportToVisio )( 
            IListObject * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AlternativeText )( 
            IListObject * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AlternativeText )( 
            IListObject * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Summary )( 
            IListObject * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Summary )( 
            IListObject * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TableObject )( 
            IListObject * This,
            /* [retval][out] */ TableObject	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Slicers )( 
            IListObject * This,
            /* [retval][out] */ Slicers	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShowAutoFilterDropDown )( 
            IListObject * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ShowAutoFilterDropDown )( 
            IListObject * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        END_INTERFACE
    } IListObjectVtbl;

    interface IListObject
    {
        CONST_VTBL struct IListObjectVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IListObject_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IListObject_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IListObject_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IListObject_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IListObject_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IListObject_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IListObject_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IListObject_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IListObject_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IListObject_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IListObject_Delete(This)	\
    ( (This)->lpVtbl -> Delete(This) ) 

#define IListObject_Publish(This,Target,LinkSource,RHS)	\
    ( (This)->lpVtbl -> Publish(This,Target,LinkSource,RHS) ) 

#define IListObject_Refresh(This)	\
    ( (This)->lpVtbl -> Refresh(This) ) 

#define IListObject_Unlink(This)	\
    ( (This)->lpVtbl -> Unlink(This) ) 

#define IListObject_Unlist(This)	\
    ( (This)->lpVtbl -> Unlist(This) ) 

#define IListObject_UpdateChanges(This,iConflictType)	\
    ( (This)->lpVtbl -> UpdateChanges(This,iConflictType) ) 

#define IListObject_Resize(This,Range)	\
    ( (This)->lpVtbl -> Resize(This,Range) ) 

#define IListObject_get__Default(This,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,RHS) ) 

#define IListObject_get_Active(This,RHS)	\
    ( (This)->lpVtbl -> get_Active(This,RHS) ) 

#define IListObject_get_DataBodyRange(This,RHS)	\
    ( (This)->lpVtbl -> get_DataBodyRange(This,RHS) ) 

#define IListObject_get_DisplayRightToLeft(This,RHS)	\
    ( (This)->lpVtbl -> get_DisplayRightToLeft(This,RHS) ) 

#define IListObject_get_HeaderRowRange(This,RHS)	\
    ( (This)->lpVtbl -> get_HeaderRowRange(This,RHS) ) 

#define IListObject_get_InsertRowRange(This,RHS)	\
    ( (This)->lpVtbl -> get_InsertRowRange(This,RHS) ) 

#define IListObject_get_ListColumns(This,RHS)	\
    ( (This)->lpVtbl -> get_ListColumns(This,RHS) ) 

#define IListObject_get_ListRows(This,RHS)	\
    ( (This)->lpVtbl -> get_ListRows(This,RHS) ) 

#define IListObject_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define IListObject_put_Name(This,RHS)	\
    ( (This)->lpVtbl -> put_Name(This,RHS) ) 

#define IListObject_get_QueryTable(This,RHS)	\
    ( (This)->lpVtbl -> get_QueryTable(This,RHS) ) 

#define IListObject_get_Range(This,RHS)	\
    ( (This)->lpVtbl -> get_Range(This,RHS) ) 

#define IListObject_get_ShowAutoFilter(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowAutoFilter(This,RHS) ) 

#define IListObject_put_ShowAutoFilter(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowAutoFilter(This,RHS) ) 

#define IListObject_get_ShowTotals(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowTotals(This,RHS) ) 

#define IListObject_put_ShowTotals(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowTotals(This,RHS) ) 

#define IListObject_get_SourceType(This,RHS)	\
    ( (This)->lpVtbl -> get_SourceType(This,RHS) ) 

#define IListObject_get_TotalsRowRange(This,RHS)	\
    ( (This)->lpVtbl -> get_TotalsRowRange(This,RHS) ) 

#define IListObject_get_SharePointURL(This,RHS)	\
    ( (This)->lpVtbl -> get_SharePointURL(This,RHS) ) 

#define IListObject_get_XmlMap(This,RHS)	\
    ( (This)->lpVtbl -> get_XmlMap(This,RHS) ) 

#define IListObject_get_DisplayName(This,RHS)	\
    ( (This)->lpVtbl -> get_DisplayName(This,RHS) ) 

#define IListObject_put_DisplayName(This,RHS)	\
    ( (This)->lpVtbl -> put_DisplayName(This,RHS) ) 

#define IListObject_get_ShowHeaders(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowHeaders(This,RHS) ) 

#define IListObject_put_ShowHeaders(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowHeaders(This,RHS) ) 

#define IListObject_get_AutoFilter(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoFilter(This,RHS) ) 

#define IListObject_get_TableStyle(This,RHS)	\
    ( (This)->lpVtbl -> get_TableStyle(This,RHS) ) 

#define IListObject_put_TableStyle(This,RHS)	\
    ( (This)->lpVtbl -> put_TableStyle(This,RHS) ) 

#define IListObject_get_ShowTableStyleFirstColumn(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowTableStyleFirstColumn(This,RHS) ) 

#define IListObject_put_ShowTableStyleFirstColumn(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowTableStyleFirstColumn(This,RHS) ) 

#define IListObject_get_ShowTableStyleLastColumn(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowTableStyleLastColumn(This,RHS) ) 

#define IListObject_put_ShowTableStyleLastColumn(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowTableStyleLastColumn(This,RHS) ) 

#define IListObject_get_ShowTableStyleRowStripes(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowTableStyleRowStripes(This,RHS) ) 

#define IListObject_put_ShowTableStyleRowStripes(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowTableStyleRowStripes(This,RHS) ) 

#define IListObject_get_ShowTableStyleColumnStripes(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowTableStyleColumnStripes(This,RHS) ) 

#define IListObject_put_ShowTableStyleColumnStripes(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowTableStyleColumnStripes(This,RHS) ) 

#define IListObject_get_Sort(This,RHS)	\
    ( (This)->lpVtbl -> get_Sort(This,RHS) ) 

#define IListObject_get_Comment(This,RHS)	\
    ( (This)->lpVtbl -> get_Comment(This,RHS) ) 

#define IListObject_put_Comment(This,RHS)	\
    ( (This)->lpVtbl -> put_Comment(This,RHS) ) 

#define IListObject_ExportToVisio(This)	\
    ( (This)->lpVtbl -> ExportToVisio(This) ) 

#define IListObject_get_AlternativeText(This,RHS)	\
    ( (This)->lpVtbl -> get_AlternativeText(This,RHS) ) 

#define IListObject_put_AlternativeText(This,RHS)	\
    ( (This)->lpVtbl -> put_AlternativeText(This,RHS) ) 

#define IListObject_get_Summary(This,RHS)	\
    ( (This)->lpVtbl -> get_Summary(This,RHS) ) 

#define IListObject_put_Summary(This,RHS)	\
    ( (This)->lpVtbl -> put_Summary(This,RHS) ) 

#define IListObject_get_TableObject(This,RHS)	\
    ( (This)->lpVtbl -> get_TableObject(This,RHS) ) 

#define IListObject_get_Slicers(This,RHS)	\
    ( (This)->lpVtbl -> get_Slicers(This,RHS) ) 

#define IListObject_get_ShowAutoFilterDropDown(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowAutoFilterDropDown(This,RHS) ) 

#define IListObject_put_ShowAutoFilterDropDown(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowAutoFilterDropDown(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IListObject_INTERFACE_DEFINED__ */


#ifndef __IListColumns_INTERFACE_DEFINED__
#define __IListColumns_INTERFACE_DEFINED__

/* interface IListColumns */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IListColumns;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024472-0001-0000-C000-000000000046")
    IListColumns : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add( 
            /* [optional][in] */ VARIANT Position,
            /* [retval][out] */ ListColumn	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ ListColumn	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ ListColumn	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IListColumnsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IListColumns * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IListColumns * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IListColumns * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IListColumns * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IListColumns * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IListColumns * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IListColumns * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IListColumns * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IListColumns * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IListColumns * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add )( 
            IListColumns * This,
            /* [optional][in] */ VARIANT Position,
            /* [retval][out] */ ListColumn	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IListColumns * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ ListColumn	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            IListColumns * This,
            /* [retval][out] */ IUnknown **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Item )( 
            IListColumns * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ ListColumn	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IListColumns * This,
            /* [retval][out] */ long *RHS);
        
        END_INTERFACE
    } IListColumnsVtbl;

    interface IListColumns
    {
        CONST_VTBL struct IListColumnsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IListColumns_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IListColumns_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IListColumns_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IListColumns_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IListColumns_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IListColumns_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IListColumns_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IListColumns_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IListColumns_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IListColumns_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IListColumns_Add(This,Position,RHS)	\
    ( (This)->lpVtbl -> Add(This,Position,RHS) ) 

#define IListColumns_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define IListColumns_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#define IListColumns_get_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Item(This,Index,RHS) ) 

#define IListColumns_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IListColumns_INTERFACE_DEFINED__ */


#ifndef __IListColumn_INTERFACE_DEFINED__
#define __IListColumn_INTERFACE_DEFINED__

/* interface IListColumn */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IListColumn;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024473-0001-0000-C000-000000000046")
    IListColumn : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_ListDataFormat( 
            /* [retval][out] */ ListDataFormat	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Index( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Name( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Range( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TotalsCalculation( 
            /* [retval][out] */ XlTotalsCalculation *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_TotalsCalculation( 
            /* [in] */ XlTotalsCalculation RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_XPath( 
            /* [retval][out] */ XPath	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_SharePointFormula( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DataBodyRange( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Total( 
            /* [retval][out] */ Range	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IListColumnVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IListColumn * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IListColumn * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IListColumn * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IListColumn * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IListColumn * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IListColumn * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IListColumn * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IListColumn * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IListColumn * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IListColumn * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IListColumn * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IListColumn * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_ListDataFormat )( 
            IListColumn * This,
            /* [retval][out] */ ListDataFormat	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Index )( 
            IListColumn * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            IListColumn * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Name )( 
            IListColumn * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Range )( 
            IListColumn * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TotalsCalculation )( 
            IListColumn * This,
            /* [retval][out] */ XlTotalsCalculation *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_TotalsCalculation )( 
            IListColumn * This,
            /* [in] */ XlTotalsCalculation RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_XPath )( 
            IListColumn * This,
            /* [retval][out] */ XPath	**RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_SharePointFormula )( 
            IListColumn * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DataBodyRange )( 
            IListColumn * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Total )( 
            IListColumn * This,
            /* [retval][out] */ Range	**RHS);
        
        END_INTERFACE
    } IListColumnVtbl;

    interface IListColumn
    {
        CONST_VTBL struct IListColumnVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IListColumn_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IListColumn_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IListColumn_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IListColumn_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IListColumn_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IListColumn_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IListColumn_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IListColumn_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IListColumn_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IListColumn_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IListColumn_Delete(This)	\
    ( (This)->lpVtbl -> Delete(This) ) 

#define IListColumn_get__Default(This,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,RHS) ) 

#define IListColumn_get_ListDataFormat(This,RHS)	\
    ( (This)->lpVtbl -> get_ListDataFormat(This,RHS) ) 

#define IListColumn_get_Index(This,RHS)	\
    ( (This)->lpVtbl -> get_Index(This,RHS) ) 

#define IListColumn_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define IListColumn_put_Name(This,RHS)	\
    ( (This)->lpVtbl -> put_Name(This,RHS) ) 

#define IListColumn_get_Range(This,RHS)	\
    ( (This)->lpVtbl -> get_Range(This,RHS) ) 

#define IListColumn_get_TotalsCalculation(This,RHS)	\
    ( (This)->lpVtbl -> get_TotalsCalculation(This,RHS) ) 

#define IListColumn_put_TotalsCalculation(This,RHS)	\
    ( (This)->lpVtbl -> put_TotalsCalculation(This,RHS) ) 

#define IListColumn_get_XPath(This,RHS)	\
    ( (This)->lpVtbl -> get_XPath(This,RHS) ) 

#define IListColumn_get_SharePointFormula(This,RHS)	\
    ( (This)->lpVtbl -> get_SharePointFormula(This,RHS) ) 

#define IListColumn_get_DataBodyRange(This,RHS)	\
    ( (This)->lpVtbl -> get_DataBodyRange(This,RHS) ) 

#define IListColumn_get_Total(This,RHS)	\
    ( (This)->lpVtbl -> get_Total(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IListColumn_INTERFACE_DEFINED__ */


#ifndef __IListRows_INTERFACE_DEFINED__
#define __IListRows_INTERFACE_DEFINED__

/* interface IListRows */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IListRows;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024474-0001-0000-C000-000000000046")
    IListRows : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [custom][helpcontext][hidden][id] */ HRESULT __stdcall _Add( 
            /* [optional][in] */ VARIANT Position,
            /* [retval][out] */ ListRow	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ ListRow	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ ListRow	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [custom][helpcontext][id] */ HRESULT __stdcall Add( 
            /* [optional][in] */ VARIANT Position,
            /* [optional][in] */ VARIANT AlwaysInsert,
            /* [retval][out] */ ListRow	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IListRowsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IListRows * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IListRows * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IListRows * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IListRows * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IListRows * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IListRows * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IListRows * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IListRows * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IListRows * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IListRows * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [custom][helpcontext][hidden][id] */ HRESULT ( __stdcall *_Add )( 
            IListRows * This,
            /* [optional][in] */ VARIANT Position,
            /* [retval][out] */ ListRow	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IListRows * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ ListRow	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            IListRows * This,
            /* [retval][out] */ IUnknown **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Item )( 
            IListRows * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ ListRow	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IListRows * This,
            /* [retval][out] */ long *RHS);
        
        /* [custom][helpcontext][id] */ HRESULT ( __stdcall *Add )( 
            IListRows * This,
            /* [optional][in] */ VARIANT Position,
            /* [optional][in] */ VARIANT AlwaysInsert,
            /* [retval][out] */ ListRow	**RHS);
        
        END_INTERFACE
    } IListRowsVtbl;

    interface IListRows
    {
        CONST_VTBL struct IListRowsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IListRows_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IListRows_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IListRows_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IListRows_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IListRows_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IListRows_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IListRows_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IListRows_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IListRows_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IListRows_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IListRows__Add(This,Position,RHS)	\
    ( (This)->lpVtbl -> _Add(This,Position,RHS) ) 

#define IListRows_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define IListRows_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#define IListRows_get_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Item(This,Index,RHS) ) 

#define IListRows_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IListRows_Add(This,Position,AlwaysInsert,RHS)	\
    ( (This)->lpVtbl -> Add(This,Position,AlwaysInsert,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IListRows_INTERFACE_DEFINED__ */


#ifndef __IListRow_INTERFACE_DEFINED__
#define __IListRow_INTERFACE_DEFINED__

/* interface IListRow */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IListRow;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024475-0001-0000-C000-000000000046")
    IListRow : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Index( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_InvalidData( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Range( 
            /* [retval][out] */ Range	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IListRowVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IListRow * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IListRow * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IListRow * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IListRow * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IListRow * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IListRow * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IListRow * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IListRow * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IListRow * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IListRow * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IListRow * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Index )( 
            IListRow * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_InvalidData )( 
            IListRow * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Range )( 
            IListRow * This,
            /* [retval][out] */ Range	**RHS);
        
        END_INTERFACE
    } IListRowVtbl;

    interface IListRow
    {
        CONST_VTBL struct IListRowVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IListRow_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IListRow_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IListRow_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IListRow_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IListRow_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IListRow_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IListRow_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IListRow_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IListRow_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IListRow_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IListRow_Delete(This)	\
    ( (This)->lpVtbl -> Delete(This) ) 

#define IListRow_get_Index(This,RHS)	\
    ( (This)->lpVtbl -> get_Index(This,RHS) ) 

#define IListRow_get_InvalidData(This,RHS)	\
    ( (This)->lpVtbl -> get_InvalidData(This,RHS) ) 

#define IListRow_get_Range(This,RHS)	\
    ( (This)->lpVtbl -> get_Range(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IListRow_INTERFACE_DEFINED__ */


#ifndef __IXmlNamespace_INTERFACE_DEFINED__
#define __IXmlNamespace_INTERFACE_DEFINED__

/* interface IXmlNamespace */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IXmlNamespace;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024476-0001-0000-C000-000000000046")
    IXmlNamespace : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Uri( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Prefix( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IXmlNamespaceVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IXmlNamespace * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IXmlNamespace * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IXmlNamespace * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IXmlNamespace * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IXmlNamespace * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IXmlNamespace * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IXmlNamespace * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IXmlNamespace * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IXmlNamespace * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IXmlNamespace * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IXmlNamespace * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Uri )( 
            IXmlNamespace * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Prefix )( 
            IXmlNamespace * This,
            /* [retval][out] */ BSTR *RHS);
        
        END_INTERFACE
    } IXmlNamespaceVtbl;

    interface IXmlNamespace
    {
        CONST_VTBL struct IXmlNamespaceVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IXmlNamespace_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IXmlNamespace_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IXmlNamespace_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IXmlNamespace_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IXmlNamespace_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IXmlNamespace_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IXmlNamespace_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IXmlNamespace_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IXmlNamespace_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IXmlNamespace_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IXmlNamespace_get__Default(This,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,RHS) ) 

#define IXmlNamespace_get_Uri(This,RHS)	\
    ( (This)->lpVtbl -> get_Uri(This,RHS) ) 

#define IXmlNamespace_get_Prefix(This,RHS)	\
    ( (This)->lpVtbl -> get_Prefix(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IXmlNamespace_INTERFACE_DEFINED__ */


#ifndef __IXmlNamespaces_INTERFACE_DEFINED__
#define __IXmlNamespaces_INTERFACE_DEFINED__

/* interface IXmlNamespaces */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IXmlNamespaces;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024477-0001-0000-C000-000000000046")
    IXmlNamespaces : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ XmlNamespace	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ XmlNamespace	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Value( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall InstallManifest( 
            /* [in] */ BSTR Path,
            /* [optional][in] */ VARIANT InstallForAllUsers) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IXmlNamespacesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IXmlNamespaces * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IXmlNamespaces * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IXmlNamespaces * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IXmlNamespaces * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IXmlNamespaces * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IXmlNamespaces * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IXmlNamespaces * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IXmlNamespaces * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IXmlNamespaces * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IXmlNamespaces * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IXmlNamespaces * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ XmlNamespace	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Item )( 
            IXmlNamespaces * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ XmlNamespace	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IXmlNamespaces * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Value )( 
            IXmlNamespaces * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            IXmlNamespaces * This,
            /* [retval][out] */ IUnknown **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *InstallManifest )( 
            IXmlNamespaces * This,
            /* [in] */ BSTR Path,
            /* [optional][in] */ VARIANT InstallForAllUsers);
        
        END_INTERFACE
    } IXmlNamespacesVtbl;

    interface IXmlNamespaces
    {
        CONST_VTBL struct IXmlNamespacesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IXmlNamespaces_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IXmlNamespaces_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IXmlNamespaces_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IXmlNamespaces_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IXmlNamespaces_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IXmlNamespaces_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IXmlNamespaces_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IXmlNamespaces_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IXmlNamespaces_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IXmlNamespaces_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IXmlNamespaces_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define IXmlNamespaces_get_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Item(This,Index,RHS) ) 

#define IXmlNamespaces_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IXmlNamespaces_get_Value(This,RHS)	\
    ( (This)->lpVtbl -> get_Value(This,RHS) ) 

#define IXmlNamespaces_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#define IXmlNamespaces_InstallManifest(This,Path,InstallForAllUsers)	\
    ( (This)->lpVtbl -> InstallManifest(This,Path,InstallForAllUsers) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IXmlNamespaces_INTERFACE_DEFINED__ */


#ifndef __IXmlDataBinding_INTERFACE_DEFINED__
#define __IXmlDataBinding_INTERFACE_DEFINED__

/* interface IXmlDataBinding */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IXmlDataBinding;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024478-0001-0000-C000-000000000046")
    IXmlDataBinding : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Refresh( 
            /* [retval][out] */ XlXmlImportResult *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall LoadSettings( 
            /* [in] */ BSTR Url) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ClearSettings( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SourceUrl( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IXmlDataBindingVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IXmlDataBinding * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IXmlDataBinding * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IXmlDataBinding * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IXmlDataBinding * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IXmlDataBinding * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IXmlDataBinding * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IXmlDataBinding * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IXmlDataBinding * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IXmlDataBinding * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IXmlDataBinding * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IXmlDataBinding * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Refresh )( 
            IXmlDataBinding * This,
            /* [retval][out] */ XlXmlImportResult *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *LoadSettings )( 
            IXmlDataBinding * This,
            /* [in] */ BSTR Url);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ClearSettings )( 
            IXmlDataBinding * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SourceUrl )( 
            IXmlDataBinding * This,
            /* [retval][out] */ BSTR *RHS);
        
        END_INTERFACE
    } IXmlDataBindingVtbl;

    interface IXmlDataBinding
    {
        CONST_VTBL struct IXmlDataBindingVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IXmlDataBinding_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IXmlDataBinding_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IXmlDataBinding_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IXmlDataBinding_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IXmlDataBinding_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IXmlDataBinding_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IXmlDataBinding_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IXmlDataBinding_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IXmlDataBinding_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IXmlDataBinding_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IXmlDataBinding_get__Default(This,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,RHS) ) 

#define IXmlDataBinding_Refresh(This,RHS)	\
    ( (This)->lpVtbl -> Refresh(This,RHS) ) 

#define IXmlDataBinding_LoadSettings(This,Url)	\
    ( (This)->lpVtbl -> LoadSettings(This,Url) ) 

#define IXmlDataBinding_ClearSettings(This)	\
    ( (This)->lpVtbl -> ClearSettings(This) ) 

#define IXmlDataBinding_get_SourceUrl(This,RHS)	\
    ( (This)->lpVtbl -> get_SourceUrl(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IXmlDataBinding_INTERFACE_DEFINED__ */


#ifndef __IXmlSchema_INTERFACE_DEFINED__
#define __IXmlSchema_INTERFACE_DEFINED__

/* interface IXmlSchema */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IXmlSchema;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024479-0001-0000-C000-000000000046")
    IXmlSchema : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Namespace( 
            /* [retval][out] */ XmlNamespace	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_XML( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IXmlSchemaVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IXmlSchema * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IXmlSchema * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IXmlSchema * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IXmlSchema * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IXmlSchema * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IXmlSchema * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IXmlSchema * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IXmlSchema * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IXmlSchema * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IXmlSchema * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Namespace )( 
            IXmlSchema * This,
            /* [retval][out] */ XmlNamespace	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_XML )( 
            IXmlSchema * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            IXmlSchema * This,
            /* [retval][out] */ BSTR *RHS);
        
        END_INTERFACE
    } IXmlSchemaVtbl;

    interface IXmlSchema
    {
        CONST_VTBL struct IXmlSchemaVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IXmlSchema_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IXmlSchema_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IXmlSchema_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IXmlSchema_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IXmlSchema_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IXmlSchema_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IXmlSchema_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IXmlSchema_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IXmlSchema_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IXmlSchema_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IXmlSchema_get_Namespace(This,RHS)	\
    ( (This)->lpVtbl -> get_Namespace(This,RHS) ) 

#define IXmlSchema_get_XML(This,RHS)	\
    ( (This)->lpVtbl -> get_XML(This,RHS) ) 

#define IXmlSchema_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IXmlSchema_INTERFACE_DEFINED__ */


#ifndef __IXmlSchemas_INTERFACE_DEFINED__
#define __IXmlSchemas_INTERFACE_DEFINED__

/* interface IXmlSchemas */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IXmlSchemas;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002447A-0001-0000-C000-000000000046")
    IXmlSchemas : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ XmlSchema	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ XmlSchema	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IXmlSchemasVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IXmlSchemas * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IXmlSchemas * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IXmlSchemas * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IXmlSchemas * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IXmlSchemas * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IXmlSchemas * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IXmlSchemas * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IXmlSchemas * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IXmlSchemas * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IXmlSchemas * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IXmlSchemas * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ XmlSchema	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Item )( 
            IXmlSchemas * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ XmlSchema	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IXmlSchemas * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            IXmlSchemas * This,
            /* [retval][out] */ IUnknown **RHS);
        
        END_INTERFACE
    } IXmlSchemasVtbl;

    interface IXmlSchemas
    {
        CONST_VTBL struct IXmlSchemasVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IXmlSchemas_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IXmlSchemas_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IXmlSchemas_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IXmlSchemas_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IXmlSchemas_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IXmlSchemas_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IXmlSchemas_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IXmlSchemas_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IXmlSchemas_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IXmlSchemas_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IXmlSchemas_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define IXmlSchemas_get_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Item(This,Index,RHS) ) 

#define IXmlSchemas_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IXmlSchemas_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IXmlSchemas_INTERFACE_DEFINED__ */


#ifndef __IXmlMap_INTERFACE_DEFINED__
#define __IXmlMap_INTERFACE_DEFINED__

/* interface IXmlMap */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IXmlMap;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002447B-0001-0000-C000-000000000046")
    IXmlMap : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Name( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_IsExportable( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShowImportExportValidationErrors( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ShowImportExportValidationErrors( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SaveDataSourceDefinition( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_SaveDataSourceDefinition( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AdjustColumnWidth( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AdjustColumnWidth( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PreserveColumnFilter( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PreserveColumnFilter( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PreserveNumberFormatting( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PreserveNumberFormatting( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AppendOnImport( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AppendOnImport( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RootElementName( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RootElementNamespace( 
            /* [retval][out] */ XmlNamespace	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Schemas( 
            /* [retval][out] */ XmlSchemas	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DataBinding( 
            /* [retval][out] */ XmlDataBinding	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Import( 
            /* [in] */ BSTR Url,
            /* [optional][in] */ VARIANT Overwrite,
            /* [retval][out] */ XlXmlImportResult *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ImportXml( 
            /* [in] */ BSTR XmlData,
            /* [optional][in] */ VARIANT Overwrite,
            /* [retval][out] */ XlXmlImportResult *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Export( 
            /* [in] */ BSTR Url,
            /* [optional][in] */ VARIANT Overwrite,
            /* [retval][out] */ XlXmlExportResult *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ExportXml( 
            /* [out] */ BSTR *Data,
            /* [retval][out] */ XlXmlExportResult *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_WorkbookConnection( 
            /* [retval][out] */ WorkbookConnection	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IXmlMapVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IXmlMap * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IXmlMap * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IXmlMap * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IXmlMap * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IXmlMap * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IXmlMap * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IXmlMap * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IXmlMap * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IXmlMap * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IXmlMap * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IXmlMap * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            IXmlMap * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Name )( 
            IXmlMap * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_IsExportable )( 
            IXmlMap * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShowImportExportValidationErrors )( 
            IXmlMap * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ShowImportExportValidationErrors )( 
            IXmlMap * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SaveDataSourceDefinition )( 
            IXmlMap * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_SaveDataSourceDefinition )( 
            IXmlMap * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AdjustColumnWidth )( 
            IXmlMap * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AdjustColumnWidth )( 
            IXmlMap * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PreserveColumnFilter )( 
            IXmlMap * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PreserveColumnFilter )( 
            IXmlMap * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PreserveNumberFormatting )( 
            IXmlMap * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PreserveNumberFormatting )( 
            IXmlMap * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AppendOnImport )( 
            IXmlMap * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AppendOnImport )( 
            IXmlMap * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RootElementName )( 
            IXmlMap * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RootElementNamespace )( 
            IXmlMap * This,
            /* [retval][out] */ XmlNamespace	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Schemas )( 
            IXmlMap * This,
            /* [retval][out] */ XmlSchemas	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DataBinding )( 
            IXmlMap * This,
            /* [retval][out] */ XmlDataBinding	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IXmlMap * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Import )( 
            IXmlMap * This,
            /* [in] */ BSTR Url,
            /* [optional][in] */ VARIANT Overwrite,
            /* [retval][out] */ XlXmlImportResult *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ImportXml )( 
            IXmlMap * This,
            /* [in] */ BSTR XmlData,
            /* [optional][in] */ VARIANT Overwrite,
            /* [retval][out] */ XlXmlImportResult *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Export )( 
            IXmlMap * This,
            /* [in] */ BSTR Url,
            /* [optional][in] */ VARIANT Overwrite,
            /* [retval][out] */ XlXmlExportResult *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ExportXml )( 
            IXmlMap * This,
            /* [out] */ BSTR *Data,
            /* [retval][out] */ XlXmlExportResult *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_WorkbookConnection )( 
            IXmlMap * This,
            /* [retval][out] */ WorkbookConnection	**RHS);
        
        END_INTERFACE
    } IXmlMapVtbl;

    interface IXmlMap
    {
        CONST_VTBL struct IXmlMapVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IXmlMap_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IXmlMap_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IXmlMap_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IXmlMap_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IXmlMap_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IXmlMap_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IXmlMap_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IXmlMap_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IXmlMap_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IXmlMap_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IXmlMap_get__Default(This,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,RHS) ) 

#define IXmlMap_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define IXmlMap_put_Name(This,RHS)	\
    ( (This)->lpVtbl -> put_Name(This,RHS) ) 

#define IXmlMap_get_IsExportable(This,RHS)	\
    ( (This)->lpVtbl -> get_IsExportable(This,RHS) ) 

#define IXmlMap_get_ShowImportExportValidationErrors(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowImportExportValidationErrors(This,RHS) ) 

#define IXmlMap_put_ShowImportExportValidationErrors(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowImportExportValidationErrors(This,RHS) ) 

#define IXmlMap_get_SaveDataSourceDefinition(This,RHS)	\
    ( (This)->lpVtbl -> get_SaveDataSourceDefinition(This,RHS) ) 

#define IXmlMap_put_SaveDataSourceDefinition(This,RHS)	\
    ( (This)->lpVtbl -> put_SaveDataSourceDefinition(This,RHS) ) 

#define IXmlMap_get_AdjustColumnWidth(This,RHS)	\
    ( (This)->lpVtbl -> get_AdjustColumnWidth(This,RHS) ) 

#define IXmlMap_put_AdjustColumnWidth(This,RHS)	\
    ( (This)->lpVtbl -> put_AdjustColumnWidth(This,RHS) ) 

#define IXmlMap_get_PreserveColumnFilter(This,RHS)	\
    ( (This)->lpVtbl -> get_PreserveColumnFilter(This,RHS) ) 

#define IXmlMap_put_PreserveColumnFilter(This,RHS)	\
    ( (This)->lpVtbl -> put_PreserveColumnFilter(This,RHS) ) 

#define IXmlMap_get_PreserveNumberFormatting(This,RHS)	\
    ( (This)->lpVtbl -> get_PreserveNumberFormatting(This,RHS) ) 

#define IXmlMap_put_PreserveNumberFormatting(This,RHS)	\
    ( (This)->lpVtbl -> put_PreserveNumberFormatting(This,RHS) ) 

#define IXmlMap_get_AppendOnImport(This,RHS)	\
    ( (This)->lpVtbl -> get_AppendOnImport(This,RHS) ) 

#define IXmlMap_put_AppendOnImport(This,RHS)	\
    ( (This)->lpVtbl -> put_AppendOnImport(This,RHS) ) 

#define IXmlMap_get_RootElementName(This,RHS)	\
    ( (This)->lpVtbl -> get_RootElementName(This,RHS) ) 

#define IXmlMap_get_RootElementNamespace(This,RHS)	\
    ( (This)->lpVtbl -> get_RootElementNamespace(This,RHS) ) 

#define IXmlMap_get_Schemas(This,RHS)	\
    ( (This)->lpVtbl -> get_Schemas(This,RHS) ) 

#define IXmlMap_get_DataBinding(This,RHS)	\
    ( (This)->lpVtbl -> get_DataBinding(This,RHS) ) 

#define IXmlMap_Delete(This)	\
    ( (This)->lpVtbl -> Delete(This) ) 

#define IXmlMap_Import(This,Url,Overwrite,RHS)	\
    ( (This)->lpVtbl -> Import(This,Url,Overwrite,RHS) ) 

#define IXmlMap_ImportXml(This,XmlData,Overwrite,RHS)	\
    ( (This)->lpVtbl -> ImportXml(This,XmlData,Overwrite,RHS) ) 

#define IXmlMap_Export(This,Url,Overwrite,RHS)	\
    ( (This)->lpVtbl -> Export(This,Url,Overwrite,RHS) ) 

#define IXmlMap_ExportXml(This,Data,RHS)	\
    ( (This)->lpVtbl -> ExportXml(This,Data,RHS) ) 

#define IXmlMap_get_WorkbookConnection(This,RHS)	\
    ( (This)->lpVtbl -> get_WorkbookConnection(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IXmlMap_INTERFACE_DEFINED__ */


#ifndef __IXmlMaps_INTERFACE_DEFINED__
#define __IXmlMaps_INTERFACE_DEFINED__

/* interface IXmlMaps */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IXmlMaps;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002447C-0001-0000-C000-000000000046")
    IXmlMaps : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add( 
            /* [in] */ BSTR Schema,
            /* [optional][in] */ VARIANT RootElementName,
            /* [retval][out] */ XmlMap	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ XmlMap	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ XmlMap	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IXmlMapsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IXmlMaps * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IXmlMaps * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IXmlMaps * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IXmlMaps * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IXmlMaps * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IXmlMaps * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IXmlMaps * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IXmlMaps * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IXmlMaps * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IXmlMaps * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add )( 
            IXmlMaps * This,
            /* [in] */ BSTR Schema,
            /* [optional][in] */ VARIANT RootElementName,
            /* [retval][out] */ XmlMap	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IXmlMaps * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ XmlMap	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Item )( 
            IXmlMaps * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ XmlMap	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IXmlMaps * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            IXmlMaps * This,
            /* [retval][out] */ IUnknown **RHS);
        
        END_INTERFACE
    } IXmlMapsVtbl;

    interface IXmlMaps
    {
        CONST_VTBL struct IXmlMapsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IXmlMaps_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IXmlMaps_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IXmlMaps_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IXmlMaps_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IXmlMaps_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IXmlMaps_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IXmlMaps_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IXmlMaps_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IXmlMaps_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IXmlMaps_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IXmlMaps_Add(This,Schema,RootElementName,RHS)	\
    ( (This)->lpVtbl -> Add(This,Schema,RootElementName,RHS) ) 

#define IXmlMaps_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define IXmlMaps_get_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Item(This,Index,RHS) ) 

#define IXmlMaps_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IXmlMaps_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IXmlMaps_INTERFACE_DEFINED__ */


#ifndef __IListDataFormat_INTERFACE_DEFINED__
#define __IListDataFormat_INTERFACE_DEFINED__

/* interface IListDataFormat */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IListDataFormat;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002447D-0001-0000-C000-000000000046")
    IListDataFormat : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [retval][out] */ XlListDataType *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Choices( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DecimalPlaces( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DefaultValue( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_IsPercent( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_lcid( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MaxCharacters( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MaxNumber( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MinNumber( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Required( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Type( 
            /* [retval][out] */ XlListDataType *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ReadOnly( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AllowFillIn( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IListDataFormatVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IListDataFormat * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IListDataFormat * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IListDataFormat * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IListDataFormat * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IListDataFormat * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IListDataFormat * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IListDataFormat * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IListDataFormat * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IListDataFormat * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IListDataFormat * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IListDataFormat * This,
            /* [retval][out] */ XlListDataType *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Choices )( 
            IListDataFormat * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DecimalPlaces )( 
            IListDataFormat * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DefaultValue )( 
            IListDataFormat * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_IsPercent )( 
            IListDataFormat * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_lcid )( 
            IListDataFormat * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MaxCharacters )( 
            IListDataFormat * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MaxNumber )( 
            IListDataFormat * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MinNumber )( 
            IListDataFormat * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Required )( 
            IListDataFormat * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Type )( 
            IListDataFormat * This,
            /* [retval][out] */ XlListDataType *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ReadOnly )( 
            IListDataFormat * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AllowFillIn )( 
            IListDataFormat * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        END_INTERFACE
    } IListDataFormatVtbl;

    interface IListDataFormat
    {
        CONST_VTBL struct IListDataFormatVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IListDataFormat_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IListDataFormat_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IListDataFormat_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IListDataFormat_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IListDataFormat_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IListDataFormat_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IListDataFormat_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IListDataFormat_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IListDataFormat_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IListDataFormat_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IListDataFormat_get__Default(This,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,RHS) ) 

#define IListDataFormat_get_Choices(This,RHS)	\
    ( (This)->lpVtbl -> get_Choices(This,RHS) ) 

#define IListDataFormat_get_DecimalPlaces(This,RHS)	\
    ( (This)->lpVtbl -> get_DecimalPlaces(This,RHS) ) 

#define IListDataFormat_get_DefaultValue(This,RHS)	\
    ( (This)->lpVtbl -> get_DefaultValue(This,RHS) ) 

#define IListDataFormat_get_IsPercent(This,RHS)	\
    ( (This)->lpVtbl -> get_IsPercent(This,RHS) ) 

#define IListDataFormat_get_lcid(This,RHS)	\
    ( (This)->lpVtbl -> get_lcid(This,RHS) ) 

#define IListDataFormat_get_MaxCharacters(This,RHS)	\
    ( (This)->lpVtbl -> get_MaxCharacters(This,RHS) ) 

#define IListDataFormat_get_MaxNumber(This,RHS)	\
    ( (This)->lpVtbl -> get_MaxNumber(This,RHS) ) 

#define IListDataFormat_get_MinNumber(This,RHS)	\
    ( (This)->lpVtbl -> get_MinNumber(This,RHS) ) 

#define IListDataFormat_get_Required(This,RHS)	\
    ( (This)->lpVtbl -> get_Required(This,RHS) ) 

#define IListDataFormat_get_Type(This,RHS)	\
    ( (This)->lpVtbl -> get_Type(This,RHS) ) 

#define IListDataFormat_get_ReadOnly(This,RHS)	\
    ( (This)->lpVtbl -> get_ReadOnly(This,RHS) ) 

#define IListDataFormat_get_AllowFillIn(This,RHS)	\
    ( (This)->lpVtbl -> get_AllowFillIn(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IListDataFormat_INTERFACE_DEFINED__ */


#ifndef __IXPath_INTERFACE_DEFINED__
#define __IXPath_INTERFACE_DEFINED__

/* interface IXPath */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IXPath;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002447E-0001-0000-C000-000000000046")
    IXPath : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Value( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Map( 
            /* [retval][out] */ XmlMap	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SetValue( 
            /* [in] */ XmlMap	*Map,
            /* [in] */ BSTR XPath,
            /* [optional][in] */ VARIANT SelectionNamespace,
            /* [optional][in] */ VARIANT Repeating) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Clear( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Repeating( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IXPathVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IXPath * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IXPath * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IXPath * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IXPath * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IXPath * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IXPath * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IXPath * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IXPath * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IXPath * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IXPath * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IXPath * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Value )( 
            IXPath * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Map )( 
            IXPath * This,
            /* [retval][out] */ XmlMap	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SetValue )( 
            IXPath * This,
            /* [in] */ XmlMap	*Map,
            /* [in] */ BSTR XPath,
            /* [optional][in] */ VARIANT SelectionNamespace,
            /* [optional][in] */ VARIANT Repeating);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Clear )( 
            IXPath * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Repeating )( 
            IXPath * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        END_INTERFACE
    } IXPathVtbl;

    interface IXPath
    {
        CONST_VTBL struct IXPathVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IXPath_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IXPath_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IXPath_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IXPath_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IXPath_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IXPath_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IXPath_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IXPath_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IXPath_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IXPath_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IXPath_get__Default(This,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,RHS) ) 

#define IXPath_get_Value(This,RHS)	\
    ( (This)->lpVtbl -> get_Value(This,RHS) ) 

#define IXPath_get_Map(This,RHS)	\
    ( (This)->lpVtbl -> get_Map(This,RHS) ) 

#define IXPath_SetValue(This,Map,XPath,SelectionNamespace,Repeating)	\
    ( (This)->lpVtbl -> SetValue(This,Map,XPath,SelectionNamespace,Repeating) ) 

#define IXPath_Clear(This)	\
    ( (This)->lpVtbl -> Clear(This) ) 

#define IXPath_get_Repeating(This,RHS)	\
    ( (This)->lpVtbl -> get_Repeating(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IXPath_INTERFACE_DEFINED__ */


#ifndef __IPivotLineCells_INTERFACE_DEFINED__
#define __IPivotLineCells_INTERFACE_DEFINED__

/* interface IPivotLineCells */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IPivotLineCells;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002447F-0001-0000-C000-000000000046")
    IPivotLineCells : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ PivotCell	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ PivotCell	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Full( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IPivotLineCellsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IPivotLineCells * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IPivotLineCells * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IPivotLineCells * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IPivotLineCells * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IPivotLineCells * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IPivotLineCells * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IPivotLineCells * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IPivotLineCells * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IPivotLineCells * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IPivotLineCells * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IPivotLineCells * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ PivotCell	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            IPivotLineCells * This,
            /* [retval][out] */ IUnknown **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Item )( 
            IPivotLineCells * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ PivotCell	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IPivotLineCells * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Full )( 
            IPivotLineCells * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        END_INTERFACE
    } IPivotLineCellsVtbl;

    interface IPivotLineCells
    {
        CONST_VTBL struct IPivotLineCellsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IPivotLineCells_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IPivotLineCells_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IPivotLineCells_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IPivotLineCells_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IPivotLineCells_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IPivotLineCells_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IPivotLineCells_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IPivotLineCells_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IPivotLineCells_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IPivotLineCells_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IPivotLineCells_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define IPivotLineCells_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#define IPivotLineCells_get_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Item(This,Index,RHS) ) 

#define IPivotLineCells_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IPivotLineCells_get_Full(This,RHS)	\
    ( (This)->lpVtbl -> get_Full(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IPivotLineCells_INTERFACE_DEFINED__ */


#ifndef __IPivotLine_INTERFACE_DEFINED__
#define __IPivotLine_INTERFACE_DEFINED__

/* interface IPivotLine */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IPivotLine;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024480-0001-0000-C000-000000000046")
    IPivotLine : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LineType( 
            /* [retval][out] */ XlPivotLineType *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Position( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PivotLineCells( 
            /* [retval][out] */ PivotLineCells	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PivotLineCellsFull( 
            /* [retval][out] */ PivotLineCells	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IPivotLineVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IPivotLine * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IPivotLine * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IPivotLine * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IPivotLine * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IPivotLine * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IPivotLine * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IPivotLine * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IPivotLine * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IPivotLine * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IPivotLine * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LineType )( 
            IPivotLine * This,
            /* [retval][out] */ XlPivotLineType *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Position )( 
            IPivotLine * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PivotLineCells )( 
            IPivotLine * This,
            /* [retval][out] */ PivotLineCells	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PivotLineCellsFull )( 
            IPivotLine * This,
            /* [retval][out] */ PivotLineCells	**RHS);
        
        END_INTERFACE
    } IPivotLineVtbl;

    interface IPivotLine
    {
        CONST_VTBL struct IPivotLineVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IPivotLine_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IPivotLine_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IPivotLine_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IPivotLine_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IPivotLine_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IPivotLine_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IPivotLine_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IPivotLine_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IPivotLine_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IPivotLine_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IPivotLine_get_LineType(This,RHS)	\
    ( (This)->lpVtbl -> get_LineType(This,RHS) ) 

#define IPivotLine_get_Position(This,RHS)	\
    ( (This)->lpVtbl -> get_Position(This,RHS) ) 

#define IPivotLine_get_PivotLineCells(This,RHS)	\
    ( (This)->lpVtbl -> get_PivotLineCells(This,RHS) ) 

#define IPivotLine_get_PivotLineCellsFull(This,RHS)	\
    ( (This)->lpVtbl -> get_PivotLineCellsFull(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IPivotLine_INTERFACE_DEFINED__ */


#ifndef __IPivotLines_INTERFACE_DEFINED__
#define __IPivotLines_INTERFACE_DEFINED__

/* interface IPivotLines */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IPivotLines;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024481-0001-0000-C000-000000000046")
    IPivotLines : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ PivotLine	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ PivotLine	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IPivotLinesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IPivotLines * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IPivotLines * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IPivotLines * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IPivotLines * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IPivotLines * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IPivotLines * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IPivotLines * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IPivotLines * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IPivotLines * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IPivotLines * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IPivotLines * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ PivotLine	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            IPivotLines * This,
            /* [retval][out] */ IUnknown **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Item )( 
            IPivotLines * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ PivotLine	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IPivotLines * This,
            /* [retval][out] */ long *RHS);
        
        END_INTERFACE
    } IPivotLinesVtbl;

    interface IPivotLines
    {
        CONST_VTBL struct IPivotLinesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IPivotLines_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IPivotLines_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IPivotLines_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IPivotLines_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IPivotLines_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IPivotLines_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IPivotLines_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IPivotLines_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IPivotLines_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IPivotLines_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IPivotLines_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define IPivotLines_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#define IPivotLines_get_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Item(This,Index,RHS) ) 

#define IPivotLines_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IPivotLines_INTERFACE_DEFINED__ */


#ifndef __IPivotAxis_INTERFACE_DEFINED__
#define __IPivotAxis_INTERFACE_DEFINED__

/* interface IPivotAxis */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IPivotAxis;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024482-0001-0000-C000-000000000046")
    IPivotAxis : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PivotLines( 
            /* [retval][out] */ PivotLines	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IPivotAxisVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IPivotAxis * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IPivotAxis * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IPivotAxis * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IPivotAxis * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IPivotAxis * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IPivotAxis * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IPivotAxis * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IPivotAxis * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IPivotAxis * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IPivotAxis * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PivotLines )( 
            IPivotAxis * This,
            /* [retval][out] */ PivotLines	**RHS);
        
        END_INTERFACE
    } IPivotAxisVtbl;

    interface IPivotAxis
    {
        CONST_VTBL struct IPivotAxisVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IPivotAxis_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IPivotAxis_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IPivotAxis_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IPivotAxis_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IPivotAxis_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IPivotAxis_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IPivotAxis_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IPivotAxis_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IPivotAxis_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IPivotAxis_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IPivotAxis_get_PivotLines(This,RHS)	\
    ( (This)->lpVtbl -> get_PivotLines(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IPivotAxis_INTERFACE_DEFINED__ */


#ifndef __IPivotFilter_INTERFACE_DEFINED__
#define __IPivotFilter_INTERFACE_DEFINED__

/* interface IPivotFilter */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IPivotFilter;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024483-0001-0000-C000-000000000046")
    IPivotFilter : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Order( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Order( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_FilterType( 
            /* [retval][out] */ XlPivotFilterType *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Description( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Active( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PivotField( 
            /* [retval][out] */ PivotField	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DataField( 
            /* [retval][out] */ PivotField	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DataCubeField( 
            /* [retval][out] */ CubeField **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Value1( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Value2( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MemberPropertyField( 
            /* [retval][out] */ PivotField	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_IsMemberPropertyFilter( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_WholeDayFilter( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_WholeDayFilter( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IPivotFilterVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IPivotFilter * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IPivotFilter * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IPivotFilter * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IPivotFilter * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IPivotFilter * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IPivotFilter * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IPivotFilter * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IPivotFilter * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IPivotFilter * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IPivotFilter * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Order )( 
            IPivotFilter * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Order )( 
            IPivotFilter * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_FilterType )( 
            IPivotFilter * This,
            /* [retval][out] */ XlPivotFilterType *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            IPivotFilter * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Description )( 
            IPivotFilter * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IPivotFilter * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Active )( 
            IPivotFilter * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PivotField )( 
            IPivotFilter * This,
            /* [retval][out] */ PivotField	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DataField )( 
            IPivotFilter * This,
            /* [retval][out] */ PivotField	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DataCubeField )( 
            IPivotFilter * This,
            /* [retval][out] */ CubeField **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Value1 )( 
            IPivotFilter * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Value2 )( 
            IPivotFilter * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MemberPropertyField )( 
            IPivotFilter * This,
            /* [retval][out] */ PivotField	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_IsMemberPropertyFilter )( 
            IPivotFilter * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_WholeDayFilter )( 
            IPivotFilter * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_WholeDayFilter )( 
            IPivotFilter * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        END_INTERFACE
    } IPivotFilterVtbl;

    interface IPivotFilter
    {
        CONST_VTBL struct IPivotFilterVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IPivotFilter_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IPivotFilter_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IPivotFilter_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IPivotFilter_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IPivotFilter_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IPivotFilter_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IPivotFilter_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IPivotFilter_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IPivotFilter_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IPivotFilter_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IPivotFilter_get_Order(This,RHS)	\
    ( (This)->lpVtbl -> get_Order(This,RHS) ) 

#define IPivotFilter_put_Order(This,RHS)	\
    ( (This)->lpVtbl -> put_Order(This,RHS) ) 

#define IPivotFilter_get_FilterType(This,RHS)	\
    ( (This)->lpVtbl -> get_FilterType(This,RHS) ) 

#define IPivotFilter_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define IPivotFilter_get_Description(This,RHS)	\
    ( (This)->lpVtbl -> get_Description(This,RHS) ) 

#define IPivotFilter_Delete(This)	\
    ( (This)->lpVtbl -> Delete(This) ) 

#define IPivotFilter_get_Active(This,RHS)	\
    ( (This)->lpVtbl -> get_Active(This,RHS) ) 

#define IPivotFilter_get_PivotField(This,RHS)	\
    ( (This)->lpVtbl -> get_PivotField(This,RHS) ) 

#define IPivotFilter_get_DataField(This,RHS)	\
    ( (This)->lpVtbl -> get_DataField(This,RHS) ) 

#define IPivotFilter_get_DataCubeField(This,RHS)	\
    ( (This)->lpVtbl -> get_DataCubeField(This,RHS) ) 

#define IPivotFilter_get_Value1(This,RHS)	\
    ( (This)->lpVtbl -> get_Value1(This,RHS) ) 

#define IPivotFilter_get_Value2(This,RHS)	\
    ( (This)->lpVtbl -> get_Value2(This,RHS) ) 

#define IPivotFilter_get_MemberPropertyField(This,RHS)	\
    ( (This)->lpVtbl -> get_MemberPropertyField(This,RHS) ) 

#define IPivotFilter_get_IsMemberPropertyFilter(This,RHS)	\
    ( (This)->lpVtbl -> get_IsMemberPropertyFilter(This,RHS) ) 

#define IPivotFilter_get_WholeDayFilter(This,RHS)	\
    ( (This)->lpVtbl -> get_WholeDayFilter(This,RHS) ) 

#define IPivotFilter_put_WholeDayFilter(This,RHS)	\
    ( (This)->lpVtbl -> put_WholeDayFilter(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IPivotFilter_INTERFACE_DEFINED__ */


#ifndef __IPivotFilters_INTERFACE_DEFINED__
#define __IPivotFilters_INTERFACE_DEFINED__

/* interface IPivotFilters */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IPivotFilters;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024484-0001-0000-C000-000000000046")
    IPivotFilters : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ PivotFilter	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ PivotFilter	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall Add( 
            /* [in] */ XlPivotFilterType Type,
            /* [optional][in] */ VARIANT DataField,
            /* [optional][in] */ VARIANT Value1,
            /* [optional][in] */ VARIANT Value2,
            /* [optional][in] */ VARIANT Order,
            /* [optional][in] */ VARIANT Name,
            /* [optional][in] */ VARIANT Description,
            /* [optional][in] */ VARIANT MemberPropertyField,
            /* [retval][out] */ PivotFilter	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add2( 
            /* [in] */ XlPivotFilterType Type,
            /* [optional][in] */ VARIANT DataField,
            /* [optional][in] */ VARIANT Value1,
            /* [optional][in] */ VARIANT Value2,
            /* [optional][in] */ VARIANT Order,
            /* [optional][in] */ VARIANT Name,
            /* [optional][in] */ VARIANT Description,
            /* [optional][in] */ VARIANT MemberPropertyField,
            /* [optional][in] */ VARIANT WholeDayFilter,
            /* [retval][out] */ PivotFilter	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IPivotFiltersVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IPivotFilters * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IPivotFilters * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IPivotFilters * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IPivotFilters * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IPivotFilters * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IPivotFilters * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IPivotFilters * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IPivotFilters * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IPivotFilters * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IPivotFilters * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IPivotFilters * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ PivotFilter	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            IPivotFilters * This,
            /* [retval][out] */ IUnknown **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Item )( 
            IPivotFilters * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ PivotFilter	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IPivotFilters * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *Add )( 
            IPivotFilters * This,
            /* [in] */ XlPivotFilterType Type,
            /* [optional][in] */ VARIANT DataField,
            /* [optional][in] */ VARIANT Value1,
            /* [optional][in] */ VARIANT Value2,
            /* [optional][in] */ VARIANT Order,
            /* [optional][in] */ VARIANT Name,
            /* [optional][in] */ VARIANT Description,
            /* [optional][in] */ VARIANT MemberPropertyField,
            /* [retval][out] */ PivotFilter	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add2 )( 
            IPivotFilters * This,
            /* [in] */ XlPivotFilterType Type,
            /* [optional][in] */ VARIANT DataField,
            /* [optional][in] */ VARIANT Value1,
            /* [optional][in] */ VARIANT Value2,
            /* [optional][in] */ VARIANT Order,
            /* [optional][in] */ VARIANT Name,
            /* [optional][in] */ VARIANT Description,
            /* [optional][in] */ VARIANT MemberPropertyField,
            /* [optional][in] */ VARIANT WholeDayFilter,
            /* [retval][out] */ PivotFilter	**RHS);
        
        END_INTERFACE
    } IPivotFiltersVtbl;

    interface IPivotFilters
    {
        CONST_VTBL struct IPivotFiltersVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IPivotFilters_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IPivotFilters_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IPivotFilters_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IPivotFilters_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IPivotFilters_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IPivotFilters_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IPivotFilters_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IPivotFilters_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IPivotFilters_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IPivotFilters_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IPivotFilters_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define IPivotFilters_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#define IPivotFilters_get_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Item(This,Index,RHS) ) 

#define IPivotFilters_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IPivotFilters_Add(This,Type,DataField,Value1,Value2,Order,Name,Description,MemberPropertyField,RHS)	\
    ( (This)->lpVtbl -> Add(This,Type,DataField,Value1,Value2,Order,Name,Description,MemberPropertyField,RHS) ) 

#define IPivotFilters_Add2(This,Type,DataField,Value1,Value2,Order,Name,Description,MemberPropertyField,WholeDayFilter,RHS)	\
    ( (This)->lpVtbl -> Add2(This,Type,DataField,Value1,Value2,Order,Name,Description,MemberPropertyField,WholeDayFilter,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IPivotFilters_INTERFACE_DEFINED__ */


#ifndef __IWorkbookConnection_INTERFACE_DEFINED__
#define __IWorkbookConnection_INTERFACE_DEFINED__

/* interface IWorkbookConnection */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IWorkbookConnection;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024485-0001-0000-C000-000000000046")
    IWorkbookConnection : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Name( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Description( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Description( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put__Default( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Type( 
            /* [retval][out] */ XlConnectionType *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_OLEDBConnection( 
            /* [retval][out] */ OLEDBConnection	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ODBCConnection( 
            /* [retval][out] */ ODBCConnection	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Ranges( 
            /* [retval][out] */ Ranges	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Refresh( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ModelConnection( 
            /* [retval][out] */ ModelConnection	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_WorksheetDataConnection( 
            /* [retval][out] */ WorksheetDataConnection	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RefreshWithRefreshAll( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_RefreshWithRefreshAll( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TextConnection( 
            /* [retval][out] */ TextConnection	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DataFeedConnection( 
            /* [retval][out] */ DataFeedConnection	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_InModel( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ModelTables( 
            /* [retval][out] */ ModelTables	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IWorkbookConnectionVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IWorkbookConnection * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IWorkbookConnection * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IWorkbookConnection * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IWorkbookConnection * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IWorkbookConnection * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IWorkbookConnection * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IWorkbookConnection * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IWorkbookConnection * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IWorkbookConnection * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IWorkbookConnection * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            IWorkbookConnection * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Name )( 
            IWorkbookConnection * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Description )( 
            IWorkbookConnection * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Description )( 
            IWorkbookConnection * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IWorkbookConnection * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put__Default )( 
            IWorkbookConnection * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Type )( 
            IWorkbookConnection * This,
            /* [retval][out] */ XlConnectionType *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_OLEDBConnection )( 
            IWorkbookConnection * This,
            /* [retval][out] */ OLEDBConnection	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ODBCConnection )( 
            IWorkbookConnection * This,
            /* [retval][out] */ ODBCConnection	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Ranges )( 
            IWorkbookConnection * This,
            /* [retval][out] */ Ranges	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IWorkbookConnection * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Refresh )( 
            IWorkbookConnection * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ModelConnection )( 
            IWorkbookConnection * This,
            /* [retval][out] */ ModelConnection	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_WorksheetDataConnection )( 
            IWorkbookConnection * This,
            /* [retval][out] */ WorksheetDataConnection	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RefreshWithRefreshAll )( 
            IWorkbookConnection * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_RefreshWithRefreshAll )( 
            IWorkbookConnection * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TextConnection )( 
            IWorkbookConnection * This,
            /* [retval][out] */ TextConnection	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DataFeedConnection )( 
            IWorkbookConnection * This,
            /* [retval][out] */ DataFeedConnection	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_InModel )( 
            IWorkbookConnection * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ModelTables )( 
            IWorkbookConnection * This,
            /* [retval][out] */ ModelTables	**RHS);
        
        END_INTERFACE
    } IWorkbookConnectionVtbl;

    interface IWorkbookConnection
    {
        CONST_VTBL struct IWorkbookConnectionVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IWorkbookConnection_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IWorkbookConnection_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IWorkbookConnection_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IWorkbookConnection_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IWorkbookConnection_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IWorkbookConnection_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IWorkbookConnection_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IWorkbookConnection_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IWorkbookConnection_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IWorkbookConnection_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IWorkbookConnection_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define IWorkbookConnection_put_Name(This,RHS)	\
    ( (This)->lpVtbl -> put_Name(This,RHS) ) 

#define IWorkbookConnection_get_Description(This,RHS)	\
    ( (This)->lpVtbl -> get_Description(This,RHS) ) 

#define IWorkbookConnection_put_Description(This,RHS)	\
    ( (This)->lpVtbl -> put_Description(This,RHS) ) 

#define IWorkbookConnection_get__Default(This,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,RHS) ) 

#define IWorkbookConnection_put__Default(This,RHS)	\
    ( (This)->lpVtbl -> put__Default(This,RHS) ) 

#define IWorkbookConnection_get_Type(This,RHS)	\
    ( (This)->lpVtbl -> get_Type(This,RHS) ) 

#define IWorkbookConnection_get_OLEDBConnection(This,RHS)	\
    ( (This)->lpVtbl -> get_OLEDBConnection(This,RHS) ) 

#define IWorkbookConnection_get_ODBCConnection(This,RHS)	\
    ( (This)->lpVtbl -> get_ODBCConnection(This,RHS) ) 

#define IWorkbookConnection_get_Ranges(This,RHS)	\
    ( (This)->lpVtbl -> get_Ranges(This,RHS) ) 

#define IWorkbookConnection_Delete(This)	\
    ( (This)->lpVtbl -> Delete(This) ) 

#define IWorkbookConnection_Refresh(This)	\
    ( (This)->lpVtbl -> Refresh(This) ) 

#define IWorkbookConnection_get_ModelConnection(This,RHS)	\
    ( (This)->lpVtbl -> get_ModelConnection(This,RHS) ) 

#define IWorkbookConnection_get_WorksheetDataConnection(This,RHS)	\
    ( (This)->lpVtbl -> get_WorksheetDataConnection(This,RHS) ) 

#define IWorkbookConnection_get_RefreshWithRefreshAll(This,RHS)	\
    ( (This)->lpVtbl -> get_RefreshWithRefreshAll(This,RHS) ) 

#define IWorkbookConnection_put_RefreshWithRefreshAll(This,RHS)	\
    ( (This)->lpVtbl -> put_RefreshWithRefreshAll(This,RHS) ) 

#define IWorkbookConnection_get_TextConnection(This,RHS)	\
    ( (This)->lpVtbl -> get_TextConnection(This,RHS) ) 

#define IWorkbookConnection_get_DataFeedConnection(This,RHS)	\
    ( (This)->lpVtbl -> get_DataFeedConnection(This,RHS) ) 

#define IWorkbookConnection_get_InModel(This,RHS)	\
    ( (This)->lpVtbl -> get_InModel(This,RHS) ) 

#define IWorkbookConnection_get_ModelTables(This,RHS)	\
    ( (This)->lpVtbl -> get_ModelTables(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IWorkbookConnection_INTERFACE_DEFINED__ */


#ifndef __IConnections_INTERFACE_DEFINED__
#define __IConnections_INTERFACE_DEFINED__

/* interface IConnections */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IConnections;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024486-0001-0000-C000-000000000046")
    IConnections : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [custom][helpcontext][hidden][id] */ HRESULT __stdcall _AddFromFile( 
            /* [in] */ BSTR Filename,
            /* [retval][out] */ WorkbookConnection	**RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall Add( 
            /* [in] */ BSTR Name,
            /* [in] */ BSTR Description,
            /* [in] */ VARIANT ConnectionString,
            /* [in] */ VARIANT CommandText,
            /* [optional][in] */ VARIANT lCmdtype,
            /* [retval][out] */ WorkbookConnection	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ WorkbookConnection	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ WorkbookConnection	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add2( 
            /* [in] */ BSTR Name,
            /* [in] */ BSTR Description,
            /* [in] */ VARIANT ConnectionString,
            /* [in] */ VARIANT CommandText,
            /* [optional][in] */ VARIANT lCmdtype,
            /* [optional][in] */ VARIANT CreateModelConnection,
            /* [optional][in] */ VARIANT ImportRelationships,
            /* [retval][out] */ WorkbookConnection	**RHS) = 0;
        
        virtual /* [custom][helpcontext][id] */ HRESULT __stdcall AddFromFile( 
            /* [in] */ BSTR Filename,
            /* [optional][in] */ VARIANT CreateModelConnection,
            /* [optional][in] */ VARIANT ImportRelationships,
            /* [retval][out] */ WorkbookConnection	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IConnectionsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IConnections * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IConnections * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IConnections * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IConnections * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IConnections * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IConnections * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IConnections * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IConnections * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IConnections * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IConnections * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IConnections * This,
            /* [retval][out] */ long *RHS);
        
        /* [custom][helpcontext][hidden][id] */ HRESULT ( __stdcall *_AddFromFile )( 
            IConnections * This,
            /* [in] */ BSTR Filename,
            /* [retval][out] */ WorkbookConnection	**RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *Add )( 
            IConnections * This,
            /* [in] */ BSTR Name,
            /* [in] */ BSTR Description,
            /* [in] */ VARIANT ConnectionString,
            /* [in] */ VARIANT CommandText,
            /* [optional][in] */ VARIANT lCmdtype,
            /* [retval][out] */ WorkbookConnection	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Item )( 
            IConnections * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ WorkbookConnection	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IConnections * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ WorkbookConnection	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            IConnections * This,
            /* [retval][out] */ IUnknown **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add2 )( 
            IConnections * This,
            /* [in] */ BSTR Name,
            /* [in] */ BSTR Description,
            /* [in] */ VARIANT ConnectionString,
            /* [in] */ VARIANT CommandText,
            /* [optional][in] */ VARIANT lCmdtype,
            /* [optional][in] */ VARIANT CreateModelConnection,
            /* [optional][in] */ VARIANT ImportRelationships,
            /* [retval][out] */ WorkbookConnection	**RHS);
        
        /* [custom][helpcontext][id] */ HRESULT ( __stdcall *AddFromFile )( 
            IConnections * This,
            /* [in] */ BSTR Filename,
            /* [optional][in] */ VARIANT CreateModelConnection,
            /* [optional][in] */ VARIANT ImportRelationships,
            /* [retval][out] */ WorkbookConnection	**RHS);
        
        END_INTERFACE
    } IConnectionsVtbl;

    interface IConnections
    {
        CONST_VTBL struct IConnectionsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IConnections_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IConnections_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IConnections_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IConnections_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IConnections_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IConnections_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IConnections_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IConnections_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IConnections_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IConnections_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IConnections_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IConnections__AddFromFile(This,Filename,RHS)	\
    ( (This)->lpVtbl -> _AddFromFile(This,Filename,RHS) ) 

#define IConnections_Add(This,Name,Description,ConnectionString,CommandText,lCmdtype,RHS)	\
    ( (This)->lpVtbl -> Add(This,Name,Description,ConnectionString,CommandText,lCmdtype,RHS) ) 

#define IConnections_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> Item(This,Index,RHS) ) 

#define IConnections_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define IConnections_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#define IConnections_Add2(This,Name,Description,ConnectionString,CommandText,lCmdtype,CreateModelConnection,ImportRelationships,RHS)	\
    ( (This)->lpVtbl -> Add2(This,Name,Description,ConnectionString,CommandText,lCmdtype,CreateModelConnection,ImportRelationships,RHS) ) 

#define IConnections_AddFromFile(This,Filename,CreateModelConnection,ImportRelationships,RHS)	\
    ( (This)->lpVtbl -> AddFromFile(This,Filename,CreateModelConnection,ImportRelationships,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IConnections_INTERFACE_DEFINED__ */


#ifndef __IWorksheetView_INTERFACE_DEFINED__
#define __IWorksheetView_INTERFACE_DEFINED__

/* interface IWorksheetView */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IWorksheetView;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024487-0001-0000-C000-000000000046")
    IWorksheetView : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Sheet( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DisplayGridlines( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DisplayGridlines( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DisplayFormulas( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DisplayFormulas( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DisplayHeadings( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DisplayHeadings( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DisplayOutline( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DisplayOutline( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DisplayZeros( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DisplayZeros( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IWorksheetViewVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IWorksheetView * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IWorksheetView * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IWorksheetView * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IWorksheetView * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IWorksheetView * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IWorksheetView * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IWorksheetView * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IWorksheetView * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IWorksheetView * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IWorksheetView * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Sheet )( 
            IWorksheetView * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DisplayGridlines )( 
            IWorksheetView * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DisplayGridlines )( 
            IWorksheetView * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DisplayFormulas )( 
            IWorksheetView * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DisplayFormulas )( 
            IWorksheetView * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DisplayHeadings )( 
            IWorksheetView * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DisplayHeadings )( 
            IWorksheetView * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DisplayOutline )( 
            IWorksheetView * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DisplayOutline )( 
            IWorksheetView * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DisplayZeros )( 
            IWorksheetView * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DisplayZeros )( 
            IWorksheetView * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        END_INTERFACE
    } IWorksheetViewVtbl;

    interface IWorksheetView
    {
        CONST_VTBL struct IWorksheetViewVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IWorksheetView_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IWorksheetView_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IWorksheetView_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IWorksheetView_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IWorksheetView_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IWorksheetView_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IWorksheetView_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IWorksheetView_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IWorksheetView_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IWorksheetView_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IWorksheetView_get_Sheet(This,RHS)	\
    ( (This)->lpVtbl -> get_Sheet(This,RHS) ) 

#define IWorksheetView_get_DisplayGridlines(This,RHS)	\
    ( (This)->lpVtbl -> get_DisplayGridlines(This,RHS) ) 

#define IWorksheetView_put_DisplayGridlines(This,RHS)	\
    ( (This)->lpVtbl -> put_DisplayGridlines(This,RHS) ) 

#define IWorksheetView_get_DisplayFormulas(This,RHS)	\
    ( (This)->lpVtbl -> get_DisplayFormulas(This,RHS) ) 

#define IWorksheetView_put_DisplayFormulas(This,RHS)	\
    ( (This)->lpVtbl -> put_DisplayFormulas(This,RHS) ) 

#define IWorksheetView_get_DisplayHeadings(This,RHS)	\
    ( (This)->lpVtbl -> get_DisplayHeadings(This,RHS) ) 

#define IWorksheetView_put_DisplayHeadings(This,RHS)	\
    ( (This)->lpVtbl -> put_DisplayHeadings(This,RHS) ) 

#define IWorksheetView_get_DisplayOutline(This,RHS)	\
    ( (This)->lpVtbl -> get_DisplayOutline(This,RHS) ) 

#define IWorksheetView_put_DisplayOutline(This,RHS)	\
    ( (This)->lpVtbl -> put_DisplayOutline(This,RHS) ) 

#define IWorksheetView_get_DisplayZeros(This,RHS)	\
    ( (This)->lpVtbl -> get_DisplayZeros(This,RHS) ) 

#define IWorksheetView_put_DisplayZeros(This,RHS)	\
    ( (This)->lpVtbl -> put_DisplayZeros(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IWorksheetView_INTERFACE_DEFINED__ */


#ifndef __IChartView_INTERFACE_DEFINED__
#define __IChartView_INTERFACE_DEFINED__

/* interface IChartView */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IChartView;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024488-0001-0000-C000-000000000046")
    IChartView : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Sheet( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IChartViewVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IChartView * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IChartView * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IChartView * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IChartView * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IChartView * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IChartView * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IChartView * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IChartView * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IChartView * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IChartView * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Sheet )( 
            IChartView * This,
            /* [retval][out] */ IDispatch **RHS);
        
        END_INTERFACE
    } IChartViewVtbl;

    interface IChartView
    {
        CONST_VTBL struct IChartViewVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IChartView_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IChartView_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IChartView_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IChartView_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IChartView_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IChartView_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IChartView_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IChartView_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IChartView_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IChartView_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IChartView_get_Sheet(This,RHS)	\
    ( (This)->lpVtbl -> get_Sheet(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IChartView_INTERFACE_DEFINED__ */


#ifndef __IModuleView_INTERFACE_DEFINED__
#define __IModuleView_INTERFACE_DEFINED__

/* interface IModuleView */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IModuleView;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024489-0001-0000-C000-000000000046")
    IModuleView : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Sheet( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IModuleViewVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IModuleView * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IModuleView * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IModuleView * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IModuleView * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IModuleView * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IModuleView * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IModuleView * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IModuleView * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IModuleView * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IModuleView * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Sheet )( 
            IModuleView * This,
            /* [retval][out] */ IDispatch **RHS);
        
        END_INTERFACE
    } IModuleViewVtbl;

    interface IModuleView
    {
        CONST_VTBL struct IModuleViewVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IModuleView_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IModuleView_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IModuleView_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IModuleView_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IModuleView_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IModuleView_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IModuleView_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IModuleView_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IModuleView_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IModuleView_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IModuleView_get_Sheet(This,RHS)	\
    ( (This)->lpVtbl -> get_Sheet(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IModuleView_INTERFACE_DEFINED__ */


#ifndef __IDialogSheetView_INTERFACE_DEFINED__
#define __IDialogSheetView_INTERFACE_DEFINED__

/* interface IDialogSheetView */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IDialogSheetView;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002448A-0001-0000-C000-000000000046")
    IDialogSheetView : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Sheet( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IDialogSheetViewVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IDialogSheetView * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IDialogSheetView * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IDialogSheetView * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IDialogSheetView * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IDialogSheetView * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IDialogSheetView * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IDialogSheetView * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IDialogSheetView * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IDialogSheetView * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IDialogSheetView * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Sheet )( 
            IDialogSheetView * This,
            /* [retval][out] */ IDispatch **RHS);
        
        END_INTERFACE
    } IDialogSheetViewVtbl;

    interface IDialogSheetView
    {
        CONST_VTBL struct IDialogSheetViewVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IDialogSheetView_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IDialogSheetView_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IDialogSheetView_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IDialogSheetView_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IDialogSheetView_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IDialogSheetView_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IDialogSheetView_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IDialogSheetView_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IDialogSheetView_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IDialogSheetView_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IDialogSheetView_get_Sheet(This,RHS)	\
    ( (This)->lpVtbl -> get_Sheet(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IDialogSheetView_INTERFACE_DEFINED__ */


#ifndef __ISheetViews_INTERFACE_DEFINED__
#define __ISheetViews_INTERFACE_DEFINED__

/* interface ISheetViews */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ISheetViews;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002448C-0001-0000-C000-000000000046")
    ISheetViews : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall _NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ISheetViewsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ISheetViews * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ISheetViews * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ISheetViews * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ISheetViews * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ISheetViews * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ISheetViews * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ISheetViews * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ISheetViews * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ISheetViews * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ISheetViews * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            ISheetViews * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *_NewEnum )( 
            ISheetViews * This,
            /* [retval][out] */ IUnknown **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Item )( 
            ISheetViews * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            ISheetViews * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS);
        
        END_INTERFACE
    } ISheetViewsVtbl;

    interface ISheetViews
    {
        CONST_VTBL struct ISheetViewsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ISheetViews_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ISheetViews_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ISheetViews_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ISheetViews_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ISheetViews_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ISheetViews_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ISheetViews_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ISheetViews_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ISheetViews_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ISheetViews_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ISheetViews_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define ISheetViews__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> _NewEnum(This,RHS) ) 

#define ISheetViews_get_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Item(This,Index,RHS) ) 

#define ISheetViews_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ISheetViews_INTERFACE_DEFINED__ */


#ifndef __IOLEDBConnection_INTERFACE_DEFINED__
#define __IOLEDBConnection_INTERFACE_DEFINED__

/* interface IOLEDBConnection */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IOLEDBConnection;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002448D-0001-0000-C000-000000000046")
    IOLEDBConnection : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ADOConnection( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_BackgroundQuery( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_BackgroundQuery( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CancelRefresh( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CommandText( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_CommandText( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CommandType( 
            /* [retval][out] */ XlCmdType *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_CommandType( 
            /* [in] */ XlCmdType RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Connection( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Connection( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_EnableRefresh( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_EnableRefresh( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LocalConnection( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_LocalConnection( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MaintainConnection( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_MaintainConnection( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall MakeConnection( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Refresh( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RefreshDate( 
            /* [retval][out] */ DATE *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Refreshing( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RefreshOnFileOpen( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_RefreshOnFileOpen( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RefreshPeriod( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_RefreshPeriod( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RobustConnect( 
            /* [retval][out] */ XlRobustConnect *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_RobustConnect( 
            /* [in] */ XlRobustConnect RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SaveAsODC( 
            /* [in] */ BSTR ODCFileName,
            /* [optional][in] */ VARIANT Description,
            /* [optional][in] */ VARIANT Keywords) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SavePassword( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_SavePassword( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SourceConnectionFile( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_SourceConnectionFile( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SourceDataFile( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_SourceDataFile( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_OLAP( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_UseLocalConnection( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_UseLocalConnection( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MaxDrillthroughRecords( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_MaxDrillthroughRecords( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_IsConnected( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ServerCredentialsMethod( 
            /* [retval][out] */ XlCredentialsMethod *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ServerCredentialsMethod( 
            /* [in] */ XlCredentialsMethod RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ServerSSOApplicationID( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ServerSSOApplicationID( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AlwaysUseConnectionFile( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AlwaysUseConnectionFile( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ServerFillColor( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ServerFillColor( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ServerFontStyle( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ServerFontStyle( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ServerNumberFormat( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ServerNumberFormat( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ServerTextColor( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ServerTextColor( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RetrieveInOfficeUILang( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_RetrieveInOfficeUILang( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Reconnect( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CalculatedMembers( 
            /* [retval][out] */ CalculatedMembers	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LocaleID( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_LocaleID( 
            /* [in] */ long RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IOLEDBConnectionVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IOLEDBConnection * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IOLEDBConnection * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IOLEDBConnection * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IOLEDBConnection * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IOLEDBConnection * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IOLEDBConnection * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IOLEDBConnection * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IOLEDBConnection * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IOLEDBConnection * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IOLEDBConnection * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ADOConnection )( 
            IOLEDBConnection * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_BackgroundQuery )( 
            IOLEDBConnection * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_BackgroundQuery )( 
            IOLEDBConnection * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CancelRefresh )( 
            IOLEDBConnection * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CommandText )( 
            IOLEDBConnection * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_CommandText )( 
            IOLEDBConnection * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CommandType )( 
            IOLEDBConnection * This,
            /* [retval][out] */ XlCmdType *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_CommandType )( 
            IOLEDBConnection * This,
            /* [in] */ XlCmdType RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Connection )( 
            IOLEDBConnection * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Connection )( 
            IOLEDBConnection * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_EnableRefresh )( 
            IOLEDBConnection * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_EnableRefresh )( 
            IOLEDBConnection * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LocalConnection )( 
            IOLEDBConnection * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_LocalConnection )( 
            IOLEDBConnection * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MaintainConnection )( 
            IOLEDBConnection * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_MaintainConnection )( 
            IOLEDBConnection * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *MakeConnection )( 
            IOLEDBConnection * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Refresh )( 
            IOLEDBConnection * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RefreshDate )( 
            IOLEDBConnection * This,
            /* [retval][out] */ DATE *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Refreshing )( 
            IOLEDBConnection * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RefreshOnFileOpen )( 
            IOLEDBConnection * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_RefreshOnFileOpen )( 
            IOLEDBConnection * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RefreshPeriod )( 
            IOLEDBConnection * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_RefreshPeriod )( 
            IOLEDBConnection * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RobustConnect )( 
            IOLEDBConnection * This,
            /* [retval][out] */ XlRobustConnect *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_RobustConnect )( 
            IOLEDBConnection * This,
            /* [in] */ XlRobustConnect RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SaveAsODC )( 
            IOLEDBConnection * This,
            /* [in] */ BSTR ODCFileName,
            /* [optional][in] */ VARIANT Description,
            /* [optional][in] */ VARIANT Keywords);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SavePassword )( 
            IOLEDBConnection * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_SavePassword )( 
            IOLEDBConnection * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SourceConnectionFile )( 
            IOLEDBConnection * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_SourceConnectionFile )( 
            IOLEDBConnection * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SourceDataFile )( 
            IOLEDBConnection * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_SourceDataFile )( 
            IOLEDBConnection * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_OLAP )( 
            IOLEDBConnection * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_UseLocalConnection )( 
            IOLEDBConnection * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_UseLocalConnection )( 
            IOLEDBConnection * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MaxDrillthroughRecords )( 
            IOLEDBConnection * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_MaxDrillthroughRecords )( 
            IOLEDBConnection * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_IsConnected )( 
            IOLEDBConnection * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ServerCredentialsMethod )( 
            IOLEDBConnection * This,
            /* [retval][out] */ XlCredentialsMethod *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ServerCredentialsMethod )( 
            IOLEDBConnection * This,
            /* [in] */ XlCredentialsMethod RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ServerSSOApplicationID )( 
            IOLEDBConnection * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ServerSSOApplicationID )( 
            IOLEDBConnection * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AlwaysUseConnectionFile )( 
            IOLEDBConnection * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AlwaysUseConnectionFile )( 
            IOLEDBConnection * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ServerFillColor )( 
            IOLEDBConnection * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ServerFillColor )( 
            IOLEDBConnection * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ServerFontStyle )( 
            IOLEDBConnection * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ServerFontStyle )( 
            IOLEDBConnection * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ServerNumberFormat )( 
            IOLEDBConnection * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ServerNumberFormat )( 
            IOLEDBConnection * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ServerTextColor )( 
            IOLEDBConnection * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ServerTextColor )( 
            IOLEDBConnection * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RetrieveInOfficeUILang )( 
            IOLEDBConnection * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_RetrieveInOfficeUILang )( 
            IOLEDBConnection * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Reconnect )( 
            IOLEDBConnection * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CalculatedMembers )( 
            IOLEDBConnection * This,
            /* [retval][out] */ CalculatedMembers	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LocaleID )( 
            IOLEDBConnection * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_LocaleID )( 
            IOLEDBConnection * This,
            /* [in] */ long RHS);
        
        END_INTERFACE
    } IOLEDBConnectionVtbl;

    interface IOLEDBConnection
    {
        CONST_VTBL struct IOLEDBConnectionVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IOLEDBConnection_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IOLEDBConnection_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IOLEDBConnection_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IOLEDBConnection_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IOLEDBConnection_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IOLEDBConnection_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IOLEDBConnection_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IOLEDBConnection_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IOLEDBConnection_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IOLEDBConnection_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IOLEDBConnection_get_ADOConnection(This,RHS)	\
    ( (This)->lpVtbl -> get_ADOConnection(This,RHS) ) 

#define IOLEDBConnection_get_BackgroundQuery(This,RHS)	\
    ( (This)->lpVtbl -> get_BackgroundQuery(This,RHS) ) 

#define IOLEDBConnection_put_BackgroundQuery(This,RHS)	\
    ( (This)->lpVtbl -> put_BackgroundQuery(This,RHS) ) 

#define IOLEDBConnection_CancelRefresh(This)	\
    ( (This)->lpVtbl -> CancelRefresh(This) ) 

#define IOLEDBConnection_get_CommandText(This,RHS)	\
    ( (This)->lpVtbl -> get_CommandText(This,RHS) ) 

#define IOLEDBConnection_put_CommandText(This,RHS)	\
    ( (This)->lpVtbl -> put_CommandText(This,RHS) ) 

#define IOLEDBConnection_get_CommandType(This,RHS)	\
    ( (This)->lpVtbl -> get_CommandType(This,RHS) ) 

#define IOLEDBConnection_put_CommandType(This,RHS)	\
    ( (This)->lpVtbl -> put_CommandType(This,RHS) ) 

#define IOLEDBConnection_get_Connection(This,RHS)	\
    ( (This)->lpVtbl -> get_Connection(This,RHS) ) 

#define IOLEDBConnection_put_Connection(This,RHS)	\
    ( (This)->lpVtbl -> put_Connection(This,RHS) ) 

#define IOLEDBConnection_get_EnableRefresh(This,RHS)	\
    ( (This)->lpVtbl -> get_EnableRefresh(This,RHS) ) 

#define IOLEDBConnection_put_EnableRefresh(This,RHS)	\
    ( (This)->lpVtbl -> put_EnableRefresh(This,RHS) ) 

#define IOLEDBConnection_get_LocalConnection(This,RHS)	\
    ( (This)->lpVtbl -> get_LocalConnection(This,RHS) ) 

#define IOLEDBConnection_put_LocalConnection(This,RHS)	\
    ( (This)->lpVtbl -> put_LocalConnection(This,RHS) ) 

#define IOLEDBConnection_get_MaintainConnection(This,RHS)	\
    ( (This)->lpVtbl -> get_MaintainConnection(This,RHS) ) 

#define IOLEDBConnection_put_MaintainConnection(This,RHS)	\
    ( (This)->lpVtbl -> put_MaintainConnection(This,RHS) ) 

#define IOLEDBConnection_MakeConnection(This)	\
    ( (This)->lpVtbl -> MakeConnection(This) ) 

#define IOLEDBConnection_Refresh(This)	\
    ( (This)->lpVtbl -> Refresh(This) ) 

#define IOLEDBConnection_get_RefreshDate(This,RHS)	\
    ( (This)->lpVtbl -> get_RefreshDate(This,RHS) ) 

#define IOLEDBConnection_get_Refreshing(This,RHS)	\
    ( (This)->lpVtbl -> get_Refreshing(This,RHS) ) 

#define IOLEDBConnection_get_RefreshOnFileOpen(This,RHS)	\
    ( (This)->lpVtbl -> get_RefreshOnFileOpen(This,RHS) ) 

#define IOLEDBConnection_put_RefreshOnFileOpen(This,RHS)	\
    ( (This)->lpVtbl -> put_RefreshOnFileOpen(This,RHS) ) 

#define IOLEDBConnection_get_RefreshPeriod(This,RHS)	\
    ( (This)->lpVtbl -> get_RefreshPeriod(This,RHS) ) 

#define IOLEDBConnection_put_RefreshPeriod(This,RHS)	\
    ( (This)->lpVtbl -> put_RefreshPeriod(This,RHS) ) 

#define IOLEDBConnection_get_RobustConnect(This,RHS)	\
    ( (This)->lpVtbl -> get_RobustConnect(This,RHS) ) 

#define IOLEDBConnection_put_RobustConnect(This,RHS)	\
    ( (This)->lpVtbl -> put_RobustConnect(This,RHS) ) 

#define IOLEDBConnection_SaveAsODC(This,ODCFileName,Description,Keywords)	\
    ( (This)->lpVtbl -> SaveAsODC(This,ODCFileName,Description,Keywords) ) 

#define IOLEDBConnection_get_SavePassword(This,RHS)	\
    ( (This)->lpVtbl -> get_SavePassword(This,RHS) ) 

#define IOLEDBConnection_put_SavePassword(This,RHS)	\
    ( (This)->lpVtbl -> put_SavePassword(This,RHS) ) 

#define IOLEDBConnection_get_SourceConnectionFile(This,RHS)	\
    ( (This)->lpVtbl -> get_SourceConnectionFile(This,RHS) ) 

#define IOLEDBConnection_put_SourceConnectionFile(This,RHS)	\
    ( (This)->lpVtbl -> put_SourceConnectionFile(This,RHS) ) 

#define IOLEDBConnection_get_SourceDataFile(This,RHS)	\
    ( (This)->lpVtbl -> get_SourceDataFile(This,RHS) ) 

#define IOLEDBConnection_put_SourceDataFile(This,RHS)	\
    ( (This)->lpVtbl -> put_SourceDataFile(This,RHS) ) 

#define IOLEDBConnection_get_OLAP(This,RHS)	\
    ( (This)->lpVtbl -> get_OLAP(This,RHS) ) 

#define IOLEDBConnection_get_UseLocalConnection(This,RHS)	\
    ( (This)->lpVtbl -> get_UseLocalConnection(This,RHS) ) 

#define IOLEDBConnection_put_UseLocalConnection(This,RHS)	\
    ( (This)->lpVtbl -> put_UseLocalConnection(This,RHS) ) 

#define IOLEDBConnection_get_MaxDrillthroughRecords(This,RHS)	\
    ( (This)->lpVtbl -> get_MaxDrillthroughRecords(This,RHS) ) 

#define IOLEDBConnection_put_MaxDrillthroughRecords(This,RHS)	\
    ( (This)->lpVtbl -> put_MaxDrillthroughRecords(This,RHS) ) 

#define IOLEDBConnection_get_IsConnected(This,RHS)	\
    ( (This)->lpVtbl -> get_IsConnected(This,RHS) ) 

#define IOLEDBConnection_get_ServerCredentialsMethod(This,RHS)	\
    ( (This)->lpVtbl -> get_ServerCredentialsMethod(This,RHS) ) 

#define IOLEDBConnection_put_ServerCredentialsMethod(This,RHS)	\
    ( (This)->lpVtbl -> put_ServerCredentialsMethod(This,RHS) ) 

#define IOLEDBConnection_get_ServerSSOApplicationID(This,RHS)	\
    ( (This)->lpVtbl -> get_ServerSSOApplicationID(This,RHS) ) 

#define IOLEDBConnection_put_ServerSSOApplicationID(This,RHS)	\
    ( (This)->lpVtbl -> put_ServerSSOApplicationID(This,RHS) ) 

#define IOLEDBConnection_get_AlwaysUseConnectionFile(This,RHS)	\
    ( (This)->lpVtbl -> get_AlwaysUseConnectionFile(This,RHS) ) 

#define IOLEDBConnection_put_AlwaysUseConnectionFile(This,RHS)	\
    ( (This)->lpVtbl -> put_AlwaysUseConnectionFile(This,RHS) ) 

#define IOLEDBConnection_get_ServerFillColor(This,RHS)	\
    ( (This)->lpVtbl -> get_ServerFillColor(This,RHS) ) 

#define IOLEDBConnection_put_ServerFillColor(This,RHS)	\
    ( (This)->lpVtbl -> put_ServerFillColor(This,RHS) ) 

#define IOLEDBConnection_get_ServerFontStyle(This,RHS)	\
    ( (This)->lpVtbl -> get_ServerFontStyle(This,RHS) ) 

#define IOLEDBConnection_put_ServerFontStyle(This,RHS)	\
    ( (This)->lpVtbl -> put_ServerFontStyle(This,RHS) ) 

#define IOLEDBConnection_get_ServerNumberFormat(This,RHS)	\
    ( (This)->lpVtbl -> get_ServerNumberFormat(This,RHS) ) 

#define IOLEDBConnection_put_ServerNumberFormat(This,RHS)	\
    ( (This)->lpVtbl -> put_ServerNumberFormat(This,RHS) ) 

#define IOLEDBConnection_get_ServerTextColor(This,RHS)	\
    ( (This)->lpVtbl -> get_ServerTextColor(This,RHS) ) 

#define IOLEDBConnection_put_ServerTextColor(This,RHS)	\
    ( (This)->lpVtbl -> put_ServerTextColor(This,RHS) ) 

#define IOLEDBConnection_get_RetrieveInOfficeUILang(This,RHS)	\
    ( (This)->lpVtbl -> get_RetrieveInOfficeUILang(This,RHS) ) 

#define IOLEDBConnection_put_RetrieveInOfficeUILang(This,RHS)	\
    ( (This)->lpVtbl -> put_RetrieveInOfficeUILang(This,RHS) ) 

#define IOLEDBConnection_Reconnect(This)	\
    ( (This)->lpVtbl -> Reconnect(This) ) 

#define IOLEDBConnection_get_CalculatedMembers(This,RHS)	\
    ( (This)->lpVtbl -> get_CalculatedMembers(This,RHS) ) 

#define IOLEDBConnection_get_LocaleID(This,RHS)	\
    ( (This)->lpVtbl -> get_LocaleID(This,RHS) ) 

#define IOLEDBConnection_put_LocaleID(This,RHS)	\
    ( (This)->lpVtbl -> put_LocaleID(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IOLEDBConnection_INTERFACE_DEFINED__ */


#ifndef __IODBCConnection_INTERFACE_DEFINED__
#define __IODBCConnection_INTERFACE_DEFINED__

/* interface IODBCConnection */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IODBCConnection;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002448E-0001-0000-C000-000000000046")
    IODBCConnection : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_BackgroundQuery( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_BackgroundQuery( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CancelRefresh( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CommandText( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_CommandText( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CommandType( 
            /* [retval][out] */ XlCmdType *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_CommandType( 
            /* [in] */ XlCmdType RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Connection( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Connection( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_EnableRefresh( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_EnableRefresh( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Refresh( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RefreshDate( 
            /* [retval][out] */ DATE *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Refreshing( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RefreshOnFileOpen( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_RefreshOnFileOpen( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RefreshPeriod( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_RefreshPeriod( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RobustConnect( 
            /* [retval][out] */ XlRobustConnect *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_RobustConnect( 
            /* [in] */ XlRobustConnect RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SaveAsODC( 
            /* [in] */ BSTR ODCFileName,
            /* [optional][in] */ VARIANT Description,
            /* [optional][in] */ VARIANT Keywords) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SavePassword( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_SavePassword( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SourceConnectionFile( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_SourceConnectionFile( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SourceData( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_SourceData( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SourceDataFile( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_SourceDataFile( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ServerCredentialsMethod( 
            /* [retval][out] */ XlCredentialsMethod *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ServerCredentialsMethod( 
            /* [in] */ XlCredentialsMethod RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ServerSSOApplicationID( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ServerSSOApplicationID( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AlwaysUseConnectionFile( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AlwaysUseConnectionFile( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IODBCConnectionVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IODBCConnection * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IODBCConnection * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IODBCConnection * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IODBCConnection * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IODBCConnection * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IODBCConnection * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IODBCConnection * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IODBCConnection * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IODBCConnection * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IODBCConnection * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_BackgroundQuery )( 
            IODBCConnection * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_BackgroundQuery )( 
            IODBCConnection * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CancelRefresh )( 
            IODBCConnection * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CommandText )( 
            IODBCConnection * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_CommandText )( 
            IODBCConnection * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CommandType )( 
            IODBCConnection * This,
            /* [retval][out] */ XlCmdType *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_CommandType )( 
            IODBCConnection * This,
            /* [in] */ XlCmdType RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Connection )( 
            IODBCConnection * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Connection )( 
            IODBCConnection * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_EnableRefresh )( 
            IODBCConnection * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_EnableRefresh )( 
            IODBCConnection * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Refresh )( 
            IODBCConnection * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RefreshDate )( 
            IODBCConnection * This,
            /* [retval][out] */ DATE *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Refreshing )( 
            IODBCConnection * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RefreshOnFileOpen )( 
            IODBCConnection * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_RefreshOnFileOpen )( 
            IODBCConnection * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RefreshPeriod )( 
            IODBCConnection * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_RefreshPeriod )( 
            IODBCConnection * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RobustConnect )( 
            IODBCConnection * This,
            /* [retval][out] */ XlRobustConnect *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_RobustConnect )( 
            IODBCConnection * This,
            /* [in] */ XlRobustConnect RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SaveAsODC )( 
            IODBCConnection * This,
            /* [in] */ BSTR ODCFileName,
            /* [optional][in] */ VARIANT Description,
            /* [optional][in] */ VARIANT Keywords);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SavePassword )( 
            IODBCConnection * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_SavePassword )( 
            IODBCConnection * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SourceConnectionFile )( 
            IODBCConnection * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_SourceConnectionFile )( 
            IODBCConnection * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SourceData )( 
            IODBCConnection * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_SourceData )( 
            IODBCConnection * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SourceDataFile )( 
            IODBCConnection * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_SourceDataFile )( 
            IODBCConnection * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ServerCredentialsMethod )( 
            IODBCConnection * This,
            /* [retval][out] */ XlCredentialsMethod *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ServerCredentialsMethod )( 
            IODBCConnection * This,
            /* [in] */ XlCredentialsMethod RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ServerSSOApplicationID )( 
            IODBCConnection * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ServerSSOApplicationID )( 
            IODBCConnection * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AlwaysUseConnectionFile )( 
            IODBCConnection * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AlwaysUseConnectionFile )( 
            IODBCConnection * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        END_INTERFACE
    } IODBCConnectionVtbl;

    interface IODBCConnection
    {
        CONST_VTBL struct IODBCConnectionVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IODBCConnection_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IODBCConnection_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IODBCConnection_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IODBCConnection_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IODBCConnection_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IODBCConnection_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IODBCConnection_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IODBCConnection_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IODBCConnection_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IODBCConnection_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IODBCConnection_get_BackgroundQuery(This,RHS)	\
    ( (This)->lpVtbl -> get_BackgroundQuery(This,RHS) ) 

#define IODBCConnection_put_BackgroundQuery(This,RHS)	\
    ( (This)->lpVtbl -> put_BackgroundQuery(This,RHS) ) 

#define IODBCConnection_CancelRefresh(This)	\
    ( (This)->lpVtbl -> CancelRefresh(This) ) 

#define IODBCConnection_get_CommandText(This,RHS)	\
    ( (This)->lpVtbl -> get_CommandText(This,RHS) ) 

#define IODBCConnection_put_CommandText(This,RHS)	\
    ( (This)->lpVtbl -> put_CommandText(This,RHS) ) 

#define IODBCConnection_get_CommandType(This,RHS)	\
    ( (This)->lpVtbl -> get_CommandType(This,RHS) ) 

#define IODBCConnection_put_CommandType(This,RHS)	\
    ( (This)->lpVtbl -> put_CommandType(This,RHS) ) 

#define IODBCConnection_get_Connection(This,RHS)	\
    ( (This)->lpVtbl -> get_Connection(This,RHS) ) 

#define IODBCConnection_put_Connection(This,RHS)	\
    ( (This)->lpVtbl -> put_Connection(This,RHS) ) 

#define IODBCConnection_get_EnableRefresh(This,RHS)	\
    ( (This)->lpVtbl -> get_EnableRefresh(This,RHS) ) 

#define IODBCConnection_put_EnableRefresh(This,RHS)	\
    ( (This)->lpVtbl -> put_EnableRefresh(This,RHS) ) 

#define IODBCConnection_Refresh(This)	\
    ( (This)->lpVtbl -> Refresh(This) ) 

#define IODBCConnection_get_RefreshDate(This,RHS)	\
    ( (This)->lpVtbl -> get_RefreshDate(This,RHS) ) 

#define IODBCConnection_get_Refreshing(This,RHS)	\
    ( (This)->lpVtbl -> get_Refreshing(This,RHS) ) 

#define IODBCConnection_get_RefreshOnFileOpen(This,RHS)	\
    ( (This)->lpVtbl -> get_RefreshOnFileOpen(This,RHS) ) 

#define IODBCConnection_put_RefreshOnFileOpen(This,RHS)	\
    ( (This)->lpVtbl -> put_RefreshOnFileOpen(This,RHS) ) 

#define IODBCConnection_get_RefreshPeriod(This,RHS)	\
    ( (This)->lpVtbl -> get_RefreshPeriod(This,RHS) ) 

#define IODBCConnection_put_RefreshPeriod(This,RHS)	\
    ( (This)->lpVtbl -> put_RefreshPeriod(This,RHS) ) 

#define IODBCConnection_get_RobustConnect(This,RHS)	\
    ( (This)->lpVtbl -> get_RobustConnect(This,RHS) ) 

#define IODBCConnection_put_RobustConnect(This,RHS)	\
    ( (This)->lpVtbl -> put_RobustConnect(This,RHS) ) 

#define IODBCConnection_SaveAsODC(This,ODCFileName,Description,Keywords)	\
    ( (This)->lpVtbl -> SaveAsODC(This,ODCFileName,Description,Keywords) ) 

#define IODBCConnection_get_SavePassword(This,RHS)	\
    ( (This)->lpVtbl -> get_SavePassword(This,RHS) ) 

#define IODBCConnection_put_SavePassword(This,RHS)	\
    ( (This)->lpVtbl -> put_SavePassword(This,RHS) ) 

#define IODBCConnection_get_SourceConnectionFile(This,RHS)	\
    ( (This)->lpVtbl -> get_SourceConnectionFile(This,RHS) ) 

#define IODBCConnection_put_SourceConnectionFile(This,RHS)	\
    ( (This)->lpVtbl -> put_SourceConnectionFile(This,RHS) ) 

#define IODBCConnection_get_SourceData(This,RHS)	\
    ( (This)->lpVtbl -> get_SourceData(This,RHS) ) 

#define IODBCConnection_put_SourceData(This,RHS)	\
    ( (This)->lpVtbl -> put_SourceData(This,RHS) ) 

#define IODBCConnection_get_SourceDataFile(This,RHS)	\
    ( (This)->lpVtbl -> get_SourceDataFile(This,RHS) ) 

#define IODBCConnection_put_SourceDataFile(This,RHS)	\
    ( (This)->lpVtbl -> put_SourceDataFile(This,RHS) ) 

#define IODBCConnection_get_ServerCredentialsMethod(This,RHS)	\
    ( (This)->lpVtbl -> get_ServerCredentialsMethod(This,RHS) ) 

#define IODBCConnection_put_ServerCredentialsMethod(This,RHS)	\
    ( (This)->lpVtbl -> put_ServerCredentialsMethod(This,RHS) ) 

#define IODBCConnection_get_ServerSSOApplicationID(This,RHS)	\
    ( (This)->lpVtbl -> get_ServerSSOApplicationID(This,RHS) ) 

#define IODBCConnection_put_ServerSSOApplicationID(This,RHS)	\
    ( (This)->lpVtbl -> put_ServerSSOApplicationID(This,RHS) ) 

#define IODBCConnection_get_AlwaysUseConnectionFile(This,RHS)	\
    ( (This)->lpVtbl -> get_AlwaysUseConnectionFile(This,RHS) ) 

#define IODBCConnection_put_AlwaysUseConnectionFile(This,RHS)	\
    ( (This)->lpVtbl -> put_AlwaysUseConnectionFile(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IODBCConnection_INTERFACE_DEFINED__ */


#ifndef __IAction_INTERFACE_DEFINED__
#define __IAction_INTERFACE_DEFINED__

/* interface IAction */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IAction;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002448F-0001-0000-C000-000000000046")
    IAction : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Caption( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Type( 
            /* [retval][out] */ XlActionType *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Coordinate( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Content( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Execute( void) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IActionVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IAction * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IAction * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IAction * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IAction * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IAction * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IAction * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IAction * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IAction * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IAction * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IAction * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            IAction * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Caption )( 
            IAction * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Type )( 
            IAction * This,
            /* [retval][out] */ XlActionType *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Coordinate )( 
            IAction * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Content )( 
            IAction * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Execute )( 
            IAction * This);
        
        END_INTERFACE
    } IActionVtbl;

    interface IAction
    {
        CONST_VTBL struct IActionVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IAction_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IAction_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IAction_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IAction_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IAction_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IAction_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IAction_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IAction_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IAction_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IAction_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IAction_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define IAction_get_Caption(This,RHS)	\
    ( (This)->lpVtbl -> get_Caption(This,RHS) ) 

#define IAction_get_Type(This,RHS)	\
    ( (This)->lpVtbl -> get_Type(This,RHS) ) 

#define IAction_get_Coordinate(This,RHS)	\
    ( (This)->lpVtbl -> get_Coordinate(This,RHS) ) 

#define IAction_get_Content(This,RHS)	\
    ( (This)->lpVtbl -> get_Content(This,RHS) ) 

#define IAction_Execute(This)	\
    ( (This)->lpVtbl -> Execute(This) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IAction_INTERFACE_DEFINED__ */


#ifndef __IActions_INTERFACE_DEFINED__
#define __IActions_INTERFACE_DEFINED__

/* interface IActions */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IActions;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024490-0001-0000-C000-000000000046")
    IActions : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Action	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Action	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IActionsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IActions * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IActions * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IActions * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IActions * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IActions * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IActions * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IActions * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IActions * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IActions * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IActions * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IActions * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Action	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            IActions * This,
            /* [retval][out] */ IUnknown **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Item )( 
            IActions * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Action	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IActions * This,
            /* [retval][out] */ long *RHS);
        
        END_INTERFACE
    } IActionsVtbl;

    interface IActions
    {
        CONST_VTBL struct IActionsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IActions_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IActions_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IActions_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IActions_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IActions_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IActions_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IActions_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IActions_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IActions_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IActions_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IActions_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define IActions_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#define IActions_get_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Item(This,Index,RHS) ) 

#define IActions_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IActions_INTERFACE_DEFINED__ */


#ifndef __IFormatColor_INTERFACE_DEFINED__
#define __IFormatColor_INTERFACE_DEFINED__

/* interface IFormatColor */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IFormatColor;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024491-0001-0000-C000-000000000046")
    IFormatColor : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Color( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Color( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ColorIndex( 
            /* [retval][out] */ XlColorIndex *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ColorIndex( 
            /* [in] */ XlColorIndex RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ThemeColor( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ThemeColor( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TintAndShade( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_TintAndShade( 
            /* [in] */ VARIANT RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IFormatColorVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IFormatColor * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IFormatColor * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IFormatColor * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IFormatColor * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IFormatColor * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IFormatColor * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IFormatColor * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IFormatColor * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IFormatColor * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IFormatColor * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Color )( 
            IFormatColor * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Color )( 
            IFormatColor * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ColorIndex )( 
            IFormatColor * This,
            /* [retval][out] */ XlColorIndex *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ColorIndex )( 
            IFormatColor * This,
            /* [in] */ XlColorIndex RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ThemeColor )( 
            IFormatColor * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ThemeColor )( 
            IFormatColor * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TintAndShade )( 
            IFormatColor * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_TintAndShade )( 
            IFormatColor * This,
            /* [in] */ VARIANT RHS);
        
        END_INTERFACE
    } IFormatColorVtbl;

    interface IFormatColor
    {
        CONST_VTBL struct IFormatColorVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IFormatColor_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IFormatColor_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IFormatColor_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IFormatColor_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IFormatColor_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IFormatColor_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IFormatColor_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IFormatColor_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IFormatColor_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IFormatColor_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IFormatColor_get_Color(This,RHS)	\
    ( (This)->lpVtbl -> get_Color(This,RHS) ) 

#define IFormatColor_put_Color(This,RHS)	\
    ( (This)->lpVtbl -> put_Color(This,RHS) ) 

#define IFormatColor_get_ColorIndex(This,RHS)	\
    ( (This)->lpVtbl -> get_ColorIndex(This,RHS) ) 

#define IFormatColor_put_ColorIndex(This,RHS)	\
    ( (This)->lpVtbl -> put_ColorIndex(This,RHS) ) 

#define IFormatColor_get_ThemeColor(This,RHS)	\
    ( (This)->lpVtbl -> get_ThemeColor(This,RHS) ) 

#define IFormatColor_put_ThemeColor(This,RHS)	\
    ( (This)->lpVtbl -> put_ThemeColor(This,RHS) ) 

#define IFormatColor_get_TintAndShade(This,RHS)	\
    ( (This)->lpVtbl -> get_TintAndShade(This,RHS) ) 

#define IFormatColor_put_TintAndShade(This,RHS)	\
    ( (This)->lpVtbl -> put_TintAndShade(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IFormatColor_INTERFACE_DEFINED__ */


#ifndef __IConditionValue_INTERFACE_DEFINED__
#define __IConditionValue_INTERFACE_DEFINED__

/* interface IConditionValue */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IConditionValue;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024492-0001-0000-C000-000000000046")
    IConditionValue : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Modify( 
            /* [in] */ XlConditionValueTypes newtype,
            /* [optional][in] */ VARIANT newvalue) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Type( 
            /* [retval][out] */ XlConditionValueTypes *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Value( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IConditionValueVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IConditionValue * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IConditionValue * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IConditionValue * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IConditionValue * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IConditionValue * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IConditionValue * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IConditionValue * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IConditionValue * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IConditionValue * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IConditionValue * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Modify )( 
            IConditionValue * This,
            /* [in] */ XlConditionValueTypes newtype,
            /* [optional][in] */ VARIANT newvalue);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Type )( 
            IConditionValue * This,
            /* [retval][out] */ XlConditionValueTypes *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Value )( 
            IConditionValue * This,
            /* [retval][out] */ VARIANT *RHS);
        
        END_INTERFACE
    } IConditionValueVtbl;

    interface IConditionValue
    {
        CONST_VTBL struct IConditionValueVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IConditionValue_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IConditionValue_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IConditionValue_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IConditionValue_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IConditionValue_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IConditionValue_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IConditionValue_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IConditionValue_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IConditionValue_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IConditionValue_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IConditionValue_Modify(This,newtype,newvalue)	\
    ( (This)->lpVtbl -> Modify(This,newtype,newvalue) ) 

#define IConditionValue_get_Type(This,RHS)	\
    ( (This)->lpVtbl -> get_Type(This,RHS) ) 

#define IConditionValue_get_Value(This,RHS)	\
    ( (This)->lpVtbl -> get_Value(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IConditionValue_INTERFACE_DEFINED__ */


#ifndef __IColorScale_INTERFACE_DEFINED__
#define __IColorScale_INTERFACE_DEFINED__

/* interface IColorScale */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IColorScale;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024493-0001-0000-C000-000000000046")
    IColorScale : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Priority( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Priority( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_StopIfTrue( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AppliesTo( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Formula( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Formula( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Type( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SetFirstPriority( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SetLastPriority( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ModifyAppliesToRange( 
            /* [in] */ Range	*Range) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PTCondition( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ScopeType( 
            /* [retval][out] */ XlPivotConditionScope *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ScopeType( 
            /* [in] */ XlPivotConditionScope RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ColorScaleCriteria( 
            /* [retval][out] */ ColorScaleCriteria	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IColorScaleVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IColorScale * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IColorScale * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IColorScale * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IColorScale * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IColorScale * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IColorScale * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IColorScale * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IColorScale * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IColorScale * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IColorScale * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Priority )( 
            IColorScale * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Priority )( 
            IColorScale * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_StopIfTrue )( 
            IColorScale * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AppliesTo )( 
            IColorScale * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Formula )( 
            IColorScale * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Formula )( 
            IColorScale * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Type )( 
            IColorScale * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SetFirstPriority )( 
            IColorScale * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SetLastPriority )( 
            IColorScale * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IColorScale * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ModifyAppliesToRange )( 
            IColorScale * This,
            /* [in] */ Range	*Range);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PTCondition )( 
            IColorScale * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ScopeType )( 
            IColorScale * This,
            /* [retval][out] */ XlPivotConditionScope *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ScopeType )( 
            IColorScale * This,
            /* [in] */ XlPivotConditionScope RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ColorScaleCriteria )( 
            IColorScale * This,
            /* [retval][out] */ ColorScaleCriteria	**RHS);
        
        END_INTERFACE
    } IColorScaleVtbl;

    interface IColorScale
    {
        CONST_VTBL struct IColorScaleVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IColorScale_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IColorScale_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IColorScale_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IColorScale_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IColorScale_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IColorScale_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IColorScale_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IColorScale_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IColorScale_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IColorScale_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IColorScale_get_Priority(This,RHS)	\
    ( (This)->lpVtbl -> get_Priority(This,RHS) ) 

#define IColorScale_put_Priority(This,RHS)	\
    ( (This)->lpVtbl -> put_Priority(This,RHS) ) 

#define IColorScale_get_StopIfTrue(This,RHS)	\
    ( (This)->lpVtbl -> get_StopIfTrue(This,RHS) ) 

#define IColorScale_get_AppliesTo(This,RHS)	\
    ( (This)->lpVtbl -> get_AppliesTo(This,RHS) ) 

#define IColorScale_get_Formula(This,RHS)	\
    ( (This)->lpVtbl -> get_Formula(This,RHS) ) 

#define IColorScale_put_Formula(This,RHS)	\
    ( (This)->lpVtbl -> put_Formula(This,RHS) ) 

#define IColorScale_get_Type(This,RHS)	\
    ( (This)->lpVtbl -> get_Type(This,RHS) ) 

#define IColorScale_SetFirstPriority(This)	\
    ( (This)->lpVtbl -> SetFirstPriority(This) ) 

#define IColorScale_SetLastPriority(This)	\
    ( (This)->lpVtbl -> SetLastPriority(This) ) 

#define IColorScale_Delete(This)	\
    ( (This)->lpVtbl -> Delete(This) ) 

#define IColorScale_ModifyAppliesToRange(This,Range)	\
    ( (This)->lpVtbl -> ModifyAppliesToRange(This,Range) ) 

#define IColorScale_get_PTCondition(This,RHS)	\
    ( (This)->lpVtbl -> get_PTCondition(This,RHS) ) 

#define IColorScale_get_ScopeType(This,RHS)	\
    ( (This)->lpVtbl -> get_ScopeType(This,RHS) ) 

#define IColorScale_put_ScopeType(This,RHS)	\
    ( (This)->lpVtbl -> put_ScopeType(This,RHS) ) 

#define IColorScale_get_ColorScaleCriteria(This,RHS)	\
    ( (This)->lpVtbl -> get_ColorScaleCriteria(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IColorScale_INTERFACE_DEFINED__ */


#ifndef __IColorScaleCriteria_INTERFACE_DEFINED__
#define __IColorScaleCriteria_INTERFACE_DEFINED__

/* interface IColorScaleCriteria */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IColorScaleCriteria;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024494-0001-0000-C000-000000000046")
    IColorScaleCriteria : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ ColorScaleCriterion	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ ColorScaleCriterion	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IColorScaleCriteriaVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IColorScaleCriteria * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IColorScaleCriteria * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IColorScaleCriteria * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IColorScaleCriteria * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IColorScaleCriteria * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IColorScaleCriteria * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IColorScaleCriteria * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IColorScaleCriteria * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IColorScaleCriteria * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ ColorScaleCriterion	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            IColorScaleCriteria * This,
            /* [retval][out] */ IUnknown **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Item )( 
            IColorScaleCriteria * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ ColorScaleCriterion	**RHS);
        
        END_INTERFACE
    } IColorScaleCriteriaVtbl;

    interface IColorScaleCriteria
    {
        CONST_VTBL struct IColorScaleCriteriaVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IColorScaleCriteria_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IColorScaleCriteria_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IColorScaleCriteria_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IColorScaleCriteria_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IColorScaleCriteria_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IColorScaleCriteria_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IColorScaleCriteria_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IColorScaleCriteria_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IColorScaleCriteria_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define IColorScaleCriteria_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#define IColorScaleCriteria_get_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Item(This,Index,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IColorScaleCriteria_INTERFACE_DEFINED__ */


#ifndef __IColorScaleCriterion_INTERFACE_DEFINED__
#define __IColorScaleCriterion_INTERFACE_DEFINED__

/* interface IColorScaleCriterion */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IColorScaleCriterion;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024495-0001-0000-C000-000000000046")
    IColorScaleCriterion : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Index( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Type( 
            /* [retval][out] */ XlConditionValueTypes *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Type( 
            /* [in] */ XlConditionValueTypes RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Value( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Value( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_FormatColor( 
            /* [retval][out] */ FormatColor	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IColorScaleCriterionVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IColorScaleCriterion * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IColorScaleCriterion * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IColorScaleCriterion * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IColorScaleCriterion * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IColorScaleCriterion * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IColorScaleCriterion * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IColorScaleCriterion * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Index )( 
            IColorScaleCriterion * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Type )( 
            IColorScaleCriterion * This,
            /* [retval][out] */ XlConditionValueTypes *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Type )( 
            IColorScaleCriterion * This,
            /* [in] */ XlConditionValueTypes RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Value )( 
            IColorScaleCriterion * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Value )( 
            IColorScaleCriterion * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_FormatColor )( 
            IColorScaleCriterion * This,
            /* [retval][out] */ FormatColor	**RHS);
        
        END_INTERFACE
    } IColorScaleCriterionVtbl;

    interface IColorScaleCriterion
    {
        CONST_VTBL struct IColorScaleCriterionVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IColorScaleCriterion_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IColorScaleCriterion_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IColorScaleCriterion_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IColorScaleCriterion_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IColorScaleCriterion_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IColorScaleCriterion_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IColorScaleCriterion_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IColorScaleCriterion_get_Index(This,RHS)	\
    ( (This)->lpVtbl -> get_Index(This,RHS) ) 

#define IColorScaleCriterion_get_Type(This,RHS)	\
    ( (This)->lpVtbl -> get_Type(This,RHS) ) 

#define IColorScaleCriterion_put_Type(This,RHS)	\
    ( (This)->lpVtbl -> put_Type(This,RHS) ) 

#define IColorScaleCriterion_get_Value(This,RHS)	\
    ( (This)->lpVtbl -> get_Value(This,RHS) ) 

#define IColorScaleCriterion_put_Value(This,RHS)	\
    ( (This)->lpVtbl -> put_Value(This,RHS) ) 

#define IColorScaleCriterion_get_FormatColor(This,RHS)	\
    ( (This)->lpVtbl -> get_FormatColor(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IColorScaleCriterion_INTERFACE_DEFINED__ */


#ifndef __IDatabar_INTERFACE_DEFINED__
#define __IDatabar_INTERFACE_DEFINED__

/* interface IDatabar */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IDatabar;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024496-0001-0000-C000-000000000046")
    IDatabar : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Priority( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Priority( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_StopIfTrue( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AppliesTo( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MinPoint( 
            /* [retval][out] */ ConditionValue	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MaxPoint( 
            /* [retval][out] */ ConditionValue	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PercentMin( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PercentMin( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PercentMax( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PercentMax( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_BarColor( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShowValue( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ShowValue( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Formula( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Formula( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Type( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SetFirstPriority( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SetLastPriority( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ModifyAppliesToRange( 
            /* [in] */ Range	*Range) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PTCondition( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ScopeType( 
            /* [retval][out] */ XlPivotConditionScope *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ScopeType( 
            /* [in] */ XlPivotConditionScope RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Direction( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Direction( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_BarFillType( 
            /* [retval][out] */ XlDataBarFillType *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_BarFillType( 
            /* [in] */ XlDataBarFillType RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AxisPosition( 
            /* [retval][out] */ XlDataBarAxisPosition *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AxisPosition( 
            /* [in] */ XlDataBarAxisPosition RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AxisColor( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_BarBorder( 
            /* [retval][out] */ DataBarBorder	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_NegativeBarFormat( 
            /* [retval][out] */ NegativeBarFormat	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IDatabarVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IDatabar * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IDatabar * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IDatabar * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IDatabar * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IDatabar * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IDatabar * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IDatabar * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IDatabar * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IDatabar * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IDatabar * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Priority )( 
            IDatabar * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Priority )( 
            IDatabar * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_StopIfTrue )( 
            IDatabar * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AppliesTo )( 
            IDatabar * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MinPoint )( 
            IDatabar * This,
            /* [retval][out] */ ConditionValue	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MaxPoint )( 
            IDatabar * This,
            /* [retval][out] */ ConditionValue	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PercentMin )( 
            IDatabar * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PercentMin )( 
            IDatabar * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PercentMax )( 
            IDatabar * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PercentMax )( 
            IDatabar * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_BarColor )( 
            IDatabar * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShowValue )( 
            IDatabar * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ShowValue )( 
            IDatabar * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Formula )( 
            IDatabar * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Formula )( 
            IDatabar * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Type )( 
            IDatabar * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SetFirstPriority )( 
            IDatabar * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SetLastPriority )( 
            IDatabar * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IDatabar * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ModifyAppliesToRange )( 
            IDatabar * This,
            /* [in] */ Range	*Range);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PTCondition )( 
            IDatabar * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ScopeType )( 
            IDatabar * This,
            /* [retval][out] */ XlPivotConditionScope *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ScopeType )( 
            IDatabar * This,
            /* [in] */ XlPivotConditionScope RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Direction )( 
            IDatabar * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Direction )( 
            IDatabar * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_BarFillType )( 
            IDatabar * This,
            /* [retval][out] */ XlDataBarFillType *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_BarFillType )( 
            IDatabar * This,
            /* [in] */ XlDataBarFillType RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AxisPosition )( 
            IDatabar * This,
            /* [retval][out] */ XlDataBarAxisPosition *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AxisPosition )( 
            IDatabar * This,
            /* [in] */ XlDataBarAxisPosition RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AxisColor )( 
            IDatabar * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_BarBorder )( 
            IDatabar * This,
            /* [retval][out] */ DataBarBorder	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_NegativeBarFormat )( 
            IDatabar * This,
            /* [retval][out] */ NegativeBarFormat	**RHS);
        
        END_INTERFACE
    } IDatabarVtbl;

    interface IDatabar
    {
        CONST_VTBL struct IDatabarVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IDatabar_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IDatabar_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IDatabar_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IDatabar_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IDatabar_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IDatabar_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IDatabar_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IDatabar_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IDatabar_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IDatabar_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IDatabar_get_Priority(This,RHS)	\
    ( (This)->lpVtbl -> get_Priority(This,RHS) ) 

#define IDatabar_put_Priority(This,RHS)	\
    ( (This)->lpVtbl -> put_Priority(This,RHS) ) 

#define IDatabar_get_StopIfTrue(This,RHS)	\
    ( (This)->lpVtbl -> get_StopIfTrue(This,RHS) ) 

#define IDatabar_get_AppliesTo(This,RHS)	\
    ( (This)->lpVtbl -> get_AppliesTo(This,RHS) ) 

#define IDatabar_get_MinPoint(This,RHS)	\
    ( (This)->lpVtbl -> get_MinPoint(This,RHS) ) 

#define IDatabar_get_MaxPoint(This,RHS)	\
    ( (This)->lpVtbl -> get_MaxPoint(This,RHS) ) 

#define IDatabar_get_PercentMin(This,RHS)	\
    ( (This)->lpVtbl -> get_PercentMin(This,RHS) ) 

#define IDatabar_put_PercentMin(This,RHS)	\
    ( (This)->lpVtbl -> put_PercentMin(This,RHS) ) 

#define IDatabar_get_PercentMax(This,RHS)	\
    ( (This)->lpVtbl -> get_PercentMax(This,RHS) ) 

#define IDatabar_put_PercentMax(This,RHS)	\
    ( (This)->lpVtbl -> put_PercentMax(This,RHS) ) 

#define IDatabar_get_BarColor(This,RHS)	\
    ( (This)->lpVtbl -> get_BarColor(This,RHS) ) 

#define IDatabar_get_ShowValue(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowValue(This,RHS) ) 

#define IDatabar_put_ShowValue(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowValue(This,RHS) ) 

#define IDatabar_get_Formula(This,RHS)	\
    ( (This)->lpVtbl -> get_Formula(This,RHS) ) 

#define IDatabar_put_Formula(This,RHS)	\
    ( (This)->lpVtbl -> put_Formula(This,RHS) ) 

#define IDatabar_get_Type(This,RHS)	\
    ( (This)->lpVtbl -> get_Type(This,RHS) ) 

#define IDatabar_SetFirstPriority(This)	\
    ( (This)->lpVtbl -> SetFirstPriority(This) ) 

#define IDatabar_SetLastPriority(This)	\
    ( (This)->lpVtbl -> SetLastPriority(This) ) 

#define IDatabar_Delete(This)	\
    ( (This)->lpVtbl -> Delete(This) ) 

#define IDatabar_ModifyAppliesToRange(This,Range)	\
    ( (This)->lpVtbl -> ModifyAppliesToRange(This,Range) ) 

#define IDatabar_get_PTCondition(This,RHS)	\
    ( (This)->lpVtbl -> get_PTCondition(This,RHS) ) 

#define IDatabar_get_ScopeType(This,RHS)	\
    ( (This)->lpVtbl -> get_ScopeType(This,RHS) ) 

#define IDatabar_put_ScopeType(This,RHS)	\
    ( (This)->lpVtbl -> put_ScopeType(This,RHS) ) 

#define IDatabar_get_Direction(This,RHS)	\
    ( (This)->lpVtbl -> get_Direction(This,RHS) ) 

#define IDatabar_put_Direction(This,RHS)	\
    ( (This)->lpVtbl -> put_Direction(This,RHS) ) 

#define IDatabar_get_BarFillType(This,RHS)	\
    ( (This)->lpVtbl -> get_BarFillType(This,RHS) ) 

#define IDatabar_put_BarFillType(This,RHS)	\
    ( (This)->lpVtbl -> put_BarFillType(This,RHS) ) 

#define IDatabar_get_AxisPosition(This,RHS)	\
    ( (This)->lpVtbl -> get_AxisPosition(This,RHS) ) 

#define IDatabar_put_AxisPosition(This,RHS)	\
    ( (This)->lpVtbl -> put_AxisPosition(This,RHS) ) 

#define IDatabar_get_AxisColor(This,RHS)	\
    ( (This)->lpVtbl -> get_AxisColor(This,RHS) ) 

#define IDatabar_get_BarBorder(This,RHS)	\
    ( (This)->lpVtbl -> get_BarBorder(This,RHS) ) 

#define IDatabar_get_NegativeBarFormat(This,RHS)	\
    ( (This)->lpVtbl -> get_NegativeBarFormat(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IDatabar_INTERFACE_DEFINED__ */


#ifndef __IIconSetCondition_INTERFACE_DEFINED__
#define __IIconSetCondition_INTERFACE_DEFINED__

/* interface IIconSetCondition */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IIconSetCondition;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024497-0001-0000-C000-000000000046")
    IIconSetCondition : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Priority( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Priority( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_StopIfTrue( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AppliesTo( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Type( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ModifyAppliesToRange( 
            /* [in] */ Range	*Range) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PTCondition( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ScopeType( 
            /* [retval][out] */ XlPivotConditionScope *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ScopeType( 
            /* [in] */ XlPivotConditionScope RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SetFirstPriority( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SetLastPriority( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ReverseOrder( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ReverseOrder( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PercentileValues( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PercentileValues( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShowIconOnly( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ShowIconOnly( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Formula( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Formula( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_IconSet( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_IconSet( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_IconCriteria( 
            /* [retval][out] */ IconCriteria	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IIconSetConditionVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IIconSetCondition * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IIconSetCondition * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IIconSetCondition * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IIconSetCondition * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IIconSetCondition * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IIconSetCondition * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IIconSetCondition * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IIconSetCondition * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IIconSetCondition * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IIconSetCondition * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Priority )( 
            IIconSetCondition * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Priority )( 
            IIconSetCondition * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_StopIfTrue )( 
            IIconSetCondition * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AppliesTo )( 
            IIconSetCondition * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Type )( 
            IIconSetCondition * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ModifyAppliesToRange )( 
            IIconSetCondition * This,
            /* [in] */ Range	*Range);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PTCondition )( 
            IIconSetCondition * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ScopeType )( 
            IIconSetCondition * This,
            /* [retval][out] */ XlPivotConditionScope *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ScopeType )( 
            IIconSetCondition * This,
            /* [in] */ XlPivotConditionScope RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SetFirstPriority )( 
            IIconSetCondition * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SetLastPriority )( 
            IIconSetCondition * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IIconSetCondition * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ReverseOrder )( 
            IIconSetCondition * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ReverseOrder )( 
            IIconSetCondition * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PercentileValues )( 
            IIconSetCondition * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PercentileValues )( 
            IIconSetCondition * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShowIconOnly )( 
            IIconSetCondition * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ShowIconOnly )( 
            IIconSetCondition * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Formula )( 
            IIconSetCondition * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Formula )( 
            IIconSetCondition * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_IconSet )( 
            IIconSetCondition * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_IconSet )( 
            IIconSetCondition * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_IconCriteria )( 
            IIconSetCondition * This,
            /* [retval][out] */ IconCriteria	**RHS);
        
        END_INTERFACE
    } IIconSetConditionVtbl;

    interface IIconSetCondition
    {
        CONST_VTBL struct IIconSetConditionVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IIconSetCondition_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IIconSetCondition_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IIconSetCondition_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IIconSetCondition_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IIconSetCondition_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IIconSetCondition_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IIconSetCondition_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IIconSetCondition_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IIconSetCondition_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IIconSetCondition_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IIconSetCondition_get_Priority(This,RHS)	\
    ( (This)->lpVtbl -> get_Priority(This,RHS) ) 

#define IIconSetCondition_put_Priority(This,RHS)	\
    ( (This)->lpVtbl -> put_Priority(This,RHS) ) 

#define IIconSetCondition_get_StopIfTrue(This,RHS)	\
    ( (This)->lpVtbl -> get_StopIfTrue(This,RHS) ) 

#define IIconSetCondition_get_AppliesTo(This,RHS)	\
    ( (This)->lpVtbl -> get_AppliesTo(This,RHS) ) 

#define IIconSetCondition_get_Type(This,RHS)	\
    ( (This)->lpVtbl -> get_Type(This,RHS) ) 

#define IIconSetCondition_ModifyAppliesToRange(This,Range)	\
    ( (This)->lpVtbl -> ModifyAppliesToRange(This,Range) ) 

#define IIconSetCondition_get_PTCondition(This,RHS)	\
    ( (This)->lpVtbl -> get_PTCondition(This,RHS) ) 

#define IIconSetCondition_get_ScopeType(This,RHS)	\
    ( (This)->lpVtbl -> get_ScopeType(This,RHS) ) 

#define IIconSetCondition_put_ScopeType(This,RHS)	\
    ( (This)->lpVtbl -> put_ScopeType(This,RHS) ) 

#define IIconSetCondition_SetFirstPriority(This)	\
    ( (This)->lpVtbl -> SetFirstPriority(This) ) 

#define IIconSetCondition_SetLastPriority(This)	\
    ( (This)->lpVtbl -> SetLastPriority(This) ) 

#define IIconSetCondition_Delete(This)	\
    ( (This)->lpVtbl -> Delete(This) ) 

#define IIconSetCondition_get_ReverseOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_ReverseOrder(This,RHS) ) 

#define IIconSetCondition_put_ReverseOrder(This,RHS)	\
    ( (This)->lpVtbl -> put_ReverseOrder(This,RHS) ) 

#define IIconSetCondition_get_PercentileValues(This,RHS)	\
    ( (This)->lpVtbl -> get_PercentileValues(This,RHS) ) 

#define IIconSetCondition_put_PercentileValues(This,RHS)	\
    ( (This)->lpVtbl -> put_PercentileValues(This,RHS) ) 

#define IIconSetCondition_get_ShowIconOnly(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowIconOnly(This,RHS) ) 

#define IIconSetCondition_put_ShowIconOnly(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowIconOnly(This,RHS) ) 

#define IIconSetCondition_get_Formula(This,RHS)	\
    ( (This)->lpVtbl -> get_Formula(This,RHS) ) 

#define IIconSetCondition_put_Formula(This,RHS)	\
    ( (This)->lpVtbl -> put_Formula(This,RHS) ) 

#define IIconSetCondition_get_IconSet(This,RHS)	\
    ( (This)->lpVtbl -> get_IconSet(This,RHS) ) 

#define IIconSetCondition_put_IconSet(This,RHS)	\
    ( (This)->lpVtbl -> put_IconSet(This,RHS) ) 

#define IIconSetCondition_get_IconCriteria(This,RHS)	\
    ( (This)->lpVtbl -> get_IconCriteria(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IIconSetCondition_INTERFACE_DEFINED__ */


#ifndef __IIconCriteria_INTERFACE_DEFINED__
#define __IIconCriteria_INTERFACE_DEFINED__

/* interface IIconCriteria */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IIconCriteria;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024498-0001-0000-C000-000000000046")
    IIconCriteria : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IconCriterion	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IconCriterion	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IIconCriteriaVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IIconCriteria * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IIconCriteria * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IIconCriteria * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IIconCriteria * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IIconCriteria * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IIconCriteria * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IIconCriteria * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IIconCriteria * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IIconCriteria * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IconCriterion	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            IIconCriteria * This,
            /* [retval][out] */ IUnknown **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Item )( 
            IIconCriteria * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IconCriterion	**RHS);
        
        END_INTERFACE
    } IIconCriteriaVtbl;

    interface IIconCriteria
    {
        CONST_VTBL struct IIconCriteriaVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IIconCriteria_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IIconCriteria_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IIconCriteria_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IIconCriteria_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IIconCriteria_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IIconCriteria_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IIconCriteria_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IIconCriteria_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IIconCriteria_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define IIconCriteria_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#define IIconCriteria_get_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Item(This,Index,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IIconCriteria_INTERFACE_DEFINED__ */


#ifndef __IIconCriterion_INTERFACE_DEFINED__
#define __IIconCriterion_INTERFACE_DEFINED__

/* interface IIconCriterion */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IIconCriterion;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("00024499-0001-0000-C000-000000000046")
    IIconCriterion : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Index( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Type( 
            /* [retval][out] */ XlConditionValueTypes *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Type( 
            /* [in] */ XlConditionValueTypes RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Value( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Value( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Operator( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Operator( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Icon( 
            /* [retval][out] */ XlIcon *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Icon( 
            /* [in] */ XlIcon RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IIconCriterionVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IIconCriterion * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IIconCriterion * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IIconCriterion * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IIconCriterion * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IIconCriterion * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IIconCriterion * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IIconCriterion * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Index )( 
            IIconCriterion * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Type )( 
            IIconCriterion * This,
            /* [retval][out] */ XlConditionValueTypes *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Type )( 
            IIconCriterion * This,
            /* [in] */ XlConditionValueTypes RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Value )( 
            IIconCriterion * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Value )( 
            IIconCriterion * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Operator )( 
            IIconCriterion * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Operator )( 
            IIconCriterion * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Icon )( 
            IIconCriterion * This,
            /* [retval][out] */ XlIcon *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Icon )( 
            IIconCriterion * This,
            /* [in] */ XlIcon RHS);
        
        END_INTERFACE
    } IIconCriterionVtbl;

    interface IIconCriterion
    {
        CONST_VTBL struct IIconCriterionVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IIconCriterion_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IIconCriterion_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IIconCriterion_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IIconCriterion_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IIconCriterion_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IIconCriterion_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IIconCriterion_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IIconCriterion_get_Index(This,RHS)	\
    ( (This)->lpVtbl -> get_Index(This,RHS) ) 

#define IIconCriterion_get_Type(This,RHS)	\
    ( (This)->lpVtbl -> get_Type(This,RHS) ) 

#define IIconCriterion_put_Type(This,RHS)	\
    ( (This)->lpVtbl -> put_Type(This,RHS) ) 

#define IIconCriterion_get_Value(This,RHS)	\
    ( (This)->lpVtbl -> get_Value(This,RHS) ) 

#define IIconCriterion_put_Value(This,RHS)	\
    ( (This)->lpVtbl -> put_Value(This,RHS) ) 

#define IIconCriterion_get_Operator(This,RHS)	\
    ( (This)->lpVtbl -> get_Operator(This,RHS) ) 

#define IIconCriterion_put_Operator(This,RHS)	\
    ( (This)->lpVtbl -> put_Operator(This,RHS) ) 

#define IIconCriterion_get_Icon(This,RHS)	\
    ( (This)->lpVtbl -> get_Icon(This,RHS) ) 

#define IIconCriterion_put_Icon(This,RHS)	\
    ( (This)->lpVtbl -> put_Icon(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IIconCriterion_INTERFACE_DEFINED__ */


#ifndef __IIcon_INTERFACE_DEFINED__
#define __IIcon_INTERFACE_DEFINED__

/* interface IIcon */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IIcon;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002449A-0001-0000-C000-000000000046")
    IIcon : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IconSet	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Index( 
            /* [retval][out] */ long *RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IIconVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IIcon * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IIcon * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IIcon * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IIcon * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IIcon * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IIcon * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IIcon * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IIcon * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IIcon * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IIcon * This,
            /* [retval][out] */ IconSet	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Index )( 
            IIcon * This,
            /* [retval][out] */ long *RHS);
        
        END_INTERFACE
    } IIconVtbl;

    interface IIcon
    {
        CONST_VTBL struct IIconVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IIcon_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IIcon_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IIcon_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IIcon_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IIcon_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IIcon_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IIcon_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IIcon_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IIcon_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IIcon_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IIcon_get_Index(This,RHS)	\
    ( (This)->lpVtbl -> get_Index(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IIcon_INTERFACE_DEFINED__ */


#ifndef __IIconSet_INTERFACE_DEFINED__
#define __IIconSet_INTERFACE_DEFINED__

/* interface IIconSet */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IIconSet;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002449B-0001-0000-C000-000000000046")
    IIconSet : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ID( 
            /* [retval][out] */ XlIconSet *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Icon	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Icon	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IIconSetVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IIconSet * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IIconSet * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IIconSet * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IIconSet * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IIconSet * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IIconSet * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IIconSet * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IIconSet * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IIconSet * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IIconSet * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ID )( 
            IIconSet * This,
            /* [retval][out] */ XlIconSet *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IIconSet * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IIconSet * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Icon	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            IIconSet * This,
            /* [retval][out] */ IUnknown **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Item )( 
            IIconSet * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Icon	**RHS);
        
        END_INTERFACE
    } IIconSetVtbl;

    interface IIconSet
    {
        CONST_VTBL struct IIconSetVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IIconSet_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IIconSet_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IIconSet_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IIconSet_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IIconSet_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IIconSet_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IIconSet_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IIconSet_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IIconSet_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IIconSet_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IIconSet_get_ID(This,RHS)	\
    ( (This)->lpVtbl -> get_ID(This,RHS) ) 

#define IIconSet_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IIconSet_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define IIconSet_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#define IIconSet_get_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Item(This,Index,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IIconSet_INTERFACE_DEFINED__ */


#ifndef __IIconSets_INTERFACE_DEFINED__
#define __IIconSets_INTERFACE_DEFINED__

/* interface IIconSets */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IIconSets;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002449C-0001-0000-C000-000000000046")
    IIconSets : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IIconSetsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IIconSets * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IIconSets * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IIconSets * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IIconSets * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IIconSets * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IIconSets * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IIconSets * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IIconSets * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IIconSets * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IIconSets * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IIconSets * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IIconSets * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            IIconSets * This,
            /* [retval][out] */ IUnknown **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Item )( 
            IIconSets * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS);
        
        END_INTERFACE
    } IIconSetsVtbl;

    interface IIconSets
    {
        CONST_VTBL struct IIconSetsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IIconSets_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IIconSets_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IIconSets_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IIconSets_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IIconSets_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IIconSets_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IIconSets_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IIconSets_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IIconSets_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IIconSets_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IIconSets_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IIconSets_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define IIconSets_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#define IIconSets_get_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Item(This,Index,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IIconSets_INTERFACE_DEFINED__ */


#ifndef __ITop10_INTERFACE_DEFINED__
#define __ITop10_INTERFACE_DEFINED__

/* interface ITop10 */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ITop10;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002449D-0001-0000-C000-000000000046")
    ITop10 : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Priority( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Priority( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_StopIfTrue( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_StopIfTrue( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AppliesTo( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TopBottom( 
            /* [retval][out] */ XlTopBottom *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_TopBottom( 
            /* [in] */ XlTopBottom RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Rank( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Rank( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Percent( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Percent( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Interior( 
            /* [retval][out] */ Interior	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Borders( 
            /* [retval][out] */ Borders	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Font( 
            /* [retval][out] */ Font	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Type( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_NumberFormat( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_NumberFormat( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SetFirstPriority( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SetLastPriority( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ModifyAppliesToRange( 
            /* [in] */ Range	*Range) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PTCondition( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ScopeType( 
            /* [retval][out] */ XlPivotConditionScope *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ScopeType( 
            /* [in] */ XlPivotConditionScope RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CalcFor( 
            /* [retval][out] */ XlCalcFor *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_CalcFor( 
            /* [in] */ XlCalcFor RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ITop10Vtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ITop10 * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ITop10 * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ITop10 * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ITop10 * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ITop10 * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ITop10 * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ITop10 * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ITop10 * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ITop10 * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ITop10 * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Priority )( 
            ITop10 * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Priority )( 
            ITop10 * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_StopIfTrue )( 
            ITop10 * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_StopIfTrue )( 
            ITop10 * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AppliesTo )( 
            ITop10 * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TopBottom )( 
            ITop10 * This,
            /* [retval][out] */ XlTopBottom *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_TopBottom )( 
            ITop10 * This,
            /* [in] */ XlTopBottom RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Rank )( 
            ITop10 * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Rank )( 
            ITop10 * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Percent )( 
            ITop10 * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Percent )( 
            ITop10 * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Interior )( 
            ITop10 * This,
            /* [retval][out] */ Interior	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Borders )( 
            ITop10 * This,
            /* [retval][out] */ Borders	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Font )( 
            ITop10 * This,
            /* [retval][out] */ Font	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Type )( 
            ITop10 * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_NumberFormat )( 
            ITop10 * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_NumberFormat )( 
            ITop10 * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SetFirstPriority )( 
            ITop10 * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SetLastPriority )( 
            ITop10 * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            ITop10 * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ModifyAppliesToRange )( 
            ITop10 * This,
            /* [in] */ Range	*Range);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PTCondition )( 
            ITop10 * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ScopeType )( 
            ITop10 * This,
            /* [retval][out] */ XlPivotConditionScope *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ScopeType )( 
            ITop10 * This,
            /* [in] */ XlPivotConditionScope RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CalcFor )( 
            ITop10 * This,
            /* [retval][out] */ XlCalcFor *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_CalcFor )( 
            ITop10 * This,
            /* [in] */ XlCalcFor RHS);
        
        END_INTERFACE
    } ITop10Vtbl;

    interface ITop10
    {
        CONST_VTBL struct ITop10Vtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ITop10_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ITop10_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ITop10_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ITop10_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ITop10_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ITop10_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ITop10_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ITop10_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ITop10_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ITop10_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ITop10_get_Priority(This,RHS)	\
    ( (This)->lpVtbl -> get_Priority(This,RHS) ) 

#define ITop10_put_Priority(This,RHS)	\
    ( (This)->lpVtbl -> put_Priority(This,RHS) ) 

#define ITop10_get_StopIfTrue(This,RHS)	\
    ( (This)->lpVtbl -> get_StopIfTrue(This,RHS) ) 

#define ITop10_put_StopIfTrue(This,RHS)	\
    ( (This)->lpVtbl -> put_StopIfTrue(This,RHS) ) 

#define ITop10_get_AppliesTo(This,RHS)	\
    ( (This)->lpVtbl -> get_AppliesTo(This,RHS) ) 

#define ITop10_get_TopBottom(This,RHS)	\
    ( (This)->lpVtbl -> get_TopBottom(This,RHS) ) 

#define ITop10_put_TopBottom(This,RHS)	\
    ( (This)->lpVtbl -> put_TopBottom(This,RHS) ) 

#define ITop10_get_Rank(This,RHS)	\
    ( (This)->lpVtbl -> get_Rank(This,RHS) ) 

#define ITop10_put_Rank(This,RHS)	\
    ( (This)->lpVtbl -> put_Rank(This,RHS) ) 

#define ITop10_get_Percent(This,RHS)	\
    ( (This)->lpVtbl -> get_Percent(This,RHS) ) 

#define ITop10_put_Percent(This,RHS)	\
    ( (This)->lpVtbl -> put_Percent(This,RHS) ) 

#define ITop10_get_Interior(This,RHS)	\
    ( (This)->lpVtbl -> get_Interior(This,RHS) ) 

#define ITop10_get_Borders(This,RHS)	\
    ( (This)->lpVtbl -> get_Borders(This,RHS) ) 

#define ITop10_get_Font(This,RHS)	\
    ( (This)->lpVtbl -> get_Font(This,RHS) ) 

#define ITop10_get_Type(This,RHS)	\
    ( (This)->lpVtbl -> get_Type(This,RHS) ) 

#define ITop10_get_NumberFormat(This,RHS)	\
    ( (This)->lpVtbl -> get_NumberFormat(This,RHS) ) 

#define ITop10_put_NumberFormat(This,RHS)	\
    ( (This)->lpVtbl -> put_NumberFormat(This,RHS) ) 

#define ITop10_SetFirstPriority(This)	\
    ( (This)->lpVtbl -> SetFirstPriority(This) ) 

#define ITop10_SetLastPriority(This)	\
    ( (This)->lpVtbl -> SetLastPriority(This) ) 

#define ITop10_Delete(This)	\
    ( (This)->lpVtbl -> Delete(This) ) 

#define ITop10_ModifyAppliesToRange(This,Range)	\
    ( (This)->lpVtbl -> ModifyAppliesToRange(This,Range) ) 

#define ITop10_get_PTCondition(This,RHS)	\
    ( (This)->lpVtbl -> get_PTCondition(This,RHS) ) 

#define ITop10_get_ScopeType(This,RHS)	\
    ( (This)->lpVtbl -> get_ScopeType(This,RHS) ) 

#define ITop10_put_ScopeType(This,RHS)	\
    ( (This)->lpVtbl -> put_ScopeType(This,RHS) ) 

#define ITop10_get_CalcFor(This,RHS)	\
    ( (This)->lpVtbl -> get_CalcFor(This,RHS) ) 

#define ITop10_put_CalcFor(This,RHS)	\
    ( (This)->lpVtbl -> put_CalcFor(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ITop10_INTERFACE_DEFINED__ */


#ifndef __IAboveAverage_INTERFACE_DEFINED__
#define __IAboveAverage_INTERFACE_DEFINED__

/* interface IAboveAverage */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IAboveAverage;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002449E-0001-0000-C000-000000000046")
    IAboveAverage : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Priority( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Priority( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_StopIfTrue( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_StopIfTrue( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AppliesTo( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AboveBelow( 
            /* [retval][out] */ XlAboveBelow *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AboveBelow( 
            /* [in] */ XlAboveBelow RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Interior( 
            /* [retval][out] */ Interior	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Borders( 
            /* [retval][out] */ Borders	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Font( 
            /* [retval][out] */ Font	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Type( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_NumberFormat( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_NumberFormat( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SetFirstPriority( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SetLastPriority( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ModifyAppliesToRange( 
            /* [in] */ Range	*Range) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PTCondition( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ScopeType( 
            /* [retval][out] */ XlPivotConditionScope *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ScopeType( 
            /* [in] */ XlPivotConditionScope RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CalcFor( 
            /* [retval][out] */ XlCalcFor *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_CalcFor( 
            /* [in] */ XlCalcFor RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_NumStdDev( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_NumStdDev( 
            /* [in] */ long RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IAboveAverageVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IAboveAverage * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IAboveAverage * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IAboveAverage * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IAboveAverage * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IAboveAverage * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IAboveAverage * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IAboveAverage * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IAboveAverage * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IAboveAverage * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IAboveAverage * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Priority )( 
            IAboveAverage * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Priority )( 
            IAboveAverage * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_StopIfTrue )( 
            IAboveAverage * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_StopIfTrue )( 
            IAboveAverage * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AppliesTo )( 
            IAboveAverage * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AboveBelow )( 
            IAboveAverage * This,
            /* [retval][out] */ XlAboveBelow *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AboveBelow )( 
            IAboveAverage * This,
            /* [in] */ XlAboveBelow RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Interior )( 
            IAboveAverage * This,
            /* [retval][out] */ Interior	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Borders )( 
            IAboveAverage * This,
            /* [retval][out] */ Borders	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Font )( 
            IAboveAverage * This,
            /* [retval][out] */ Font	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Type )( 
            IAboveAverage * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_NumberFormat )( 
            IAboveAverage * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_NumberFormat )( 
            IAboveAverage * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SetFirstPriority )( 
            IAboveAverage * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SetLastPriority )( 
            IAboveAverage * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IAboveAverage * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ModifyAppliesToRange )( 
            IAboveAverage * This,
            /* [in] */ Range	*Range);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PTCondition )( 
            IAboveAverage * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ScopeType )( 
            IAboveAverage * This,
            /* [retval][out] */ XlPivotConditionScope *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ScopeType )( 
            IAboveAverage * This,
            /* [in] */ XlPivotConditionScope RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CalcFor )( 
            IAboveAverage * This,
            /* [retval][out] */ XlCalcFor *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_CalcFor )( 
            IAboveAverage * This,
            /* [in] */ XlCalcFor RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_NumStdDev )( 
            IAboveAverage * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_NumStdDev )( 
            IAboveAverage * This,
            /* [in] */ long RHS);
        
        END_INTERFACE
    } IAboveAverageVtbl;

    interface IAboveAverage
    {
        CONST_VTBL struct IAboveAverageVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IAboveAverage_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IAboveAverage_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IAboveAverage_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IAboveAverage_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IAboveAverage_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IAboveAverage_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IAboveAverage_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IAboveAverage_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IAboveAverage_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IAboveAverage_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IAboveAverage_get_Priority(This,RHS)	\
    ( (This)->lpVtbl -> get_Priority(This,RHS) ) 

#define IAboveAverage_put_Priority(This,RHS)	\
    ( (This)->lpVtbl -> put_Priority(This,RHS) ) 

#define IAboveAverage_get_StopIfTrue(This,RHS)	\
    ( (This)->lpVtbl -> get_StopIfTrue(This,RHS) ) 

#define IAboveAverage_put_StopIfTrue(This,RHS)	\
    ( (This)->lpVtbl -> put_StopIfTrue(This,RHS) ) 

#define IAboveAverage_get_AppliesTo(This,RHS)	\
    ( (This)->lpVtbl -> get_AppliesTo(This,RHS) ) 

#define IAboveAverage_get_AboveBelow(This,RHS)	\
    ( (This)->lpVtbl -> get_AboveBelow(This,RHS) ) 

#define IAboveAverage_put_AboveBelow(This,RHS)	\
    ( (This)->lpVtbl -> put_AboveBelow(This,RHS) ) 

#define IAboveAverage_get_Interior(This,RHS)	\
    ( (This)->lpVtbl -> get_Interior(This,RHS) ) 

#define IAboveAverage_get_Borders(This,RHS)	\
    ( (This)->lpVtbl -> get_Borders(This,RHS) ) 

#define IAboveAverage_get_Font(This,RHS)	\
    ( (This)->lpVtbl -> get_Font(This,RHS) ) 

#define IAboveAverage_get_Type(This,RHS)	\
    ( (This)->lpVtbl -> get_Type(This,RHS) ) 

#define IAboveAverage_get_NumberFormat(This,RHS)	\
    ( (This)->lpVtbl -> get_NumberFormat(This,RHS) ) 

#define IAboveAverage_put_NumberFormat(This,RHS)	\
    ( (This)->lpVtbl -> put_NumberFormat(This,RHS) ) 

#define IAboveAverage_SetFirstPriority(This)	\
    ( (This)->lpVtbl -> SetFirstPriority(This) ) 

#define IAboveAverage_SetLastPriority(This)	\
    ( (This)->lpVtbl -> SetLastPriority(This) ) 

#define IAboveAverage_Delete(This)	\
    ( (This)->lpVtbl -> Delete(This) ) 

#define IAboveAverage_ModifyAppliesToRange(This,Range)	\
    ( (This)->lpVtbl -> ModifyAppliesToRange(This,Range) ) 

#define IAboveAverage_get_PTCondition(This,RHS)	\
    ( (This)->lpVtbl -> get_PTCondition(This,RHS) ) 

#define IAboveAverage_get_ScopeType(This,RHS)	\
    ( (This)->lpVtbl -> get_ScopeType(This,RHS) ) 

#define IAboveAverage_put_ScopeType(This,RHS)	\
    ( (This)->lpVtbl -> put_ScopeType(This,RHS) ) 

#define IAboveAverage_get_CalcFor(This,RHS)	\
    ( (This)->lpVtbl -> get_CalcFor(This,RHS) ) 

#define IAboveAverage_put_CalcFor(This,RHS)	\
    ( (This)->lpVtbl -> put_CalcFor(This,RHS) ) 

#define IAboveAverage_get_NumStdDev(This,RHS)	\
    ( (This)->lpVtbl -> get_NumStdDev(This,RHS) ) 

#define IAboveAverage_put_NumStdDev(This,RHS)	\
    ( (This)->lpVtbl -> put_NumStdDev(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IAboveAverage_INTERFACE_DEFINED__ */


#ifndef __IUniqueValues_INTERFACE_DEFINED__
#define __IUniqueValues_INTERFACE_DEFINED__

/* interface IUniqueValues */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IUniqueValues;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002449F-0001-0000-C000-000000000046")
    IUniqueValues : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Priority( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Priority( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_StopIfTrue( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_StopIfTrue( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AppliesTo( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DupeUnique( 
            /* [retval][out] */ XlDupeUnique *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DupeUnique( 
            /* [in] */ XlDupeUnique RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Interior( 
            /* [retval][out] */ Interior	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Borders( 
            /* [retval][out] */ Borders	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Font( 
            /* [retval][out] */ Font	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Type( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_NumberFormat( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_NumberFormat( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SetFirstPriority( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SetLastPriority( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ModifyAppliesToRange( 
            /* [in] */ Range	*Range) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PTCondition( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ScopeType( 
            /* [retval][out] */ XlPivotConditionScope *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ScopeType( 
            /* [in] */ XlPivotConditionScope RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IUniqueValuesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IUniqueValues * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IUniqueValues * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IUniqueValues * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IUniqueValues * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IUniqueValues * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IUniqueValues * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IUniqueValues * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IUniqueValues * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IUniqueValues * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IUniqueValues * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Priority )( 
            IUniqueValues * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Priority )( 
            IUniqueValues * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_StopIfTrue )( 
            IUniqueValues * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_StopIfTrue )( 
            IUniqueValues * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AppliesTo )( 
            IUniqueValues * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DupeUnique )( 
            IUniqueValues * This,
            /* [retval][out] */ XlDupeUnique *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DupeUnique )( 
            IUniqueValues * This,
            /* [in] */ XlDupeUnique RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Interior )( 
            IUniqueValues * This,
            /* [retval][out] */ Interior	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Borders )( 
            IUniqueValues * This,
            /* [retval][out] */ Borders	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Font )( 
            IUniqueValues * This,
            /* [retval][out] */ Font	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Type )( 
            IUniqueValues * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_NumberFormat )( 
            IUniqueValues * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_NumberFormat )( 
            IUniqueValues * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SetFirstPriority )( 
            IUniqueValues * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SetLastPriority )( 
            IUniqueValues * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IUniqueValues * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ModifyAppliesToRange )( 
            IUniqueValues * This,
            /* [in] */ Range	*Range);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PTCondition )( 
            IUniqueValues * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ScopeType )( 
            IUniqueValues * This,
            /* [retval][out] */ XlPivotConditionScope *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ScopeType )( 
            IUniqueValues * This,
            /* [in] */ XlPivotConditionScope RHS);
        
        END_INTERFACE
    } IUniqueValuesVtbl;

    interface IUniqueValues
    {
        CONST_VTBL struct IUniqueValuesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IUniqueValues_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IUniqueValues_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IUniqueValues_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IUniqueValues_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IUniqueValues_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IUniqueValues_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IUniqueValues_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IUniqueValues_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IUniqueValues_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IUniqueValues_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IUniqueValues_get_Priority(This,RHS)	\
    ( (This)->lpVtbl -> get_Priority(This,RHS) ) 

#define IUniqueValues_put_Priority(This,RHS)	\
    ( (This)->lpVtbl -> put_Priority(This,RHS) ) 

#define IUniqueValues_get_StopIfTrue(This,RHS)	\
    ( (This)->lpVtbl -> get_StopIfTrue(This,RHS) ) 

#define IUniqueValues_put_StopIfTrue(This,RHS)	\
    ( (This)->lpVtbl -> put_StopIfTrue(This,RHS) ) 

#define IUniqueValues_get_AppliesTo(This,RHS)	\
    ( (This)->lpVtbl -> get_AppliesTo(This,RHS) ) 

#define IUniqueValues_get_DupeUnique(This,RHS)	\
    ( (This)->lpVtbl -> get_DupeUnique(This,RHS) ) 

#define IUniqueValues_put_DupeUnique(This,RHS)	\
    ( (This)->lpVtbl -> put_DupeUnique(This,RHS) ) 

#define IUniqueValues_get_Interior(This,RHS)	\
    ( (This)->lpVtbl -> get_Interior(This,RHS) ) 

#define IUniqueValues_get_Borders(This,RHS)	\
    ( (This)->lpVtbl -> get_Borders(This,RHS) ) 

#define IUniqueValues_get_Font(This,RHS)	\
    ( (This)->lpVtbl -> get_Font(This,RHS) ) 

#define IUniqueValues_get_Type(This,RHS)	\
    ( (This)->lpVtbl -> get_Type(This,RHS) ) 

#define IUniqueValues_get_NumberFormat(This,RHS)	\
    ( (This)->lpVtbl -> get_NumberFormat(This,RHS) ) 

#define IUniqueValues_put_NumberFormat(This,RHS)	\
    ( (This)->lpVtbl -> put_NumberFormat(This,RHS) ) 

#define IUniqueValues_SetFirstPriority(This)	\
    ( (This)->lpVtbl -> SetFirstPriority(This) ) 

#define IUniqueValues_SetLastPriority(This)	\
    ( (This)->lpVtbl -> SetLastPriority(This) ) 

#define IUniqueValues_Delete(This)	\
    ( (This)->lpVtbl -> Delete(This) ) 

#define IUniqueValues_ModifyAppliesToRange(This,Range)	\
    ( (This)->lpVtbl -> ModifyAppliesToRange(This,Range) ) 

#define IUniqueValues_get_PTCondition(This,RHS)	\
    ( (This)->lpVtbl -> get_PTCondition(This,RHS) ) 

#define IUniqueValues_get_ScopeType(This,RHS)	\
    ( (This)->lpVtbl -> get_ScopeType(This,RHS) ) 

#define IUniqueValues_put_ScopeType(This,RHS)	\
    ( (This)->lpVtbl -> put_ScopeType(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IUniqueValues_INTERFACE_DEFINED__ */


#ifndef __IRanges_INTERFACE_DEFINED__
#define __IRanges_INTERFACE_DEFINED__

/* interface IRanges */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IRanges;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244A0-0001-0000-C000-000000000046")
    IRanges : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IRangesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IRanges * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IRanges * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IRanges * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IRanges * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IRanges * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IRanges * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IRanges * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IRanges * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IRanges * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IRanges * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IRanges * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            IRanges * This,
            /* [retval][out] */ IUnknown **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Item )( 
            IRanges * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IRanges * This,
            /* [retval][out] */ long *RHS);
        
        END_INTERFACE
    } IRangesVtbl;

    interface IRanges
    {
        CONST_VTBL struct IRangesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IRanges_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IRanges_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IRanges_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IRanges_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IRanges_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IRanges_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IRanges_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IRanges_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IRanges_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IRanges_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IRanges_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define IRanges_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#define IRanges_get_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Item(This,Index,RHS) ) 

#define IRanges_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IRanges_INTERFACE_DEFINED__ */


#ifndef __IHeaderFooter_INTERFACE_DEFINED__
#define __IHeaderFooter_INTERFACE_DEFINED__

/* interface IHeaderFooter */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IHeaderFooter;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244A1-0001-0000-C000-000000000046")
    IHeaderFooter : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Text( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Text( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Picture( 
            /* [retval][out] */ Graphic	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IHeaderFooterVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IHeaderFooter * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IHeaderFooter * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IHeaderFooter * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IHeaderFooter * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IHeaderFooter * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IHeaderFooter * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IHeaderFooter * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Text )( 
            IHeaderFooter * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Text )( 
            IHeaderFooter * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Picture )( 
            IHeaderFooter * This,
            /* [retval][out] */ Graphic	**RHS);
        
        END_INTERFACE
    } IHeaderFooterVtbl;

    interface IHeaderFooter
    {
        CONST_VTBL struct IHeaderFooterVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IHeaderFooter_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IHeaderFooter_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IHeaderFooter_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IHeaderFooter_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IHeaderFooter_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IHeaderFooter_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IHeaderFooter_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IHeaderFooter_get_Text(This,RHS)	\
    ( (This)->lpVtbl -> get_Text(This,RHS) ) 

#define IHeaderFooter_put_Text(This,RHS)	\
    ( (This)->lpVtbl -> put_Text(This,RHS) ) 

#define IHeaderFooter_get_Picture(This,RHS)	\
    ( (This)->lpVtbl -> get_Picture(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IHeaderFooter_INTERFACE_DEFINED__ */


#ifndef __IPage_INTERFACE_DEFINED__
#define __IPage_INTERFACE_DEFINED__

/* interface IPage */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IPage;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244A2-0001-0000-C000-000000000046")
    IPage : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LeftHeader( 
            /* [retval][out] */ HeaderFooter	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CenterHeader( 
            /* [retval][out] */ HeaderFooter	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RightHeader( 
            /* [retval][out] */ HeaderFooter	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LeftFooter( 
            /* [retval][out] */ HeaderFooter	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CenterFooter( 
            /* [retval][out] */ HeaderFooter	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RightFooter( 
            /* [retval][out] */ HeaderFooter	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IPageVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IPage * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IPage * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IPage * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IPage * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IPage * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IPage * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IPage * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LeftHeader )( 
            IPage * This,
            /* [retval][out] */ HeaderFooter	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CenterHeader )( 
            IPage * This,
            /* [retval][out] */ HeaderFooter	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RightHeader )( 
            IPage * This,
            /* [retval][out] */ HeaderFooter	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LeftFooter )( 
            IPage * This,
            /* [retval][out] */ HeaderFooter	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CenterFooter )( 
            IPage * This,
            /* [retval][out] */ HeaderFooter	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RightFooter )( 
            IPage * This,
            /* [retval][out] */ HeaderFooter	**RHS);
        
        END_INTERFACE
    } IPageVtbl;

    interface IPage
    {
        CONST_VTBL struct IPageVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IPage_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IPage_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IPage_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IPage_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IPage_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IPage_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IPage_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IPage_get_LeftHeader(This,RHS)	\
    ( (This)->lpVtbl -> get_LeftHeader(This,RHS) ) 

#define IPage_get_CenterHeader(This,RHS)	\
    ( (This)->lpVtbl -> get_CenterHeader(This,RHS) ) 

#define IPage_get_RightHeader(This,RHS)	\
    ( (This)->lpVtbl -> get_RightHeader(This,RHS) ) 

#define IPage_get_LeftFooter(This,RHS)	\
    ( (This)->lpVtbl -> get_LeftFooter(This,RHS) ) 

#define IPage_get_CenterFooter(This,RHS)	\
    ( (This)->lpVtbl -> get_CenterFooter(This,RHS) ) 

#define IPage_get_RightFooter(This,RHS)	\
    ( (This)->lpVtbl -> get_RightFooter(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IPage_INTERFACE_DEFINED__ */


#ifndef __IPages_INTERFACE_DEFINED__
#define __IPages_INTERFACE_DEFINED__

/* interface IPages */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IPages;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244A3-0001-0000-C000-000000000046")
    IPages : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Page	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Page	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IPagesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IPages * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IPages * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IPages * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IPages * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IPages * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IPages * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IPages * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Item )( 
            IPages * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Page	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IPages * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Page	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IPages * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            IPages * This,
            /* [retval][out] */ IUnknown **RHS);
        
        END_INTERFACE
    } IPagesVtbl;

    interface IPages
    {
        CONST_VTBL struct IPagesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IPages_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IPages_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IPages_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IPages_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IPages_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IPages_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IPages_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IPages_get_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Item(This,Index,RHS) ) 

#define IPages_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define IPages_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IPages_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IPages_INTERFACE_DEFINED__ */


#ifndef __IServerViewableItems_INTERFACE_DEFINED__
#define __IServerViewableItems_INTERFACE_DEFINED__

/* interface IServerViewableItems */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IServerViewableItems;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244A4-0001-0000-C000-000000000046")
    IServerViewableItems : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add( 
            /* [in] */ VARIANT Obj,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [in] */ VARIANT Index) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall DeleteAll( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IServerViewableItemsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IServerViewableItems * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IServerViewableItems * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IServerViewableItems * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IServerViewableItems * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IServerViewableItems * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IServerViewableItems * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IServerViewableItems * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IServerViewableItems * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IServerViewableItems * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IServerViewableItems * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IServerViewableItems * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add )( 
            IServerViewableItems * This,
            /* [in] */ VARIANT Obj,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IServerViewableItems * This,
            /* [in] */ VARIANT Index);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *DeleteAll )( 
            IServerViewableItems * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Item )( 
            IServerViewableItems * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IServerViewableItems * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            IServerViewableItems * This,
            /* [retval][out] */ IUnknown **RHS);
        
        END_INTERFACE
    } IServerViewableItemsVtbl;

    interface IServerViewableItems
    {
        CONST_VTBL struct IServerViewableItemsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IServerViewableItems_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IServerViewableItems_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IServerViewableItems_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IServerViewableItems_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IServerViewableItems_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IServerViewableItems_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IServerViewableItems_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IServerViewableItems_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IServerViewableItems_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IServerViewableItems_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IServerViewableItems_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IServerViewableItems_Add(This,Obj,RHS)	\
    ( (This)->lpVtbl -> Add(This,Obj,RHS) ) 

#define IServerViewableItems_Delete(This,Index)	\
    ( (This)->lpVtbl -> Delete(This,Index) ) 

#define IServerViewableItems_DeleteAll(This)	\
    ( (This)->lpVtbl -> DeleteAll(This) ) 

#define IServerViewableItems_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> Item(This,Index,RHS) ) 

#define IServerViewableItems_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define IServerViewableItems_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IServerViewableItems_INTERFACE_DEFINED__ */


#ifndef __ITableStyleElement_INTERFACE_DEFINED__
#define __ITableStyleElement_INTERFACE_DEFINED__

/* interface ITableStyleElement */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ITableStyleElement;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244A5-0001-0000-C000-000000000046")
    ITableStyleElement : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HasFormat( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Interior( 
            /* [retval][out] */ Interior	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Borders( 
            /* [retval][out] */ Borders	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Font( 
            /* [retval][out] */ Font	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_StripeSize( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_StripeSize( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Clear( void) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ITableStyleElementVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ITableStyleElement * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ITableStyleElement * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ITableStyleElement * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ITableStyleElement * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ITableStyleElement * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ITableStyleElement * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ITableStyleElement * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ITableStyleElement * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ITableStyleElement * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ITableStyleElement * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HasFormat )( 
            ITableStyleElement * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Interior )( 
            ITableStyleElement * This,
            /* [retval][out] */ Interior	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Borders )( 
            ITableStyleElement * This,
            /* [retval][out] */ Borders	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Font )( 
            ITableStyleElement * This,
            /* [retval][out] */ Font	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_StripeSize )( 
            ITableStyleElement * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_StripeSize )( 
            ITableStyleElement * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Clear )( 
            ITableStyleElement * This);
        
        END_INTERFACE
    } ITableStyleElementVtbl;

    interface ITableStyleElement
    {
        CONST_VTBL struct ITableStyleElementVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ITableStyleElement_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ITableStyleElement_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ITableStyleElement_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ITableStyleElement_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ITableStyleElement_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ITableStyleElement_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ITableStyleElement_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ITableStyleElement_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ITableStyleElement_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ITableStyleElement_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ITableStyleElement_get_HasFormat(This,RHS)	\
    ( (This)->lpVtbl -> get_HasFormat(This,RHS) ) 

#define ITableStyleElement_get_Interior(This,RHS)	\
    ( (This)->lpVtbl -> get_Interior(This,RHS) ) 

#define ITableStyleElement_get_Borders(This,RHS)	\
    ( (This)->lpVtbl -> get_Borders(This,RHS) ) 

#define ITableStyleElement_get_Font(This,RHS)	\
    ( (This)->lpVtbl -> get_Font(This,RHS) ) 

#define ITableStyleElement_get_StripeSize(This,RHS)	\
    ( (This)->lpVtbl -> get_StripeSize(This,RHS) ) 

#define ITableStyleElement_put_StripeSize(This,RHS)	\
    ( (This)->lpVtbl -> put_StripeSize(This,RHS) ) 

#define ITableStyleElement_Clear(This)	\
    ( (This)->lpVtbl -> Clear(This) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ITableStyleElement_INTERFACE_DEFINED__ */


#ifndef __ITableStyleElements_INTERFACE_DEFINED__
#define __ITableStyleElements_INTERFACE_DEFINED__

/* interface ITableStyleElements */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ITableStyleElements;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244A6-0001-0000-C000-000000000046")
    ITableStyleElements : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Item( 
            /* [in] */ XlTableStyleElementType Index,
            /* [retval][out] */ TableStyleElement	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ XlTableStyleElementType Index,
            /* [retval][out] */ TableStyleElement	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ITableStyleElementsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ITableStyleElements * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ITableStyleElements * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ITableStyleElements * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ITableStyleElements * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ITableStyleElements * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ITableStyleElements * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ITableStyleElements * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ITableStyleElements * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ITableStyleElements * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ITableStyleElements * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            ITableStyleElements * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Item )( 
            ITableStyleElements * This,
            /* [in] */ XlTableStyleElementType Index,
            /* [retval][out] */ TableStyleElement	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            ITableStyleElements * This,
            /* [in] */ XlTableStyleElementType Index,
            /* [retval][out] */ TableStyleElement	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            ITableStyleElements * This,
            /* [retval][out] */ IUnknown **RHS);
        
        END_INTERFACE
    } ITableStyleElementsVtbl;

    interface ITableStyleElements
    {
        CONST_VTBL struct ITableStyleElementsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ITableStyleElements_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ITableStyleElements_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ITableStyleElements_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ITableStyleElements_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ITableStyleElements_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ITableStyleElements_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ITableStyleElements_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ITableStyleElements_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ITableStyleElements_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ITableStyleElements_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ITableStyleElements_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define ITableStyleElements_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> Item(This,Index,RHS) ) 

#define ITableStyleElements_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define ITableStyleElements_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ITableStyleElements_INTERFACE_DEFINED__ */


#ifndef __ITableStyle_INTERFACE_DEFINED__
#define __ITableStyle_INTERFACE_DEFINED__

/* interface ITableStyle */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ITableStyle;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244A7-0001-0000-C000-000000000046")
    ITableStyle : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_NameLocal( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_BuiltIn( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TableStyleElements( 
            /* [retval][out] */ TableStyleElements	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShowAsAvailableTableStyle( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ShowAsAvailableTableStyle( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShowAsAvailablePivotTableStyle( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ShowAsAvailablePivotTableStyle( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Duplicate( 
            /* [optional][in] */ VARIANT NewTableStyleName,
            /* [retval][out] */ TableStyle	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShowAsAvailableSlicerStyle( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ShowAsAvailableSlicerStyle( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShowAsAvailableTimelineStyle( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ShowAsAvailableTimelineStyle( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ITableStyleVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ITableStyle * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ITableStyle * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ITableStyle * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ITableStyle * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ITableStyle * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ITableStyle * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ITableStyle * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ITableStyle * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ITableStyle * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ITableStyle * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            ITableStyle * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            ITableStyle * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_NameLocal )( 
            ITableStyle * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_BuiltIn )( 
            ITableStyle * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TableStyleElements )( 
            ITableStyle * This,
            /* [retval][out] */ TableStyleElements	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShowAsAvailableTableStyle )( 
            ITableStyle * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ShowAsAvailableTableStyle )( 
            ITableStyle * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShowAsAvailablePivotTableStyle )( 
            ITableStyle * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ShowAsAvailablePivotTableStyle )( 
            ITableStyle * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            ITableStyle * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Duplicate )( 
            ITableStyle * This,
            /* [optional][in] */ VARIANT NewTableStyleName,
            /* [retval][out] */ TableStyle	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShowAsAvailableSlicerStyle )( 
            ITableStyle * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ShowAsAvailableSlicerStyle )( 
            ITableStyle * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShowAsAvailableTimelineStyle )( 
            ITableStyle * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ShowAsAvailableTimelineStyle )( 
            ITableStyle * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        END_INTERFACE
    } ITableStyleVtbl;

    interface ITableStyle
    {
        CONST_VTBL struct ITableStyleVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ITableStyle_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ITableStyle_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ITableStyle_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ITableStyle_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ITableStyle_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ITableStyle_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ITableStyle_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ITableStyle_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ITableStyle_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ITableStyle_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ITableStyle_get__Default(This,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,RHS) ) 

#define ITableStyle_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define ITableStyle_get_NameLocal(This,RHS)	\
    ( (This)->lpVtbl -> get_NameLocal(This,RHS) ) 

#define ITableStyle_get_BuiltIn(This,RHS)	\
    ( (This)->lpVtbl -> get_BuiltIn(This,RHS) ) 

#define ITableStyle_get_TableStyleElements(This,RHS)	\
    ( (This)->lpVtbl -> get_TableStyleElements(This,RHS) ) 

#define ITableStyle_get_ShowAsAvailableTableStyle(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowAsAvailableTableStyle(This,RHS) ) 

#define ITableStyle_put_ShowAsAvailableTableStyle(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowAsAvailableTableStyle(This,RHS) ) 

#define ITableStyle_get_ShowAsAvailablePivotTableStyle(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowAsAvailablePivotTableStyle(This,RHS) ) 

#define ITableStyle_put_ShowAsAvailablePivotTableStyle(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowAsAvailablePivotTableStyle(This,RHS) ) 

#define ITableStyle_Delete(This)	\
    ( (This)->lpVtbl -> Delete(This) ) 

#define ITableStyle_Duplicate(This,NewTableStyleName,RHS)	\
    ( (This)->lpVtbl -> Duplicate(This,NewTableStyleName,RHS) ) 

#define ITableStyle_get_ShowAsAvailableSlicerStyle(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowAsAvailableSlicerStyle(This,RHS) ) 

#define ITableStyle_put_ShowAsAvailableSlicerStyle(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowAsAvailableSlicerStyle(This,RHS) ) 

#define ITableStyle_get_ShowAsAvailableTimelineStyle(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowAsAvailableTimelineStyle(This,RHS) ) 

#define ITableStyle_put_ShowAsAvailableTimelineStyle(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowAsAvailableTimelineStyle(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ITableStyle_INTERFACE_DEFINED__ */


#ifndef __ITableStyles_INTERFACE_DEFINED__
#define __ITableStyles_INTERFACE_DEFINED__

/* interface ITableStyles */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ITableStyles;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244A8-0001-0000-C000-000000000046")
    ITableStyles : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add( 
            /* [in] */ BSTR TableStyleName,
            /* [retval][out] */ TableStyle	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ TableStyle	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ TableStyle	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ITableStylesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ITableStyles * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ITableStyles * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ITableStyles * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ITableStyles * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ITableStyles * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ITableStyles * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ITableStyles * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ITableStyles * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ITableStyles * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ITableStyles * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            ITableStyles * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add )( 
            ITableStyles * This,
            /* [in] */ BSTR TableStyleName,
            /* [retval][out] */ TableStyle	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Item )( 
            ITableStyles * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ TableStyle	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            ITableStyles * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ TableStyle	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            ITableStyles * This,
            /* [retval][out] */ IUnknown **RHS);
        
        END_INTERFACE
    } ITableStylesVtbl;

    interface ITableStyles
    {
        CONST_VTBL struct ITableStylesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ITableStyles_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ITableStyles_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ITableStyles_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ITableStyles_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ITableStyles_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ITableStyles_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ITableStyles_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ITableStyles_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ITableStyles_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ITableStyles_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ITableStyles_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define ITableStyles_Add(This,TableStyleName,RHS)	\
    ( (This)->lpVtbl -> Add(This,TableStyleName,RHS) ) 

#define ITableStyles_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> Item(This,Index,RHS) ) 

#define ITableStyles_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define ITableStyles_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ITableStyles_INTERFACE_DEFINED__ */


#ifndef __ISortField_INTERFACE_DEFINED__
#define __ISortField_INTERFACE_DEFINED__

/* interface ISortField */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ISortField;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244A9-0001-0000-C000-000000000046")
    ISortField : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SortOn( 
            /* [retval][out] */ XlSortOn *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_SortOn( 
            /* [in] */ XlSortOn RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SortOnValue( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Key( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Order( 
            /* [retval][out] */ XlSortOrder *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Order( 
            /* [in] */ XlSortOrder RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CustomOrder( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_CustomOrder( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DataOption( 
            /* [retval][out] */ XlSortDataOption *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DataOption( 
            /* [in] */ XlSortDataOption RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Priority( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Priority( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ModifyKey( 
            /* [in] */ Range	*Key) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SetIcon( 
            /* [in] */ Icon	*Icon) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ISortFieldVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ISortField * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ISortField * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ISortField * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ISortField * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ISortField * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ISortField * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ISortField * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ISortField * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ISortField * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ISortField * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SortOn )( 
            ISortField * This,
            /* [retval][out] */ XlSortOn *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_SortOn )( 
            ISortField * This,
            /* [in] */ XlSortOn RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SortOnValue )( 
            ISortField * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Key )( 
            ISortField * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Order )( 
            ISortField * This,
            /* [retval][out] */ XlSortOrder *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Order )( 
            ISortField * This,
            /* [in] */ XlSortOrder RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CustomOrder )( 
            ISortField * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_CustomOrder )( 
            ISortField * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DataOption )( 
            ISortField * This,
            /* [retval][out] */ XlSortDataOption *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DataOption )( 
            ISortField * This,
            /* [in] */ XlSortDataOption RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Priority )( 
            ISortField * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Priority )( 
            ISortField * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            ISortField * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ModifyKey )( 
            ISortField * This,
            /* [in] */ Range	*Key);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SetIcon )( 
            ISortField * This,
            /* [in] */ Icon	*Icon);
        
        END_INTERFACE
    } ISortFieldVtbl;

    interface ISortField
    {
        CONST_VTBL struct ISortFieldVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ISortField_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ISortField_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ISortField_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ISortField_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ISortField_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ISortField_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ISortField_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ISortField_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ISortField_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ISortField_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ISortField_get_SortOn(This,RHS)	\
    ( (This)->lpVtbl -> get_SortOn(This,RHS) ) 

#define ISortField_put_SortOn(This,RHS)	\
    ( (This)->lpVtbl -> put_SortOn(This,RHS) ) 

#define ISortField_get_SortOnValue(This,RHS)	\
    ( (This)->lpVtbl -> get_SortOnValue(This,RHS) ) 

#define ISortField_get_Key(This,RHS)	\
    ( (This)->lpVtbl -> get_Key(This,RHS) ) 

#define ISortField_get_Order(This,RHS)	\
    ( (This)->lpVtbl -> get_Order(This,RHS) ) 

#define ISortField_put_Order(This,RHS)	\
    ( (This)->lpVtbl -> put_Order(This,RHS) ) 

#define ISortField_get_CustomOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_CustomOrder(This,RHS) ) 

#define ISortField_put_CustomOrder(This,RHS)	\
    ( (This)->lpVtbl -> put_CustomOrder(This,RHS) ) 

#define ISortField_get_DataOption(This,RHS)	\
    ( (This)->lpVtbl -> get_DataOption(This,RHS) ) 

#define ISortField_put_DataOption(This,RHS)	\
    ( (This)->lpVtbl -> put_DataOption(This,RHS) ) 

#define ISortField_get_Priority(This,RHS)	\
    ( (This)->lpVtbl -> get_Priority(This,RHS) ) 

#define ISortField_put_Priority(This,RHS)	\
    ( (This)->lpVtbl -> put_Priority(This,RHS) ) 

#define ISortField_Delete(This)	\
    ( (This)->lpVtbl -> Delete(This) ) 

#define ISortField_ModifyKey(This,Key)	\
    ( (This)->lpVtbl -> ModifyKey(This,Key) ) 

#define ISortField_SetIcon(This,Icon)	\
    ( (This)->lpVtbl -> SetIcon(This,Icon) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ISortField_INTERFACE_DEFINED__ */


#ifndef __ISortFields_INTERFACE_DEFINED__
#define __ISortFields_INTERFACE_DEFINED__

/* interface ISortFields */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ISortFields;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244AA-0001-0000-C000-000000000046")
    ISortFields : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add( 
            /* [in] */ Range	*Key,
            /* [optional][in] */ VARIANT SortOn,
            /* [optional][in] */ VARIANT Order,
            /* [optional][in] */ VARIANT CustomOrder,
            /* [optional][in] */ VARIANT DataOption,
            /* [retval][out] */ SortField	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ SortField	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Clear( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ SortField	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ISortFieldsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ISortFields * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ISortFields * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ISortFields * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ISortFields * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ISortFields * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ISortFields * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ISortFields * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ISortFields * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ISortFields * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ISortFields * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add )( 
            ISortFields * This,
            /* [in] */ Range	*Key,
            /* [optional][in] */ VARIANT SortOn,
            /* [optional][in] */ VARIANT Order,
            /* [optional][in] */ VARIANT CustomOrder,
            /* [optional][in] */ VARIANT DataOption,
            /* [retval][out] */ SortField	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Item )( 
            ISortFields * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ SortField	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            ISortFields * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Clear )( 
            ISortFields * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            ISortFields * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ SortField	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            ISortFields * This,
            /* [retval][out] */ IUnknown **RHS);
        
        END_INTERFACE
    } ISortFieldsVtbl;

    interface ISortFields
    {
        CONST_VTBL struct ISortFieldsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ISortFields_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ISortFields_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ISortFields_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ISortFields_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ISortFields_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ISortFields_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ISortFields_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ISortFields_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ISortFields_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ISortFields_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ISortFields_Add(This,Key,SortOn,Order,CustomOrder,DataOption,RHS)	\
    ( (This)->lpVtbl -> Add(This,Key,SortOn,Order,CustomOrder,DataOption,RHS) ) 

#define ISortFields_get_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Item(This,Index,RHS) ) 

#define ISortFields_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define ISortFields_Clear(This)	\
    ( (This)->lpVtbl -> Clear(This) ) 

#define ISortFields_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define ISortFields_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ISortFields_INTERFACE_DEFINED__ */


#ifndef __ISort_INTERFACE_DEFINED__
#define __ISort_INTERFACE_DEFINED__

/* interface ISort */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ISort;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244AB-0001-0000-C000-000000000046")
    ISort : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Rng( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Header( 
            /* [retval][out] */ XlYesNoGuess *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Header( 
            /* [in] */ XlYesNoGuess RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MatchCase( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_MatchCase( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Orientation( 
            /* [retval][out] */ XlSortOrientation *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Orientation( 
            /* [in] */ XlSortOrientation RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SortMethod( 
            /* [retval][out] */ XlSortMethod *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_SortMethod( 
            /* [in] */ XlSortMethod RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SortFields( 
            /* [retval][out] */ SortFields	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SetRange( 
            /* [in] */ Range	*Rng) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Apply( void) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ISortVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ISort * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ISort * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ISort * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ISort * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ISort * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ISort * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ISort * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ISort * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ISort * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ISort * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Rng )( 
            ISort * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Header )( 
            ISort * This,
            /* [retval][out] */ XlYesNoGuess *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Header )( 
            ISort * This,
            /* [in] */ XlYesNoGuess RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MatchCase )( 
            ISort * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_MatchCase )( 
            ISort * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Orientation )( 
            ISort * This,
            /* [retval][out] */ XlSortOrientation *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Orientation )( 
            ISort * This,
            /* [in] */ XlSortOrientation RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SortMethod )( 
            ISort * This,
            /* [retval][out] */ XlSortMethod *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_SortMethod )( 
            ISort * This,
            /* [in] */ XlSortMethod RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SortFields )( 
            ISort * This,
            /* [retval][out] */ SortFields	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SetRange )( 
            ISort * This,
            /* [in] */ Range	*Rng);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Apply )( 
            ISort * This);
        
        END_INTERFACE
    } ISortVtbl;

    interface ISort
    {
        CONST_VTBL struct ISortVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ISort_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ISort_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ISort_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ISort_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ISort_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ISort_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ISort_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ISort_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ISort_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ISort_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ISort_get_Rng(This,RHS)	\
    ( (This)->lpVtbl -> get_Rng(This,RHS) ) 

#define ISort_get_Header(This,RHS)	\
    ( (This)->lpVtbl -> get_Header(This,RHS) ) 

#define ISort_put_Header(This,RHS)	\
    ( (This)->lpVtbl -> put_Header(This,RHS) ) 

#define ISort_get_MatchCase(This,RHS)	\
    ( (This)->lpVtbl -> get_MatchCase(This,RHS) ) 

#define ISort_put_MatchCase(This,RHS)	\
    ( (This)->lpVtbl -> put_MatchCase(This,RHS) ) 

#define ISort_get_Orientation(This,RHS)	\
    ( (This)->lpVtbl -> get_Orientation(This,RHS) ) 

#define ISort_put_Orientation(This,RHS)	\
    ( (This)->lpVtbl -> put_Orientation(This,RHS) ) 

#define ISort_get_SortMethod(This,RHS)	\
    ( (This)->lpVtbl -> get_SortMethod(This,RHS) ) 

#define ISort_put_SortMethod(This,RHS)	\
    ( (This)->lpVtbl -> put_SortMethod(This,RHS) ) 

#define ISort_get_SortFields(This,RHS)	\
    ( (This)->lpVtbl -> get_SortFields(This,RHS) ) 

#define ISort_SetRange(This,Rng)	\
    ( (This)->lpVtbl -> SetRange(This,Rng) ) 

#define ISort_Apply(This)	\
    ( (This)->lpVtbl -> Apply(This) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ISort_INTERFACE_DEFINED__ */


#ifndef __IResearch_INTERFACE_DEFINED__
#define __IResearch_INTERFACE_DEFINED__

/* interface IResearch */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IResearch;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244AC-0001-0000-C000-000000000046")
    IResearch : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Query( 
            /* [in] */ BSTR ServiceID,
            /* [optional][in] */ VARIANT QueryString,
            /* [optional][in] */ VARIANT QueryLanguage,
            /* [optional][in] */ VARIANT UseSelection,
            /* [optional][in] */ VARIANT LaunchQuery,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall IsResearchService( 
            /* [in] */ BSTR ServiceID,
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SetLanguagePair( 
            /* [in] */ long LanguageFrom,
            /* [in] */ long LanguageTo,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IResearchVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IResearch * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IResearch * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IResearch * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IResearch * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IResearch * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IResearch * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IResearch * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IResearch * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IResearch * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IResearch * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Query )( 
            IResearch * This,
            /* [in] */ BSTR ServiceID,
            /* [optional][in] */ VARIANT QueryString,
            /* [optional][in] */ VARIANT QueryLanguage,
            /* [optional][in] */ VARIANT UseSelection,
            /* [optional][in] */ VARIANT LaunchQuery,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *IsResearchService )( 
            IResearch * This,
            /* [in] */ BSTR ServiceID,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SetLanguagePair )( 
            IResearch * This,
            /* [in] */ long LanguageFrom,
            /* [in] */ long LanguageTo,
            /* [retval][out] */ VARIANT *RHS);
        
        END_INTERFACE
    } IResearchVtbl;

    interface IResearch
    {
        CONST_VTBL struct IResearchVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IResearch_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IResearch_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IResearch_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IResearch_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IResearch_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IResearch_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IResearch_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IResearch_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IResearch_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IResearch_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IResearch_Query(This,ServiceID,QueryString,QueryLanguage,UseSelection,LaunchQuery,RHS)	\
    ( (This)->lpVtbl -> Query(This,ServiceID,QueryString,QueryLanguage,UseSelection,LaunchQuery,RHS) ) 

#define IResearch_IsResearchService(This,ServiceID,RHS)	\
    ( (This)->lpVtbl -> IsResearchService(This,ServiceID,RHS) ) 

#define IResearch_SetLanguagePair(This,LanguageFrom,LanguageTo,RHS)	\
    ( (This)->lpVtbl -> SetLanguagePair(This,LanguageFrom,LanguageTo,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IResearch_INTERFACE_DEFINED__ */


#ifndef __IColorStop_INTERFACE_DEFINED__
#define __IColorStop_INTERFACE_DEFINED__

/* interface IColorStop */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IColorStop;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244AD-0001-0000-C000-000000000046")
    IColorStop : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Color( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Color( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ThemeColor( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ThemeColor( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TintAndShade( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_TintAndShade( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Position( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Position( 
            /* [in] */ double RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IColorStopVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IColorStop * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IColorStop * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IColorStop * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IColorStop * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IColorStop * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IColorStop * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IColorStop * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IColorStop * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IColorStop * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IColorStop * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IColorStop * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Color )( 
            IColorStop * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Color )( 
            IColorStop * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ThemeColor )( 
            IColorStop * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ThemeColor )( 
            IColorStop * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TintAndShade )( 
            IColorStop * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_TintAndShade )( 
            IColorStop * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Position )( 
            IColorStop * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Position )( 
            IColorStop * This,
            /* [in] */ double RHS);
        
        END_INTERFACE
    } IColorStopVtbl;

    interface IColorStop
    {
        CONST_VTBL struct IColorStopVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IColorStop_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IColorStop_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IColorStop_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IColorStop_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IColorStop_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IColorStop_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IColorStop_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IColorStop_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IColorStop_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IColorStop_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IColorStop_Delete(This)	\
    ( (This)->lpVtbl -> Delete(This) ) 

#define IColorStop_get_Color(This,RHS)	\
    ( (This)->lpVtbl -> get_Color(This,RHS) ) 

#define IColorStop_put_Color(This,RHS)	\
    ( (This)->lpVtbl -> put_Color(This,RHS) ) 

#define IColorStop_get_ThemeColor(This,RHS)	\
    ( (This)->lpVtbl -> get_ThemeColor(This,RHS) ) 

#define IColorStop_put_ThemeColor(This,RHS)	\
    ( (This)->lpVtbl -> put_ThemeColor(This,RHS) ) 

#define IColorStop_get_TintAndShade(This,RHS)	\
    ( (This)->lpVtbl -> get_TintAndShade(This,RHS) ) 

#define IColorStop_put_TintAndShade(This,RHS)	\
    ( (This)->lpVtbl -> put_TintAndShade(This,RHS) ) 

#define IColorStop_get_Position(This,RHS)	\
    ( (This)->lpVtbl -> get_Position(This,RHS) ) 

#define IColorStop_put_Position(This,RHS)	\
    ( (This)->lpVtbl -> put_Position(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IColorStop_INTERFACE_DEFINED__ */


#ifndef __IColorStops_INTERFACE_DEFINED__
#define __IColorStops_INTERFACE_DEFINED__

/* interface IColorStops */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IColorStops;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244AE-0001-0000-C000-000000000046")
    IColorStops : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add( 
            /* [in] */ double Position,
            /* [retval][out] */ ColorStop	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ ColorStop	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ ColorStop	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Clear( void) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IColorStopsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IColorStops * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IColorStops * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IColorStops * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IColorStops * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IColorStops * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IColorStops * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IColorStops * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IColorStops * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IColorStops * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IColorStops * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IColorStops * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add )( 
            IColorStops * This,
            /* [in] */ double Position,
            /* [retval][out] */ ColorStop	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Item )( 
            IColorStops * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ ColorStop	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IColorStops * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ ColorStop	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            IColorStops * This,
            /* [retval][out] */ IUnknown **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Clear )( 
            IColorStops * This);
        
        END_INTERFACE
    } IColorStopsVtbl;

    interface IColorStops
    {
        CONST_VTBL struct IColorStopsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IColorStops_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IColorStops_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IColorStops_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IColorStops_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IColorStops_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IColorStops_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IColorStops_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IColorStops_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IColorStops_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IColorStops_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IColorStops_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IColorStops_Add(This,Position,RHS)	\
    ( (This)->lpVtbl -> Add(This,Position,RHS) ) 

#define IColorStops_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> Item(This,Index,RHS) ) 

#define IColorStops_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define IColorStops_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#define IColorStops_Clear(This)	\
    ( (This)->lpVtbl -> Clear(This) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IColorStops_INTERFACE_DEFINED__ */


#ifndef __ILinearGradient_INTERFACE_DEFINED__
#define __ILinearGradient_INTERFACE_DEFINED__

/* interface ILinearGradient */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ILinearGradient;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244AF-0001-0000-C000-000000000046")
    ILinearGradient : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ColorStops( 
            /* [retval][out] */ ColorStops	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Degree( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Degree( 
            /* [in] */ double RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ILinearGradientVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ILinearGradient * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ILinearGradient * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ILinearGradient * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ILinearGradient * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ILinearGradient * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ILinearGradient * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ILinearGradient * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ILinearGradient * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ILinearGradient * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ILinearGradient * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ColorStops )( 
            ILinearGradient * This,
            /* [retval][out] */ ColorStops	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Degree )( 
            ILinearGradient * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Degree )( 
            ILinearGradient * This,
            /* [in] */ double RHS);
        
        END_INTERFACE
    } ILinearGradientVtbl;

    interface ILinearGradient
    {
        CONST_VTBL struct ILinearGradientVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ILinearGradient_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ILinearGradient_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ILinearGradient_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ILinearGradient_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ILinearGradient_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ILinearGradient_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ILinearGradient_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ILinearGradient_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ILinearGradient_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ILinearGradient_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ILinearGradient_get_ColorStops(This,RHS)	\
    ( (This)->lpVtbl -> get_ColorStops(This,RHS) ) 

#define ILinearGradient_get_Degree(This,RHS)	\
    ( (This)->lpVtbl -> get_Degree(This,RHS) ) 

#define ILinearGradient_put_Degree(This,RHS)	\
    ( (This)->lpVtbl -> put_Degree(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ILinearGradient_INTERFACE_DEFINED__ */


#ifndef __IRectangularGradient_INTERFACE_DEFINED__
#define __IRectangularGradient_INTERFACE_DEFINED__

/* interface IRectangularGradient */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IRectangularGradient;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244B0-0001-0000-C000-000000000046")
    IRectangularGradient : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ColorStops( 
            /* [retval][out] */ ColorStops	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RectangleTop( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_RectangleTop( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RectangleBottom( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_RectangleBottom( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RectangleLeft( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_RectangleLeft( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RectangleRight( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_RectangleRight( 
            /* [in] */ double RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IRectangularGradientVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IRectangularGradient * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IRectangularGradient * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IRectangularGradient * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IRectangularGradient * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IRectangularGradient * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IRectangularGradient * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IRectangularGradient * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IRectangularGradient * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IRectangularGradient * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IRectangularGradient * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ColorStops )( 
            IRectangularGradient * This,
            /* [retval][out] */ ColorStops	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RectangleTop )( 
            IRectangularGradient * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_RectangleTop )( 
            IRectangularGradient * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RectangleBottom )( 
            IRectangularGradient * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_RectangleBottom )( 
            IRectangularGradient * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RectangleLeft )( 
            IRectangularGradient * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_RectangleLeft )( 
            IRectangularGradient * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RectangleRight )( 
            IRectangularGradient * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_RectangleRight )( 
            IRectangularGradient * This,
            /* [in] */ double RHS);
        
        END_INTERFACE
    } IRectangularGradientVtbl;

    interface IRectangularGradient
    {
        CONST_VTBL struct IRectangularGradientVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IRectangularGradient_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IRectangularGradient_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IRectangularGradient_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IRectangularGradient_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IRectangularGradient_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IRectangularGradient_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IRectangularGradient_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IRectangularGradient_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IRectangularGradient_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IRectangularGradient_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IRectangularGradient_get_ColorStops(This,RHS)	\
    ( (This)->lpVtbl -> get_ColorStops(This,RHS) ) 

#define IRectangularGradient_get_RectangleTop(This,RHS)	\
    ( (This)->lpVtbl -> get_RectangleTop(This,RHS) ) 

#define IRectangularGradient_put_RectangleTop(This,RHS)	\
    ( (This)->lpVtbl -> put_RectangleTop(This,RHS) ) 

#define IRectangularGradient_get_RectangleBottom(This,RHS)	\
    ( (This)->lpVtbl -> get_RectangleBottom(This,RHS) ) 

#define IRectangularGradient_put_RectangleBottom(This,RHS)	\
    ( (This)->lpVtbl -> put_RectangleBottom(This,RHS) ) 

#define IRectangularGradient_get_RectangleLeft(This,RHS)	\
    ( (This)->lpVtbl -> get_RectangleLeft(This,RHS) ) 

#define IRectangularGradient_put_RectangleLeft(This,RHS)	\
    ( (This)->lpVtbl -> put_RectangleLeft(This,RHS) ) 

#define IRectangularGradient_get_RectangleRight(This,RHS)	\
    ( (This)->lpVtbl -> get_RectangleRight(This,RHS) ) 

#define IRectangularGradient_put_RectangleRight(This,RHS)	\
    ( (This)->lpVtbl -> put_RectangleRight(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IRectangularGradient_INTERFACE_DEFINED__ */


#ifndef __IMultiThreadedCalculation_INTERFACE_DEFINED__
#define __IMultiThreadedCalculation_INTERFACE_DEFINED__

/* interface IMultiThreadedCalculation */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IMultiThreadedCalculation;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244B1-0001-0000-C000-000000000046")
    IMultiThreadedCalculation : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Enabled( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Enabled( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ThreadMode( 
            /* [retval][out] */ XlThreadMode *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ThreadMode( 
            /* [in] */ XlThreadMode RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ThreadCount( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ThreadCount( 
            /* [in] */ long RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IMultiThreadedCalculationVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IMultiThreadedCalculation * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IMultiThreadedCalculation * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IMultiThreadedCalculation * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IMultiThreadedCalculation * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IMultiThreadedCalculation * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IMultiThreadedCalculation * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IMultiThreadedCalculation * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IMultiThreadedCalculation * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IMultiThreadedCalculation * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IMultiThreadedCalculation * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Enabled )( 
            IMultiThreadedCalculation * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Enabled )( 
            IMultiThreadedCalculation * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ThreadMode )( 
            IMultiThreadedCalculation * This,
            /* [retval][out] */ XlThreadMode *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ThreadMode )( 
            IMultiThreadedCalculation * This,
            /* [in] */ XlThreadMode RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ThreadCount )( 
            IMultiThreadedCalculation * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ThreadCount )( 
            IMultiThreadedCalculation * This,
            /* [in] */ long RHS);
        
        END_INTERFACE
    } IMultiThreadedCalculationVtbl;

    interface IMultiThreadedCalculation
    {
        CONST_VTBL struct IMultiThreadedCalculationVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IMultiThreadedCalculation_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IMultiThreadedCalculation_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IMultiThreadedCalculation_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IMultiThreadedCalculation_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IMultiThreadedCalculation_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IMultiThreadedCalculation_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IMultiThreadedCalculation_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IMultiThreadedCalculation_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IMultiThreadedCalculation_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IMultiThreadedCalculation_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IMultiThreadedCalculation_get_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> get_Enabled(This,RHS) ) 

#define IMultiThreadedCalculation_put_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> put_Enabled(This,RHS) ) 

#define IMultiThreadedCalculation_get_ThreadMode(This,RHS)	\
    ( (This)->lpVtbl -> get_ThreadMode(This,RHS) ) 

#define IMultiThreadedCalculation_put_ThreadMode(This,RHS)	\
    ( (This)->lpVtbl -> put_ThreadMode(This,RHS) ) 

#define IMultiThreadedCalculation_get_ThreadCount(This,RHS)	\
    ( (This)->lpVtbl -> get_ThreadCount(This,RHS) ) 

#define IMultiThreadedCalculation_put_ThreadCount(This,RHS)	\
    ( (This)->lpVtbl -> put_ThreadCount(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IMultiThreadedCalculation_INTERFACE_DEFINED__ */


#ifndef __IChartFormat_INTERFACE_DEFINED__
#define __IChartFormat_INTERFACE_DEFINED__

/* interface IChartFormat */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IChartFormat;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244B2-0001-0000-C000-000000000046")
    IChartFormat : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Fill( 
            /* [retval][out] */ FillFormat **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Glow( 
            /* [retval][out] */ /* external definition not present */ GlowFormat **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Line( 
            /* [retval][out] */ LineFormat **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PictureFormat( 
            /* [retval][out] */ PictureFormat **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Shadow( 
            /* [retval][out] */ ShadowFormat **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SoftEdge( 
            /* [retval][out] */ /* external definition not present */ SoftEdgeFormat **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TextFrame2( 
            /* [retval][out] */ TextFrame2 **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ThreeD( 
            /* [retval][out] */ ThreeDFormat **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Adjustments( 
            /* [retval][out] */ Adjustments **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AutoShapeType( 
            /* [retval][out] */ MsoAutoShapeType *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AutoShapeType( 
            /* [in] */ MsoAutoShapeType RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IChartFormatVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IChartFormat * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IChartFormat * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IChartFormat * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IChartFormat * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IChartFormat * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IChartFormat * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IChartFormat * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IChartFormat * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IChartFormat * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IChartFormat * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Fill )( 
            IChartFormat * This,
            /* [retval][out] */ FillFormat **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Glow )( 
            IChartFormat * This,
            /* [retval][out] */ /* external definition not present */ GlowFormat **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Line )( 
            IChartFormat * This,
            /* [retval][out] */ LineFormat **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PictureFormat )( 
            IChartFormat * This,
            /* [retval][out] */ PictureFormat **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Shadow )( 
            IChartFormat * This,
            /* [retval][out] */ ShadowFormat **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SoftEdge )( 
            IChartFormat * This,
            /* [retval][out] */ /* external definition not present */ SoftEdgeFormat **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TextFrame2 )( 
            IChartFormat * This,
            /* [retval][out] */ TextFrame2 **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ThreeD )( 
            IChartFormat * This,
            /* [retval][out] */ ThreeDFormat **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Adjustments )( 
            IChartFormat * This,
            /* [retval][out] */ Adjustments **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AutoShapeType )( 
            IChartFormat * This,
            /* [retval][out] */ MsoAutoShapeType *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AutoShapeType )( 
            IChartFormat * This,
            /* [in] */ MsoAutoShapeType RHS);
        
        END_INTERFACE
    } IChartFormatVtbl;

    interface IChartFormat
    {
        CONST_VTBL struct IChartFormatVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IChartFormat_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IChartFormat_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IChartFormat_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IChartFormat_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IChartFormat_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IChartFormat_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IChartFormat_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IChartFormat_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IChartFormat_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IChartFormat_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IChartFormat_get_Fill(This,RHS)	\
    ( (This)->lpVtbl -> get_Fill(This,RHS) ) 

#define IChartFormat_get_Glow(This,RHS)	\
    ( (This)->lpVtbl -> get_Glow(This,RHS) ) 

#define IChartFormat_get_Line(This,RHS)	\
    ( (This)->lpVtbl -> get_Line(This,RHS) ) 

#define IChartFormat_get_PictureFormat(This,RHS)	\
    ( (This)->lpVtbl -> get_PictureFormat(This,RHS) ) 

#define IChartFormat_get_Shadow(This,RHS)	\
    ( (This)->lpVtbl -> get_Shadow(This,RHS) ) 

#define IChartFormat_get_SoftEdge(This,RHS)	\
    ( (This)->lpVtbl -> get_SoftEdge(This,RHS) ) 

#define IChartFormat_get_TextFrame2(This,RHS)	\
    ( (This)->lpVtbl -> get_TextFrame2(This,RHS) ) 

#define IChartFormat_get_ThreeD(This,RHS)	\
    ( (This)->lpVtbl -> get_ThreeD(This,RHS) ) 

#define IChartFormat_get_Adjustments(This,RHS)	\
    ( (This)->lpVtbl -> get_Adjustments(This,RHS) ) 

#define IChartFormat_get_AutoShapeType(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoShapeType(This,RHS) ) 

#define IChartFormat_put_AutoShapeType(This,RHS)	\
    ( (This)->lpVtbl -> put_AutoShapeType(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IChartFormat_INTERFACE_DEFINED__ */


#ifndef __IFileExportConverter_INTERFACE_DEFINED__
#define __IFileExportConverter_INTERFACE_DEFINED__

/* interface IFileExportConverter */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IFileExportConverter;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244B3-0001-0000-C000-000000000046")
    IFileExportConverter : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Extensions( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Description( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_FileFormat( 
            /* [retval][out] */ long *RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IFileExportConverterVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IFileExportConverter * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IFileExportConverter * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IFileExportConverter * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IFileExportConverter * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IFileExportConverter * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IFileExportConverter * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IFileExportConverter * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IFileExportConverter * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IFileExportConverter * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IFileExportConverter * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Extensions )( 
            IFileExportConverter * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Description )( 
            IFileExportConverter * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_FileFormat )( 
            IFileExportConverter * This,
            /* [retval][out] */ long *RHS);
        
        END_INTERFACE
    } IFileExportConverterVtbl;

    interface IFileExportConverter
    {
        CONST_VTBL struct IFileExportConverterVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IFileExportConverter_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IFileExportConverter_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IFileExportConverter_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IFileExportConverter_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IFileExportConverter_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IFileExportConverter_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IFileExportConverter_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IFileExportConverter_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IFileExportConverter_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IFileExportConverter_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IFileExportConverter_get_Extensions(This,RHS)	\
    ( (This)->lpVtbl -> get_Extensions(This,RHS) ) 

#define IFileExportConverter_get_Description(This,RHS)	\
    ( (This)->lpVtbl -> get_Description(This,RHS) ) 

#define IFileExportConverter_get_FileFormat(This,RHS)	\
    ( (This)->lpVtbl -> get_FileFormat(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IFileExportConverter_INTERFACE_DEFINED__ */


#ifndef __IFileExportConverters_INTERFACE_DEFINED__
#define __IFileExportConverters_INTERFACE_DEFINED__

/* interface IFileExportConverters */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IFileExportConverters;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244B4-0001-0000-C000-000000000046")
    IFileExportConverters : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ FileExportConverter	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ FileExportConverter	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IFileExportConvertersVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IFileExportConverters * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IFileExportConverters * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IFileExportConverters * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IFileExportConverters * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IFileExportConverters * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IFileExportConverters * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IFileExportConverters * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IFileExportConverters * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IFileExportConverters * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IFileExportConverters * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IFileExportConverters * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IFileExportConverters * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ FileExportConverter	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            IFileExportConverters * This,
            /* [retval][out] */ IUnknown **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Item )( 
            IFileExportConverters * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ FileExportConverter	**RHS);
        
        END_INTERFACE
    } IFileExportConvertersVtbl;

    interface IFileExportConverters
    {
        CONST_VTBL struct IFileExportConvertersVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IFileExportConverters_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IFileExportConverters_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IFileExportConverters_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IFileExportConverters_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IFileExportConverters_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IFileExportConverters_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IFileExportConverters_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IFileExportConverters_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IFileExportConverters_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IFileExportConverters_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IFileExportConverters_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IFileExportConverters_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define IFileExportConverters_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#define IFileExportConverters_get_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Item(This,Index,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IFileExportConverters_INTERFACE_DEFINED__ */


#ifndef __IAddIns2_INTERFACE_DEFINED__
#define __IAddIns2_INTERFACE_DEFINED__

/* interface IAddIns2 */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IAddIns2;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244B5-0001-0000-C000-000000000046")
    IAddIns2 : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add( 
            /* [in] */ BSTR Filename,
            /* [optional][in] */ VARIANT CopyFile,
            /* [retval][out] */ AddIn	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ AddIn	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ AddIn	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IAddIns2Vtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IAddIns2 * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IAddIns2 * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IAddIns2 * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IAddIns2 * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IAddIns2 * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IAddIns2 * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IAddIns2 * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IAddIns2 * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IAddIns2 * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IAddIns2 * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add )( 
            IAddIns2 * This,
            /* [in] */ BSTR Filename,
            /* [optional][in] */ VARIANT CopyFile,
            /* [retval][out] */ AddIn	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IAddIns2 * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Item )( 
            IAddIns2 * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ AddIn	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            IAddIns2 * This,
            /* [retval][out] */ IUnknown **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IAddIns2 * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ AddIn	**RHS);
        
        END_INTERFACE
    } IAddIns2Vtbl;

    interface IAddIns2
    {
        CONST_VTBL struct IAddIns2Vtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IAddIns2_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IAddIns2_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IAddIns2_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IAddIns2_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IAddIns2_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IAddIns2_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IAddIns2_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IAddIns2_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IAddIns2_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IAddIns2_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IAddIns2_Add(This,Filename,CopyFile,RHS)	\
    ( (This)->lpVtbl -> Add(This,Filename,CopyFile,RHS) ) 

#define IAddIns2_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IAddIns2_get_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Item(This,Index,RHS) ) 

#define IAddIns2_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#define IAddIns2_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IAddIns2_INTERFACE_DEFINED__ */


#ifndef __ISparklineGroups_INTERFACE_DEFINED__
#define __ISparklineGroups_INTERFACE_DEFINED__

/* interface ISparklineGroups */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ISparklineGroups;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244B6-0001-0000-C000-000000000046")
    ISparklineGroups : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add( 
            /* [in] */ XlSparkType Type,
            /* [in] */ BSTR SourceData,
            /* [retval][out] */ SparklineGroup	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ SparklineGroup	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ SparklineGroup	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Clear( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ClearGroups( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Group( 
            /* [in] */ Range	*Location) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Ungroup( void) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ISparklineGroupsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ISparklineGroups * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ISparklineGroups * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ISparklineGroups * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ISparklineGroups * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ISparklineGroups * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ISparklineGroups * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ISparklineGroups * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ISparklineGroups * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ISparklineGroups * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ISparklineGroups * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add )( 
            ISparklineGroups * This,
            /* [in] */ XlSparkType Type,
            /* [in] */ BSTR SourceData,
            /* [retval][out] */ SparklineGroup	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            ISparklineGroups * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Item )( 
            ISparklineGroups * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ SparklineGroup	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            ISparklineGroups * This,
            /* [retval][out] */ IUnknown **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            ISparklineGroups * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ SparklineGroup	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Clear )( 
            ISparklineGroups * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ClearGroups )( 
            ISparklineGroups * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Group )( 
            ISparklineGroups * This,
            /* [in] */ Range	*Location);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Ungroup )( 
            ISparklineGroups * This);
        
        END_INTERFACE
    } ISparklineGroupsVtbl;

    interface ISparklineGroups
    {
        CONST_VTBL struct ISparklineGroupsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ISparklineGroups_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ISparklineGroups_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ISparklineGroups_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ISparklineGroups_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ISparklineGroups_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ISparklineGroups_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ISparklineGroups_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ISparklineGroups_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ISparklineGroups_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ISparklineGroups_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ISparklineGroups_Add(This,Type,SourceData,RHS)	\
    ( (This)->lpVtbl -> Add(This,Type,SourceData,RHS) ) 

#define ISparklineGroups_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define ISparklineGroups_get_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Item(This,Index,RHS) ) 

#define ISparklineGroups_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#define ISparklineGroups_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define ISparklineGroups_Clear(This)	\
    ( (This)->lpVtbl -> Clear(This) ) 

#define ISparklineGroups_ClearGroups(This)	\
    ( (This)->lpVtbl -> ClearGroups(This) ) 

#define ISparklineGroups_Group(This,Location)	\
    ( (This)->lpVtbl -> Group(This,Location) ) 

#define ISparklineGroups_Ungroup(This)	\
    ( (This)->lpVtbl -> Ungroup(This) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ISparklineGroups_INTERFACE_DEFINED__ */


#ifndef __ISparklineGroup_INTERFACE_DEFINED__
#define __ISparklineGroup_INTERFACE_DEFINED__

/* interface ISparklineGroup */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ISparklineGroup;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244B7-0001-0000-C000-000000000046")
    ISparklineGroup : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Sparkline	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Location( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propputref][id] */ HRESULT __stdcall putref_Location( 
            /* [in] */ Range	*RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SourceData( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_SourceData( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DateRange( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DateRange( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ModifyLocation( 
            /* [in] */ Range	*Location) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ModifySourceData( 
            /* [in] */ BSTR SourceData) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Modify( 
            /* [in] */ Range	*Location,
            /* [in] */ BSTR SourceData) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ModifyDateRange( 
            /* [in] */ BSTR DateRange) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Type( 
            /* [retval][out] */ XlSparkType *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Type( 
            /* [in] */ XlSparkType RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SeriesColor( 
            /* [retval][out] */ FormatColor	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Points( 
            /* [retval][out] */ SparkPoints	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Axes( 
            /* [retval][out] */ SparkAxes	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DisplayBlanksAs( 
            /* [retval][out] */ XlDisplayBlanksAs *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DisplayBlanksAs( 
            /* [in] */ XlDisplayBlanksAs RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DisplayHidden( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DisplayHidden( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LineWeight( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_LineWeight( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PlotBy( 
            /* [retval][out] */ XlSparklineRowCol *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PlotBy( 
            /* [in] */ XlSparklineRowCol RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ISparklineGroupVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ISparklineGroup * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ISparklineGroup * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ISparklineGroup * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ISparklineGroup * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ISparklineGroup * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ISparklineGroup * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ISparklineGroup * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ISparklineGroup * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ISparklineGroup * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ISparklineGroup * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            ISparklineGroup * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Item )( 
            ISparklineGroup * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Sparkline	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            ISparklineGroup * This,
            /* [retval][out] */ IUnknown **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Location )( 
            ISparklineGroup * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propputref][id] */ HRESULT ( __stdcall *putref_Location )( 
            ISparklineGroup * This,
            /* [in] */ Range	*RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SourceData )( 
            ISparklineGroup * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_SourceData )( 
            ISparklineGroup * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DateRange )( 
            ISparklineGroup * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DateRange )( 
            ISparklineGroup * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ModifyLocation )( 
            ISparklineGroup * This,
            /* [in] */ Range	*Location);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ModifySourceData )( 
            ISparklineGroup * This,
            /* [in] */ BSTR SourceData);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Modify )( 
            ISparklineGroup * This,
            /* [in] */ Range	*Location,
            /* [in] */ BSTR SourceData);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ModifyDateRange )( 
            ISparklineGroup * This,
            /* [in] */ BSTR DateRange);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            ISparklineGroup * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Type )( 
            ISparklineGroup * This,
            /* [retval][out] */ XlSparkType *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Type )( 
            ISparklineGroup * This,
            /* [in] */ XlSparkType RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SeriesColor )( 
            ISparklineGroup * This,
            /* [retval][out] */ FormatColor	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Points )( 
            ISparklineGroup * This,
            /* [retval][out] */ SparkPoints	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Axes )( 
            ISparklineGroup * This,
            /* [retval][out] */ SparkAxes	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DisplayBlanksAs )( 
            ISparklineGroup * This,
            /* [retval][out] */ XlDisplayBlanksAs *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DisplayBlanksAs )( 
            ISparklineGroup * This,
            /* [in] */ XlDisplayBlanksAs RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DisplayHidden )( 
            ISparklineGroup * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DisplayHidden )( 
            ISparklineGroup * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LineWeight )( 
            ISparklineGroup * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_LineWeight )( 
            ISparklineGroup * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PlotBy )( 
            ISparklineGroup * This,
            /* [retval][out] */ XlSparklineRowCol *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PlotBy )( 
            ISparklineGroup * This,
            /* [in] */ XlSparklineRowCol RHS);
        
        END_INTERFACE
    } ISparklineGroupVtbl;

    interface ISparklineGroup
    {
        CONST_VTBL struct ISparklineGroupVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ISparklineGroup_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ISparklineGroup_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ISparklineGroup_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ISparklineGroup_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ISparklineGroup_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ISparklineGroup_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ISparklineGroup_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ISparklineGroup_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ISparklineGroup_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ISparklineGroup_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ISparklineGroup_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define ISparklineGroup_get_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Item(This,Index,RHS) ) 

#define ISparklineGroup_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#define ISparklineGroup_get_Location(This,RHS)	\
    ( (This)->lpVtbl -> get_Location(This,RHS) ) 

#define ISparklineGroup_putref_Location(This,RHS)	\
    ( (This)->lpVtbl -> putref_Location(This,RHS) ) 

#define ISparklineGroup_get_SourceData(This,RHS)	\
    ( (This)->lpVtbl -> get_SourceData(This,RHS) ) 

#define ISparklineGroup_put_SourceData(This,RHS)	\
    ( (This)->lpVtbl -> put_SourceData(This,RHS) ) 

#define ISparklineGroup_get_DateRange(This,RHS)	\
    ( (This)->lpVtbl -> get_DateRange(This,RHS) ) 

#define ISparklineGroup_put_DateRange(This,RHS)	\
    ( (This)->lpVtbl -> put_DateRange(This,RHS) ) 

#define ISparklineGroup_ModifyLocation(This,Location)	\
    ( (This)->lpVtbl -> ModifyLocation(This,Location) ) 

#define ISparklineGroup_ModifySourceData(This,SourceData)	\
    ( (This)->lpVtbl -> ModifySourceData(This,SourceData) ) 

#define ISparklineGroup_Modify(This,Location,SourceData)	\
    ( (This)->lpVtbl -> Modify(This,Location,SourceData) ) 

#define ISparklineGroup_ModifyDateRange(This,DateRange)	\
    ( (This)->lpVtbl -> ModifyDateRange(This,DateRange) ) 

#define ISparklineGroup_Delete(This)	\
    ( (This)->lpVtbl -> Delete(This) ) 

#define ISparklineGroup_get_Type(This,RHS)	\
    ( (This)->lpVtbl -> get_Type(This,RHS) ) 

#define ISparklineGroup_put_Type(This,RHS)	\
    ( (This)->lpVtbl -> put_Type(This,RHS) ) 

#define ISparklineGroup_get_SeriesColor(This,RHS)	\
    ( (This)->lpVtbl -> get_SeriesColor(This,RHS) ) 

#define ISparklineGroup_get_Points(This,RHS)	\
    ( (This)->lpVtbl -> get_Points(This,RHS) ) 

#define ISparklineGroup_get_Axes(This,RHS)	\
    ( (This)->lpVtbl -> get_Axes(This,RHS) ) 

#define ISparklineGroup_get_DisplayBlanksAs(This,RHS)	\
    ( (This)->lpVtbl -> get_DisplayBlanksAs(This,RHS) ) 

#define ISparklineGroup_put_DisplayBlanksAs(This,RHS)	\
    ( (This)->lpVtbl -> put_DisplayBlanksAs(This,RHS) ) 

#define ISparklineGroup_get_DisplayHidden(This,RHS)	\
    ( (This)->lpVtbl -> get_DisplayHidden(This,RHS) ) 

#define ISparklineGroup_put_DisplayHidden(This,RHS)	\
    ( (This)->lpVtbl -> put_DisplayHidden(This,RHS) ) 

#define ISparklineGroup_get_LineWeight(This,RHS)	\
    ( (This)->lpVtbl -> get_LineWeight(This,RHS) ) 

#define ISparklineGroup_put_LineWeight(This,RHS)	\
    ( (This)->lpVtbl -> put_LineWeight(This,RHS) ) 

#define ISparklineGroup_get_PlotBy(This,RHS)	\
    ( (This)->lpVtbl -> get_PlotBy(This,RHS) ) 

#define ISparklineGroup_put_PlotBy(This,RHS)	\
    ( (This)->lpVtbl -> put_PlotBy(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ISparklineGroup_INTERFACE_DEFINED__ */


#ifndef __ISparkPoints_INTERFACE_DEFINED__
#define __ISparkPoints_INTERFACE_DEFINED__

/* interface ISparkPoints */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ISparkPoints;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244B8-0001-0000-C000-000000000046")
    ISparkPoints : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Negative( 
            /* [retval][out] */ SparkColor	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Markers( 
            /* [retval][out] */ SparkColor	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Highpoint( 
            /* [retval][out] */ SparkColor	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Lowpoint( 
            /* [retval][out] */ SparkColor	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Firstpoint( 
            /* [retval][out] */ SparkColor	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Lastpoint( 
            /* [retval][out] */ SparkColor	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ISparkPointsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ISparkPoints * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ISparkPoints * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ISparkPoints * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ISparkPoints * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ISparkPoints * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ISparkPoints * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ISparkPoints * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ISparkPoints * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ISparkPoints * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ISparkPoints * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Negative )( 
            ISparkPoints * This,
            /* [retval][out] */ SparkColor	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Markers )( 
            ISparkPoints * This,
            /* [retval][out] */ SparkColor	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Highpoint )( 
            ISparkPoints * This,
            /* [retval][out] */ SparkColor	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Lowpoint )( 
            ISparkPoints * This,
            /* [retval][out] */ SparkColor	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Firstpoint )( 
            ISparkPoints * This,
            /* [retval][out] */ SparkColor	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Lastpoint )( 
            ISparkPoints * This,
            /* [retval][out] */ SparkColor	**RHS);
        
        END_INTERFACE
    } ISparkPointsVtbl;

    interface ISparkPoints
    {
        CONST_VTBL struct ISparkPointsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ISparkPoints_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ISparkPoints_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ISparkPoints_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ISparkPoints_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ISparkPoints_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ISparkPoints_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ISparkPoints_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ISparkPoints_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ISparkPoints_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ISparkPoints_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ISparkPoints_get_Negative(This,RHS)	\
    ( (This)->lpVtbl -> get_Negative(This,RHS) ) 

#define ISparkPoints_get_Markers(This,RHS)	\
    ( (This)->lpVtbl -> get_Markers(This,RHS) ) 

#define ISparkPoints_get_Highpoint(This,RHS)	\
    ( (This)->lpVtbl -> get_Highpoint(This,RHS) ) 

#define ISparkPoints_get_Lowpoint(This,RHS)	\
    ( (This)->lpVtbl -> get_Lowpoint(This,RHS) ) 

#define ISparkPoints_get_Firstpoint(This,RHS)	\
    ( (This)->lpVtbl -> get_Firstpoint(This,RHS) ) 

#define ISparkPoints_get_Lastpoint(This,RHS)	\
    ( (This)->lpVtbl -> get_Lastpoint(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ISparkPoints_INTERFACE_DEFINED__ */


#ifndef __ISparkline_INTERFACE_DEFINED__
#define __ISparkline_INTERFACE_DEFINED__

/* interface ISparkline */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ISparkline;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244B9-0001-0000-C000-000000000046")
    ISparkline : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Location( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propputref][id] */ HRESULT __stdcall putref_Location( 
            /* [in] */ Range	*RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SourceData( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_SourceData( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ModifyLocation( 
            /* [in] */ Range	*Range) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ModifySourceData( 
            /* [in] */ BSTR Formula) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ISparklineVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ISparkline * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ISparkline * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ISparkline * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ISparkline * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ISparkline * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ISparkline * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ISparkline * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ISparkline * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ISparkline * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ISparkline * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Location )( 
            ISparkline * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propputref][id] */ HRESULT ( __stdcall *putref_Location )( 
            ISparkline * This,
            /* [in] */ Range	*RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SourceData )( 
            ISparkline * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_SourceData )( 
            ISparkline * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ModifyLocation )( 
            ISparkline * This,
            /* [in] */ Range	*Range);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ModifySourceData )( 
            ISparkline * This,
            /* [in] */ BSTR Formula);
        
        END_INTERFACE
    } ISparklineVtbl;

    interface ISparkline
    {
        CONST_VTBL struct ISparklineVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ISparkline_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ISparkline_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ISparkline_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ISparkline_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ISparkline_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ISparkline_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ISparkline_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ISparkline_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ISparkline_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ISparkline_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ISparkline_get_Location(This,RHS)	\
    ( (This)->lpVtbl -> get_Location(This,RHS) ) 

#define ISparkline_putref_Location(This,RHS)	\
    ( (This)->lpVtbl -> putref_Location(This,RHS) ) 

#define ISparkline_get_SourceData(This,RHS)	\
    ( (This)->lpVtbl -> get_SourceData(This,RHS) ) 

#define ISparkline_put_SourceData(This,RHS)	\
    ( (This)->lpVtbl -> put_SourceData(This,RHS) ) 

#define ISparkline_ModifyLocation(This,Range)	\
    ( (This)->lpVtbl -> ModifyLocation(This,Range) ) 

#define ISparkline_ModifySourceData(This,Formula)	\
    ( (This)->lpVtbl -> ModifySourceData(This,Formula) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ISparkline_INTERFACE_DEFINED__ */


#ifndef __ISparkAxes_INTERFACE_DEFINED__
#define __ISparkAxes_INTERFACE_DEFINED__

/* interface ISparkAxes */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ISparkAxes;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244BA-0001-0000-C000-000000000046")
    ISparkAxes : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Vertical( 
            /* [retval][out] */ SparkVerticalAxis	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Horizontal( 
            /* [retval][out] */ SparkHorizontalAxis	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ISparkAxesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ISparkAxes * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ISparkAxes * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ISparkAxes * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ISparkAxes * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ISparkAxes * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ISparkAxes * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ISparkAxes * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ISparkAxes * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ISparkAxes * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ISparkAxes * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Vertical )( 
            ISparkAxes * This,
            /* [retval][out] */ SparkVerticalAxis	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Horizontal )( 
            ISparkAxes * This,
            /* [retval][out] */ SparkHorizontalAxis	**RHS);
        
        END_INTERFACE
    } ISparkAxesVtbl;

    interface ISparkAxes
    {
        CONST_VTBL struct ISparkAxesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ISparkAxes_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ISparkAxes_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ISparkAxes_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ISparkAxes_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ISparkAxes_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ISparkAxes_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ISparkAxes_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ISparkAxes_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ISparkAxes_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ISparkAxes_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ISparkAxes_get_Vertical(This,RHS)	\
    ( (This)->lpVtbl -> get_Vertical(This,RHS) ) 

#define ISparkAxes_get_Horizontal(This,RHS)	\
    ( (This)->lpVtbl -> get_Horizontal(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ISparkAxes_INTERFACE_DEFINED__ */


#ifndef __ISparkHorizontalAxis_INTERFACE_DEFINED__
#define __ISparkHorizontalAxis_INTERFACE_DEFINED__

/* interface ISparkHorizontalAxis */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ISparkHorizontalAxis;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244BB-0001-0000-C000-000000000046")
    ISparkHorizontalAxis : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Axis( 
            /* [retval][out] */ SparkColor	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_IsDateAxis( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RightToLeftPlotOrder( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_RightToLeftPlotOrder( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ISparkHorizontalAxisVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ISparkHorizontalAxis * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ISparkHorizontalAxis * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ISparkHorizontalAxis * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ISparkHorizontalAxis * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ISparkHorizontalAxis * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ISparkHorizontalAxis * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ISparkHorizontalAxis * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ISparkHorizontalAxis * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ISparkHorizontalAxis * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ISparkHorizontalAxis * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Axis )( 
            ISparkHorizontalAxis * This,
            /* [retval][out] */ SparkColor	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_IsDateAxis )( 
            ISparkHorizontalAxis * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RightToLeftPlotOrder )( 
            ISparkHorizontalAxis * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_RightToLeftPlotOrder )( 
            ISparkHorizontalAxis * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        END_INTERFACE
    } ISparkHorizontalAxisVtbl;

    interface ISparkHorizontalAxis
    {
        CONST_VTBL struct ISparkHorizontalAxisVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ISparkHorizontalAxis_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ISparkHorizontalAxis_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ISparkHorizontalAxis_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ISparkHorizontalAxis_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ISparkHorizontalAxis_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ISparkHorizontalAxis_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ISparkHorizontalAxis_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ISparkHorizontalAxis_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ISparkHorizontalAxis_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ISparkHorizontalAxis_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ISparkHorizontalAxis_get_Axis(This,RHS)	\
    ( (This)->lpVtbl -> get_Axis(This,RHS) ) 

#define ISparkHorizontalAxis_get_IsDateAxis(This,RHS)	\
    ( (This)->lpVtbl -> get_IsDateAxis(This,RHS) ) 

#define ISparkHorizontalAxis_get_RightToLeftPlotOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_RightToLeftPlotOrder(This,RHS) ) 

#define ISparkHorizontalAxis_put_RightToLeftPlotOrder(This,RHS)	\
    ( (This)->lpVtbl -> put_RightToLeftPlotOrder(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ISparkHorizontalAxis_INTERFACE_DEFINED__ */


#ifndef __ISparkVerticalAxis_INTERFACE_DEFINED__
#define __ISparkVerticalAxis_INTERFACE_DEFINED__

/* interface ISparkVerticalAxis */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ISparkVerticalAxis;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244BC-0001-0000-C000-000000000046")
    ISparkVerticalAxis : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MinScaleType( 
            /* [retval][out] */ XlSparkScale *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_MinScaleType( 
            /* [in] */ XlSparkScale RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CustomMinScaleValue( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_CustomMinScaleValue( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MaxScaleType( 
            /* [retval][out] */ XlSparkScale *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_MaxScaleType( 
            /* [in] */ XlSparkScale RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CustomMaxScaleValue( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_CustomMaxScaleValue( 
            /* [in] */ VARIANT RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ISparkVerticalAxisVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ISparkVerticalAxis * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ISparkVerticalAxis * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ISparkVerticalAxis * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ISparkVerticalAxis * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ISparkVerticalAxis * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ISparkVerticalAxis * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ISparkVerticalAxis * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ISparkVerticalAxis * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ISparkVerticalAxis * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ISparkVerticalAxis * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MinScaleType )( 
            ISparkVerticalAxis * This,
            /* [retval][out] */ XlSparkScale *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_MinScaleType )( 
            ISparkVerticalAxis * This,
            /* [in] */ XlSparkScale RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CustomMinScaleValue )( 
            ISparkVerticalAxis * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_CustomMinScaleValue )( 
            ISparkVerticalAxis * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MaxScaleType )( 
            ISparkVerticalAxis * This,
            /* [retval][out] */ XlSparkScale *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_MaxScaleType )( 
            ISparkVerticalAxis * This,
            /* [in] */ XlSparkScale RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CustomMaxScaleValue )( 
            ISparkVerticalAxis * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_CustomMaxScaleValue )( 
            ISparkVerticalAxis * This,
            /* [in] */ VARIANT RHS);
        
        END_INTERFACE
    } ISparkVerticalAxisVtbl;

    interface ISparkVerticalAxis
    {
        CONST_VTBL struct ISparkVerticalAxisVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ISparkVerticalAxis_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ISparkVerticalAxis_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ISparkVerticalAxis_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ISparkVerticalAxis_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ISparkVerticalAxis_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ISparkVerticalAxis_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ISparkVerticalAxis_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ISparkVerticalAxis_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ISparkVerticalAxis_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ISparkVerticalAxis_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ISparkVerticalAxis_get_MinScaleType(This,RHS)	\
    ( (This)->lpVtbl -> get_MinScaleType(This,RHS) ) 

#define ISparkVerticalAxis_put_MinScaleType(This,RHS)	\
    ( (This)->lpVtbl -> put_MinScaleType(This,RHS) ) 

#define ISparkVerticalAxis_get_CustomMinScaleValue(This,RHS)	\
    ( (This)->lpVtbl -> get_CustomMinScaleValue(This,RHS) ) 

#define ISparkVerticalAxis_put_CustomMinScaleValue(This,RHS)	\
    ( (This)->lpVtbl -> put_CustomMinScaleValue(This,RHS) ) 

#define ISparkVerticalAxis_get_MaxScaleType(This,RHS)	\
    ( (This)->lpVtbl -> get_MaxScaleType(This,RHS) ) 

#define ISparkVerticalAxis_put_MaxScaleType(This,RHS)	\
    ( (This)->lpVtbl -> put_MaxScaleType(This,RHS) ) 

#define ISparkVerticalAxis_get_CustomMaxScaleValue(This,RHS)	\
    ( (This)->lpVtbl -> get_CustomMaxScaleValue(This,RHS) ) 

#define ISparkVerticalAxis_put_CustomMaxScaleValue(This,RHS)	\
    ( (This)->lpVtbl -> put_CustomMaxScaleValue(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ISparkVerticalAxis_INTERFACE_DEFINED__ */


#ifndef __ISparkColor_INTERFACE_DEFINED__
#define __ISparkColor_INTERFACE_DEFINED__

/* interface ISparkColor */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ISparkColor;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244BD-0001-0000-C000-000000000046")
    ISparkColor : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Visible( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Visible( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Color( 
            /* [retval][out] */ FormatColor	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ISparkColorVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ISparkColor * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ISparkColor * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ISparkColor * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ISparkColor * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ISparkColor * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ISparkColor * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ISparkColor * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ISparkColor * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ISparkColor * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ISparkColor * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Visible )( 
            ISparkColor * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Visible )( 
            ISparkColor * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Color )( 
            ISparkColor * This,
            /* [retval][out] */ FormatColor	**RHS);
        
        END_INTERFACE
    } ISparkColorVtbl;

    interface ISparkColor
    {
        CONST_VTBL struct ISparkColorVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ISparkColor_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ISparkColor_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ISparkColor_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ISparkColor_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ISparkColor_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ISparkColor_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ISparkColor_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ISparkColor_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ISparkColor_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ISparkColor_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ISparkColor_get_Visible(This,RHS)	\
    ( (This)->lpVtbl -> get_Visible(This,RHS) ) 

#define ISparkColor_put_Visible(This,RHS)	\
    ( (This)->lpVtbl -> put_Visible(This,RHS) ) 

#define ISparkColor_get_Color(This,RHS)	\
    ( (This)->lpVtbl -> get_Color(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ISparkColor_INTERFACE_DEFINED__ */


#ifndef __IDataBarBorder_INTERFACE_DEFINED__
#define __IDataBarBorder_INTERFACE_DEFINED__

/* interface IDataBarBorder */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IDataBarBorder;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244BE-0001-0000-C000-000000000046")
    IDataBarBorder : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Type( 
            /* [retval][out] */ XlDataBarBorderType *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Type( 
            /* [in] */ XlDataBarBorderType RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Color( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IDataBarBorderVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IDataBarBorder * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IDataBarBorder * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IDataBarBorder * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IDataBarBorder * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IDataBarBorder * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IDataBarBorder * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IDataBarBorder * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IDataBarBorder * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IDataBarBorder * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IDataBarBorder * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Type )( 
            IDataBarBorder * This,
            /* [retval][out] */ XlDataBarBorderType *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Type )( 
            IDataBarBorder * This,
            /* [in] */ XlDataBarBorderType RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Color )( 
            IDataBarBorder * This,
            /* [retval][out] */ IDispatch **RHS);
        
        END_INTERFACE
    } IDataBarBorderVtbl;

    interface IDataBarBorder
    {
        CONST_VTBL struct IDataBarBorderVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IDataBarBorder_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IDataBarBorder_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IDataBarBorder_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IDataBarBorder_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IDataBarBorder_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IDataBarBorder_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IDataBarBorder_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IDataBarBorder_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IDataBarBorder_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IDataBarBorder_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IDataBarBorder_get_Type(This,RHS)	\
    ( (This)->lpVtbl -> get_Type(This,RHS) ) 

#define IDataBarBorder_put_Type(This,RHS)	\
    ( (This)->lpVtbl -> put_Type(This,RHS) ) 

#define IDataBarBorder_get_Color(This,RHS)	\
    ( (This)->lpVtbl -> get_Color(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IDataBarBorder_INTERFACE_DEFINED__ */


#ifndef __INegativeBarFormat_INTERFACE_DEFINED__
#define __INegativeBarFormat_INTERFACE_DEFINED__

/* interface INegativeBarFormat */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_INegativeBarFormat;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244BF-0001-0000-C000-000000000046")
    INegativeBarFormat : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ColorType( 
            /* [retval][out] */ XlDataBarNegativeColorType *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ColorType( 
            /* [in] */ XlDataBarNegativeColorType RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_BorderColorType( 
            /* [retval][out] */ XlDataBarNegativeColorType *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_BorderColorType( 
            /* [in] */ XlDataBarNegativeColorType RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Color( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_BorderColor( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct INegativeBarFormatVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            INegativeBarFormat * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            INegativeBarFormat * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            INegativeBarFormat * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            INegativeBarFormat * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            INegativeBarFormat * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            INegativeBarFormat * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            INegativeBarFormat * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            INegativeBarFormat * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            INegativeBarFormat * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            INegativeBarFormat * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ColorType )( 
            INegativeBarFormat * This,
            /* [retval][out] */ XlDataBarNegativeColorType *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ColorType )( 
            INegativeBarFormat * This,
            /* [in] */ XlDataBarNegativeColorType RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_BorderColorType )( 
            INegativeBarFormat * This,
            /* [retval][out] */ XlDataBarNegativeColorType *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_BorderColorType )( 
            INegativeBarFormat * This,
            /* [in] */ XlDataBarNegativeColorType RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Color )( 
            INegativeBarFormat * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_BorderColor )( 
            INegativeBarFormat * This,
            /* [retval][out] */ IDispatch **RHS);
        
        END_INTERFACE
    } INegativeBarFormatVtbl;

    interface INegativeBarFormat
    {
        CONST_VTBL struct INegativeBarFormatVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define INegativeBarFormat_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define INegativeBarFormat_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define INegativeBarFormat_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define INegativeBarFormat_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define INegativeBarFormat_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define INegativeBarFormat_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define INegativeBarFormat_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define INegativeBarFormat_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define INegativeBarFormat_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define INegativeBarFormat_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define INegativeBarFormat_get_ColorType(This,RHS)	\
    ( (This)->lpVtbl -> get_ColorType(This,RHS) ) 

#define INegativeBarFormat_put_ColorType(This,RHS)	\
    ( (This)->lpVtbl -> put_ColorType(This,RHS) ) 

#define INegativeBarFormat_get_BorderColorType(This,RHS)	\
    ( (This)->lpVtbl -> get_BorderColorType(This,RHS) ) 

#define INegativeBarFormat_put_BorderColorType(This,RHS)	\
    ( (This)->lpVtbl -> put_BorderColorType(This,RHS) ) 

#define INegativeBarFormat_get_Color(This,RHS)	\
    ( (This)->lpVtbl -> get_Color(This,RHS) ) 

#define INegativeBarFormat_get_BorderColor(This,RHS)	\
    ( (This)->lpVtbl -> get_BorderColor(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __INegativeBarFormat_INTERFACE_DEFINED__ */


#ifndef __IValueChange_INTERFACE_DEFINED__
#define __IValueChange_INTERFACE_DEFINED__

/* interface IValueChange */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IValueChange;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244C0-0001-0000-C000-000000000046")
    IValueChange : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Order( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_VisibleInPivotTable( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PivotCell( 
            /* [retval][out] */ PivotCell	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Tuple( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Value( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AllocationValue( 
            /* [retval][out] */ XlAllocationValue *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AllocationMethod( 
            /* [retval][out] */ XlAllocationMethod *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AllocationWeightExpression( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( void) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IValueChangeVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IValueChange * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IValueChange * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IValueChange * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IValueChange * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IValueChange * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IValueChange * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IValueChange * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IValueChange * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IValueChange * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IValueChange * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Order )( 
            IValueChange * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_VisibleInPivotTable )( 
            IValueChange * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PivotCell )( 
            IValueChange * This,
            /* [retval][out] */ PivotCell	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Tuple )( 
            IValueChange * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Value )( 
            IValueChange * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AllocationValue )( 
            IValueChange * This,
            /* [retval][out] */ XlAllocationValue *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AllocationMethod )( 
            IValueChange * This,
            /* [retval][out] */ XlAllocationMethod *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AllocationWeightExpression )( 
            IValueChange * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IValueChange * This);
        
        END_INTERFACE
    } IValueChangeVtbl;

    interface IValueChange
    {
        CONST_VTBL struct IValueChangeVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IValueChange_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IValueChange_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IValueChange_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IValueChange_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IValueChange_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IValueChange_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IValueChange_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IValueChange_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IValueChange_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IValueChange_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IValueChange_get_Order(This,RHS)	\
    ( (This)->lpVtbl -> get_Order(This,RHS) ) 

#define IValueChange_get_VisibleInPivotTable(This,RHS)	\
    ( (This)->lpVtbl -> get_VisibleInPivotTable(This,RHS) ) 

#define IValueChange_get_PivotCell(This,RHS)	\
    ( (This)->lpVtbl -> get_PivotCell(This,RHS) ) 

#define IValueChange_get_Tuple(This,RHS)	\
    ( (This)->lpVtbl -> get_Tuple(This,RHS) ) 

#define IValueChange_get_Value(This,RHS)	\
    ( (This)->lpVtbl -> get_Value(This,RHS) ) 

#define IValueChange_get_AllocationValue(This,RHS)	\
    ( (This)->lpVtbl -> get_AllocationValue(This,RHS) ) 

#define IValueChange_get_AllocationMethod(This,RHS)	\
    ( (This)->lpVtbl -> get_AllocationMethod(This,RHS) ) 

#define IValueChange_get_AllocationWeightExpression(This,RHS)	\
    ( (This)->lpVtbl -> get_AllocationWeightExpression(This,RHS) ) 

#define IValueChange_Delete(This)	\
    ( (This)->lpVtbl -> Delete(This) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IValueChange_INTERFACE_DEFINED__ */


#ifndef __IPivotTableChangeList_INTERFACE_DEFINED__
#define __IPivotTableChangeList_INTERFACE_DEFINED__

/* interface IPivotTableChangeList */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IPivotTableChangeList;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244C1-0001-0000-C000-000000000046")
    IPivotTableChangeList : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ ValueChange	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ ValueChange	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add( 
            /* [in] */ BSTR Tuple,
            /* [in] */ double Value,
            /* [optional][in] */ VARIANT AllocationValue,
            /* [optional][in] */ VARIANT AllocationMethod,
            /* [optional][in] */ VARIANT AllocationWeightExpression,
            /* [retval][out] */ ValueChange	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IPivotTableChangeListVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IPivotTableChangeList * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IPivotTableChangeList * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IPivotTableChangeList * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IPivotTableChangeList * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IPivotTableChangeList * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IPivotTableChangeList * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IPivotTableChangeList * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IPivotTableChangeList * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IPivotTableChangeList * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IPivotTableChangeList * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IPivotTableChangeList * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ ValueChange	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            IPivotTableChangeList * This,
            /* [retval][out] */ IUnknown **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Item )( 
            IPivotTableChangeList * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ ValueChange	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IPivotTableChangeList * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add )( 
            IPivotTableChangeList * This,
            /* [in] */ BSTR Tuple,
            /* [in] */ double Value,
            /* [optional][in] */ VARIANT AllocationValue,
            /* [optional][in] */ VARIANT AllocationMethod,
            /* [optional][in] */ VARIANT AllocationWeightExpression,
            /* [retval][out] */ ValueChange	**RHS);
        
        END_INTERFACE
    } IPivotTableChangeListVtbl;

    interface IPivotTableChangeList
    {
        CONST_VTBL struct IPivotTableChangeListVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IPivotTableChangeList_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IPivotTableChangeList_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IPivotTableChangeList_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IPivotTableChangeList_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IPivotTableChangeList_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IPivotTableChangeList_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IPivotTableChangeList_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IPivotTableChangeList_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IPivotTableChangeList_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IPivotTableChangeList_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IPivotTableChangeList_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define IPivotTableChangeList_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#define IPivotTableChangeList_get_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Item(This,Index,RHS) ) 

#define IPivotTableChangeList_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IPivotTableChangeList_Add(This,Tuple,Value,AllocationValue,AllocationMethod,AllocationWeightExpression,RHS)	\
    ( (This)->lpVtbl -> Add(This,Tuple,Value,AllocationValue,AllocationMethod,AllocationWeightExpression,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IPivotTableChangeList_INTERFACE_DEFINED__ */


#ifndef __IDisplayFormat_INTERFACE_DEFINED__
#define __IDisplayFormat_INTERFACE_DEFINED__

/* interface IDisplayFormat */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IDisplayFormat;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244C2-0001-0000-C000-000000000046")
    IDisplayFormat : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Borders( 
            /* [retval][out] */ Borders	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Characters( 
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Length,
            /* [retval][out] */ Characters	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Font( 
            /* [retval][out] */ Font	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Style( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AddIndent( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_FormulaHidden( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HorizontalAlignment( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_IndentLevel( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Interior( 
            /* [retval][out] */ Interior	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Locked( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MergeCells( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_NumberFormat( 
            /* [lcid][in] */ long lcidIn,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_NumberFormatLocal( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Orientation( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ReadingOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShrinkToFit( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_VerticalAlignment( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_WrapText( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IDisplayFormatVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IDisplayFormat * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IDisplayFormat * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IDisplayFormat * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IDisplayFormat * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IDisplayFormat * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IDisplayFormat * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IDisplayFormat * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IDisplayFormat * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IDisplayFormat * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IDisplayFormat * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Borders )( 
            IDisplayFormat * This,
            /* [retval][out] */ Borders	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Characters )( 
            IDisplayFormat * This,
            /* [optional][in] */ VARIANT Start,
            /* [optional][in] */ VARIANT Length,
            /* [retval][out] */ Characters	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Font )( 
            IDisplayFormat * This,
            /* [retval][out] */ Font	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Style )( 
            IDisplayFormat * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AddIndent )( 
            IDisplayFormat * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_FormulaHidden )( 
            IDisplayFormat * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HorizontalAlignment )( 
            IDisplayFormat * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_IndentLevel )( 
            IDisplayFormat * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Interior )( 
            IDisplayFormat * This,
            /* [retval][out] */ Interior	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Locked )( 
            IDisplayFormat * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MergeCells )( 
            IDisplayFormat * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_NumberFormat )( 
            IDisplayFormat * This,
            /* [lcid][in] */ long lcidIn,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_NumberFormatLocal )( 
            IDisplayFormat * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Orientation )( 
            IDisplayFormat * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ReadingOrder )( 
            IDisplayFormat * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShrinkToFit )( 
            IDisplayFormat * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_VerticalAlignment )( 
            IDisplayFormat * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_WrapText )( 
            IDisplayFormat * This,
            /* [retval][out] */ VARIANT *RHS);
        
        END_INTERFACE
    } IDisplayFormatVtbl;

    interface IDisplayFormat
    {
        CONST_VTBL struct IDisplayFormatVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IDisplayFormat_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IDisplayFormat_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IDisplayFormat_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IDisplayFormat_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IDisplayFormat_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IDisplayFormat_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IDisplayFormat_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IDisplayFormat_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IDisplayFormat_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IDisplayFormat_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IDisplayFormat_get_Borders(This,RHS)	\
    ( (This)->lpVtbl -> get_Borders(This,RHS) ) 

#define IDisplayFormat_get_Characters(This,Start,Length,RHS)	\
    ( (This)->lpVtbl -> get_Characters(This,Start,Length,RHS) ) 

#define IDisplayFormat_get_Font(This,RHS)	\
    ( (This)->lpVtbl -> get_Font(This,RHS) ) 

#define IDisplayFormat_get_Style(This,RHS)	\
    ( (This)->lpVtbl -> get_Style(This,RHS) ) 

#define IDisplayFormat_get_AddIndent(This,RHS)	\
    ( (This)->lpVtbl -> get_AddIndent(This,RHS) ) 

#define IDisplayFormat_get_FormulaHidden(This,RHS)	\
    ( (This)->lpVtbl -> get_FormulaHidden(This,RHS) ) 

#define IDisplayFormat_get_HorizontalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> get_HorizontalAlignment(This,RHS) ) 

#define IDisplayFormat_get_IndentLevel(This,RHS)	\
    ( (This)->lpVtbl -> get_IndentLevel(This,RHS) ) 

#define IDisplayFormat_get_Interior(This,RHS)	\
    ( (This)->lpVtbl -> get_Interior(This,RHS) ) 

#define IDisplayFormat_get_Locked(This,RHS)	\
    ( (This)->lpVtbl -> get_Locked(This,RHS) ) 

#define IDisplayFormat_get_MergeCells(This,RHS)	\
    ( (This)->lpVtbl -> get_MergeCells(This,RHS) ) 

#define IDisplayFormat_get_NumberFormat(This,lcidIn,RHS)	\
    ( (This)->lpVtbl -> get_NumberFormat(This,lcidIn,RHS) ) 

#define IDisplayFormat_get_NumberFormatLocal(This,RHS)	\
    ( (This)->lpVtbl -> get_NumberFormatLocal(This,RHS) ) 

#define IDisplayFormat_get_Orientation(This,RHS)	\
    ( (This)->lpVtbl -> get_Orientation(This,RHS) ) 

#define IDisplayFormat_get_ReadingOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_ReadingOrder(This,RHS) ) 

#define IDisplayFormat_get_ShrinkToFit(This,RHS)	\
    ( (This)->lpVtbl -> get_ShrinkToFit(This,RHS) ) 

#define IDisplayFormat_get_VerticalAlignment(This,RHS)	\
    ( (This)->lpVtbl -> get_VerticalAlignment(This,RHS) ) 

#define IDisplayFormat_get_WrapText(This,RHS)	\
    ( (This)->lpVtbl -> get_WrapText(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IDisplayFormat_INTERFACE_DEFINED__ */


#ifndef __ISlicerCaches_INTERFACE_DEFINED__
#define __ISlicerCaches_INTERFACE_DEFINED__

/* interface ISlicerCaches */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ISlicerCaches;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244C3-0001-0000-C000-000000000046")
    ISlicerCaches : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ SlicerCache	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ SlicerCache	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
        virtual /* [helpcontext][hidden][id] */ HRESULT __stdcall Add( 
            /* [in] */ VARIANT Source,
            /* [in] */ VARIANT SourceField,
            /* [optional][in] */ VARIANT Name,
            /* [retval][out] */ SlicerCache	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add2( 
            /* [in] */ VARIANT Source,
            /* [in] */ VARIANT SourceField,
            /* [optional][in] */ VARIANT Name,
            /* [optional][in] */ VARIANT SlicerCacheType,
            /* [retval][out] */ SlicerCache	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ISlicerCachesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ISlicerCaches * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ISlicerCaches * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ISlicerCaches * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ISlicerCaches * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ISlicerCaches * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ISlicerCaches * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ISlicerCaches * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ISlicerCaches * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ISlicerCaches * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ISlicerCaches * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            ISlicerCaches * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Item )( 
            ISlicerCaches * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ SlicerCache	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            ISlicerCaches * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ SlicerCache	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            ISlicerCaches * This,
            /* [retval][out] */ IUnknown **RHS);
        
        /* [helpcontext][hidden][id] */ HRESULT ( __stdcall *Add )( 
            ISlicerCaches * This,
            /* [in] */ VARIANT Source,
            /* [in] */ VARIANT SourceField,
            /* [optional][in] */ VARIANT Name,
            /* [retval][out] */ SlicerCache	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add2 )( 
            ISlicerCaches * This,
            /* [in] */ VARIANT Source,
            /* [in] */ VARIANT SourceField,
            /* [optional][in] */ VARIANT Name,
            /* [optional][in] */ VARIANT SlicerCacheType,
            /* [retval][out] */ SlicerCache	**RHS);
        
        END_INTERFACE
    } ISlicerCachesVtbl;

    interface ISlicerCaches
    {
        CONST_VTBL struct ISlicerCachesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ISlicerCaches_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ISlicerCaches_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ISlicerCaches_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ISlicerCaches_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ISlicerCaches_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ISlicerCaches_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ISlicerCaches_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ISlicerCaches_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ISlicerCaches_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ISlicerCaches_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ISlicerCaches_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define ISlicerCaches_get_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Item(This,Index,RHS) ) 

#define ISlicerCaches_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define ISlicerCaches_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#define ISlicerCaches_Add(This,Source,SourceField,Name,RHS)	\
    ( (This)->lpVtbl -> Add(This,Source,SourceField,Name,RHS) ) 

#define ISlicerCaches_Add2(This,Source,SourceField,Name,SlicerCacheType,RHS)	\
    ( (This)->lpVtbl -> Add2(This,Source,SourceField,Name,SlicerCacheType,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ISlicerCaches_INTERFACE_DEFINED__ */


#ifndef __ISlicerCache_INTERFACE_DEFINED__
#define __ISlicerCache_INTERFACE_DEFINED__

/* interface ISlicerCache */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ISlicerCache;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244C4-0001-0000-C000-000000000046")
    ISlicerCache : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Index( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_OLAP( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SourceType( 
            /* [retval][out] */ XlPivotTableSourceType *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_WorkbookConnection( 
            /* [retval][out] */ WorkbookConnection	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Slicers( 
            /* [retval][out] */ Slicers	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PivotTables( 
            /* [retval][out] */ SlicerPivotTables	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SlicerCacheLevels( 
            /* [retval][out] */ SlicerCacheLevels	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Name( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_VisibleSlicerItems( 
            /* [retval][out] */ SlicerItems	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_VisibleSlicerItemsList( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_VisibleSlicerItemsList( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SlicerItems( 
            /* [retval][out] */ SlicerItems	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CrossFilterType( 
            /* [retval][out] */ XlSlicerCrossFilterType *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_CrossFilterType( 
            /* [in] */ XlSlicerCrossFilterType RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SortItems( 
            /* [retval][out] */ XlSlicerSort *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_SortItems( 
            /* [in] */ XlSlicerSort RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SourceName( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SortUsingCustomLists( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_SortUsingCustomLists( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShowAllItems( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ShowAllItems( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ClearManualFilter( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TimelineState( 
            /* [retval][out] */ TimelineState	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ClearAllFilters( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SlicerCacheType( 
            /* [retval][out] */ XlSlicerCacheType *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_FilterCleared( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_List( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RequireManualUpdate( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_RequireManualUpdate( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ListObject( 
            /* [retval][out] */ ListObject	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ClearDateFilter( void) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ISlicerCacheVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ISlicerCache * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ISlicerCache * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ISlicerCache * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ISlicerCache * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ISlicerCache * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ISlicerCache * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ISlicerCache * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ISlicerCache * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ISlicerCache * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ISlicerCache * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Index )( 
            ISlicerCache * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_OLAP )( 
            ISlicerCache * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SourceType )( 
            ISlicerCache * This,
            /* [retval][out] */ XlPivotTableSourceType *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_WorkbookConnection )( 
            ISlicerCache * This,
            /* [retval][out] */ WorkbookConnection	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Slicers )( 
            ISlicerCache * This,
            /* [retval][out] */ Slicers	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PivotTables )( 
            ISlicerCache * This,
            /* [retval][out] */ SlicerPivotTables	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SlicerCacheLevels )( 
            ISlicerCache * This,
            /* [retval][out] */ SlicerCacheLevels	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            ISlicerCache * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Name )( 
            ISlicerCache * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_VisibleSlicerItems )( 
            ISlicerCache * This,
            /* [retval][out] */ SlicerItems	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_VisibleSlicerItemsList )( 
            ISlicerCache * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_VisibleSlicerItemsList )( 
            ISlicerCache * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SlicerItems )( 
            ISlicerCache * This,
            /* [retval][out] */ SlicerItems	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CrossFilterType )( 
            ISlicerCache * This,
            /* [retval][out] */ XlSlicerCrossFilterType *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_CrossFilterType )( 
            ISlicerCache * This,
            /* [in] */ XlSlicerCrossFilterType RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SortItems )( 
            ISlicerCache * This,
            /* [retval][out] */ XlSlicerSort *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_SortItems )( 
            ISlicerCache * This,
            /* [in] */ XlSlicerSort RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SourceName )( 
            ISlicerCache * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SortUsingCustomLists )( 
            ISlicerCache * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_SortUsingCustomLists )( 
            ISlicerCache * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShowAllItems )( 
            ISlicerCache * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ShowAllItems )( 
            ISlicerCache * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ClearManualFilter )( 
            ISlicerCache * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            ISlicerCache * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TimelineState )( 
            ISlicerCache * This,
            /* [retval][out] */ TimelineState	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ClearAllFilters )( 
            ISlicerCache * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SlicerCacheType )( 
            ISlicerCache * This,
            /* [retval][out] */ XlSlicerCacheType *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_FilterCleared )( 
            ISlicerCache * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_List )( 
            ISlicerCache * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RequireManualUpdate )( 
            ISlicerCache * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_RequireManualUpdate )( 
            ISlicerCache * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ListObject )( 
            ISlicerCache * This,
            /* [retval][out] */ ListObject	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ClearDateFilter )( 
            ISlicerCache * This);
        
        END_INTERFACE
    } ISlicerCacheVtbl;

    interface ISlicerCache
    {
        CONST_VTBL struct ISlicerCacheVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ISlicerCache_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ISlicerCache_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ISlicerCache_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ISlicerCache_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ISlicerCache_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ISlicerCache_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ISlicerCache_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ISlicerCache_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ISlicerCache_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ISlicerCache_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ISlicerCache_get_Index(This,RHS)	\
    ( (This)->lpVtbl -> get_Index(This,RHS) ) 

#define ISlicerCache_get_OLAP(This,RHS)	\
    ( (This)->lpVtbl -> get_OLAP(This,RHS) ) 

#define ISlicerCache_get_SourceType(This,RHS)	\
    ( (This)->lpVtbl -> get_SourceType(This,RHS) ) 

#define ISlicerCache_get_WorkbookConnection(This,RHS)	\
    ( (This)->lpVtbl -> get_WorkbookConnection(This,RHS) ) 

#define ISlicerCache_get_Slicers(This,RHS)	\
    ( (This)->lpVtbl -> get_Slicers(This,RHS) ) 

#define ISlicerCache_get_PivotTables(This,RHS)	\
    ( (This)->lpVtbl -> get_PivotTables(This,RHS) ) 

#define ISlicerCache_get_SlicerCacheLevels(This,RHS)	\
    ( (This)->lpVtbl -> get_SlicerCacheLevels(This,RHS) ) 

#define ISlicerCache_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define ISlicerCache_put_Name(This,RHS)	\
    ( (This)->lpVtbl -> put_Name(This,RHS) ) 

#define ISlicerCache_get_VisibleSlicerItems(This,RHS)	\
    ( (This)->lpVtbl -> get_VisibleSlicerItems(This,RHS) ) 

#define ISlicerCache_get_VisibleSlicerItemsList(This,RHS)	\
    ( (This)->lpVtbl -> get_VisibleSlicerItemsList(This,RHS) ) 

#define ISlicerCache_put_VisibleSlicerItemsList(This,RHS)	\
    ( (This)->lpVtbl -> put_VisibleSlicerItemsList(This,RHS) ) 

#define ISlicerCache_get_SlicerItems(This,RHS)	\
    ( (This)->lpVtbl -> get_SlicerItems(This,RHS) ) 

#define ISlicerCache_get_CrossFilterType(This,RHS)	\
    ( (This)->lpVtbl -> get_CrossFilterType(This,RHS) ) 

#define ISlicerCache_put_CrossFilterType(This,RHS)	\
    ( (This)->lpVtbl -> put_CrossFilterType(This,RHS) ) 

#define ISlicerCache_get_SortItems(This,RHS)	\
    ( (This)->lpVtbl -> get_SortItems(This,RHS) ) 

#define ISlicerCache_put_SortItems(This,RHS)	\
    ( (This)->lpVtbl -> put_SortItems(This,RHS) ) 

#define ISlicerCache_get_SourceName(This,RHS)	\
    ( (This)->lpVtbl -> get_SourceName(This,RHS) ) 

#define ISlicerCache_get_SortUsingCustomLists(This,RHS)	\
    ( (This)->lpVtbl -> get_SortUsingCustomLists(This,RHS) ) 

#define ISlicerCache_put_SortUsingCustomLists(This,RHS)	\
    ( (This)->lpVtbl -> put_SortUsingCustomLists(This,RHS) ) 

#define ISlicerCache_get_ShowAllItems(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowAllItems(This,RHS) ) 

#define ISlicerCache_put_ShowAllItems(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowAllItems(This,RHS) ) 

#define ISlicerCache_ClearManualFilter(This)	\
    ( (This)->lpVtbl -> ClearManualFilter(This) ) 

#define ISlicerCache_Delete(This)	\
    ( (This)->lpVtbl -> Delete(This) ) 

#define ISlicerCache_get_TimelineState(This,RHS)	\
    ( (This)->lpVtbl -> get_TimelineState(This,RHS) ) 

#define ISlicerCache_ClearAllFilters(This)	\
    ( (This)->lpVtbl -> ClearAllFilters(This) ) 

#define ISlicerCache_get_SlicerCacheType(This,RHS)	\
    ( (This)->lpVtbl -> get_SlicerCacheType(This,RHS) ) 

#define ISlicerCache_get_FilterCleared(This,RHS)	\
    ( (This)->lpVtbl -> get_FilterCleared(This,RHS) ) 

#define ISlicerCache_get_List(This,RHS)	\
    ( (This)->lpVtbl -> get_List(This,RHS) ) 

#define ISlicerCache_get_RequireManualUpdate(This,RHS)	\
    ( (This)->lpVtbl -> get_RequireManualUpdate(This,RHS) ) 

#define ISlicerCache_put_RequireManualUpdate(This,RHS)	\
    ( (This)->lpVtbl -> put_RequireManualUpdate(This,RHS) ) 

#define ISlicerCache_get_ListObject(This,RHS)	\
    ( (This)->lpVtbl -> get_ListObject(This,RHS) ) 

#define ISlicerCache_ClearDateFilter(This)	\
    ( (This)->lpVtbl -> ClearDateFilter(This) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ISlicerCache_INTERFACE_DEFINED__ */


#ifndef __ISlicerCacheLevels_INTERFACE_DEFINED__
#define __ISlicerCacheLevels_INTERFACE_DEFINED__

/* interface ISlicerCacheLevels */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ISlicerCacheLevels;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244C5-0001-0000-C000-000000000046")
    ISlicerCacheLevels : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Item( 
            /* [optional][in] */ VARIANT Level,
            /* [retval][out] */ SlicerCacheLevel	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [optional][in] */ VARIANT Level,
            /* [retval][out] */ SlicerCacheLevel	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ISlicerCacheLevelsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ISlicerCacheLevels * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ISlicerCacheLevels * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ISlicerCacheLevels * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ISlicerCacheLevels * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ISlicerCacheLevels * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ISlicerCacheLevels * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ISlicerCacheLevels * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ISlicerCacheLevels * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ISlicerCacheLevels * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ISlicerCacheLevels * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            ISlicerCacheLevels * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Item )( 
            ISlicerCacheLevels * This,
            /* [optional][in] */ VARIANT Level,
            /* [retval][out] */ SlicerCacheLevel	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            ISlicerCacheLevels * This,
            /* [optional][in] */ VARIANT Level,
            /* [retval][out] */ SlicerCacheLevel	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            ISlicerCacheLevels * This,
            /* [retval][out] */ IUnknown **RHS);
        
        END_INTERFACE
    } ISlicerCacheLevelsVtbl;

    interface ISlicerCacheLevels
    {
        CONST_VTBL struct ISlicerCacheLevelsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ISlicerCacheLevels_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ISlicerCacheLevels_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ISlicerCacheLevels_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ISlicerCacheLevels_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ISlicerCacheLevels_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ISlicerCacheLevels_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ISlicerCacheLevels_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ISlicerCacheLevels_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ISlicerCacheLevels_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ISlicerCacheLevels_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ISlicerCacheLevels_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define ISlicerCacheLevels_get_Item(This,Level,RHS)	\
    ( (This)->lpVtbl -> get_Item(This,Level,RHS) ) 

#define ISlicerCacheLevels_get__Default(This,Level,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Level,RHS) ) 

#define ISlicerCacheLevels_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ISlicerCacheLevels_INTERFACE_DEFINED__ */


#ifndef __ISlicerCacheLevel_INTERFACE_DEFINED__
#define __ISlicerCacheLevel_INTERFACE_DEFINED__

/* interface ISlicerCacheLevel */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ISlicerCacheLevel;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244C6-0001-0000-C000-000000000046")
    ISlicerCacheLevel : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SlicerItems( 
            /* [retval][out] */ SlicerItems	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Ordinal( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CrossFilterType( 
            /* [retval][out] */ XlSlicerCrossFilterType *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_CrossFilterType( 
            /* [in] */ XlSlicerCrossFilterType RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SortItems( 
            /* [retval][out] */ XlSlicerSort *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_SortItems( 
            /* [in] */ XlSlicerSort RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_VisibleSlicerItemsList( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ISlicerCacheLevelVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ISlicerCacheLevel * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ISlicerCacheLevel * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ISlicerCacheLevel * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ISlicerCacheLevel * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ISlicerCacheLevel * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ISlicerCacheLevel * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ISlicerCacheLevel * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ISlicerCacheLevel * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ISlicerCacheLevel * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ISlicerCacheLevel * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SlicerItems )( 
            ISlicerCacheLevel * This,
            /* [retval][out] */ SlicerItems	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            ISlicerCacheLevel * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Ordinal )( 
            ISlicerCacheLevel * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            ISlicerCacheLevel * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CrossFilterType )( 
            ISlicerCacheLevel * This,
            /* [retval][out] */ XlSlicerCrossFilterType *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_CrossFilterType )( 
            ISlicerCacheLevel * This,
            /* [in] */ XlSlicerCrossFilterType RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SortItems )( 
            ISlicerCacheLevel * This,
            /* [retval][out] */ XlSlicerSort *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_SortItems )( 
            ISlicerCacheLevel * This,
            /* [in] */ XlSlicerSort RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_VisibleSlicerItemsList )( 
            ISlicerCacheLevel * This,
            /* [retval][out] */ VARIANT *RHS);
        
        END_INTERFACE
    } ISlicerCacheLevelVtbl;

    interface ISlicerCacheLevel
    {
        CONST_VTBL struct ISlicerCacheLevelVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ISlicerCacheLevel_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ISlicerCacheLevel_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ISlicerCacheLevel_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ISlicerCacheLevel_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ISlicerCacheLevel_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ISlicerCacheLevel_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ISlicerCacheLevel_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ISlicerCacheLevel_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ISlicerCacheLevel_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ISlicerCacheLevel_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ISlicerCacheLevel_get_SlicerItems(This,RHS)	\
    ( (This)->lpVtbl -> get_SlicerItems(This,RHS) ) 

#define ISlicerCacheLevel_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define ISlicerCacheLevel_get_Ordinal(This,RHS)	\
    ( (This)->lpVtbl -> get_Ordinal(This,RHS) ) 

#define ISlicerCacheLevel_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define ISlicerCacheLevel_get_CrossFilterType(This,RHS)	\
    ( (This)->lpVtbl -> get_CrossFilterType(This,RHS) ) 

#define ISlicerCacheLevel_put_CrossFilterType(This,RHS)	\
    ( (This)->lpVtbl -> put_CrossFilterType(This,RHS) ) 

#define ISlicerCacheLevel_get_SortItems(This,RHS)	\
    ( (This)->lpVtbl -> get_SortItems(This,RHS) ) 

#define ISlicerCacheLevel_put_SortItems(This,RHS)	\
    ( (This)->lpVtbl -> put_SortItems(This,RHS) ) 

#define ISlicerCacheLevel_get_VisibleSlicerItemsList(This,RHS)	\
    ( (This)->lpVtbl -> get_VisibleSlicerItemsList(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ISlicerCacheLevel_INTERFACE_DEFINED__ */


#ifndef __ISlicers_INTERFACE_DEFINED__
#define __ISlicers_INTERFACE_DEFINED__

/* interface ISlicers */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ISlicers;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244C7-0001-0000-C000-000000000046")
    ISlicers : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Slicer	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Slicer	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add( 
            /* [in] */ VARIANT SlicerDestination,
            /* [optional][in] */ VARIANT Level,
            /* [optional][in] */ VARIANT Name,
            /* [optional][in] */ VARIANT Caption,
            /* [optional][in] */ VARIANT Top,
            /* [optional][in] */ VARIANT Left,
            /* [optional][in] */ VARIANT Width,
            /* [optional][in] */ VARIANT Height,
            /* [retval][out] */ Slicer	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ISlicersVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ISlicers * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ISlicers * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ISlicers * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ISlicers * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ISlicers * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ISlicers * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ISlicers * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ISlicers * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ISlicers * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ISlicers * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            ISlicers * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Item )( 
            ISlicers * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Slicer	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            ISlicers * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Slicer	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            ISlicers * This,
            /* [retval][out] */ IUnknown **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add )( 
            ISlicers * This,
            /* [in] */ VARIANT SlicerDestination,
            /* [optional][in] */ VARIANT Level,
            /* [optional][in] */ VARIANT Name,
            /* [optional][in] */ VARIANT Caption,
            /* [optional][in] */ VARIANT Top,
            /* [optional][in] */ VARIANT Left,
            /* [optional][in] */ VARIANT Width,
            /* [optional][in] */ VARIANT Height,
            /* [retval][out] */ Slicer	**RHS);
        
        END_INTERFACE
    } ISlicersVtbl;

    interface ISlicers
    {
        CONST_VTBL struct ISlicersVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ISlicers_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ISlicers_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ISlicers_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ISlicers_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ISlicers_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ISlicers_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ISlicers_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ISlicers_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ISlicers_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ISlicers_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ISlicers_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define ISlicers_get_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Item(This,Index,RHS) ) 

#define ISlicers_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define ISlicers_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#define ISlicers_Add(This,SlicerDestination,Level,Name,Caption,Top,Left,Width,Height,RHS)	\
    ( (This)->lpVtbl -> Add(This,SlicerDestination,Level,Name,Caption,Top,Left,Width,Height,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ISlicers_INTERFACE_DEFINED__ */


#ifndef __ISlicer_INTERFACE_DEFINED__
#define __ISlicer_INTERFACE_DEFINED__

/* interface ISlicer */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ISlicer;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244C8-0001-0000-C000-000000000046")
    ISlicer : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Name( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Caption( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Caption( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Top( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Top( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Left( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Left( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DisableMoveResizeUI( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DisableMoveResizeUI( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Width( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Width( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Height( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Height( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RowHeight( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_RowHeight( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ColumnWidth( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ColumnWidth( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_NumberOfColumns( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_NumberOfColumns( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DisplayHeader( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_DisplayHeader( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Locked( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Locked( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SlicerCache( 
            /* [retval][out] */ SlicerCache	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SlicerCacheLevel( 
            /* [retval][out] */ SlicerCacheLevel	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Shape( 
            /* [retval][out] */ Shape	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Style( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Style( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Cut( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Copy( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ActiveItem( 
            /* [retval][out] */ SlicerItem	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TimelineViewState( 
            /* [retval][out] */ TimelineViewState	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SlicerCacheType( 
            /* [retval][out] */ XlSlicerCacheType *RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ISlicerVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ISlicer * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ISlicer * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ISlicer * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ISlicer * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ISlicer * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ISlicer * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ISlicer * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ISlicer * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ISlicer * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ISlicer * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            ISlicer * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Name )( 
            ISlicer * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Caption )( 
            ISlicer * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Caption )( 
            ISlicer * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Top )( 
            ISlicer * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Top )( 
            ISlicer * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Left )( 
            ISlicer * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Left )( 
            ISlicer * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DisableMoveResizeUI )( 
            ISlicer * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DisableMoveResizeUI )( 
            ISlicer * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Width )( 
            ISlicer * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Width )( 
            ISlicer * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Height )( 
            ISlicer * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Height )( 
            ISlicer * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RowHeight )( 
            ISlicer * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_RowHeight )( 
            ISlicer * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ColumnWidth )( 
            ISlicer * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ColumnWidth )( 
            ISlicer * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_NumberOfColumns )( 
            ISlicer * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_NumberOfColumns )( 
            ISlicer * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DisplayHeader )( 
            ISlicer * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_DisplayHeader )( 
            ISlicer * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Locked )( 
            ISlicer * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Locked )( 
            ISlicer * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SlicerCache )( 
            ISlicer * This,
            /* [retval][out] */ SlicerCache	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SlicerCacheLevel )( 
            ISlicer * This,
            /* [retval][out] */ SlicerCacheLevel	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Shape )( 
            ISlicer * This,
            /* [retval][out] */ Shape	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Style )( 
            ISlicer * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Style )( 
            ISlicer * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            ISlicer * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Cut )( 
            ISlicer * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Copy )( 
            ISlicer * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ActiveItem )( 
            ISlicer * This,
            /* [retval][out] */ SlicerItem	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TimelineViewState )( 
            ISlicer * This,
            /* [retval][out] */ TimelineViewState	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SlicerCacheType )( 
            ISlicer * This,
            /* [retval][out] */ XlSlicerCacheType *RHS);
        
        END_INTERFACE
    } ISlicerVtbl;

    interface ISlicer
    {
        CONST_VTBL struct ISlicerVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ISlicer_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ISlicer_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ISlicer_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ISlicer_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ISlicer_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ISlicer_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ISlicer_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ISlicer_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ISlicer_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ISlicer_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ISlicer_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define ISlicer_put_Name(This,RHS)	\
    ( (This)->lpVtbl -> put_Name(This,RHS) ) 

#define ISlicer_get_Caption(This,RHS)	\
    ( (This)->lpVtbl -> get_Caption(This,RHS) ) 

#define ISlicer_put_Caption(This,RHS)	\
    ( (This)->lpVtbl -> put_Caption(This,RHS) ) 

#define ISlicer_get_Top(This,RHS)	\
    ( (This)->lpVtbl -> get_Top(This,RHS) ) 

#define ISlicer_put_Top(This,RHS)	\
    ( (This)->lpVtbl -> put_Top(This,RHS) ) 

#define ISlicer_get_Left(This,RHS)	\
    ( (This)->lpVtbl -> get_Left(This,RHS) ) 

#define ISlicer_put_Left(This,RHS)	\
    ( (This)->lpVtbl -> put_Left(This,RHS) ) 

#define ISlicer_get_DisableMoveResizeUI(This,RHS)	\
    ( (This)->lpVtbl -> get_DisableMoveResizeUI(This,RHS) ) 

#define ISlicer_put_DisableMoveResizeUI(This,RHS)	\
    ( (This)->lpVtbl -> put_DisableMoveResizeUI(This,RHS) ) 

#define ISlicer_get_Width(This,RHS)	\
    ( (This)->lpVtbl -> get_Width(This,RHS) ) 

#define ISlicer_put_Width(This,RHS)	\
    ( (This)->lpVtbl -> put_Width(This,RHS) ) 

#define ISlicer_get_Height(This,RHS)	\
    ( (This)->lpVtbl -> get_Height(This,RHS) ) 

#define ISlicer_put_Height(This,RHS)	\
    ( (This)->lpVtbl -> put_Height(This,RHS) ) 

#define ISlicer_get_RowHeight(This,RHS)	\
    ( (This)->lpVtbl -> get_RowHeight(This,RHS) ) 

#define ISlicer_put_RowHeight(This,RHS)	\
    ( (This)->lpVtbl -> put_RowHeight(This,RHS) ) 

#define ISlicer_get_ColumnWidth(This,RHS)	\
    ( (This)->lpVtbl -> get_ColumnWidth(This,RHS) ) 

#define ISlicer_put_ColumnWidth(This,RHS)	\
    ( (This)->lpVtbl -> put_ColumnWidth(This,RHS) ) 

#define ISlicer_get_NumberOfColumns(This,RHS)	\
    ( (This)->lpVtbl -> get_NumberOfColumns(This,RHS) ) 

#define ISlicer_put_NumberOfColumns(This,RHS)	\
    ( (This)->lpVtbl -> put_NumberOfColumns(This,RHS) ) 

#define ISlicer_get_DisplayHeader(This,RHS)	\
    ( (This)->lpVtbl -> get_DisplayHeader(This,RHS) ) 

#define ISlicer_put_DisplayHeader(This,RHS)	\
    ( (This)->lpVtbl -> put_DisplayHeader(This,RHS) ) 

#define ISlicer_get_Locked(This,RHS)	\
    ( (This)->lpVtbl -> get_Locked(This,RHS) ) 

#define ISlicer_put_Locked(This,RHS)	\
    ( (This)->lpVtbl -> put_Locked(This,RHS) ) 

#define ISlicer_get_SlicerCache(This,RHS)	\
    ( (This)->lpVtbl -> get_SlicerCache(This,RHS) ) 

#define ISlicer_get_SlicerCacheLevel(This,RHS)	\
    ( (This)->lpVtbl -> get_SlicerCacheLevel(This,RHS) ) 

#define ISlicer_get_Shape(This,RHS)	\
    ( (This)->lpVtbl -> get_Shape(This,RHS) ) 

#define ISlicer_get_Style(This,RHS)	\
    ( (This)->lpVtbl -> get_Style(This,RHS) ) 

#define ISlicer_put_Style(This,RHS)	\
    ( (This)->lpVtbl -> put_Style(This,RHS) ) 

#define ISlicer_Delete(This)	\
    ( (This)->lpVtbl -> Delete(This) ) 

#define ISlicer_Cut(This)	\
    ( (This)->lpVtbl -> Cut(This) ) 

#define ISlicer_Copy(This)	\
    ( (This)->lpVtbl -> Copy(This) ) 

#define ISlicer_get_ActiveItem(This,RHS)	\
    ( (This)->lpVtbl -> get_ActiveItem(This,RHS) ) 

#define ISlicer_get_TimelineViewState(This,RHS)	\
    ( (This)->lpVtbl -> get_TimelineViewState(This,RHS) ) 

#define ISlicer_get_SlicerCacheType(This,RHS)	\
    ( (This)->lpVtbl -> get_SlicerCacheType(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ISlicer_INTERFACE_DEFINED__ */


#ifndef __ISlicerItem_INTERFACE_DEFINED__
#define __ISlicerItem_INTERFACE_DEFINED__

/* interface ISlicerItem */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ISlicerItem;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244C9-0001-0000-C000-000000000046")
    ISlicerItem : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ SlicerCache	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Caption( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SourceName( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SourceNameStandard( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Value( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Selected( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Selected( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_HasData( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ISlicerItemVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ISlicerItem * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ISlicerItem * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ISlicerItem * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ISlicerItem * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ISlicerItem * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ISlicerItem * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ISlicerItem * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ISlicerItem * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ISlicerItem * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ISlicerItem * This,
            /* [retval][out] */ SlicerCache	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Caption )( 
            ISlicerItem * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            ISlicerItem * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SourceName )( 
            ISlicerItem * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SourceNameStandard )( 
            ISlicerItem * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Value )( 
            ISlicerItem * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Selected )( 
            ISlicerItem * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Selected )( 
            ISlicerItem * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_HasData )( 
            ISlicerItem * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        END_INTERFACE
    } ISlicerItemVtbl;

    interface ISlicerItem
    {
        CONST_VTBL struct ISlicerItemVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ISlicerItem_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ISlicerItem_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ISlicerItem_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ISlicerItem_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ISlicerItem_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ISlicerItem_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ISlicerItem_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ISlicerItem_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ISlicerItem_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ISlicerItem_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ISlicerItem_get_Caption(This,RHS)	\
    ( (This)->lpVtbl -> get_Caption(This,RHS) ) 

#define ISlicerItem_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define ISlicerItem_get_SourceName(This,RHS)	\
    ( (This)->lpVtbl -> get_SourceName(This,RHS) ) 

#define ISlicerItem_get_SourceNameStandard(This,RHS)	\
    ( (This)->lpVtbl -> get_SourceNameStandard(This,RHS) ) 

#define ISlicerItem_get_Value(This,RHS)	\
    ( (This)->lpVtbl -> get_Value(This,RHS) ) 

#define ISlicerItem_get_Selected(This,RHS)	\
    ( (This)->lpVtbl -> get_Selected(This,RHS) ) 

#define ISlicerItem_put_Selected(This,RHS)	\
    ( (This)->lpVtbl -> put_Selected(This,RHS) ) 

#define ISlicerItem_get_HasData(This,RHS)	\
    ( (This)->lpVtbl -> get_HasData(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ISlicerItem_INTERFACE_DEFINED__ */


#ifndef __ISlicerItems_INTERFACE_DEFINED__
#define __ISlicerItems_INTERFACE_DEFINED__

/* interface ISlicerItems */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ISlicerItems;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244CA-0001-0000-C000-000000000046")
    ISlicerItems : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ SlicerItem	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ SlicerItem	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ISlicerItemsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ISlicerItems * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ISlicerItems * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ISlicerItems * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ISlicerItems * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ISlicerItems * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ISlicerItems * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ISlicerItems * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ISlicerItems * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ISlicerItems * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ISlicerItems * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            ISlicerItems * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Item )( 
            ISlicerItems * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ SlicerItem	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            ISlicerItems * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ SlicerItem	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            ISlicerItems * This,
            /* [retval][out] */ IUnknown **RHS);
        
        END_INTERFACE
    } ISlicerItemsVtbl;

    interface ISlicerItems
    {
        CONST_VTBL struct ISlicerItemsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ISlicerItems_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ISlicerItems_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ISlicerItems_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ISlicerItems_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ISlicerItems_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ISlicerItems_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ISlicerItems_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ISlicerItems_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ISlicerItems_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ISlicerItems_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ISlicerItems_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define ISlicerItems_get_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Item(This,Index,RHS) ) 

#define ISlicerItems_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define ISlicerItems_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ISlicerItems_INTERFACE_DEFINED__ */


#ifndef __ISlicerPivotTables_INTERFACE_DEFINED__
#define __ISlicerPivotTables_INTERFACE_DEFINED__

/* interface ISlicerPivotTables */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ISlicerPivotTables;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244CB-0001-0000-C000-000000000046")
    ISlicerPivotTables : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ PivotTable	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ PivotTable	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall AddPivotTable( 
            /* [in] */ PivotTable	*PivotTable) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall RemovePivotTable( 
            /* [in] */ VARIANT PivotTable) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ISlicerPivotTablesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ISlicerPivotTables * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ISlicerPivotTables * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ISlicerPivotTables * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ISlicerPivotTables * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ISlicerPivotTables * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ISlicerPivotTables * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ISlicerPivotTables * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ISlicerPivotTables * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ISlicerPivotTables * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ISlicerPivotTables * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            ISlicerPivotTables * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Item )( 
            ISlicerPivotTables * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ PivotTable	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            ISlicerPivotTables * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ PivotTable	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            ISlicerPivotTables * This,
            /* [retval][out] */ IUnknown **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *AddPivotTable )( 
            ISlicerPivotTables * This,
            /* [in] */ PivotTable	*PivotTable);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *RemovePivotTable )( 
            ISlicerPivotTables * This,
            /* [in] */ VARIANT PivotTable);
        
        END_INTERFACE
    } ISlicerPivotTablesVtbl;

    interface ISlicerPivotTables
    {
        CONST_VTBL struct ISlicerPivotTablesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ISlicerPivotTables_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ISlicerPivotTables_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ISlicerPivotTables_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ISlicerPivotTables_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ISlicerPivotTables_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ISlicerPivotTables_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ISlicerPivotTables_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ISlicerPivotTables_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ISlicerPivotTables_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ISlicerPivotTables_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ISlicerPivotTables_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define ISlicerPivotTables_get_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Item(This,Index,RHS) ) 

#define ISlicerPivotTables_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define ISlicerPivotTables_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#define ISlicerPivotTables_AddPivotTable(This,PivotTable)	\
    ( (This)->lpVtbl -> AddPivotTable(This,PivotTable) ) 

#define ISlicerPivotTables_RemovePivotTable(This,PivotTable)	\
    ( (This)->lpVtbl -> RemovePivotTable(This,PivotTable) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ISlicerPivotTables_INTERFACE_DEFINED__ */


#ifndef __IProtectedViewWindows_INTERFACE_DEFINED__
#define __IProtectedViewWindows_INTERFACE_DEFINED__

/* interface IProtectedViewWindows */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IProtectedViewWindows;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244CC-0001-0000-C000-000000000046")
    IProtectedViewWindows : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ ProtectedViewWindow	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ ProtectedViewWindow	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Open( 
            /* [in] */ BSTR Filename,
            /* [optional][in] */ VARIANT Password,
            /* [optional][in] */ VARIANT AddToMru,
            /* [optional][in] */ VARIANT RepairMode,
            /* [retval][out] */ ProtectedViewWindow	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IProtectedViewWindowsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IProtectedViewWindows * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IProtectedViewWindows * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IProtectedViewWindows * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IProtectedViewWindows * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IProtectedViewWindows * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IProtectedViewWindows * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IProtectedViewWindows * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IProtectedViewWindows * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IProtectedViewWindows * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IProtectedViewWindows * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IProtectedViewWindows * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Item )( 
            IProtectedViewWindows * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ ProtectedViewWindow	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            IProtectedViewWindows * This,
            /* [retval][out] */ IUnknown **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IProtectedViewWindows * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ ProtectedViewWindow	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Open )( 
            IProtectedViewWindows * This,
            /* [in] */ BSTR Filename,
            /* [optional][in] */ VARIANT Password,
            /* [optional][in] */ VARIANT AddToMru,
            /* [optional][in] */ VARIANT RepairMode,
            /* [retval][out] */ ProtectedViewWindow	**RHS);
        
        END_INTERFACE
    } IProtectedViewWindowsVtbl;

    interface IProtectedViewWindows
    {
        CONST_VTBL struct IProtectedViewWindowsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IProtectedViewWindows_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IProtectedViewWindows_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IProtectedViewWindows_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IProtectedViewWindows_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IProtectedViewWindows_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IProtectedViewWindows_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IProtectedViewWindows_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IProtectedViewWindows_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IProtectedViewWindows_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IProtectedViewWindows_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IProtectedViewWindows_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IProtectedViewWindows_get_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> get_Item(This,Index,RHS) ) 

#define IProtectedViewWindows_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#define IProtectedViewWindows_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define IProtectedViewWindows_Open(This,Filename,Password,AddToMru,RepairMode,RHS)	\
    ( (This)->lpVtbl -> Open(This,Filename,Password,AddToMru,RepairMode,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IProtectedViewWindows_INTERFACE_DEFINED__ */


#ifndef __IProtectedViewWindow_INTERFACE_DEFINED__
#define __IProtectedViewWindow_INTERFACE_DEFINED__

/* interface IProtectedViewWindow */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IProtectedViewWindow;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244CD-0001-0000-C000-000000000046")
    IProtectedViewWindow : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Caption( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Caption( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_EnableResize( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_EnableResize( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Height( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Height( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Left( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Left( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Top( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Top( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Width( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Width( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Visible( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Visible( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SourceName( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SourcePath( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_WindowState( 
            /* [retval][out] */ XlProtectedViewWindowState *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_WindowState( 
            /* [in] */ XlProtectedViewWindowState RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Workbook( 
            /* [retval][out] */ Workbook	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Activate( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Close( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Edit( 
            /* [optional][in] */ VARIANT WriteResPassword,
            /* [optional][in] */ VARIANT UpdateLinks,
            /* [retval][out] */ Workbook	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IProtectedViewWindowVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IProtectedViewWindow * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IProtectedViewWindow * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IProtectedViewWindow * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IProtectedViewWindow * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IProtectedViewWindow * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IProtectedViewWindow * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IProtectedViewWindow * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IProtectedViewWindow * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Caption )( 
            IProtectedViewWindow * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Caption )( 
            IProtectedViewWindow * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_EnableResize )( 
            IProtectedViewWindow * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_EnableResize )( 
            IProtectedViewWindow * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Height )( 
            IProtectedViewWindow * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Height )( 
            IProtectedViewWindow * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Left )( 
            IProtectedViewWindow * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Left )( 
            IProtectedViewWindow * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Top )( 
            IProtectedViewWindow * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Top )( 
            IProtectedViewWindow * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Width )( 
            IProtectedViewWindow * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Width )( 
            IProtectedViewWindow * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Visible )( 
            IProtectedViewWindow * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Visible )( 
            IProtectedViewWindow * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SourceName )( 
            IProtectedViewWindow * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SourcePath )( 
            IProtectedViewWindow * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_WindowState )( 
            IProtectedViewWindow * This,
            /* [retval][out] */ XlProtectedViewWindowState *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_WindowState )( 
            IProtectedViewWindow * This,
            /* [in] */ XlProtectedViewWindowState RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Workbook )( 
            IProtectedViewWindow * This,
            /* [retval][out] */ Workbook	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Activate )( 
            IProtectedViewWindow * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Close )( 
            IProtectedViewWindow * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Edit )( 
            IProtectedViewWindow * This,
            /* [optional][in] */ VARIANT WriteResPassword,
            /* [optional][in] */ VARIANT UpdateLinks,
            /* [retval][out] */ Workbook	**RHS);
        
        END_INTERFACE
    } IProtectedViewWindowVtbl;

    interface IProtectedViewWindow
    {
        CONST_VTBL struct IProtectedViewWindowVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IProtectedViewWindow_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IProtectedViewWindow_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IProtectedViewWindow_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IProtectedViewWindow_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IProtectedViewWindow_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IProtectedViewWindow_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IProtectedViewWindow_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IProtectedViewWindow_get__Default(This,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,RHS) ) 

#define IProtectedViewWindow_get_Caption(This,RHS)	\
    ( (This)->lpVtbl -> get_Caption(This,RHS) ) 

#define IProtectedViewWindow_put_Caption(This,RHS)	\
    ( (This)->lpVtbl -> put_Caption(This,RHS) ) 

#define IProtectedViewWindow_get_EnableResize(This,RHS)	\
    ( (This)->lpVtbl -> get_EnableResize(This,RHS) ) 

#define IProtectedViewWindow_put_EnableResize(This,RHS)	\
    ( (This)->lpVtbl -> put_EnableResize(This,RHS) ) 

#define IProtectedViewWindow_get_Height(This,RHS)	\
    ( (This)->lpVtbl -> get_Height(This,RHS) ) 

#define IProtectedViewWindow_put_Height(This,RHS)	\
    ( (This)->lpVtbl -> put_Height(This,RHS) ) 

#define IProtectedViewWindow_get_Left(This,RHS)	\
    ( (This)->lpVtbl -> get_Left(This,RHS) ) 

#define IProtectedViewWindow_put_Left(This,RHS)	\
    ( (This)->lpVtbl -> put_Left(This,RHS) ) 

#define IProtectedViewWindow_get_Top(This,RHS)	\
    ( (This)->lpVtbl -> get_Top(This,RHS) ) 

#define IProtectedViewWindow_put_Top(This,RHS)	\
    ( (This)->lpVtbl -> put_Top(This,RHS) ) 

#define IProtectedViewWindow_get_Width(This,RHS)	\
    ( (This)->lpVtbl -> get_Width(This,RHS) ) 

#define IProtectedViewWindow_put_Width(This,RHS)	\
    ( (This)->lpVtbl -> put_Width(This,RHS) ) 

#define IProtectedViewWindow_get_Visible(This,RHS)	\
    ( (This)->lpVtbl -> get_Visible(This,RHS) ) 

#define IProtectedViewWindow_put_Visible(This,RHS)	\
    ( (This)->lpVtbl -> put_Visible(This,RHS) ) 

#define IProtectedViewWindow_get_SourceName(This,RHS)	\
    ( (This)->lpVtbl -> get_SourceName(This,RHS) ) 

#define IProtectedViewWindow_get_SourcePath(This,RHS)	\
    ( (This)->lpVtbl -> get_SourcePath(This,RHS) ) 

#define IProtectedViewWindow_get_WindowState(This,RHS)	\
    ( (This)->lpVtbl -> get_WindowState(This,RHS) ) 

#define IProtectedViewWindow_put_WindowState(This,RHS)	\
    ( (This)->lpVtbl -> put_WindowState(This,RHS) ) 

#define IProtectedViewWindow_get_Workbook(This,RHS)	\
    ( (This)->lpVtbl -> get_Workbook(This,RHS) ) 

#define IProtectedViewWindow_Activate(This)	\
    ( (This)->lpVtbl -> Activate(This) ) 

#define IProtectedViewWindow_Close(This,RHS)	\
    ( (This)->lpVtbl -> Close(This,RHS) ) 

#define IProtectedViewWindow_Edit(This,WriteResPassword,UpdateLinks,RHS)	\
    ( (This)->lpVtbl -> Edit(This,WriteResPassword,UpdateLinks,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IProtectedViewWindow_INTERFACE_DEFINED__ */


#ifndef __ITableObject_INTERFACE_DEFINED__
#define __ITableObject_INTERFACE_DEFINED__

/* interface ITableObject */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ITableObject;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244CE-0001-0000-C000-000000000046")
    ITableObject : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RowNumbers( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_RowNumbers( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_FetchedRowOverflow( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RefreshStyle( 
            /* [retval][out] */ XlCellInsertionMode *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_RefreshStyle( 
            /* [in] */ XlCellInsertionMode RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_EnableRefresh( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_EnableRefresh( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Destination( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ResultRange( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Refresh( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_EnableEditing( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_EnableEditing( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PreserveColumnInfo( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PreserveColumnInfo( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PreserveFormatting( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PreserveFormatting( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AdjustColumnWidth( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AdjustColumnWidth( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ListObject( 
            /* [retval][out] */ ListObject	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_WorkbookConnection( 
            /* [retval][out] */ WorkbookConnection	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ITableObjectVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ITableObject * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ITableObject * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ITableObject * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ITableObject * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ITableObject * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ITableObject * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ITableObject * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ITableObject * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ITableObject * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ITableObject * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RowNumbers )( 
            ITableObject * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_RowNumbers )( 
            ITableObject * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_FetchedRowOverflow )( 
            ITableObject * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RefreshStyle )( 
            ITableObject * This,
            /* [retval][out] */ XlCellInsertionMode *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_RefreshStyle )( 
            ITableObject * This,
            /* [in] */ XlCellInsertionMode RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_EnableRefresh )( 
            ITableObject * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_EnableRefresh )( 
            ITableObject * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Destination )( 
            ITableObject * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ResultRange )( 
            ITableObject * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            ITableObject * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Refresh )( 
            ITableObject * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_EnableEditing )( 
            ITableObject * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_EnableEditing )( 
            ITableObject * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PreserveColumnInfo )( 
            ITableObject * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PreserveColumnInfo )( 
            ITableObject * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PreserveFormatting )( 
            ITableObject * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PreserveFormatting )( 
            ITableObject * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AdjustColumnWidth )( 
            ITableObject * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AdjustColumnWidth )( 
            ITableObject * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ListObject )( 
            ITableObject * This,
            /* [retval][out] */ ListObject	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_WorkbookConnection )( 
            ITableObject * This,
            /* [retval][out] */ WorkbookConnection	**RHS);
        
        END_INTERFACE
    } ITableObjectVtbl;

    interface ITableObject
    {
        CONST_VTBL struct ITableObjectVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ITableObject_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ITableObject_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ITableObject_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ITableObject_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ITableObject_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ITableObject_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ITableObject_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ITableObject_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ITableObject_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ITableObject_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ITableObject_get_RowNumbers(This,RHS)	\
    ( (This)->lpVtbl -> get_RowNumbers(This,RHS) ) 

#define ITableObject_put_RowNumbers(This,RHS)	\
    ( (This)->lpVtbl -> put_RowNumbers(This,RHS) ) 

#define ITableObject_get_FetchedRowOverflow(This,RHS)	\
    ( (This)->lpVtbl -> get_FetchedRowOverflow(This,RHS) ) 

#define ITableObject_get_RefreshStyle(This,RHS)	\
    ( (This)->lpVtbl -> get_RefreshStyle(This,RHS) ) 

#define ITableObject_put_RefreshStyle(This,RHS)	\
    ( (This)->lpVtbl -> put_RefreshStyle(This,RHS) ) 

#define ITableObject_get_EnableRefresh(This,RHS)	\
    ( (This)->lpVtbl -> get_EnableRefresh(This,RHS) ) 

#define ITableObject_put_EnableRefresh(This,RHS)	\
    ( (This)->lpVtbl -> put_EnableRefresh(This,RHS) ) 

#define ITableObject_get_Destination(This,RHS)	\
    ( (This)->lpVtbl -> get_Destination(This,RHS) ) 

#define ITableObject_get_ResultRange(This,RHS)	\
    ( (This)->lpVtbl -> get_ResultRange(This,RHS) ) 

#define ITableObject_Delete(This)	\
    ( (This)->lpVtbl -> Delete(This) ) 

#define ITableObject_Refresh(This,RHS)	\
    ( (This)->lpVtbl -> Refresh(This,RHS) ) 

#define ITableObject_get_EnableEditing(This,RHS)	\
    ( (This)->lpVtbl -> get_EnableEditing(This,RHS) ) 

#define ITableObject_put_EnableEditing(This,RHS)	\
    ( (This)->lpVtbl -> put_EnableEditing(This,RHS) ) 

#define ITableObject_get_PreserveColumnInfo(This,RHS)	\
    ( (This)->lpVtbl -> get_PreserveColumnInfo(This,RHS) ) 

#define ITableObject_put_PreserveColumnInfo(This,RHS)	\
    ( (This)->lpVtbl -> put_PreserveColumnInfo(This,RHS) ) 

#define ITableObject_get_PreserveFormatting(This,RHS)	\
    ( (This)->lpVtbl -> get_PreserveFormatting(This,RHS) ) 

#define ITableObject_put_PreserveFormatting(This,RHS)	\
    ( (This)->lpVtbl -> put_PreserveFormatting(This,RHS) ) 

#define ITableObject_get_AdjustColumnWidth(This,RHS)	\
    ( (This)->lpVtbl -> get_AdjustColumnWidth(This,RHS) ) 

#define ITableObject_put_AdjustColumnWidth(This,RHS)	\
    ( (This)->lpVtbl -> put_AdjustColumnWidth(This,RHS) ) 

#define ITableObject_get_ListObject(This,RHS)	\
    ( (This)->lpVtbl -> get_ListObject(This,RHS) ) 

#define ITableObject_get_WorkbookConnection(This,RHS)	\
    ( (This)->lpVtbl -> get_WorkbookConnection(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ITableObject_INTERFACE_DEFINED__ */


#ifndef __IPivotValueCell_INTERFACE_DEFINED__
#define __IPivotValueCell_INTERFACE_DEFINED__

/* interface IPivotValueCell */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IPivotValueCell;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244CF-0001-0000-C000-000000000046")
    IPivotValueCell : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PivotCell( 
            /* [retval][out] */ PivotCell	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Value( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall ShowDetail( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ServerActions( 
            /* [retval][out] */ Actions	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IPivotValueCellVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IPivotValueCell * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IPivotValueCell * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IPivotValueCell * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IPivotValueCell * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IPivotValueCell * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IPivotValueCell * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IPivotValueCell * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IPivotValueCell * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IPivotValueCell * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IPivotValueCell * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PivotCell )( 
            IPivotValueCell * This,
            /* [retval][out] */ PivotCell	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Value )( 
            IPivotValueCell * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *ShowDetail )( 
            IPivotValueCell * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ServerActions )( 
            IPivotValueCell * This,
            /* [retval][out] */ Actions	**RHS);
        
        END_INTERFACE
    } IPivotValueCellVtbl;

    interface IPivotValueCell
    {
        CONST_VTBL struct IPivotValueCellVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IPivotValueCell_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IPivotValueCell_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IPivotValueCell_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IPivotValueCell_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IPivotValueCell_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IPivotValueCell_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IPivotValueCell_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IPivotValueCell_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IPivotValueCell_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IPivotValueCell_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IPivotValueCell_get_PivotCell(This,RHS)	\
    ( (This)->lpVtbl -> get_PivotCell(This,RHS) ) 

#define IPivotValueCell_get_Value(This,RHS)	\
    ( (This)->lpVtbl -> get_Value(This,RHS) ) 

#define IPivotValueCell_ShowDetail(This)	\
    ( (This)->lpVtbl -> ShowDetail(This) ) 

#define IPivotValueCell_get_ServerActions(This,RHS)	\
    ( (This)->lpVtbl -> get_ServerActions(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IPivotValueCell_INTERFACE_DEFINED__ */


#ifndef __IQuickAnalysis_INTERFACE_DEFINED__
#define __IQuickAnalysis_INTERFACE_DEFINED__

/* interface IQuickAnalysis */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IQuickAnalysis;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244D0-0001-0000-C000-000000000046")
    IQuickAnalysis : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Show( 
            /* [defaultvalue][optional][in] */ XlQuickAnalysisMode XlQuickAnalysisMode = xlLensOnly) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Hide( 
            /* [defaultvalue][optional][in] */ XlQuickAnalysisMode XlQuickAnalysisMode = xlLensOnly) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IQuickAnalysisVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IQuickAnalysis * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IQuickAnalysis * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IQuickAnalysis * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IQuickAnalysis * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IQuickAnalysis * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IQuickAnalysis * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IQuickAnalysis * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IQuickAnalysis * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IQuickAnalysis * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IQuickAnalysis * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Show )( 
            IQuickAnalysis * This,
            /* [defaultvalue][optional][in] */ XlQuickAnalysisMode XlQuickAnalysisMode);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Hide )( 
            IQuickAnalysis * This,
            /* [defaultvalue][optional][in] */ XlQuickAnalysisMode XlQuickAnalysisMode);
        
        END_INTERFACE
    } IQuickAnalysisVtbl;

    interface IQuickAnalysis
    {
        CONST_VTBL struct IQuickAnalysisVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IQuickAnalysis_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IQuickAnalysis_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IQuickAnalysis_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IQuickAnalysis_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IQuickAnalysis_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IQuickAnalysis_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IQuickAnalysis_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IQuickAnalysis_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IQuickAnalysis_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IQuickAnalysis_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IQuickAnalysis_Show(This,XlQuickAnalysisMode)	\
    ( (This)->lpVtbl -> Show(This,XlQuickAnalysisMode) ) 

#define IQuickAnalysis_Hide(This,XlQuickAnalysisMode)	\
    ( (This)->lpVtbl -> Hide(This,XlQuickAnalysisMode) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IQuickAnalysis_INTERFACE_DEFINED__ */


#ifndef __IModelConnection_INTERFACE_DEFINED__
#define __IModelConnection_INTERFACE_DEFINED__

/* interface IModelConnection */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IModelConnection;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244D1-0001-0000-C000-000000000046")
    IModelConnection : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CommandText( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_CommandText( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CommandType( 
            /* [retval][out] */ XlCmdType *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_CommandType( 
            /* [in] */ XlCmdType RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ADOConnection( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CalculatedMembers( 
            /* [retval][out] */ CalculatedMembers	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IModelConnectionVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IModelConnection * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IModelConnection * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IModelConnection * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IModelConnection * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IModelConnection * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IModelConnection * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IModelConnection * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IModelConnection * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IModelConnection * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IModelConnection * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CommandText )( 
            IModelConnection * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_CommandText )( 
            IModelConnection * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CommandType )( 
            IModelConnection * This,
            /* [retval][out] */ XlCmdType *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_CommandType )( 
            IModelConnection * This,
            /* [in] */ XlCmdType RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ADOConnection )( 
            IModelConnection * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CalculatedMembers )( 
            IModelConnection * This,
            /* [retval][out] */ CalculatedMembers	**RHS);
        
        END_INTERFACE
    } IModelConnectionVtbl;

    interface IModelConnection
    {
        CONST_VTBL struct IModelConnectionVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IModelConnection_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IModelConnection_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IModelConnection_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IModelConnection_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IModelConnection_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IModelConnection_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IModelConnection_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IModelConnection_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IModelConnection_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IModelConnection_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IModelConnection_get_CommandText(This,RHS)	\
    ( (This)->lpVtbl -> get_CommandText(This,RHS) ) 

#define IModelConnection_put_CommandText(This,RHS)	\
    ( (This)->lpVtbl -> put_CommandText(This,RHS) ) 

#define IModelConnection_get_CommandType(This,RHS)	\
    ( (This)->lpVtbl -> get_CommandType(This,RHS) ) 

#define IModelConnection_put_CommandType(This,RHS)	\
    ( (This)->lpVtbl -> put_CommandType(This,RHS) ) 

#define IModelConnection_get_ADOConnection(This,RHS)	\
    ( (This)->lpVtbl -> get_ADOConnection(This,RHS) ) 

#define IModelConnection_get_CalculatedMembers(This,RHS)	\
    ( (This)->lpVtbl -> get_CalculatedMembers(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IModelConnection_INTERFACE_DEFINED__ */


#ifndef __IWorksheetDataConnection_INTERFACE_DEFINED__
#define __IWorksheetDataConnection_INTERFACE_DEFINED__

/* interface IWorksheetDataConnection */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IWorksheetDataConnection;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244D2-0001-0000-C000-000000000046")
    IWorksheetDataConnection : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Connection( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CommandText( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_CommandText( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CommandType( 
            /* [retval][out] */ XlCmdType *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_CommandType( 
            /* [in] */ XlCmdType RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IWorksheetDataConnectionVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IWorksheetDataConnection * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IWorksheetDataConnection * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IWorksheetDataConnection * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IWorksheetDataConnection * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IWorksheetDataConnection * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IWorksheetDataConnection * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IWorksheetDataConnection * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IWorksheetDataConnection * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IWorksheetDataConnection * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IWorksheetDataConnection * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Connection )( 
            IWorksheetDataConnection * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CommandText )( 
            IWorksheetDataConnection * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_CommandText )( 
            IWorksheetDataConnection * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CommandType )( 
            IWorksheetDataConnection * This,
            /* [retval][out] */ XlCmdType *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_CommandType )( 
            IWorksheetDataConnection * This,
            /* [in] */ XlCmdType RHS);
        
        END_INTERFACE
    } IWorksheetDataConnectionVtbl;

    interface IWorksheetDataConnection
    {
        CONST_VTBL struct IWorksheetDataConnectionVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IWorksheetDataConnection_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IWorksheetDataConnection_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IWorksheetDataConnection_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IWorksheetDataConnection_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IWorksheetDataConnection_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IWorksheetDataConnection_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IWorksheetDataConnection_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IWorksheetDataConnection_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IWorksheetDataConnection_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IWorksheetDataConnection_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IWorksheetDataConnection_get_Connection(This,RHS)	\
    ( (This)->lpVtbl -> get_Connection(This,RHS) ) 

#define IWorksheetDataConnection_get_CommandText(This,RHS)	\
    ( (This)->lpVtbl -> get_CommandText(This,RHS) ) 

#define IWorksheetDataConnection_put_CommandText(This,RHS)	\
    ( (This)->lpVtbl -> put_CommandText(This,RHS) ) 

#define IWorksheetDataConnection_get_CommandType(This,RHS)	\
    ( (This)->lpVtbl -> get_CommandType(This,RHS) ) 

#define IWorksheetDataConnection_put_CommandType(This,RHS)	\
    ( (This)->lpVtbl -> put_CommandType(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IWorksheetDataConnection_INTERFACE_DEFINED__ */


#ifndef __ITextConnection_INTERFACE_DEFINED__
#define __ITextConnection_INTERFACE_DEFINED__

/* interface ITextConnection */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ITextConnection;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244D3-0001-0000-C000-000000000046")
    ITextConnection : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Connection( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Connection( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TextFileHeaderRow( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_TextFileHeaderRow( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TextFileColumnDataTypes( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_TextFileColumnDataTypes( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TextFileCommaDelimiter( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_TextFileCommaDelimiter( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TextFileConsecutiveDelimiter( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_TextFileConsecutiveDelimiter( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TextFileDecimalSeparator( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_TextFileDecimalSeparator( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TextFileFixedColumnWidths( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_TextFileFixedColumnWidths( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TextFileOtherDelimiter( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_TextFileOtherDelimiter( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TextFileParseType( 
            /* [retval][out] */ XlTextParsingType *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_TextFileParseType( 
            /* [in] */ XlTextParsingType RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TextFilePlatform( 
            /* [retval][out] */ XlPlatform *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_TextFilePlatform( 
            /* [in] */ XlPlatform RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TextFilePromptOnRefresh( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_TextFilePromptOnRefresh( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TextFileSemicolonDelimiter( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_TextFileSemicolonDelimiter( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TextFileSpaceDelimiter( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_TextFileSpaceDelimiter( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TextFileStartRow( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_TextFileStartRow( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TextFileTabDelimiter( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_TextFileTabDelimiter( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TextFileTextQualifier( 
            /* [retval][out] */ XlTextQualifier *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_TextFileTextQualifier( 
            /* [in] */ XlTextQualifier RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TextFileThousandsSeparator( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_TextFileThousandsSeparator( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TextFileTrailingMinusNumbers( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_TextFileTrailingMinusNumbers( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TextFileVisualLayout( 
            /* [retval][out] */ XlTextVisualLayoutType *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_TextFileVisualLayout( 
            /* [in] */ XlTextVisualLayoutType RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ITextConnectionVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ITextConnection * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ITextConnection * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ITextConnection * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ITextConnection * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ITextConnection * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ITextConnection * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ITextConnection * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ITextConnection * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ITextConnection * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ITextConnection * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Connection )( 
            ITextConnection * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Connection )( 
            ITextConnection * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TextFileHeaderRow )( 
            ITextConnection * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_TextFileHeaderRow )( 
            ITextConnection * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TextFileColumnDataTypes )( 
            ITextConnection * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_TextFileColumnDataTypes )( 
            ITextConnection * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TextFileCommaDelimiter )( 
            ITextConnection * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_TextFileCommaDelimiter )( 
            ITextConnection * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TextFileConsecutiveDelimiter )( 
            ITextConnection * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_TextFileConsecutiveDelimiter )( 
            ITextConnection * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TextFileDecimalSeparator )( 
            ITextConnection * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_TextFileDecimalSeparator )( 
            ITextConnection * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TextFileFixedColumnWidths )( 
            ITextConnection * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_TextFileFixedColumnWidths )( 
            ITextConnection * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TextFileOtherDelimiter )( 
            ITextConnection * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_TextFileOtherDelimiter )( 
            ITextConnection * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TextFileParseType )( 
            ITextConnection * This,
            /* [retval][out] */ XlTextParsingType *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_TextFileParseType )( 
            ITextConnection * This,
            /* [in] */ XlTextParsingType RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TextFilePlatform )( 
            ITextConnection * This,
            /* [retval][out] */ XlPlatform *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_TextFilePlatform )( 
            ITextConnection * This,
            /* [in] */ XlPlatform RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TextFilePromptOnRefresh )( 
            ITextConnection * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_TextFilePromptOnRefresh )( 
            ITextConnection * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TextFileSemicolonDelimiter )( 
            ITextConnection * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_TextFileSemicolonDelimiter )( 
            ITextConnection * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TextFileSpaceDelimiter )( 
            ITextConnection * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_TextFileSpaceDelimiter )( 
            ITextConnection * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TextFileStartRow )( 
            ITextConnection * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_TextFileStartRow )( 
            ITextConnection * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TextFileTabDelimiter )( 
            ITextConnection * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_TextFileTabDelimiter )( 
            ITextConnection * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TextFileTextQualifier )( 
            ITextConnection * This,
            /* [retval][out] */ XlTextQualifier *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_TextFileTextQualifier )( 
            ITextConnection * This,
            /* [in] */ XlTextQualifier RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TextFileThousandsSeparator )( 
            ITextConnection * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_TextFileThousandsSeparator )( 
            ITextConnection * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TextFileTrailingMinusNumbers )( 
            ITextConnection * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_TextFileTrailingMinusNumbers )( 
            ITextConnection * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TextFileVisualLayout )( 
            ITextConnection * This,
            /* [retval][out] */ XlTextVisualLayoutType *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_TextFileVisualLayout )( 
            ITextConnection * This,
            /* [in] */ XlTextVisualLayoutType RHS);
        
        END_INTERFACE
    } ITextConnectionVtbl;

    interface ITextConnection
    {
        CONST_VTBL struct ITextConnectionVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ITextConnection_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ITextConnection_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ITextConnection_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ITextConnection_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ITextConnection_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ITextConnection_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ITextConnection_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ITextConnection_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ITextConnection_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ITextConnection_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ITextConnection_get_Connection(This,RHS)	\
    ( (This)->lpVtbl -> get_Connection(This,RHS) ) 

#define ITextConnection_put_Connection(This,RHS)	\
    ( (This)->lpVtbl -> put_Connection(This,RHS) ) 

#define ITextConnection_get_TextFileHeaderRow(This,RHS)	\
    ( (This)->lpVtbl -> get_TextFileHeaderRow(This,RHS) ) 

#define ITextConnection_put_TextFileHeaderRow(This,RHS)	\
    ( (This)->lpVtbl -> put_TextFileHeaderRow(This,RHS) ) 

#define ITextConnection_get_TextFileColumnDataTypes(This,RHS)	\
    ( (This)->lpVtbl -> get_TextFileColumnDataTypes(This,RHS) ) 

#define ITextConnection_put_TextFileColumnDataTypes(This,RHS)	\
    ( (This)->lpVtbl -> put_TextFileColumnDataTypes(This,RHS) ) 

#define ITextConnection_get_TextFileCommaDelimiter(This,RHS)	\
    ( (This)->lpVtbl -> get_TextFileCommaDelimiter(This,RHS) ) 

#define ITextConnection_put_TextFileCommaDelimiter(This,RHS)	\
    ( (This)->lpVtbl -> put_TextFileCommaDelimiter(This,RHS) ) 

#define ITextConnection_get_TextFileConsecutiveDelimiter(This,RHS)	\
    ( (This)->lpVtbl -> get_TextFileConsecutiveDelimiter(This,RHS) ) 

#define ITextConnection_put_TextFileConsecutiveDelimiter(This,RHS)	\
    ( (This)->lpVtbl -> put_TextFileConsecutiveDelimiter(This,RHS) ) 

#define ITextConnection_get_TextFileDecimalSeparator(This,RHS)	\
    ( (This)->lpVtbl -> get_TextFileDecimalSeparator(This,RHS) ) 

#define ITextConnection_put_TextFileDecimalSeparator(This,RHS)	\
    ( (This)->lpVtbl -> put_TextFileDecimalSeparator(This,RHS) ) 

#define ITextConnection_get_TextFileFixedColumnWidths(This,RHS)	\
    ( (This)->lpVtbl -> get_TextFileFixedColumnWidths(This,RHS) ) 

#define ITextConnection_put_TextFileFixedColumnWidths(This,RHS)	\
    ( (This)->lpVtbl -> put_TextFileFixedColumnWidths(This,RHS) ) 

#define ITextConnection_get_TextFileOtherDelimiter(This,RHS)	\
    ( (This)->lpVtbl -> get_TextFileOtherDelimiter(This,RHS) ) 

#define ITextConnection_put_TextFileOtherDelimiter(This,RHS)	\
    ( (This)->lpVtbl -> put_TextFileOtherDelimiter(This,RHS) ) 

#define ITextConnection_get_TextFileParseType(This,RHS)	\
    ( (This)->lpVtbl -> get_TextFileParseType(This,RHS) ) 

#define ITextConnection_put_TextFileParseType(This,RHS)	\
    ( (This)->lpVtbl -> put_TextFileParseType(This,RHS) ) 

#define ITextConnection_get_TextFilePlatform(This,RHS)	\
    ( (This)->lpVtbl -> get_TextFilePlatform(This,RHS) ) 

#define ITextConnection_put_TextFilePlatform(This,RHS)	\
    ( (This)->lpVtbl -> put_TextFilePlatform(This,RHS) ) 

#define ITextConnection_get_TextFilePromptOnRefresh(This,RHS)	\
    ( (This)->lpVtbl -> get_TextFilePromptOnRefresh(This,RHS) ) 

#define ITextConnection_put_TextFilePromptOnRefresh(This,RHS)	\
    ( (This)->lpVtbl -> put_TextFilePromptOnRefresh(This,RHS) ) 

#define ITextConnection_get_TextFileSemicolonDelimiter(This,RHS)	\
    ( (This)->lpVtbl -> get_TextFileSemicolonDelimiter(This,RHS) ) 

#define ITextConnection_put_TextFileSemicolonDelimiter(This,RHS)	\
    ( (This)->lpVtbl -> put_TextFileSemicolonDelimiter(This,RHS) ) 

#define ITextConnection_get_TextFileSpaceDelimiter(This,RHS)	\
    ( (This)->lpVtbl -> get_TextFileSpaceDelimiter(This,RHS) ) 

#define ITextConnection_put_TextFileSpaceDelimiter(This,RHS)	\
    ( (This)->lpVtbl -> put_TextFileSpaceDelimiter(This,RHS) ) 

#define ITextConnection_get_TextFileStartRow(This,RHS)	\
    ( (This)->lpVtbl -> get_TextFileStartRow(This,RHS) ) 

#define ITextConnection_put_TextFileStartRow(This,RHS)	\
    ( (This)->lpVtbl -> put_TextFileStartRow(This,RHS) ) 

#define ITextConnection_get_TextFileTabDelimiter(This,RHS)	\
    ( (This)->lpVtbl -> get_TextFileTabDelimiter(This,RHS) ) 

#define ITextConnection_put_TextFileTabDelimiter(This,RHS)	\
    ( (This)->lpVtbl -> put_TextFileTabDelimiter(This,RHS) ) 

#define ITextConnection_get_TextFileTextQualifier(This,RHS)	\
    ( (This)->lpVtbl -> get_TextFileTextQualifier(This,RHS) ) 

#define ITextConnection_put_TextFileTextQualifier(This,RHS)	\
    ( (This)->lpVtbl -> put_TextFileTextQualifier(This,RHS) ) 

#define ITextConnection_get_TextFileThousandsSeparator(This,RHS)	\
    ( (This)->lpVtbl -> get_TextFileThousandsSeparator(This,RHS) ) 

#define ITextConnection_put_TextFileThousandsSeparator(This,RHS)	\
    ( (This)->lpVtbl -> put_TextFileThousandsSeparator(This,RHS) ) 

#define ITextConnection_get_TextFileTrailingMinusNumbers(This,RHS)	\
    ( (This)->lpVtbl -> get_TextFileTrailingMinusNumbers(This,RHS) ) 

#define ITextConnection_put_TextFileTrailingMinusNumbers(This,RHS)	\
    ( (This)->lpVtbl -> put_TextFileTrailingMinusNumbers(This,RHS) ) 

#define ITextConnection_get_TextFileVisualLayout(This,RHS)	\
    ( (This)->lpVtbl -> get_TextFileVisualLayout(This,RHS) ) 

#define ITextConnection_put_TextFileVisualLayout(This,RHS)	\
    ( (This)->lpVtbl -> put_TextFileVisualLayout(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ITextConnection_INTERFACE_DEFINED__ */


#ifndef __IDataFeedConnection_INTERFACE_DEFINED__
#define __IDataFeedConnection_INTERFACE_DEFINED__

/* interface IDataFeedConnection */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IDataFeedConnection;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244D4-0001-0000-C000-000000000046")
    IDataFeedConnection : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AlwaysUseConnectionFile( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AlwaysUseConnectionFile( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CommandText( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_CommandText( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_CommandType( 
            /* [retval][out] */ XlCmdType *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_CommandType( 
            /* [in] */ XlCmdType RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Connection( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Connection( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_EnableRefresh( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_EnableRefresh( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RefreshDate( 
            /* [retval][out] */ DATE *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Refreshing( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RefreshOnFileOpen( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_RefreshOnFileOpen( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RefreshPeriod( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_RefreshPeriod( 
            /* [in] */ long RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SavePassword( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_SavePassword( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ServerCredentialsMethod( 
            /* [retval][out] */ XlCredentialsMethod *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ServerCredentialsMethod( 
            /* [in] */ XlCredentialsMethod RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SourceConnectionFile( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_SourceConnectionFile( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SourceDataFile( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_SourceDataFile( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CancelRefresh( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Refresh( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SaveAsODC( 
            /* [in] */ BSTR ODCFileName,
            /* [optional][in] */ VARIANT Description,
            /* [optional][in] */ VARIANT Keywords) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IDataFeedConnectionVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IDataFeedConnection * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IDataFeedConnection * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IDataFeedConnection * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IDataFeedConnection * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IDataFeedConnection * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IDataFeedConnection * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IDataFeedConnection * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IDataFeedConnection * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IDataFeedConnection * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IDataFeedConnection * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AlwaysUseConnectionFile )( 
            IDataFeedConnection * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AlwaysUseConnectionFile )( 
            IDataFeedConnection * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CommandText )( 
            IDataFeedConnection * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_CommandText )( 
            IDataFeedConnection * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_CommandType )( 
            IDataFeedConnection * This,
            /* [retval][out] */ XlCmdType *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_CommandType )( 
            IDataFeedConnection * This,
            /* [in] */ XlCmdType RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Connection )( 
            IDataFeedConnection * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Connection )( 
            IDataFeedConnection * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_EnableRefresh )( 
            IDataFeedConnection * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_EnableRefresh )( 
            IDataFeedConnection * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RefreshDate )( 
            IDataFeedConnection * This,
            /* [retval][out] */ DATE *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Refreshing )( 
            IDataFeedConnection * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RefreshOnFileOpen )( 
            IDataFeedConnection * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_RefreshOnFileOpen )( 
            IDataFeedConnection * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RefreshPeriod )( 
            IDataFeedConnection * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_RefreshPeriod )( 
            IDataFeedConnection * This,
            /* [in] */ long RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SavePassword )( 
            IDataFeedConnection * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_SavePassword )( 
            IDataFeedConnection * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ServerCredentialsMethod )( 
            IDataFeedConnection * This,
            /* [retval][out] */ XlCredentialsMethod *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ServerCredentialsMethod )( 
            IDataFeedConnection * This,
            /* [in] */ XlCredentialsMethod RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SourceConnectionFile )( 
            IDataFeedConnection * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_SourceConnectionFile )( 
            IDataFeedConnection * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SourceDataFile )( 
            IDataFeedConnection * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_SourceDataFile )( 
            IDataFeedConnection * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CancelRefresh )( 
            IDataFeedConnection * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Refresh )( 
            IDataFeedConnection * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SaveAsODC )( 
            IDataFeedConnection * This,
            /* [in] */ BSTR ODCFileName,
            /* [optional][in] */ VARIANT Description,
            /* [optional][in] */ VARIANT Keywords);
        
        END_INTERFACE
    } IDataFeedConnectionVtbl;

    interface IDataFeedConnection
    {
        CONST_VTBL struct IDataFeedConnectionVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IDataFeedConnection_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IDataFeedConnection_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IDataFeedConnection_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IDataFeedConnection_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IDataFeedConnection_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IDataFeedConnection_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IDataFeedConnection_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IDataFeedConnection_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IDataFeedConnection_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IDataFeedConnection_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IDataFeedConnection_get_AlwaysUseConnectionFile(This,RHS)	\
    ( (This)->lpVtbl -> get_AlwaysUseConnectionFile(This,RHS) ) 

#define IDataFeedConnection_put_AlwaysUseConnectionFile(This,RHS)	\
    ( (This)->lpVtbl -> put_AlwaysUseConnectionFile(This,RHS) ) 

#define IDataFeedConnection_get_CommandText(This,RHS)	\
    ( (This)->lpVtbl -> get_CommandText(This,RHS) ) 

#define IDataFeedConnection_put_CommandText(This,RHS)	\
    ( (This)->lpVtbl -> put_CommandText(This,RHS) ) 

#define IDataFeedConnection_get_CommandType(This,RHS)	\
    ( (This)->lpVtbl -> get_CommandType(This,RHS) ) 

#define IDataFeedConnection_put_CommandType(This,RHS)	\
    ( (This)->lpVtbl -> put_CommandType(This,RHS) ) 

#define IDataFeedConnection_get_Connection(This,RHS)	\
    ( (This)->lpVtbl -> get_Connection(This,RHS) ) 

#define IDataFeedConnection_put_Connection(This,RHS)	\
    ( (This)->lpVtbl -> put_Connection(This,RHS) ) 

#define IDataFeedConnection_get_EnableRefresh(This,RHS)	\
    ( (This)->lpVtbl -> get_EnableRefresh(This,RHS) ) 

#define IDataFeedConnection_put_EnableRefresh(This,RHS)	\
    ( (This)->lpVtbl -> put_EnableRefresh(This,RHS) ) 

#define IDataFeedConnection_get_RefreshDate(This,RHS)	\
    ( (This)->lpVtbl -> get_RefreshDate(This,RHS) ) 

#define IDataFeedConnection_get_Refreshing(This,RHS)	\
    ( (This)->lpVtbl -> get_Refreshing(This,RHS) ) 

#define IDataFeedConnection_get_RefreshOnFileOpen(This,RHS)	\
    ( (This)->lpVtbl -> get_RefreshOnFileOpen(This,RHS) ) 

#define IDataFeedConnection_put_RefreshOnFileOpen(This,RHS)	\
    ( (This)->lpVtbl -> put_RefreshOnFileOpen(This,RHS) ) 

#define IDataFeedConnection_get_RefreshPeriod(This,RHS)	\
    ( (This)->lpVtbl -> get_RefreshPeriod(This,RHS) ) 

#define IDataFeedConnection_put_RefreshPeriod(This,RHS)	\
    ( (This)->lpVtbl -> put_RefreshPeriod(This,RHS) ) 

#define IDataFeedConnection_get_SavePassword(This,RHS)	\
    ( (This)->lpVtbl -> get_SavePassword(This,RHS) ) 

#define IDataFeedConnection_put_SavePassword(This,RHS)	\
    ( (This)->lpVtbl -> put_SavePassword(This,RHS) ) 

#define IDataFeedConnection_get_ServerCredentialsMethod(This,RHS)	\
    ( (This)->lpVtbl -> get_ServerCredentialsMethod(This,RHS) ) 

#define IDataFeedConnection_put_ServerCredentialsMethod(This,RHS)	\
    ( (This)->lpVtbl -> put_ServerCredentialsMethod(This,RHS) ) 

#define IDataFeedConnection_get_SourceConnectionFile(This,RHS)	\
    ( (This)->lpVtbl -> get_SourceConnectionFile(This,RHS) ) 

#define IDataFeedConnection_put_SourceConnectionFile(This,RHS)	\
    ( (This)->lpVtbl -> put_SourceConnectionFile(This,RHS) ) 

#define IDataFeedConnection_get_SourceDataFile(This,RHS)	\
    ( (This)->lpVtbl -> get_SourceDataFile(This,RHS) ) 

#define IDataFeedConnection_put_SourceDataFile(This,RHS)	\
    ( (This)->lpVtbl -> put_SourceDataFile(This,RHS) ) 

#define IDataFeedConnection_CancelRefresh(This)	\
    ( (This)->lpVtbl -> CancelRefresh(This) ) 

#define IDataFeedConnection_Refresh(This)	\
    ( (This)->lpVtbl -> Refresh(This) ) 

#define IDataFeedConnection_SaveAsODC(This,ODCFileName,Description,Keywords)	\
    ( (This)->lpVtbl -> SaveAsODC(This,ODCFileName,Description,Keywords) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IDataFeedConnection_INTERFACE_DEFINED__ */


#ifndef __IModelTableColumn_INTERFACE_DEFINED__
#define __IModelTableColumn_INTERFACE_DEFINED__

/* interface IModelTableColumn */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IModelTableColumn;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244D5-0001-0000-C000-000000000046")
    IModelTableColumn : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DataType( 
            /* [retval][out] */ long *RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IModelTableColumnVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IModelTableColumn * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IModelTableColumn * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IModelTableColumn * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IModelTableColumn * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IModelTableColumn * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IModelTableColumn * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IModelTableColumn * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IModelTableColumn * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IModelTableColumn * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IModelTableColumn * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            IModelTableColumn * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DataType )( 
            IModelTableColumn * This,
            /* [retval][out] */ long *RHS);
        
        END_INTERFACE
    } IModelTableColumnVtbl;

    interface IModelTableColumn
    {
        CONST_VTBL struct IModelTableColumnVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IModelTableColumn_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IModelTableColumn_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IModelTableColumn_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IModelTableColumn_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IModelTableColumn_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IModelTableColumn_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IModelTableColumn_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IModelTableColumn_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IModelTableColumn_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IModelTableColumn_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IModelTableColumn_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define IModelTableColumn_get_DataType(This,RHS)	\
    ( (This)->lpVtbl -> get_DataType(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IModelTableColumn_INTERFACE_DEFINED__ */


#ifndef __IModelTableColumns_INTERFACE_DEFINED__
#define __IModelTableColumns_INTERFACE_DEFINED__

/* interface IModelTableColumns */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IModelTableColumns;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244D6-0001-0000-C000-000000000046")
    IModelTableColumns : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ ModelTableColumn	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ ModelTableColumn	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IModelTableColumnsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IModelTableColumns * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IModelTableColumns * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IModelTableColumns * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IModelTableColumns * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IModelTableColumns * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IModelTableColumns * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IModelTableColumns * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IModelTableColumns * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IModelTableColumns * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IModelTableColumns * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IModelTableColumns * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Item )( 
            IModelTableColumns * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ ModelTableColumn	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IModelTableColumns * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ ModelTableColumn	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            IModelTableColumns * This,
            /* [retval][out] */ IUnknown **RHS);
        
        END_INTERFACE
    } IModelTableColumnsVtbl;

    interface IModelTableColumns
    {
        CONST_VTBL struct IModelTableColumnsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IModelTableColumns_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IModelTableColumns_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IModelTableColumns_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IModelTableColumns_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IModelTableColumns_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IModelTableColumns_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IModelTableColumns_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IModelTableColumns_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IModelTableColumns_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IModelTableColumns_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IModelTableColumns_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IModelTableColumns_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> Item(This,Index,RHS) ) 

#define IModelTableColumns_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define IModelTableColumns_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IModelTableColumns_INTERFACE_DEFINED__ */


#ifndef __IModelTable_INTERFACE_DEFINED__
#define __IModelTable_INTERFACE_DEFINED__

/* interface IModelTable */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IModelTable;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244D7-0001-0000-C000-000000000046")
    IModelTable : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SourceName( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ModelTableColumns( 
            /* [retval][out] */ ModelTableColumns	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SourceWorkbookConnection( 
            /* [retval][out] */ WorkbookConnection	**RHS) = 0;
        
        virtual /* [hidden][restricted] */ void __stdcall _Dummy7( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Refresh( void) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RecordCount( 
            /* [retval][out] */ long *RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IModelTableVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IModelTable * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IModelTable * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IModelTable * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IModelTable * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IModelTable * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IModelTable * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IModelTable * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IModelTable * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IModelTable * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IModelTable * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            IModelTable * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SourceName )( 
            IModelTable * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ModelTableColumns )( 
            IModelTable * This,
            /* [retval][out] */ ModelTableColumns	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SourceWorkbookConnection )( 
            IModelTable * This,
            /* [retval][out] */ WorkbookConnection	**RHS);
        
        /* [hidden][restricted] */ void ( __stdcall *_Dummy7 )( 
            IModelTable * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Refresh )( 
            IModelTable * This);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RecordCount )( 
            IModelTable * This,
            /* [retval][out] */ long *RHS);
        
        END_INTERFACE
    } IModelTableVtbl;

    interface IModelTable
    {
        CONST_VTBL struct IModelTableVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IModelTable_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IModelTable_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IModelTable_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IModelTable_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IModelTable_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IModelTable_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IModelTable_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IModelTable_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IModelTable_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IModelTable_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IModelTable_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define IModelTable_get_SourceName(This,RHS)	\
    ( (This)->lpVtbl -> get_SourceName(This,RHS) ) 

#define IModelTable_get_ModelTableColumns(This,RHS)	\
    ( (This)->lpVtbl -> get_ModelTableColumns(This,RHS) ) 

#define IModelTable_get_SourceWorkbookConnection(This,RHS)	\
    ( (This)->lpVtbl -> get_SourceWorkbookConnection(This,RHS) ) 

#define IModelTable__Dummy7(This)	\
    ( (This)->lpVtbl -> _Dummy7(This) ) 

#define IModelTable_Refresh(This)	\
    ( (This)->lpVtbl -> Refresh(This) ) 

#define IModelTable_get_RecordCount(This,RHS)	\
    ( (This)->lpVtbl -> get_RecordCount(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IModelTable_INTERFACE_DEFINED__ */


#ifndef __IModelTables_INTERFACE_DEFINED__
#define __IModelTables_INTERFACE_DEFINED__

/* interface IModelTables */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IModelTables;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244D8-0001-0000-C000-000000000046")
    IModelTables : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ ModelTable	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ ModelTable	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IModelTablesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IModelTables * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IModelTables * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IModelTables * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IModelTables * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IModelTables * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IModelTables * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IModelTables * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IModelTables * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IModelTables * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IModelTables * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IModelTables * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Item )( 
            IModelTables * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ ModelTable	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IModelTables * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ ModelTable	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            IModelTables * This,
            /* [retval][out] */ IUnknown **RHS);
        
        END_INTERFACE
    } IModelTablesVtbl;

    interface IModelTables
    {
        CONST_VTBL struct IModelTablesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IModelTables_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IModelTables_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IModelTables_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IModelTables_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IModelTables_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IModelTables_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IModelTables_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IModelTables_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IModelTables_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IModelTables_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IModelTables_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IModelTables_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> Item(This,Index,RHS) ) 

#define IModelTables_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define IModelTables_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IModelTables_INTERFACE_DEFINED__ */


#ifndef __IModelRelationship_INTERFACE_DEFINED__
#define __IModelRelationship_INTERFACE_DEFINED__

/* interface IModelRelationship */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IModelRelationship;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244D9-0001-0000-C000-000000000046")
    IModelRelationship : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ForeignKeyTable( 
            /* [retval][out] */ ModelTable	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ForeignKeyColumn( 
            /* [retval][out] */ ModelTableColumn	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PrimaryKeyTable( 
            /* [retval][out] */ ModelTable	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PrimaryKeyColumn( 
            /* [retval][out] */ ModelTableColumn	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Active( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Active( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( void) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IModelRelationshipVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IModelRelationship * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IModelRelationship * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IModelRelationship * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IModelRelationship * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IModelRelationship * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IModelRelationship * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IModelRelationship * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IModelRelationship * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IModelRelationship * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IModelRelationship * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ForeignKeyTable )( 
            IModelRelationship * This,
            /* [retval][out] */ ModelTable	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ForeignKeyColumn )( 
            IModelRelationship * This,
            /* [retval][out] */ ModelTableColumn	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PrimaryKeyTable )( 
            IModelRelationship * This,
            /* [retval][out] */ ModelTable	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PrimaryKeyColumn )( 
            IModelRelationship * This,
            /* [retval][out] */ ModelTableColumn	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Active )( 
            IModelRelationship * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Active )( 
            IModelRelationship * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IModelRelationship * This);
        
        END_INTERFACE
    } IModelRelationshipVtbl;

    interface IModelRelationship
    {
        CONST_VTBL struct IModelRelationshipVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IModelRelationship_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IModelRelationship_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IModelRelationship_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IModelRelationship_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IModelRelationship_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IModelRelationship_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IModelRelationship_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IModelRelationship_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IModelRelationship_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IModelRelationship_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IModelRelationship_get_ForeignKeyTable(This,RHS)	\
    ( (This)->lpVtbl -> get_ForeignKeyTable(This,RHS) ) 

#define IModelRelationship_get_ForeignKeyColumn(This,RHS)	\
    ( (This)->lpVtbl -> get_ForeignKeyColumn(This,RHS) ) 

#define IModelRelationship_get_PrimaryKeyTable(This,RHS)	\
    ( (This)->lpVtbl -> get_PrimaryKeyTable(This,RHS) ) 

#define IModelRelationship_get_PrimaryKeyColumn(This,RHS)	\
    ( (This)->lpVtbl -> get_PrimaryKeyColumn(This,RHS) ) 

#define IModelRelationship_get_Active(This,RHS)	\
    ( (This)->lpVtbl -> get_Active(This,RHS) ) 

#define IModelRelationship_put_Active(This,RHS)	\
    ( (This)->lpVtbl -> put_Active(This,RHS) ) 

#define IModelRelationship_Delete(This)	\
    ( (This)->lpVtbl -> Delete(This) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IModelRelationship_INTERFACE_DEFINED__ */


#ifndef __IModelRelationships_INTERFACE_DEFINED__
#define __IModelRelationships_INTERFACE_DEFINED__

/* interface IModelRelationships */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IModelRelationships;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244DA-0001-0000-C000-000000000046")
    IModelRelationships : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ ModelRelationship	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ ModelRelationship	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Add( 
            /* [in] */ ModelTableColumn	*ForeignKeyColumn,
            /* [in] */ ModelTableColumn	*PrimaryKeyColumn,
            /* [retval][out] */ ModelRelationship	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IModelRelationshipsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IModelRelationships * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IModelRelationships * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IModelRelationships * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IModelRelationships * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IModelRelationships * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IModelRelationships * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IModelRelationships * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IModelRelationships * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IModelRelationships * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IModelRelationships * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IModelRelationships * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Item )( 
            IModelRelationships * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ ModelRelationship	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IModelRelationships * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ ModelRelationship	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            IModelRelationships * This,
            /* [retval][out] */ IUnknown **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Add )( 
            IModelRelationships * This,
            /* [in] */ ModelTableColumn	*ForeignKeyColumn,
            /* [in] */ ModelTableColumn	*PrimaryKeyColumn,
            /* [retval][out] */ ModelRelationship	**RHS);
        
        END_INTERFACE
    } IModelRelationshipsVtbl;

    interface IModelRelationships
    {
        CONST_VTBL struct IModelRelationshipsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IModelRelationships_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IModelRelationships_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IModelRelationships_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IModelRelationships_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IModelRelationships_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IModelRelationships_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IModelRelationships_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IModelRelationships_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IModelRelationships_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IModelRelationships_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IModelRelationships_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IModelRelationships_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> Item(This,Index,RHS) ) 

#define IModelRelationships_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define IModelRelationships_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#define IModelRelationships_Add(This,ForeignKeyColumn,PrimaryKeyColumn,RHS)	\
    ( (This)->lpVtbl -> Add(This,ForeignKeyColumn,PrimaryKeyColumn,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IModelRelationships_INTERFACE_DEFINED__ */


#ifndef __IModel_INTERFACE_DEFINED__
#define __IModel_INTERFACE_DEFINED__

/* interface IModel */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IModel;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244DB-0001-0000-C000-000000000046")
    IModel : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ModelTables( 
            /* [retval][out] */ ModelTables	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ModelRelationships( 
            /* [retval][out] */ ModelRelationships	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Refresh( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall AddConnection( 
            /* [in] */ WorkbookConnection	*ConnectionToDataSource,
            /* [retval][out] */ WorkbookConnection	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CreateModelWorkbookConnection( 
            /* [in] */ VARIANT ModelTable,
            /* [retval][out] */ WorkbookConnection	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_DataModelConnection( 
            /* [retval][out] */ WorkbookConnection	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Initialize( void) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IModelVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IModel * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IModel * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IModel * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IModel * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IModel * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IModel * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IModel * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IModel * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IModel * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IModel * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ModelTables )( 
            IModel * This,
            /* [retval][out] */ ModelTables	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ModelRelationships )( 
            IModel * This,
            /* [retval][out] */ ModelRelationships	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Refresh )( 
            IModel * This);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *AddConnection )( 
            IModel * This,
            /* [in] */ WorkbookConnection	*ConnectionToDataSource,
            /* [retval][out] */ WorkbookConnection	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CreateModelWorkbookConnection )( 
            IModel * This,
            /* [in] */ VARIANT ModelTable,
            /* [retval][out] */ WorkbookConnection	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_DataModelConnection )( 
            IModel * This,
            /* [retval][out] */ WorkbookConnection	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            IModel * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Initialize )( 
            IModel * This);
        
        END_INTERFACE
    } IModelVtbl;

    interface IModel
    {
        CONST_VTBL struct IModelVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IModel_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IModel_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IModel_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IModel_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IModel_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IModel_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IModel_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IModel_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IModel_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IModel_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IModel_get_ModelTables(This,RHS)	\
    ( (This)->lpVtbl -> get_ModelTables(This,RHS) ) 

#define IModel_get_ModelRelationships(This,RHS)	\
    ( (This)->lpVtbl -> get_ModelRelationships(This,RHS) ) 

#define IModel_Refresh(This)	\
    ( (This)->lpVtbl -> Refresh(This) ) 

#define IModel_AddConnection(This,ConnectionToDataSource,RHS)	\
    ( (This)->lpVtbl -> AddConnection(This,ConnectionToDataSource,RHS) ) 

#define IModel_CreateModelWorkbookConnection(This,ModelTable,RHS)	\
    ( (This)->lpVtbl -> CreateModelWorkbookConnection(This,ModelTable,RHS) ) 

#define IModel_get_DataModelConnection(This,RHS)	\
    ( (This)->lpVtbl -> get_DataModelConnection(This,RHS) ) 

#define IModel_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define IModel_Initialize(This)	\
    ( (This)->lpVtbl -> Initialize(This) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IModel_INTERFACE_DEFINED__ */


#ifndef __IFullSeriesCollection_INTERFACE_DEFINED__
#define __IFullSeriesCollection_INTERFACE_DEFINED__

/* interface IFullSeriesCollection */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IFullSeriesCollection;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244DC-0001-0000-C000-000000000046")
    IFullSeriesCollection : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Series	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall _NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall _Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Series	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IFullSeriesCollectionVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IFullSeriesCollection * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IFullSeriesCollection * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IFullSeriesCollection * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IFullSeriesCollection * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IFullSeriesCollection * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IFullSeriesCollection * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IFullSeriesCollection * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IFullSeriesCollection * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IFullSeriesCollection * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IFullSeriesCollection * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IFullSeriesCollection * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Item )( 
            IFullSeriesCollection * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Series	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *_NewEnum )( 
            IFullSeriesCollection * This,
            /* [retval][out] */ IUnknown **RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *_Default )( 
            IFullSeriesCollection * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ Series	**RHS);
        
        END_INTERFACE
    } IFullSeriesCollectionVtbl;

    interface IFullSeriesCollection
    {
        CONST_VTBL struct IFullSeriesCollectionVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IFullSeriesCollection_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IFullSeriesCollection_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IFullSeriesCollection_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IFullSeriesCollection_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IFullSeriesCollection_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IFullSeriesCollection_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IFullSeriesCollection_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IFullSeriesCollection_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IFullSeriesCollection_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IFullSeriesCollection_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IFullSeriesCollection_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IFullSeriesCollection_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> Item(This,Index,RHS) ) 

#define IFullSeriesCollection__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> _NewEnum(This,RHS) ) 

#define IFullSeriesCollection__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> _Default(This,Index,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IFullSeriesCollection_INTERFACE_DEFINED__ */


#ifndef __IChartCategory_INTERFACE_DEFINED__
#define __IChartCategory_INTERFACE_DEFINED__

/* interface IChartCategory */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IChartCategory;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244DD-0001-0000-C000-000000000046")
    IChartCategory : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_IsFiltered( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_IsFiltered( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IChartCategoryVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IChartCategory * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IChartCategory * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IChartCategory * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IChartCategory * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IChartCategory * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IChartCategory * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IChartCategory * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IChartCategory * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IChartCategory * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IChartCategory * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            IChartCategory * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_IsFiltered )( 
            IChartCategory * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_IsFiltered )( 
            IChartCategory * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        END_INTERFACE
    } IChartCategoryVtbl;

    interface IChartCategory
    {
        CONST_VTBL struct IChartCategoryVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IChartCategory_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IChartCategory_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IChartCategory_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IChartCategory_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IChartCategory_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IChartCategory_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IChartCategory_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IChartCategory_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IChartCategory_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IChartCategory_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IChartCategory_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define IChartCategory_get_IsFiltered(This,RHS)	\
    ( (This)->lpVtbl -> get_IsFiltered(This,RHS) ) 

#define IChartCategory_put_IsFiltered(This,RHS)	\
    ( (This)->lpVtbl -> put_IsFiltered(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IChartCategory_INTERFACE_DEFINED__ */


#ifndef __ICategoryCollection_INTERFACE_DEFINED__
#define __ICategoryCollection_INTERFACE_DEFINED__

/* interface ICategoryCollection */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ICategoryCollection;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244DE-0001-0000-C000-000000000046")
    ICategoryCollection : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ ChartCategory	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall _Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ ChartCategory	**RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ICategoryCollectionVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ICategoryCollection * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ICategoryCollection * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ICategoryCollection * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ICategoryCollection * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ICategoryCollection * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ICategoryCollection * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ICategoryCollection * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ICategoryCollection * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ICategoryCollection * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ICategoryCollection * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            ICategoryCollection * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Item )( 
            ICategoryCollection * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ ChartCategory	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *_Default )( 
            ICategoryCollection * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ ChartCategory	**RHS);
        
        END_INTERFACE
    } ICategoryCollectionVtbl;

    interface ICategoryCollection
    {
        CONST_VTBL struct ICategoryCollectionVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ICategoryCollection_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ICategoryCollection_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ICategoryCollection_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ICategoryCollection_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ICategoryCollection_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ICategoryCollection_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ICategoryCollection_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ICategoryCollection_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ICategoryCollection_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ICategoryCollection_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ICategoryCollection_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define ICategoryCollection_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> Item(This,Index,RHS) ) 

#define ICategoryCollection__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> _Default(This,Index,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ICategoryCollection_INTERFACE_DEFINED__ */


#ifndef __ITimelineState_INTERFACE_DEFINED__
#define __ITimelineState_INTERFACE_DEFINED__

/* interface ITimelineState */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ITimelineState;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244DF-0001-0000-C000-000000000046")
    ITimelineState : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_StartDate( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_EndDate( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_FilterType( 
            /* [retval][out] */ XlPivotFilterType *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_FilterValue1( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_FilterValue2( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SingleRangeFilterState( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SetFilterDateRange( 
            /* [in] */ VARIANT StartDate,
            /* [in] */ VARIANT EndDate,
            /* [retval][out] */ XlFilterStatus *RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ITimelineStateVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ITimelineState * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ITimelineState * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ITimelineState * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ITimelineState * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ITimelineState * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ITimelineState * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ITimelineState * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ITimelineState * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ITimelineState * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ITimelineState * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_StartDate )( 
            ITimelineState * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_EndDate )( 
            ITimelineState * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_FilterType )( 
            ITimelineState * This,
            /* [retval][out] */ XlPivotFilterType *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_FilterValue1 )( 
            ITimelineState * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_FilterValue2 )( 
            ITimelineState * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SingleRangeFilterState )( 
            ITimelineState * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SetFilterDateRange )( 
            ITimelineState * This,
            /* [in] */ VARIANT StartDate,
            /* [in] */ VARIANT EndDate,
            /* [retval][out] */ XlFilterStatus *RHS);
        
        END_INTERFACE
    } ITimelineStateVtbl;

    interface ITimelineState
    {
        CONST_VTBL struct ITimelineStateVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ITimelineState_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ITimelineState_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ITimelineState_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ITimelineState_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ITimelineState_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ITimelineState_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ITimelineState_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ITimelineState_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ITimelineState_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ITimelineState_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ITimelineState_get_StartDate(This,RHS)	\
    ( (This)->lpVtbl -> get_StartDate(This,RHS) ) 

#define ITimelineState_get_EndDate(This,RHS)	\
    ( (This)->lpVtbl -> get_EndDate(This,RHS) ) 

#define ITimelineState_get_FilterType(This,RHS)	\
    ( (This)->lpVtbl -> get_FilterType(This,RHS) ) 

#define ITimelineState_get_FilterValue1(This,RHS)	\
    ( (This)->lpVtbl -> get_FilterValue1(This,RHS) ) 

#define ITimelineState_get_FilterValue2(This,RHS)	\
    ( (This)->lpVtbl -> get_FilterValue2(This,RHS) ) 

#define ITimelineState_get_SingleRangeFilterState(This,RHS)	\
    ( (This)->lpVtbl -> get_SingleRangeFilterState(This,RHS) ) 

#define ITimelineState_SetFilterDateRange(This,StartDate,EndDate,RHS)	\
    ( (This)->lpVtbl -> SetFilterDateRange(This,StartDate,EndDate,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ITimelineState_INTERFACE_DEFINED__ */


#ifndef __ITimelineViewState_INTERFACE_DEFINED__
#define __ITimelineViewState_INTERFACE_DEFINED__

/* interface ITimelineViewState */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_ITimelineViewState;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244E0-0001-0000-C000-000000000046")
    ITimelineViewState : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShowHeader( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ShowHeader( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShowSelectionLabel( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ShowSelectionLabel( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShowTimeLevel( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ShowTimeLevel( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShowHorizontalScrollbar( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ShowHorizontalScrollbar( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Level( 
            /* [retval][out] */ XlTimelineLevel *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Level( 
            /* [in] */ XlTimelineLevel RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct ITimelineViewStateVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ITimelineViewState * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ITimelineViewState * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ITimelineViewState * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ITimelineViewState * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ITimelineViewState * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ITimelineViewState * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ITimelineViewState * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            ITimelineViewState * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            ITimelineViewState * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            ITimelineViewState * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShowHeader )( 
            ITimelineViewState * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ShowHeader )( 
            ITimelineViewState * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShowSelectionLabel )( 
            ITimelineViewState * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ShowSelectionLabel )( 
            ITimelineViewState * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShowTimeLevel )( 
            ITimelineViewState * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ShowTimeLevel )( 
            ITimelineViewState * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShowHorizontalScrollbar )( 
            ITimelineViewState * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ShowHorizontalScrollbar )( 
            ITimelineViewState * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Level )( 
            ITimelineViewState * This,
            /* [retval][out] */ XlTimelineLevel *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Level )( 
            ITimelineViewState * This,
            /* [in] */ XlTimelineLevel RHS);
        
        END_INTERFACE
    } ITimelineViewStateVtbl;

    interface ITimelineViewState
    {
        CONST_VTBL struct ITimelineViewStateVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ITimelineViewState_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ITimelineViewState_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ITimelineViewState_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ITimelineViewState_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ITimelineViewState_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ITimelineViewState_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ITimelineViewState_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define ITimelineViewState_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define ITimelineViewState_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define ITimelineViewState_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define ITimelineViewState_get_ShowHeader(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowHeader(This,RHS) ) 

#define ITimelineViewState_put_ShowHeader(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowHeader(This,RHS) ) 

#define ITimelineViewState_get_ShowSelectionLabel(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowSelectionLabel(This,RHS) ) 

#define ITimelineViewState_put_ShowSelectionLabel(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowSelectionLabel(This,RHS) ) 

#define ITimelineViewState_get_ShowTimeLevel(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowTimeLevel(This,RHS) ) 

#define ITimelineViewState_put_ShowTimeLevel(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowTimeLevel(This,RHS) ) 

#define ITimelineViewState_get_ShowHorizontalScrollbar(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowHorizontalScrollbar(This,RHS) ) 

#define ITimelineViewState_put_ShowHorizontalScrollbar(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowHorizontalScrollbar(This,RHS) ) 

#define ITimelineViewState_get_Level(This,RHS)	\
    ( (This)->lpVtbl -> get_Level(This,RHS) ) 

#define ITimelineViewState_put_Level(This,RHS)	\
    ( (This)->lpVtbl -> put_Level(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ITimelineViewState_INTERFACE_DEFINED__ */


#ifndef __IModelTableNames_INTERFACE_DEFINED__
#define __IModelTableNames_INTERFACE_DEFINED__

/* interface IModelTableNames */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IModelTableNames;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244E1-0001-0000-C000-000000000046")
    IModelTableNames : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ BSTR *RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IModelTableNamesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IModelTableNames * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IModelTableNames * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IModelTableNames * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IModelTableNames * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IModelTableNames * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IModelTableNames * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IModelTableNames * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IModelTableNames * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IModelTableNames * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IModelTableNames * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IModelTableNames * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Item )( 
            IModelTableNames * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IModelTableNames * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ BSTR *RHS);
        
        END_INTERFACE
    } IModelTableNamesVtbl;

    interface IModelTableNames
    {
        CONST_VTBL struct IModelTableNamesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IModelTableNames_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IModelTableNames_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IModelTableNames_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IModelTableNames_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IModelTableNames_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IModelTableNames_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IModelTableNames_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IModelTableNames_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IModelTableNames_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IModelTableNames_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IModelTableNames_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IModelTableNames_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> Item(This,Index,RHS) ) 

#define IModelTableNames_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IModelTableNames_INTERFACE_DEFINED__ */


#ifndef __IModelTableNameChange_INTERFACE_DEFINED__
#define __IModelTableNameChange_INTERFACE_DEFINED__

/* interface IModelTableNameChange */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IModelTableNameChange;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244E2-0001-0000-C000-000000000046")
    IModelTableNameChange : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TableNameOld( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TableNameNew( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IModelTableNameChangeVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IModelTableNameChange * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IModelTableNameChange * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IModelTableNameChange * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IModelTableNameChange * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IModelTableNameChange * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IModelTableNameChange * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IModelTableNameChange * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IModelTableNameChange * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IModelTableNameChange * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IModelTableNameChange * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TableNameOld )( 
            IModelTableNameChange * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TableNameNew )( 
            IModelTableNameChange * This,
            /* [retval][out] */ BSTR *RHS);
        
        END_INTERFACE
    } IModelTableNameChangeVtbl;

    interface IModelTableNameChange
    {
        CONST_VTBL struct IModelTableNameChangeVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IModelTableNameChange_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IModelTableNameChange_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IModelTableNameChange_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IModelTableNameChange_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IModelTableNameChange_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IModelTableNameChange_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IModelTableNameChange_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IModelTableNameChange_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IModelTableNameChange_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IModelTableNameChange_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IModelTableNameChange_get_TableNameOld(This,RHS)	\
    ( (This)->lpVtbl -> get_TableNameOld(This,RHS) ) 

#define IModelTableNameChange_get_TableNameNew(This,RHS)	\
    ( (This)->lpVtbl -> get_TableNameNew(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IModelTableNameChange_INTERFACE_DEFINED__ */


#ifndef __IModelTableNameChanges_INTERFACE_DEFINED__
#define __IModelTableNameChanges_INTERFACE_DEFINED__

/* interface IModelTableNameChanges */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IModelTableNameChanges;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244E3-0001-0000-C000-000000000046")
    IModelTableNameChanges : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ ModelTableNameChange	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ ModelTableNameChange	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IModelTableNameChangesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IModelTableNameChanges * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IModelTableNameChanges * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IModelTableNameChanges * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IModelTableNameChanges * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IModelTableNameChanges * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IModelTableNameChanges * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IModelTableNameChanges * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IModelTableNameChanges * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IModelTableNameChanges * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IModelTableNameChanges * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IModelTableNameChanges * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Item )( 
            IModelTableNameChanges * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ ModelTableNameChange	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IModelTableNameChanges * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ ModelTableNameChange	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            IModelTableNameChanges * This,
            /* [retval][out] */ IUnknown **RHS);
        
        END_INTERFACE
    } IModelTableNameChangesVtbl;

    interface IModelTableNameChanges
    {
        CONST_VTBL struct IModelTableNameChangesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IModelTableNameChanges_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IModelTableNameChanges_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IModelTableNameChanges_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IModelTableNameChanges_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IModelTableNameChanges_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IModelTableNameChanges_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IModelTableNameChanges_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IModelTableNameChanges_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IModelTableNameChanges_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IModelTableNameChanges_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IModelTableNameChanges_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IModelTableNameChanges_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> Item(This,Index,RHS) ) 

#define IModelTableNameChanges_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define IModelTableNameChanges_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IModelTableNameChanges_INTERFACE_DEFINED__ */


#ifndef __IModelChanges_INTERFACE_DEFINED__
#define __IModelChanges_INTERFACE_DEFINED__

/* interface IModelChanges */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IModelChanges;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244E4-0001-0000-C000-000000000046")
    IModelChanges : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TablesAdded( 
            /* [retval][out] */ ModelTableNames	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TablesDeleted( 
            /* [retval][out] */ ModelTableNames	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TablesModified( 
            /* [retval][out] */ ModelTableNames	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TableNamesChanged( 
            /* [retval][out] */ ModelTableNameChanges	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_RelationshipChange( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ColumnsAdded( 
            /* [retval][out] */ ModelColumnNames	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ColumnsDeleted( 
            /* [retval][out] */ ModelColumnNames	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ColumnsChanged( 
            /* [retval][out] */ ModelColumnChanges	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MeasuresAdded( 
            /* [retval][out] */ ModelMeasureNames	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_UnknownChange( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Source( 
            /* [retval][out] */ XlModelChangeSource *RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IModelChangesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IModelChanges * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IModelChanges * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IModelChanges * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IModelChanges * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IModelChanges * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IModelChanges * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IModelChanges * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IModelChanges * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IModelChanges * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IModelChanges * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TablesAdded )( 
            IModelChanges * This,
            /* [retval][out] */ ModelTableNames	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TablesDeleted )( 
            IModelChanges * This,
            /* [retval][out] */ ModelTableNames	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TablesModified )( 
            IModelChanges * This,
            /* [retval][out] */ ModelTableNames	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TableNamesChanged )( 
            IModelChanges * This,
            /* [retval][out] */ ModelTableNameChanges	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_RelationshipChange )( 
            IModelChanges * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ColumnsAdded )( 
            IModelChanges * This,
            /* [retval][out] */ ModelColumnNames	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ColumnsDeleted )( 
            IModelChanges * This,
            /* [retval][out] */ ModelColumnNames	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ColumnsChanged )( 
            IModelChanges * This,
            /* [retval][out] */ ModelColumnChanges	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MeasuresAdded )( 
            IModelChanges * This,
            /* [retval][out] */ ModelMeasureNames	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_UnknownChange )( 
            IModelChanges * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Source )( 
            IModelChanges * This,
            /* [retval][out] */ XlModelChangeSource *RHS);
        
        END_INTERFACE
    } IModelChangesVtbl;

    interface IModelChanges
    {
        CONST_VTBL struct IModelChangesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IModelChanges_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IModelChanges_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IModelChanges_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IModelChanges_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IModelChanges_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IModelChanges_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IModelChanges_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IModelChanges_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IModelChanges_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IModelChanges_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IModelChanges_get_TablesAdded(This,RHS)	\
    ( (This)->lpVtbl -> get_TablesAdded(This,RHS) ) 

#define IModelChanges_get_TablesDeleted(This,RHS)	\
    ( (This)->lpVtbl -> get_TablesDeleted(This,RHS) ) 

#define IModelChanges_get_TablesModified(This,RHS)	\
    ( (This)->lpVtbl -> get_TablesModified(This,RHS) ) 

#define IModelChanges_get_TableNamesChanged(This,RHS)	\
    ( (This)->lpVtbl -> get_TableNamesChanged(This,RHS) ) 

#define IModelChanges_get_RelationshipChange(This,RHS)	\
    ( (This)->lpVtbl -> get_RelationshipChange(This,RHS) ) 

#define IModelChanges_get_ColumnsAdded(This,RHS)	\
    ( (This)->lpVtbl -> get_ColumnsAdded(This,RHS) ) 

#define IModelChanges_get_ColumnsDeleted(This,RHS)	\
    ( (This)->lpVtbl -> get_ColumnsDeleted(This,RHS) ) 

#define IModelChanges_get_ColumnsChanged(This,RHS)	\
    ( (This)->lpVtbl -> get_ColumnsChanged(This,RHS) ) 

#define IModelChanges_get_MeasuresAdded(This,RHS)	\
    ( (This)->lpVtbl -> get_MeasuresAdded(This,RHS) ) 

#define IModelChanges_get_UnknownChange(This,RHS)	\
    ( (This)->lpVtbl -> get_UnknownChange(This,RHS) ) 

#define IModelChanges_get_Source(This,RHS)	\
    ( (This)->lpVtbl -> get_Source(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IModelChanges_INTERFACE_DEFINED__ */


#ifndef __IModelColumnName_INTERFACE_DEFINED__
#define __IModelColumnName_INTERFACE_DEFINED__

/* interface IModelColumnName */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IModelColumnName;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244E5-0001-0000-C000-000000000046")
    IModelColumnName : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TableName( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ColumnName( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IModelColumnNameVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IModelColumnName * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IModelColumnName * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IModelColumnName * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IModelColumnName * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IModelColumnName * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IModelColumnName * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IModelColumnName * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IModelColumnName * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IModelColumnName * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IModelColumnName * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TableName )( 
            IModelColumnName * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ColumnName )( 
            IModelColumnName * This,
            /* [retval][out] */ BSTR *RHS);
        
        END_INTERFACE
    } IModelColumnNameVtbl;

    interface IModelColumnName
    {
        CONST_VTBL struct IModelColumnNameVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IModelColumnName_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IModelColumnName_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IModelColumnName_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IModelColumnName_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IModelColumnName_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IModelColumnName_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IModelColumnName_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IModelColumnName_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IModelColumnName_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IModelColumnName_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IModelColumnName_get_TableName(This,RHS)	\
    ( (This)->lpVtbl -> get_TableName(This,RHS) ) 

#define IModelColumnName_get_ColumnName(This,RHS)	\
    ( (This)->lpVtbl -> get_ColumnName(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IModelColumnName_INTERFACE_DEFINED__ */


#ifndef __IModelColumnNames_INTERFACE_DEFINED__
#define __IModelColumnNames_INTERFACE_DEFINED__

/* interface IModelColumnNames */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IModelColumnNames;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244E6-0001-0000-C000-000000000046")
    IModelColumnNames : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ ModelColumnName	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ ModelColumnName	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IModelColumnNamesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IModelColumnNames * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IModelColumnNames * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IModelColumnNames * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IModelColumnNames * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IModelColumnNames * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IModelColumnNames * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IModelColumnNames * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IModelColumnNames * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IModelColumnNames * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IModelColumnNames * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IModelColumnNames * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Item )( 
            IModelColumnNames * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ ModelColumnName	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IModelColumnNames * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ ModelColumnName	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            IModelColumnNames * This,
            /* [retval][out] */ IUnknown **RHS);
        
        END_INTERFACE
    } IModelColumnNamesVtbl;

    interface IModelColumnNames
    {
        CONST_VTBL struct IModelColumnNamesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IModelColumnNames_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IModelColumnNames_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IModelColumnNames_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IModelColumnNames_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IModelColumnNames_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IModelColumnNames_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IModelColumnNames_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IModelColumnNames_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IModelColumnNames_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IModelColumnNames_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IModelColumnNames_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IModelColumnNames_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> Item(This,Index,RHS) ) 

#define IModelColumnNames_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define IModelColumnNames_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IModelColumnNames_INTERFACE_DEFINED__ */


#ifndef __IModelColumnChange_INTERFACE_DEFINED__
#define __IModelColumnChange_INTERFACE_DEFINED__

/* interface IModelColumnChange */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IModelColumnChange;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244E7-0001-0000-C000-000000000046")
    IModelColumnChange : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TableName( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ColumnName( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IModelColumnChangeVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IModelColumnChange * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IModelColumnChange * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IModelColumnChange * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IModelColumnChange * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IModelColumnChange * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IModelColumnChange * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IModelColumnChange * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IModelColumnChange * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IModelColumnChange * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IModelColumnChange * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TableName )( 
            IModelColumnChange * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ColumnName )( 
            IModelColumnChange * This,
            /* [retval][out] */ BSTR *RHS);
        
        END_INTERFACE
    } IModelColumnChangeVtbl;

    interface IModelColumnChange
    {
        CONST_VTBL struct IModelColumnChangeVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IModelColumnChange_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IModelColumnChange_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IModelColumnChange_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IModelColumnChange_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IModelColumnChange_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IModelColumnChange_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IModelColumnChange_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IModelColumnChange_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IModelColumnChange_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IModelColumnChange_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IModelColumnChange_get_TableName(This,RHS)	\
    ( (This)->lpVtbl -> get_TableName(This,RHS) ) 

#define IModelColumnChange_get_ColumnName(This,RHS)	\
    ( (This)->lpVtbl -> get_ColumnName(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IModelColumnChange_INTERFACE_DEFINED__ */


#ifndef __IModelColumnChanges_INTERFACE_DEFINED__
#define __IModelColumnChanges_INTERFACE_DEFINED__

/* interface IModelColumnChanges */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IModelColumnChanges;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244E8-0001-0000-C000-000000000046")
    IModelColumnChanges : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ ModelColumnChange	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ ModelColumnChange	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IModelColumnChangesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IModelColumnChanges * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IModelColumnChanges * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IModelColumnChanges * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IModelColumnChanges * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IModelColumnChanges * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IModelColumnChanges * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IModelColumnChanges * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IModelColumnChanges * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IModelColumnChanges * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IModelColumnChanges * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IModelColumnChanges * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Item )( 
            IModelColumnChanges * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ ModelColumnChange	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IModelColumnChanges * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ ModelColumnChange	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            IModelColumnChanges * This,
            /* [retval][out] */ IUnknown **RHS);
        
        END_INTERFACE
    } IModelColumnChangesVtbl;

    interface IModelColumnChanges
    {
        CONST_VTBL struct IModelColumnChangesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IModelColumnChanges_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IModelColumnChanges_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IModelColumnChanges_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IModelColumnChanges_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IModelColumnChanges_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IModelColumnChanges_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IModelColumnChanges_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IModelColumnChanges_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IModelColumnChanges_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IModelColumnChanges_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IModelColumnChanges_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IModelColumnChanges_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> Item(This,Index,RHS) ) 

#define IModelColumnChanges_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define IModelColumnChanges_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IModelColumnChanges_INTERFACE_DEFINED__ */


#ifndef __IModelMeasureName_INTERFACE_DEFINED__
#define __IModelMeasureName_INTERFACE_DEFINED__

/* interface IModelMeasureName */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IModelMeasureName;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244E9-0001-0000-C000-000000000046")
    IModelMeasureName : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TableName( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_MeasureName( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IModelMeasureNameVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IModelMeasureName * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IModelMeasureName * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IModelMeasureName * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IModelMeasureName * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IModelMeasureName * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IModelMeasureName * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IModelMeasureName * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IModelMeasureName * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IModelMeasureName * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IModelMeasureName * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TableName )( 
            IModelMeasureName * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_MeasureName )( 
            IModelMeasureName * This,
            /* [retval][out] */ BSTR *RHS);
        
        END_INTERFACE
    } IModelMeasureNameVtbl;

    interface IModelMeasureName
    {
        CONST_VTBL struct IModelMeasureNameVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IModelMeasureName_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IModelMeasureName_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IModelMeasureName_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IModelMeasureName_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IModelMeasureName_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IModelMeasureName_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IModelMeasureName_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IModelMeasureName_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IModelMeasureName_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IModelMeasureName_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IModelMeasureName_get_TableName(This,RHS)	\
    ( (This)->lpVtbl -> get_TableName(This,RHS) ) 

#define IModelMeasureName_get_MeasureName(This,RHS)	\
    ( (This)->lpVtbl -> get_MeasureName(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IModelMeasureName_INTERFACE_DEFINED__ */


#ifndef __IModelMeasureNames_INTERFACE_DEFINED__
#define __IModelMeasureNames_INTERFACE_DEFINED__

/* interface IModelMeasureNames */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IModelMeasureNames;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("000244EA-0001-0000-C000-000000000046")
    IModelMeasureNames : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Count( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Item( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ ModelMeasureName	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__Default( 
            /* [in] */ VARIANT Index,
            /* [retval][out] */ ModelMeasureName	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get__NewEnum( 
            /* [retval][out] */ IUnknown **RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IModelMeasureNamesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IModelMeasureNames * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IModelMeasureNames * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IModelMeasureNames * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IModelMeasureNames * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IModelMeasureNames * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IModelMeasureNames * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IModelMeasureNames * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IModelMeasureNames * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IModelMeasureNames * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IModelMeasureNames * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Count )( 
            IModelMeasureNames * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Item )( 
            IModelMeasureNames * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ ModelMeasureName	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__Default )( 
            IModelMeasureNames * This,
            /* [in] */ VARIANT Index,
            /* [retval][out] */ ModelMeasureName	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get__NewEnum )( 
            IModelMeasureNames * This,
            /* [retval][out] */ IUnknown **RHS);
        
        END_INTERFACE
    } IModelMeasureNamesVtbl;

    interface IModelMeasureNames
    {
        CONST_VTBL struct IModelMeasureNamesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IModelMeasureNames_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IModelMeasureNames_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IModelMeasureNames_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IModelMeasureNames_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IModelMeasureNames_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IModelMeasureNames_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IModelMeasureNames_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IModelMeasureNames_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IModelMeasureNames_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IModelMeasureNames_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IModelMeasureNames_get_Count(This,RHS)	\
    ( (This)->lpVtbl -> get_Count(This,RHS) ) 

#define IModelMeasureNames_Item(This,Index,RHS)	\
    ( (This)->lpVtbl -> Item(This,Index,RHS) ) 

#define IModelMeasureNames_get__Default(This,Index,RHS)	\
    ( (This)->lpVtbl -> get__Default(This,Index,RHS) ) 

#define IModelMeasureNames_get__NewEnum(This,RHS)	\
    ( (This)->lpVtbl -> get__NewEnum(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IModelMeasureNames_INTERFACE_DEFINED__ */


#ifndef __Font_DISPINTERFACE_DEFINED__
#define __Font_DISPINTERFACE_DEFINED__

/* dispinterface Font */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Font;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002084D-0000-0000-C000-000000000046")
    Font : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct FontVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Font * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Font * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Font * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Font * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Font * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Font * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Font * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } FontVtbl;

    interface Font
    {
        CONST_VTBL struct FontVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Font_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Font_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Font_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Font_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Font_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Font_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Font_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Font_DISPINTERFACE_DEFINED__ */


#ifndef __Window_DISPINTERFACE_DEFINED__
#define __Window_DISPINTERFACE_DEFINED__

/* dispinterface Window */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Window;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00020893-0000-0000-C000-000000000046")
    Window : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct WindowVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Window * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Window * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Window * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Window * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Window * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Window * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Window * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } WindowVtbl;

    interface Window
    {
        CONST_VTBL struct WindowVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Window_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Window_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Window_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Window_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Window_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Window_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Window_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Window_DISPINTERFACE_DEFINED__ */


#ifndef __Windows_DISPINTERFACE_DEFINED__
#define __Windows_DISPINTERFACE_DEFINED__

/* dispinterface Windows */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Windows;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00020892-0000-0000-C000-000000000046")
    Windows : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct WindowsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Windows * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Windows * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Windows * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Windows * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Windows * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Windows * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Windows * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } WindowsVtbl;

    interface Windows
    {
        CONST_VTBL struct WindowsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Windows_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Windows_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Windows_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Windows_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Windows_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Windows_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Windows_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Windows_DISPINTERFACE_DEFINED__ */


#ifndef __AppEvents_DISPINTERFACE_DEFINED__
#define __AppEvents_DISPINTERFACE_DEFINED__

/* dispinterface AppEvents */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_AppEvents;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024413-0000-0000-C000-000000000046")
    AppEvents : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct AppEventsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            AppEvents * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            AppEvents * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            AppEvents * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            AppEvents * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            AppEvents * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            AppEvents * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            AppEvents * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } AppEventsVtbl;

    interface AppEvents
    {
        CONST_VTBL struct AppEventsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define AppEvents_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define AppEvents_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define AppEvents_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define AppEvents_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define AppEvents_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define AppEvents_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define AppEvents_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __AppEvents_DISPINTERFACE_DEFINED__ */


#ifndef __WorksheetFunction_DISPINTERFACE_DEFINED__
#define __WorksheetFunction_DISPINTERFACE_DEFINED__

/* dispinterface WorksheetFunction */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_WorksheetFunction;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00020845-0000-0000-C000-000000000046")
    WorksheetFunction : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct WorksheetFunctionVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            WorksheetFunction * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            WorksheetFunction * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            WorksheetFunction * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            WorksheetFunction * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            WorksheetFunction * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            WorksheetFunction * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            WorksheetFunction * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } WorksheetFunctionVtbl;

    interface WorksheetFunction
    {
        CONST_VTBL struct WorksheetFunctionVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define WorksheetFunction_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define WorksheetFunction_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define WorksheetFunction_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define WorksheetFunction_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define WorksheetFunction_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define WorksheetFunction_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define WorksheetFunction_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __WorksheetFunction_DISPINTERFACE_DEFINED__ */


#ifndef __Range_DISPINTERFACE_DEFINED__
#define __Range_DISPINTERFACE_DEFINED__

/* dispinterface Range */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Range;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00020846-0000-0000-C000-000000000046")
    Range : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct RangeVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Range * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Range * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Range * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Range * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Range * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Range * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Range * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } RangeVtbl;

    interface Range
    {
        CONST_VTBL struct RangeVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Range_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Range_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Range_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Range_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Range_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Range_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Range_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Range_DISPINTERFACE_DEFINED__ */


#ifndef __ChartEvents_DISPINTERFACE_DEFINED__
#define __ChartEvents_DISPINTERFACE_DEFINED__

/* dispinterface ChartEvents */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_ChartEvents;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002440F-0000-0000-C000-000000000046")
    ChartEvents : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ChartEventsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ChartEvents * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ChartEvents * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ChartEvents * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ChartEvents * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ChartEvents * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ChartEvents * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ChartEvents * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ChartEventsVtbl;

    interface ChartEvents
    {
        CONST_VTBL struct ChartEventsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ChartEvents_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ChartEvents_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ChartEvents_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ChartEvents_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ChartEvents_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ChartEvents_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ChartEvents_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __ChartEvents_DISPINTERFACE_DEFINED__ */


#ifndef __VPageBreak_DISPINTERFACE_DEFINED__
#define __VPageBreak_DISPINTERFACE_DEFINED__

/* dispinterface VPageBreak */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_VPageBreak;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024402-0000-0000-C000-000000000046")
    VPageBreak : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct VPageBreakVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            VPageBreak * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            VPageBreak * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            VPageBreak * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            VPageBreak * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            VPageBreak * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            VPageBreak * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            VPageBreak * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } VPageBreakVtbl;

    interface VPageBreak
    {
        CONST_VTBL struct VPageBreakVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define VPageBreak_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define VPageBreak_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define VPageBreak_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define VPageBreak_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define VPageBreak_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define VPageBreak_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define VPageBreak_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __VPageBreak_DISPINTERFACE_DEFINED__ */


#ifndef __HPageBreak_DISPINTERFACE_DEFINED__
#define __HPageBreak_DISPINTERFACE_DEFINED__

/* dispinterface HPageBreak */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_HPageBreak;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024401-0000-0000-C000-000000000046")
    HPageBreak : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct HPageBreakVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            HPageBreak * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            HPageBreak * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            HPageBreak * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            HPageBreak * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            HPageBreak * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            HPageBreak * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            HPageBreak * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } HPageBreakVtbl;

    interface HPageBreak
    {
        CONST_VTBL struct HPageBreakVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define HPageBreak_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define HPageBreak_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define HPageBreak_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define HPageBreak_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define HPageBreak_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define HPageBreak_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define HPageBreak_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __HPageBreak_DISPINTERFACE_DEFINED__ */


#ifndef __HPageBreaks_DISPINTERFACE_DEFINED__
#define __HPageBreaks_DISPINTERFACE_DEFINED__

/* dispinterface HPageBreaks */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_HPageBreaks;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024404-0000-0000-C000-000000000046")
    HPageBreaks : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct HPageBreaksVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            HPageBreaks * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            HPageBreaks * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            HPageBreaks * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            HPageBreaks * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            HPageBreaks * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            HPageBreaks * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            HPageBreaks * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } HPageBreaksVtbl;

    interface HPageBreaks
    {
        CONST_VTBL struct HPageBreaksVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define HPageBreaks_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define HPageBreaks_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define HPageBreaks_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define HPageBreaks_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define HPageBreaks_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define HPageBreaks_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define HPageBreaks_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __HPageBreaks_DISPINTERFACE_DEFINED__ */


#ifndef __VPageBreaks_DISPINTERFACE_DEFINED__
#define __VPageBreaks_DISPINTERFACE_DEFINED__

/* dispinterface VPageBreaks */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_VPageBreaks;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024405-0000-0000-C000-000000000046")
    VPageBreaks : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct VPageBreaksVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            VPageBreaks * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            VPageBreaks * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            VPageBreaks * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            VPageBreaks * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            VPageBreaks * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            VPageBreaks * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            VPageBreaks * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } VPageBreaksVtbl;

    interface VPageBreaks
    {
        CONST_VTBL struct VPageBreaksVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define VPageBreaks_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define VPageBreaks_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define VPageBreaks_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define VPageBreaks_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define VPageBreaks_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define VPageBreaks_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define VPageBreaks_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __VPageBreaks_DISPINTERFACE_DEFINED__ */


#ifndef __RecentFile_DISPINTERFACE_DEFINED__
#define __RecentFile_DISPINTERFACE_DEFINED__

/* dispinterface RecentFile */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_RecentFile;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024407-0000-0000-C000-000000000046")
    RecentFile : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct RecentFileVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            RecentFile * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            RecentFile * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            RecentFile * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            RecentFile * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            RecentFile * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            RecentFile * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            RecentFile * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } RecentFileVtbl;

    interface RecentFile
    {
        CONST_VTBL struct RecentFileVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define RecentFile_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define RecentFile_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define RecentFile_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define RecentFile_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define RecentFile_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define RecentFile_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define RecentFile_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __RecentFile_DISPINTERFACE_DEFINED__ */


#ifndef __RecentFiles_DISPINTERFACE_DEFINED__
#define __RecentFiles_DISPINTERFACE_DEFINED__

/* dispinterface RecentFiles */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_RecentFiles;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024406-0000-0000-C000-000000000046")
    RecentFiles : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct RecentFilesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            RecentFiles * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            RecentFiles * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            RecentFiles * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            RecentFiles * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            RecentFiles * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            RecentFiles * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            RecentFiles * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } RecentFilesVtbl;

    interface RecentFiles
    {
        CONST_VTBL struct RecentFilesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define RecentFiles_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define RecentFiles_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define RecentFiles_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define RecentFiles_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define RecentFiles_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define RecentFiles_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define RecentFiles_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __RecentFiles_DISPINTERFACE_DEFINED__ */


#ifndef __DocEvents_DISPINTERFACE_DEFINED__
#define __DocEvents_DISPINTERFACE_DEFINED__

/* dispinterface DocEvents */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_DocEvents;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024411-0000-0000-C000-000000000046")
    DocEvents : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct DocEventsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            DocEvents * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            DocEvents * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            DocEvents * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            DocEvents * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            DocEvents * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            DocEvents * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            DocEvents * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } DocEventsVtbl;

    interface DocEvents
    {
        CONST_VTBL struct DocEventsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define DocEvents_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define DocEvents_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define DocEvents_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define DocEvents_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define DocEvents_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define DocEvents_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define DocEvents_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __DocEvents_DISPINTERFACE_DEFINED__ */


#ifndef __Style_DISPINTERFACE_DEFINED__
#define __Style_DISPINTERFACE_DEFINED__

/* dispinterface Style */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Style;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00020852-0000-0000-C000-000000000046")
    Style : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct StyleVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Style * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Style * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Style * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Style * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Style * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Style * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Style * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } StyleVtbl;

    interface Style
    {
        CONST_VTBL struct StyleVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Style_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Style_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Style_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Style_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Style_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Style_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Style_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Style_DISPINTERFACE_DEFINED__ */


#ifndef __Styles_DISPINTERFACE_DEFINED__
#define __Styles_DISPINTERFACE_DEFINED__

/* dispinterface Styles */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Styles;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00020853-0000-0000-C000-000000000046")
    Styles : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct StylesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Styles * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Styles * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Styles * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Styles * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Styles * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Styles * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Styles * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } StylesVtbl;

    interface Styles
    {
        CONST_VTBL struct StylesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Styles_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Styles_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Styles_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Styles_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Styles_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Styles_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Styles_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Styles_DISPINTERFACE_DEFINED__ */


#ifndef __Borders_DISPINTERFACE_DEFINED__
#define __Borders_DISPINTERFACE_DEFINED__

/* dispinterface Borders */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Borders;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00020855-0000-0000-C000-000000000046")
    Borders : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct BordersVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Borders * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Borders * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Borders * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Borders * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Borders * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Borders * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Borders * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } BordersVtbl;

    interface Borders
    {
        CONST_VTBL struct BordersVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Borders_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Borders_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Borders_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Borders_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Borders_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Borders_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Borders_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Borders_DISPINTERFACE_DEFINED__ */


#ifndef __AddIn_DISPINTERFACE_DEFINED__
#define __AddIn_DISPINTERFACE_DEFINED__

/* dispinterface AddIn */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_AddIn;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00020857-0000-0000-C000-000000000046")
    AddIn : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct AddInVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            AddIn * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            AddIn * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            AddIn * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            AddIn * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            AddIn * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            AddIn * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            AddIn * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } AddInVtbl;

    interface AddIn
    {
        CONST_VTBL struct AddInVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define AddIn_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define AddIn_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define AddIn_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define AddIn_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define AddIn_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define AddIn_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define AddIn_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __AddIn_DISPINTERFACE_DEFINED__ */


#ifndef __AddIns_DISPINTERFACE_DEFINED__
#define __AddIns_DISPINTERFACE_DEFINED__

/* dispinterface AddIns */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_AddIns;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00020858-0000-0000-C000-000000000046")
    AddIns : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct AddInsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            AddIns * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            AddIns * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            AddIns * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            AddIns * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            AddIns * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            AddIns * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            AddIns * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } AddInsVtbl;

    interface AddIns
    {
        CONST_VTBL struct AddInsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define AddIns_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define AddIns_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define AddIns_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define AddIns_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define AddIns_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define AddIns_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define AddIns_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __AddIns_DISPINTERFACE_DEFINED__ */


#ifndef __Toolbar_DISPINTERFACE_DEFINED__
#define __Toolbar_DISPINTERFACE_DEFINED__

/* dispinterface Toolbar */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_Toolbar;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002085C-0000-0000-C000-000000000046")
    Toolbar : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ToolbarVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Toolbar * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Toolbar * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Toolbar * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Toolbar * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Toolbar * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Toolbar * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Toolbar * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ToolbarVtbl;

    interface Toolbar
    {
        CONST_VTBL struct ToolbarVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Toolbar_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Toolbar_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Toolbar_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Toolbar_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Toolbar_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Toolbar_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Toolbar_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Toolbar_DISPINTERFACE_DEFINED__ */


#ifndef __Toolbars_DISPINTERFACE_DEFINED__
#define __Toolbars_DISPINTERFACE_DEFINED__

/* dispinterface Toolbars */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_Toolbars;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002085D-0000-0000-C000-000000000046")
    Toolbars : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ToolbarsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Toolbars * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Toolbars * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Toolbars * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Toolbars * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Toolbars * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Toolbars * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Toolbars * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ToolbarsVtbl;

    interface Toolbars
    {
        CONST_VTBL struct ToolbarsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Toolbars_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Toolbars_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Toolbars_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Toolbars_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Toolbars_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Toolbars_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Toolbars_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Toolbars_DISPINTERFACE_DEFINED__ */


#ifndef __ToolbarButton_DISPINTERFACE_DEFINED__
#define __ToolbarButton_DISPINTERFACE_DEFINED__

/* dispinterface ToolbarButton */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_ToolbarButton;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002085E-0000-0000-C000-000000000046")
    ToolbarButton : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ToolbarButtonVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ToolbarButton * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ToolbarButton * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ToolbarButton * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ToolbarButton * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ToolbarButton * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ToolbarButton * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ToolbarButton * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ToolbarButtonVtbl;

    interface ToolbarButton
    {
        CONST_VTBL struct ToolbarButtonVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ToolbarButton_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ToolbarButton_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ToolbarButton_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ToolbarButton_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ToolbarButton_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ToolbarButton_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ToolbarButton_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __ToolbarButton_DISPINTERFACE_DEFINED__ */


#ifndef __ToolbarButtons_DISPINTERFACE_DEFINED__
#define __ToolbarButtons_DISPINTERFACE_DEFINED__

/* dispinterface ToolbarButtons */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_ToolbarButtons;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002085F-0000-0000-C000-000000000046")
    ToolbarButtons : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ToolbarButtonsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ToolbarButtons * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ToolbarButtons * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ToolbarButtons * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ToolbarButtons * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ToolbarButtons * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ToolbarButtons * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ToolbarButtons * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ToolbarButtonsVtbl;

    interface ToolbarButtons
    {
        CONST_VTBL struct ToolbarButtonsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ToolbarButtons_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ToolbarButtons_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ToolbarButtons_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ToolbarButtons_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ToolbarButtons_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ToolbarButtons_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ToolbarButtons_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __ToolbarButtons_DISPINTERFACE_DEFINED__ */


#ifndef __Areas_DISPINTERFACE_DEFINED__
#define __Areas_DISPINTERFACE_DEFINED__

/* dispinterface Areas */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Areas;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00020860-0000-0000-C000-000000000046")
    Areas : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct AreasVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Areas * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Areas * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Areas * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Areas * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Areas * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Areas * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Areas * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } AreasVtbl;

    interface Areas
    {
        CONST_VTBL struct AreasVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Areas_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Areas_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Areas_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Areas_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Areas_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Areas_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Areas_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Areas_DISPINTERFACE_DEFINED__ */


#ifndef __WorkbookEvents_DISPINTERFACE_DEFINED__
#define __WorkbookEvents_DISPINTERFACE_DEFINED__

/* dispinterface WorkbookEvents */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_WorkbookEvents;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024412-0000-0000-C000-000000000046")
    WorkbookEvents : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct WorkbookEventsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            WorkbookEvents * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            WorkbookEvents * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            WorkbookEvents * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            WorkbookEvents * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            WorkbookEvents * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            WorkbookEvents * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            WorkbookEvents * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } WorkbookEventsVtbl;

    interface WorkbookEvents
    {
        CONST_VTBL struct WorkbookEventsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define WorkbookEvents_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define WorkbookEvents_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define WorkbookEvents_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define WorkbookEvents_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define WorkbookEvents_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define WorkbookEvents_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define WorkbookEvents_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __WorkbookEvents_DISPINTERFACE_DEFINED__ */


#ifndef __MenuBars_DISPINTERFACE_DEFINED__
#define __MenuBars_DISPINTERFACE_DEFINED__

/* dispinterface MenuBars */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_MenuBars;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00020863-0000-0000-C000-000000000046")
    MenuBars : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct MenuBarsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            MenuBars * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            MenuBars * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            MenuBars * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            MenuBars * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            MenuBars * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            MenuBars * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            MenuBars * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } MenuBarsVtbl;

    interface MenuBars
    {
        CONST_VTBL struct MenuBarsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define MenuBars_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define MenuBars_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define MenuBars_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define MenuBars_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define MenuBars_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define MenuBars_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define MenuBars_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __MenuBars_DISPINTERFACE_DEFINED__ */


#ifndef __MenuBar_DISPINTERFACE_DEFINED__
#define __MenuBar_DISPINTERFACE_DEFINED__

/* dispinterface MenuBar */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_MenuBar;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00020864-0000-0000-C000-000000000046")
    MenuBar : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct MenuBarVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            MenuBar * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            MenuBar * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            MenuBar * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            MenuBar * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            MenuBar * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            MenuBar * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            MenuBar * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } MenuBarVtbl;

    interface MenuBar
    {
        CONST_VTBL struct MenuBarVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define MenuBar_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define MenuBar_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define MenuBar_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define MenuBar_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define MenuBar_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define MenuBar_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define MenuBar_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __MenuBar_DISPINTERFACE_DEFINED__ */


#ifndef __Menus_DISPINTERFACE_DEFINED__
#define __Menus_DISPINTERFACE_DEFINED__

/* dispinterface Menus */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_Menus;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00020865-0000-0000-C000-000000000046")
    Menus : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct MenusVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Menus * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Menus * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Menus * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Menus * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Menus * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Menus * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Menus * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } MenusVtbl;

    interface Menus
    {
        CONST_VTBL struct MenusVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Menus_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Menus_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Menus_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Menus_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Menus_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Menus_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Menus_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Menus_DISPINTERFACE_DEFINED__ */


#ifndef __Menu_DISPINTERFACE_DEFINED__
#define __Menu_DISPINTERFACE_DEFINED__

/* dispinterface Menu */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_Menu;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00020866-0000-0000-C000-000000000046")
    Menu : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct MenuVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Menu * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Menu * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Menu * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Menu * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Menu * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Menu * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Menu * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } MenuVtbl;

    interface Menu
    {
        CONST_VTBL struct MenuVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Menu_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Menu_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Menu_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Menu_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Menu_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Menu_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Menu_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Menu_DISPINTERFACE_DEFINED__ */


#ifndef __MenuItems_DISPINTERFACE_DEFINED__
#define __MenuItems_DISPINTERFACE_DEFINED__

/* dispinterface MenuItems */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_MenuItems;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00020867-0000-0000-C000-000000000046")
    MenuItems : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct MenuItemsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            MenuItems * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            MenuItems * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            MenuItems * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            MenuItems * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            MenuItems * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            MenuItems * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            MenuItems * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } MenuItemsVtbl;

    interface MenuItems
    {
        CONST_VTBL struct MenuItemsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define MenuItems_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define MenuItems_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define MenuItems_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define MenuItems_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define MenuItems_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define MenuItems_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define MenuItems_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __MenuItems_DISPINTERFACE_DEFINED__ */


#ifndef __MenuItem_DISPINTERFACE_DEFINED__
#define __MenuItem_DISPINTERFACE_DEFINED__

/* dispinterface MenuItem */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_MenuItem;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00020868-0000-0000-C000-000000000046")
    MenuItem : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct MenuItemVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            MenuItem * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            MenuItem * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            MenuItem * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            MenuItem * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            MenuItem * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            MenuItem * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            MenuItem * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } MenuItemVtbl;

    interface MenuItem
    {
        CONST_VTBL struct MenuItemVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define MenuItem_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define MenuItem_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define MenuItem_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define MenuItem_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define MenuItem_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define MenuItem_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define MenuItem_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __MenuItem_DISPINTERFACE_DEFINED__ */


#ifndef __Charts_DISPINTERFACE_DEFINED__
#define __Charts_DISPINTERFACE_DEFINED__

/* dispinterface Charts */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Charts;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002086D-0000-0000-C000-000000000046")
    Charts : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ChartsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Charts * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Charts * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Charts * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Charts * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Charts * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Charts * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Charts * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ChartsVtbl;

    interface Charts
    {
        CONST_VTBL struct ChartsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Charts_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Charts_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Charts_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Charts_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Charts_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Charts_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Charts_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Charts_DISPINTERFACE_DEFINED__ */


#ifndef __DrawingObjects_DISPINTERFACE_DEFINED__
#define __DrawingObjects_DISPINTERFACE_DEFINED__

/* dispinterface DrawingObjects */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_DrawingObjects;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002086F-0000-0000-C000-000000000046")
    DrawingObjects : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct DrawingObjectsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            DrawingObjects * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            DrawingObjects * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            DrawingObjects * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            DrawingObjects * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            DrawingObjects * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            DrawingObjects * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            DrawingObjects * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } DrawingObjectsVtbl;

    interface DrawingObjects
    {
        CONST_VTBL struct DrawingObjectsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define DrawingObjects_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define DrawingObjects_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define DrawingObjects_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define DrawingObjects_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define DrawingObjects_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define DrawingObjects_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define DrawingObjects_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __DrawingObjects_DISPINTERFACE_DEFINED__ */


#ifndef __PivotCache_DISPINTERFACE_DEFINED__
#define __PivotCache_DISPINTERFACE_DEFINED__

/* dispinterface PivotCache */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_PivotCache;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002441C-0000-0000-C000-000000000046")
    PivotCache : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct PivotCacheVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            PivotCache * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            PivotCache * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            PivotCache * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            PivotCache * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            PivotCache * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            PivotCache * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            PivotCache * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } PivotCacheVtbl;

    interface PivotCache
    {
        CONST_VTBL struct PivotCacheVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define PivotCache_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define PivotCache_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define PivotCache_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define PivotCache_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define PivotCache_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define PivotCache_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define PivotCache_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __PivotCache_DISPINTERFACE_DEFINED__ */


#ifndef __PivotCaches_DISPINTERFACE_DEFINED__
#define __PivotCaches_DISPINTERFACE_DEFINED__

/* dispinterface PivotCaches */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_PivotCaches;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002441D-0000-0000-C000-000000000046")
    PivotCaches : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct PivotCachesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            PivotCaches * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            PivotCaches * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            PivotCaches * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            PivotCaches * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            PivotCaches * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            PivotCaches * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            PivotCaches * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } PivotCachesVtbl;

    interface PivotCaches
    {
        CONST_VTBL struct PivotCachesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define PivotCaches_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define PivotCaches_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define PivotCaches_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define PivotCaches_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define PivotCaches_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define PivotCaches_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define PivotCaches_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __PivotCaches_DISPINTERFACE_DEFINED__ */


#ifndef __PivotFormula_DISPINTERFACE_DEFINED__
#define __PivotFormula_DISPINTERFACE_DEFINED__

/* dispinterface PivotFormula */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_PivotFormula;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002441E-0000-0000-C000-000000000046")
    PivotFormula : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct PivotFormulaVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            PivotFormula * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            PivotFormula * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            PivotFormula * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            PivotFormula * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            PivotFormula * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            PivotFormula * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            PivotFormula * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } PivotFormulaVtbl;

    interface PivotFormula
    {
        CONST_VTBL struct PivotFormulaVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define PivotFormula_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define PivotFormula_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define PivotFormula_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define PivotFormula_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define PivotFormula_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define PivotFormula_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define PivotFormula_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __PivotFormula_DISPINTERFACE_DEFINED__ */


#ifndef __PivotFormulas_DISPINTERFACE_DEFINED__
#define __PivotFormulas_DISPINTERFACE_DEFINED__

/* dispinterface PivotFormulas */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_PivotFormulas;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002441F-0000-0000-C000-000000000046")
    PivotFormulas : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct PivotFormulasVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            PivotFormulas * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            PivotFormulas * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            PivotFormulas * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            PivotFormulas * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            PivotFormulas * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            PivotFormulas * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            PivotFormulas * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } PivotFormulasVtbl;

    interface PivotFormulas
    {
        CONST_VTBL struct PivotFormulasVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define PivotFormulas_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define PivotFormulas_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define PivotFormulas_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define PivotFormulas_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define PivotFormulas_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define PivotFormulas_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define PivotFormulas_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __PivotFormulas_DISPINTERFACE_DEFINED__ */


#ifndef __PivotTable_DISPINTERFACE_DEFINED__
#define __PivotTable_DISPINTERFACE_DEFINED__

/* dispinterface PivotTable */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_PivotTable;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00020872-0000-0000-C000-000000000046")
    PivotTable : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct PivotTableVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            PivotTable * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            PivotTable * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            PivotTable * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            PivotTable * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            PivotTable * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            PivotTable * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            PivotTable * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } PivotTableVtbl;

    interface PivotTable
    {
        CONST_VTBL struct PivotTableVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define PivotTable_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define PivotTable_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define PivotTable_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define PivotTable_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define PivotTable_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define PivotTable_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define PivotTable_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __PivotTable_DISPINTERFACE_DEFINED__ */


#ifndef __PivotTables_DISPINTERFACE_DEFINED__
#define __PivotTables_DISPINTERFACE_DEFINED__

/* dispinterface PivotTables */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_PivotTables;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00020873-0000-0000-C000-000000000046")
    PivotTables : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct PivotTablesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            PivotTables * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            PivotTables * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            PivotTables * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            PivotTables * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            PivotTables * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            PivotTables * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            PivotTables * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } PivotTablesVtbl;

    interface PivotTables
    {
        CONST_VTBL struct PivotTablesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define PivotTables_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define PivotTables_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define PivotTables_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define PivotTables_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define PivotTables_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define PivotTables_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define PivotTables_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __PivotTables_DISPINTERFACE_DEFINED__ */


#ifndef __PivotField_DISPINTERFACE_DEFINED__
#define __PivotField_DISPINTERFACE_DEFINED__

/* dispinterface PivotField */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_PivotField;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00020874-0000-0000-C000-000000000046")
    PivotField : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct PivotFieldVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            PivotField * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            PivotField * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            PivotField * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            PivotField * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            PivotField * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            PivotField * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            PivotField * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } PivotFieldVtbl;

    interface PivotField
    {
        CONST_VTBL struct PivotFieldVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define PivotField_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define PivotField_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define PivotField_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define PivotField_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define PivotField_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define PivotField_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define PivotField_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __PivotField_DISPINTERFACE_DEFINED__ */


#ifndef __PivotFields_DISPINTERFACE_DEFINED__
#define __PivotFields_DISPINTERFACE_DEFINED__

/* dispinterface PivotFields */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_PivotFields;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00020875-0000-0000-C000-000000000046")
    PivotFields : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct PivotFieldsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            PivotFields * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            PivotFields * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            PivotFields * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            PivotFields * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            PivotFields * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            PivotFields * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            PivotFields * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } PivotFieldsVtbl;

    interface PivotFields
    {
        CONST_VTBL struct PivotFieldsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define PivotFields_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define PivotFields_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define PivotFields_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define PivotFields_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define PivotFields_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define PivotFields_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define PivotFields_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __PivotFields_DISPINTERFACE_DEFINED__ */


#ifndef __CalculatedFields_DISPINTERFACE_DEFINED__
#define __CalculatedFields_DISPINTERFACE_DEFINED__

/* dispinterface CalculatedFields */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_CalculatedFields;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024420-0000-0000-C000-000000000046")
    CalculatedFields : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct CalculatedFieldsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            CalculatedFields * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            CalculatedFields * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            CalculatedFields * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            CalculatedFields * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            CalculatedFields * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            CalculatedFields * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            CalculatedFields * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } CalculatedFieldsVtbl;

    interface CalculatedFields
    {
        CONST_VTBL struct CalculatedFieldsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define CalculatedFields_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define CalculatedFields_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define CalculatedFields_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define CalculatedFields_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define CalculatedFields_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define CalculatedFields_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define CalculatedFields_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __CalculatedFields_DISPINTERFACE_DEFINED__ */


#ifndef __PivotItem_DISPINTERFACE_DEFINED__
#define __PivotItem_DISPINTERFACE_DEFINED__

/* dispinterface PivotItem */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_PivotItem;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00020876-0000-0000-C000-000000000046")
    PivotItem : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct PivotItemVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            PivotItem * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            PivotItem * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            PivotItem * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            PivotItem * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            PivotItem * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            PivotItem * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            PivotItem * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } PivotItemVtbl;

    interface PivotItem
    {
        CONST_VTBL struct PivotItemVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define PivotItem_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define PivotItem_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define PivotItem_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define PivotItem_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define PivotItem_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define PivotItem_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define PivotItem_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __PivotItem_DISPINTERFACE_DEFINED__ */


#ifndef __PivotItems_DISPINTERFACE_DEFINED__
#define __PivotItems_DISPINTERFACE_DEFINED__

/* dispinterface PivotItems */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_PivotItems;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00020877-0000-0000-C000-000000000046")
    PivotItems : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct PivotItemsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            PivotItems * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            PivotItems * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            PivotItems * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            PivotItems * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            PivotItems * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            PivotItems * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            PivotItems * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } PivotItemsVtbl;

    interface PivotItems
    {
        CONST_VTBL struct PivotItemsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define PivotItems_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define PivotItems_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define PivotItems_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define PivotItems_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define PivotItems_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define PivotItems_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define PivotItems_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __PivotItems_DISPINTERFACE_DEFINED__ */


#ifndef __CalculatedItems_DISPINTERFACE_DEFINED__
#define __CalculatedItems_DISPINTERFACE_DEFINED__

/* dispinterface CalculatedItems */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_CalculatedItems;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024421-0000-0000-C000-000000000046")
    CalculatedItems : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct CalculatedItemsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            CalculatedItems * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            CalculatedItems * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            CalculatedItems * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            CalculatedItems * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            CalculatedItems * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            CalculatedItems * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            CalculatedItems * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } CalculatedItemsVtbl;

    interface CalculatedItems
    {
        CONST_VTBL struct CalculatedItemsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define CalculatedItems_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define CalculatedItems_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define CalculatedItems_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define CalculatedItems_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define CalculatedItems_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define CalculatedItems_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define CalculatedItems_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __CalculatedItems_DISPINTERFACE_DEFINED__ */


#ifndef __Characters_DISPINTERFACE_DEFINED__
#define __Characters_DISPINTERFACE_DEFINED__

/* dispinterface Characters */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Characters;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00020878-0000-0000-C000-000000000046")
    Characters : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct CharactersVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Characters * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Characters * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Characters * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Characters * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Characters * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Characters * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Characters * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } CharactersVtbl;

    interface Characters
    {
        CONST_VTBL struct CharactersVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Characters_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Characters_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Characters_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Characters_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Characters_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Characters_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Characters_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Characters_DISPINTERFACE_DEFINED__ */


#ifndef __Dialogs_DISPINTERFACE_DEFINED__
#define __Dialogs_DISPINTERFACE_DEFINED__

/* dispinterface Dialogs */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Dialogs;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00020879-0000-0000-C000-000000000046")
    Dialogs : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct DialogsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Dialogs * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Dialogs * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Dialogs * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Dialogs * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Dialogs * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Dialogs * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Dialogs * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } DialogsVtbl;

    interface Dialogs
    {
        CONST_VTBL struct DialogsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Dialogs_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Dialogs_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Dialogs_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Dialogs_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Dialogs_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Dialogs_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Dialogs_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Dialogs_DISPINTERFACE_DEFINED__ */


#ifndef __Dialog_DISPINTERFACE_DEFINED__
#define __Dialog_DISPINTERFACE_DEFINED__

/* dispinterface Dialog */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Dialog;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002087A-0000-0000-C000-000000000046")
    Dialog : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct DialogVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Dialog * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Dialog * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Dialog * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Dialog * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Dialog * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Dialog * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Dialog * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } DialogVtbl;

    interface Dialog
    {
        CONST_VTBL struct DialogVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Dialog_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Dialog_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Dialog_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Dialog_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Dialog_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Dialog_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Dialog_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Dialog_DISPINTERFACE_DEFINED__ */


#ifndef __SoundNote_DISPINTERFACE_DEFINED__
#define __SoundNote_DISPINTERFACE_DEFINED__

/* dispinterface SoundNote */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_SoundNote;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002087B-0000-0000-C000-000000000046")
    SoundNote : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct SoundNoteVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            SoundNote * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            SoundNote * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            SoundNote * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            SoundNote * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            SoundNote * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            SoundNote * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            SoundNote * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } SoundNoteVtbl;

    interface SoundNote
    {
        CONST_VTBL struct SoundNoteVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define SoundNote_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define SoundNote_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define SoundNote_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define SoundNote_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define SoundNote_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define SoundNote_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define SoundNote_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __SoundNote_DISPINTERFACE_DEFINED__ */


#ifndef __Button_DISPINTERFACE_DEFINED__
#define __Button_DISPINTERFACE_DEFINED__

/* dispinterface Button */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_Button;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002087D-0000-0000-C000-000000000046")
    Button : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ButtonVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Button * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Button * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Button * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Button * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Button * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Button * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Button * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ButtonVtbl;

    interface Button
    {
        CONST_VTBL struct ButtonVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Button_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Button_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Button_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Button_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Button_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Button_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Button_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Button_DISPINTERFACE_DEFINED__ */


#ifndef __Buttons_DISPINTERFACE_DEFINED__
#define __Buttons_DISPINTERFACE_DEFINED__

/* dispinterface Buttons */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_Buttons;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002087E-0000-0000-C000-000000000046")
    Buttons : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ButtonsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Buttons * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Buttons * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Buttons * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Buttons * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Buttons * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Buttons * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Buttons * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ButtonsVtbl;

    interface Buttons
    {
        CONST_VTBL struct ButtonsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Buttons_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Buttons_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Buttons_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Buttons_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Buttons_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Buttons_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Buttons_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Buttons_DISPINTERFACE_DEFINED__ */


#ifndef __CheckBox_DISPINTERFACE_DEFINED__
#define __CheckBox_DISPINTERFACE_DEFINED__

/* dispinterface CheckBox */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_CheckBox;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002087F-0000-0000-C000-000000000046")
    CheckBox : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct CheckBoxVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            CheckBox * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            CheckBox * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            CheckBox * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            CheckBox * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            CheckBox * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            CheckBox * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            CheckBox * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } CheckBoxVtbl;

    interface CheckBox
    {
        CONST_VTBL struct CheckBoxVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define CheckBox_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define CheckBox_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define CheckBox_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define CheckBox_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define CheckBox_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define CheckBox_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define CheckBox_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __CheckBox_DISPINTERFACE_DEFINED__ */


#ifndef __CheckBoxes_DISPINTERFACE_DEFINED__
#define __CheckBoxes_DISPINTERFACE_DEFINED__

/* dispinterface CheckBoxes */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_CheckBoxes;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00020880-0000-0000-C000-000000000046")
    CheckBoxes : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct CheckBoxesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            CheckBoxes * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            CheckBoxes * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            CheckBoxes * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            CheckBoxes * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            CheckBoxes * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            CheckBoxes * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            CheckBoxes * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } CheckBoxesVtbl;

    interface CheckBoxes
    {
        CONST_VTBL struct CheckBoxesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define CheckBoxes_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define CheckBoxes_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define CheckBoxes_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define CheckBoxes_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define CheckBoxes_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define CheckBoxes_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define CheckBoxes_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __CheckBoxes_DISPINTERFACE_DEFINED__ */


#ifndef __OptionButton_DISPINTERFACE_DEFINED__
#define __OptionButton_DISPINTERFACE_DEFINED__

/* dispinterface OptionButton */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_OptionButton;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00020881-0000-0000-C000-000000000046")
    OptionButton : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct OptionButtonVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            OptionButton * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            OptionButton * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            OptionButton * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            OptionButton * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            OptionButton * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            OptionButton * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            OptionButton * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } OptionButtonVtbl;

    interface OptionButton
    {
        CONST_VTBL struct OptionButtonVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define OptionButton_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define OptionButton_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define OptionButton_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define OptionButton_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define OptionButton_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define OptionButton_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define OptionButton_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __OptionButton_DISPINTERFACE_DEFINED__ */


#ifndef __OptionButtons_DISPINTERFACE_DEFINED__
#define __OptionButtons_DISPINTERFACE_DEFINED__

/* dispinterface OptionButtons */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_OptionButtons;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00020882-0000-0000-C000-000000000046")
    OptionButtons : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct OptionButtonsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            OptionButtons * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            OptionButtons * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            OptionButtons * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            OptionButtons * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            OptionButtons * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            OptionButtons * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            OptionButtons * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } OptionButtonsVtbl;

    interface OptionButtons
    {
        CONST_VTBL struct OptionButtonsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define OptionButtons_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define OptionButtons_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define OptionButtons_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define OptionButtons_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define OptionButtons_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define OptionButtons_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define OptionButtons_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __OptionButtons_DISPINTERFACE_DEFINED__ */


#ifndef __EditBox_DISPINTERFACE_DEFINED__
#define __EditBox_DISPINTERFACE_DEFINED__

/* dispinterface EditBox */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_EditBox;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00020883-0000-0000-C000-000000000046")
    EditBox : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct EditBoxVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            EditBox * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            EditBox * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            EditBox * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            EditBox * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            EditBox * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            EditBox * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            EditBox * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } EditBoxVtbl;

    interface EditBox
    {
        CONST_VTBL struct EditBoxVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define EditBox_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define EditBox_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define EditBox_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define EditBox_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define EditBox_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define EditBox_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define EditBox_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __EditBox_DISPINTERFACE_DEFINED__ */


#ifndef __EditBoxes_DISPINTERFACE_DEFINED__
#define __EditBoxes_DISPINTERFACE_DEFINED__

/* dispinterface EditBoxes */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_EditBoxes;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00020884-0000-0000-C000-000000000046")
    EditBoxes : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct EditBoxesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            EditBoxes * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            EditBoxes * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            EditBoxes * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            EditBoxes * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            EditBoxes * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            EditBoxes * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            EditBoxes * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } EditBoxesVtbl;

    interface EditBoxes
    {
        CONST_VTBL struct EditBoxesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define EditBoxes_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define EditBoxes_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define EditBoxes_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define EditBoxes_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define EditBoxes_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define EditBoxes_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define EditBoxes_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __EditBoxes_DISPINTERFACE_DEFINED__ */


#ifndef __ScrollBar_DISPINTERFACE_DEFINED__
#define __ScrollBar_DISPINTERFACE_DEFINED__

/* dispinterface ScrollBar */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_ScrollBar;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00020885-0000-0000-C000-000000000046")
    ScrollBar : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ScrollBarVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ScrollBar * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ScrollBar * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ScrollBar * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ScrollBar * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ScrollBar * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ScrollBar * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ScrollBar * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ScrollBarVtbl;

    interface ScrollBar
    {
        CONST_VTBL struct ScrollBarVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ScrollBar_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ScrollBar_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ScrollBar_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ScrollBar_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ScrollBar_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ScrollBar_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ScrollBar_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __ScrollBar_DISPINTERFACE_DEFINED__ */


#ifndef __ScrollBars_DISPINTERFACE_DEFINED__
#define __ScrollBars_DISPINTERFACE_DEFINED__

/* dispinterface ScrollBars */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_ScrollBars;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00020886-0000-0000-C000-000000000046")
    ScrollBars : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ScrollBarsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ScrollBars * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ScrollBars * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ScrollBars * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ScrollBars * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ScrollBars * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ScrollBars * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ScrollBars * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ScrollBarsVtbl;

    interface ScrollBars
    {
        CONST_VTBL struct ScrollBarsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ScrollBars_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ScrollBars_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ScrollBars_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ScrollBars_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ScrollBars_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ScrollBars_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ScrollBars_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __ScrollBars_DISPINTERFACE_DEFINED__ */


#ifndef __ListBox_DISPINTERFACE_DEFINED__
#define __ListBox_DISPINTERFACE_DEFINED__

/* dispinterface ListBox */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_ListBox;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00020887-0000-0000-C000-000000000046")
    ListBox : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ListBoxVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ListBox * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ListBox * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ListBox * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ListBox * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ListBox * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ListBox * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ListBox * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ListBoxVtbl;

    interface ListBox
    {
        CONST_VTBL struct ListBoxVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ListBox_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ListBox_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ListBox_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ListBox_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ListBox_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ListBox_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ListBox_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __ListBox_DISPINTERFACE_DEFINED__ */


#ifndef __ListBoxes_DISPINTERFACE_DEFINED__
#define __ListBoxes_DISPINTERFACE_DEFINED__

/* dispinterface ListBoxes */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_ListBoxes;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00020888-0000-0000-C000-000000000046")
    ListBoxes : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ListBoxesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ListBoxes * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ListBoxes * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ListBoxes * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ListBoxes * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ListBoxes * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ListBoxes * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ListBoxes * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ListBoxesVtbl;

    interface ListBoxes
    {
        CONST_VTBL struct ListBoxesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ListBoxes_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ListBoxes_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ListBoxes_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ListBoxes_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ListBoxes_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ListBoxes_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ListBoxes_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __ListBoxes_DISPINTERFACE_DEFINED__ */


#ifndef __GroupBox_DISPINTERFACE_DEFINED__
#define __GroupBox_DISPINTERFACE_DEFINED__

/* dispinterface GroupBox */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_GroupBox;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00020889-0000-0000-C000-000000000046")
    GroupBox : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct GroupBoxVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            GroupBox * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            GroupBox * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            GroupBox * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            GroupBox * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            GroupBox * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            GroupBox * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            GroupBox * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } GroupBoxVtbl;

    interface GroupBox
    {
        CONST_VTBL struct GroupBoxVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define GroupBox_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define GroupBox_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define GroupBox_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define GroupBox_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define GroupBox_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define GroupBox_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define GroupBox_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __GroupBox_DISPINTERFACE_DEFINED__ */


#ifndef __GroupBoxes_DISPINTERFACE_DEFINED__
#define __GroupBoxes_DISPINTERFACE_DEFINED__

/* dispinterface GroupBoxes */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_GroupBoxes;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002088A-0000-0000-C000-000000000046")
    GroupBoxes : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct GroupBoxesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            GroupBoxes * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            GroupBoxes * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            GroupBoxes * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            GroupBoxes * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            GroupBoxes * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            GroupBoxes * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            GroupBoxes * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } GroupBoxesVtbl;

    interface GroupBoxes
    {
        CONST_VTBL struct GroupBoxesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define GroupBoxes_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define GroupBoxes_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define GroupBoxes_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define GroupBoxes_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define GroupBoxes_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define GroupBoxes_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define GroupBoxes_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __GroupBoxes_DISPINTERFACE_DEFINED__ */


#ifndef __DropDown_DISPINTERFACE_DEFINED__
#define __DropDown_DISPINTERFACE_DEFINED__

/* dispinterface DropDown */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_DropDown;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002088B-0000-0000-C000-000000000046")
    DropDown : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct DropDownVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            DropDown * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            DropDown * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            DropDown * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            DropDown * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            DropDown * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            DropDown * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            DropDown * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } DropDownVtbl;

    interface DropDown
    {
        CONST_VTBL struct DropDownVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define DropDown_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define DropDown_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define DropDown_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define DropDown_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define DropDown_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define DropDown_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define DropDown_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __DropDown_DISPINTERFACE_DEFINED__ */


#ifndef __DropDowns_DISPINTERFACE_DEFINED__
#define __DropDowns_DISPINTERFACE_DEFINED__

/* dispinterface DropDowns */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_DropDowns;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002088C-0000-0000-C000-000000000046")
    DropDowns : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct DropDownsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            DropDowns * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            DropDowns * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            DropDowns * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            DropDowns * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            DropDowns * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            DropDowns * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            DropDowns * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } DropDownsVtbl;

    interface DropDowns
    {
        CONST_VTBL struct DropDownsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define DropDowns_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define DropDowns_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define DropDowns_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define DropDowns_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define DropDowns_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define DropDowns_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define DropDowns_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __DropDowns_DISPINTERFACE_DEFINED__ */


#ifndef __Spinner_DISPINTERFACE_DEFINED__
#define __Spinner_DISPINTERFACE_DEFINED__

/* dispinterface Spinner */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_Spinner;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002088D-0000-0000-C000-000000000046")
    Spinner : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct SpinnerVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Spinner * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Spinner * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Spinner * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Spinner * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Spinner * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Spinner * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Spinner * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } SpinnerVtbl;

    interface Spinner
    {
        CONST_VTBL struct SpinnerVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Spinner_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Spinner_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Spinner_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Spinner_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Spinner_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Spinner_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Spinner_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Spinner_DISPINTERFACE_DEFINED__ */


#ifndef __Spinners_DISPINTERFACE_DEFINED__
#define __Spinners_DISPINTERFACE_DEFINED__

/* dispinterface Spinners */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_Spinners;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002088E-0000-0000-C000-000000000046")
    Spinners : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct SpinnersVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Spinners * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Spinners * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Spinners * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Spinners * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Spinners * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Spinners * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Spinners * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } SpinnersVtbl;

    interface Spinners
    {
        CONST_VTBL struct SpinnersVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Spinners_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Spinners_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Spinners_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Spinners_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Spinners_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Spinners_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Spinners_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Spinners_DISPINTERFACE_DEFINED__ */


#ifndef __DialogFrame_DISPINTERFACE_DEFINED__
#define __DialogFrame_DISPINTERFACE_DEFINED__

/* dispinterface DialogFrame */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_DialogFrame;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002088F-0000-0000-C000-000000000046")
    DialogFrame : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct DialogFrameVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            DialogFrame * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            DialogFrame * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            DialogFrame * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            DialogFrame * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            DialogFrame * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            DialogFrame * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            DialogFrame * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } DialogFrameVtbl;

    interface DialogFrame
    {
        CONST_VTBL struct DialogFrameVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define DialogFrame_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define DialogFrame_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define DialogFrame_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define DialogFrame_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define DialogFrame_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define DialogFrame_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define DialogFrame_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __DialogFrame_DISPINTERFACE_DEFINED__ */


#ifndef __Label_DISPINTERFACE_DEFINED__
#define __Label_DISPINTERFACE_DEFINED__

/* dispinterface Label */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_Label;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00020890-0000-0000-C000-000000000046")
    Label : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct LabelVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Label * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Label * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Label * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Label * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Label * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Label * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Label * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } LabelVtbl;

    interface Label
    {
        CONST_VTBL struct LabelVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Label_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Label_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Label_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Label_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Label_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Label_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Label_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Label_DISPINTERFACE_DEFINED__ */


#ifndef __Labels_DISPINTERFACE_DEFINED__
#define __Labels_DISPINTERFACE_DEFINED__

/* dispinterface Labels */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_Labels;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00020891-0000-0000-C000-000000000046")
    Labels : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct LabelsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Labels * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Labels * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Labels * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Labels * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Labels * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Labels * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Labels * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } LabelsVtbl;

    interface Labels
    {
        CONST_VTBL struct LabelsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Labels_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Labels_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Labels_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Labels_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Labels_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Labels_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Labels_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Labels_DISPINTERFACE_DEFINED__ */


#ifndef __Panes_DISPINTERFACE_DEFINED__
#define __Panes_DISPINTERFACE_DEFINED__

/* dispinterface Panes */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Panes;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00020894-0000-0000-C000-000000000046")
    Panes : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct PanesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Panes * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Panes * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Panes * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Panes * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Panes * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Panes * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Panes * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } PanesVtbl;

    interface Panes
    {
        CONST_VTBL struct PanesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Panes_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Panes_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Panes_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Panes_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Panes_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Panes_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Panes_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Panes_DISPINTERFACE_DEFINED__ */


#ifndef __Pane_DISPINTERFACE_DEFINED__
#define __Pane_DISPINTERFACE_DEFINED__

/* dispinterface Pane */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Pane;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00020895-0000-0000-C000-000000000046")
    Pane : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct PaneVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Pane * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Pane * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Pane * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Pane * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Pane * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Pane * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Pane * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } PaneVtbl;

    interface Pane
    {
        CONST_VTBL struct PaneVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Pane_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Pane_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Pane_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Pane_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Pane_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Pane_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Pane_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Pane_DISPINTERFACE_DEFINED__ */


#ifndef __Scenarios_DISPINTERFACE_DEFINED__
#define __Scenarios_DISPINTERFACE_DEFINED__

/* dispinterface Scenarios */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Scenarios;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00020896-0000-0000-C000-000000000046")
    Scenarios : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ScenariosVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Scenarios * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Scenarios * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Scenarios * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Scenarios * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Scenarios * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Scenarios * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Scenarios * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ScenariosVtbl;

    interface Scenarios
    {
        CONST_VTBL struct ScenariosVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Scenarios_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Scenarios_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Scenarios_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Scenarios_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Scenarios_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Scenarios_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Scenarios_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Scenarios_DISPINTERFACE_DEFINED__ */


#ifndef __Scenario_DISPINTERFACE_DEFINED__
#define __Scenario_DISPINTERFACE_DEFINED__

/* dispinterface Scenario */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Scenario;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00020897-0000-0000-C000-000000000046")
    Scenario : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ScenarioVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Scenario * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Scenario * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Scenario * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Scenario * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Scenario * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Scenario * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Scenario * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ScenarioVtbl;

    interface Scenario
    {
        CONST_VTBL struct ScenarioVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Scenario_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Scenario_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Scenario_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Scenario_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Scenario_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Scenario_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Scenario_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Scenario_DISPINTERFACE_DEFINED__ */


#ifndef __GroupObject_DISPINTERFACE_DEFINED__
#define __GroupObject_DISPINTERFACE_DEFINED__

/* dispinterface GroupObject */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_GroupObject;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00020898-0000-0000-C000-000000000046")
    GroupObject : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct GroupObjectVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            GroupObject * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            GroupObject * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            GroupObject * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            GroupObject * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            GroupObject * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            GroupObject * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            GroupObject * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } GroupObjectVtbl;

    interface GroupObject
    {
        CONST_VTBL struct GroupObjectVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define GroupObject_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define GroupObject_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define GroupObject_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define GroupObject_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define GroupObject_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define GroupObject_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define GroupObject_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __GroupObject_DISPINTERFACE_DEFINED__ */


#ifndef __GroupObjects_DISPINTERFACE_DEFINED__
#define __GroupObjects_DISPINTERFACE_DEFINED__

/* dispinterface GroupObjects */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_GroupObjects;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00020899-0000-0000-C000-000000000046")
    GroupObjects : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct GroupObjectsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            GroupObjects * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            GroupObjects * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            GroupObjects * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            GroupObjects * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            GroupObjects * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            GroupObjects * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            GroupObjects * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } GroupObjectsVtbl;

    interface GroupObjects
    {
        CONST_VTBL struct GroupObjectsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define GroupObjects_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define GroupObjects_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define GroupObjects_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define GroupObjects_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define GroupObjects_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define GroupObjects_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define GroupObjects_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __GroupObjects_DISPINTERFACE_DEFINED__ */


#ifndef __Line_DISPINTERFACE_DEFINED__
#define __Line_DISPINTERFACE_DEFINED__

/* dispinterface Line */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_Line;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002089A-0000-0000-C000-000000000046")
    Line : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct LineVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Line * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Line * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Line * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Line * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Line * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Line * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Line * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } LineVtbl;

    interface Line
    {
        CONST_VTBL struct LineVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Line_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Line_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Line_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Line_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Line_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Line_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Line_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Line_DISPINTERFACE_DEFINED__ */


#ifndef __Lines_DISPINTERFACE_DEFINED__
#define __Lines_DISPINTERFACE_DEFINED__

/* dispinterface Lines */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_Lines;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002089B-0000-0000-C000-000000000046")
    Lines : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct LinesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Lines * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Lines * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Lines * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Lines * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Lines * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Lines * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Lines * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } LinesVtbl;

    interface Lines
    {
        CONST_VTBL struct LinesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Lines_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Lines_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Lines_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Lines_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Lines_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Lines_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Lines_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Lines_DISPINTERFACE_DEFINED__ */


#ifndef __Rectangle_DISPINTERFACE_DEFINED__
#define __Rectangle_DISPINTERFACE_DEFINED__

/* dispinterface Rectangle */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_Rectangle;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002089C-0000-0000-C000-000000000046")
    Rectangle : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct RectangleVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Rectangle * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Rectangle * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Rectangle * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Rectangle * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Rectangle * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Rectangle * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Rectangle * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } RectangleVtbl;

    interface Rectangle
    {
        CONST_VTBL struct RectangleVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Rectangle_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Rectangle_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Rectangle_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Rectangle_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Rectangle_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Rectangle_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Rectangle_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Rectangle_DISPINTERFACE_DEFINED__ */


#ifndef __Rectangles_DISPINTERFACE_DEFINED__
#define __Rectangles_DISPINTERFACE_DEFINED__

/* dispinterface Rectangles */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_Rectangles;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002089D-0000-0000-C000-000000000046")
    Rectangles : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct RectanglesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Rectangles * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Rectangles * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Rectangles * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Rectangles * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Rectangles * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Rectangles * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Rectangles * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } RectanglesVtbl;

    interface Rectangles
    {
        CONST_VTBL struct RectanglesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Rectangles_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Rectangles_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Rectangles_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Rectangles_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Rectangles_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Rectangles_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Rectangles_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Rectangles_DISPINTERFACE_DEFINED__ */


#ifndef __Oval_DISPINTERFACE_DEFINED__
#define __Oval_DISPINTERFACE_DEFINED__

/* dispinterface Oval */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_Oval;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002089E-0000-0000-C000-000000000046")
    Oval : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct OvalVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Oval * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Oval * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Oval * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Oval * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Oval * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Oval * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Oval * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } OvalVtbl;

    interface Oval
    {
        CONST_VTBL struct OvalVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Oval_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Oval_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Oval_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Oval_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Oval_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Oval_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Oval_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Oval_DISPINTERFACE_DEFINED__ */


#ifndef __Ovals_DISPINTERFACE_DEFINED__
#define __Ovals_DISPINTERFACE_DEFINED__

/* dispinterface Ovals */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_Ovals;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002089F-0000-0000-C000-000000000046")
    Ovals : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct OvalsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Ovals * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Ovals * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Ovals * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Ovals * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Ovals * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Ovals * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Ovals * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } OvalsVtbl;

    interface Ovals
    {
        CONST_VTBL struct OvalsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Ovals_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Ovals_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Ovals_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Ovals_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Ovals_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Ovals_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Ovals_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Ovals_DISPINTERFACE_DEFINED__ */


#ifndef __Arc_DISPINTERFACE_DEFINED__
#define __Arc_DISPINTERFACE_DEFINED__

/* dispinterface Arc */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_Arc;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000208A0-0000-0000-C000-000000000046")
    Arc : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ArcVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Arc * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Arc * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Arc * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Arc * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Arc * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Arc * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Arc * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ArcVtbl;

    interface Arc
    {
        CONST_VTBL struct ArcVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Arc_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Arc_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Arc_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Arc_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Arc_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Arc_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Arc_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Arc_DISPINTERFACE_DEFINED__ */


#ifndef __Arcs_DISPINTERFACE_DEFINED__
#define __Arcs_DISPINTERFACE_DEFINED__

/* dispinterface Arcs */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_Arcs;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000208A1-0000-0000-C000-000000000046")
    Arcs : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ArcsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Arcs * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Arcs * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Arcs * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Arcs * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Arcs * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Arcs * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Arcs * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ArcsVtbl;

    interface Arcs
    {
        CONST_VTBL struct ArcsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Arcs_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Arcs_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Arcs_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Arcs_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Arcs_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Arcs_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Arcs_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Arcs_DISPINTERFACE_DEFINED__ */


#ifndef __OLEObjectEvents_DISPINTERFACE_DEFINED__
#define __OLEObjectEvents_DISPINTERFACE_DEFINED__

/* dispinterface OLEObjectEvents */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_OLEObjectEvents;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024410-0000-0000-C000-000000000046")
    OLEObjectEvents : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct OLEObjectEventsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            OLEObjectEvents * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            OLEObjectEvents * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            OLEObjectEvents * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            OLEObjectEvents * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            OLEObjectEvents * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            OLEObjectEvents * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            OLEObjectEvents * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } OLEObjectEventsVtbl;

    interface OLEObjectEvents
    {
        CONST_VTBL struct OLEObjectEventsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define OLEObjectEvents_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define OLEObjectEvents_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define OLEObjectEvents_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define OLEObjectEvents_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define OLEObjectEvents_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define OLEObjectEvents_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define OLEObjectEvents_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __OLEObjectEvents_DISPINTERFACE_DEFINED__ */


#ifndef ___OLEObject_DISPINTERFACE_DEFINED__
#define ___OLEObject_DISPINTERFACE_DEFINED__

/* dispinterface _OLEObject */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID__OLEObject;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000208A2-0000-0000-C000-000000000046")
    _OLEObject : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct _OLEObjectVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            _OLEObject * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            _OLEObject * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            _OLEObject * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            _OLEObject * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            _OLEObject * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            _OLEObject * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            _OLEObject * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } _OLEObjectVtbl;

    interface _OLEObject
    {
        CONST_VTBL struct _OLEObjectVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define _OLEObject_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define _OLEObject_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define _OLEObject_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define _OLEObject_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define _OLEObject_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define _OLEObject_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define _OLEObject_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* ___OLEObject_DISPINTERFACE_DEFINED__ */


#ifndef __OLEObjects_DISPINTERFACE_DEFINED__
#define __OLEObjects_DISPINTERFACE_DEFINED__

/* dispinterface OLEObjects */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_OLEObjects;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000208A3-0000-0000-C000-000000000046")
    OLEObjects : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct OLEObjectsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            OLEObjects * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            OLEObjects * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            OLEObjects * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            OLEObjects * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            OLEObjects * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            OLEObjects * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            OLEObjects * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } OLEObjectsVtbl;

    interface OLEObjects
    {
        CONST_VTBL struct OLEObjectsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define OLEObjects_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define OLEObjects_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define OLEObjects_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define OLEObjects_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define OLEObjects_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define OLEObjects_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define OLEObjects_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __OLEObjects_DISPINTERFACE_DEFINED__ */


#ifndef __TextBox_DISPINTERFACE_DEFINED__
#define __TextBox_DISPINTERFACE_DEFINED__

/* dispinterface TextBox */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_TextBox;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000208A4-0000-0000-C000-000000000046")
    TextBox : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct TextBoxVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            TextBox * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            TextBox * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            TextBox * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            TextBox * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            TextBox * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            TextBox * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            TextBox * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } TextBoxVtbl;

    interface TextBox
    {
        CONST_VTBL struct TextBoxVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define TextBox_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define TextBox_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define TextBox_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define TextBox_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define TextBox_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define TextBox_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define TextBox_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __TextBox_DISPINTERFACE_DEFINED__ */


#ifndef __TextBoxes_DISPINTERFACE_DEFINED__
#define __TextBoxes_DISPINTERFACE_DEFINED__

/* dispinterface TextBoxes */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_TextBoxes;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000208A5-0000-0000-C000-000000000046")
    TextBoxes : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct TextBoxesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            TextBoxes * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            TextBoxes * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            TextBoxes * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            TextBoxes * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            TextBoxes * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            TextBoxes * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            TextBoxes * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } TextBoxesVtbl;

    interface TextBoxes
    {
        CONST_VTBL struct TextBoxesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define TextBoxes_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define TextBoxes_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define TextBoxes_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define TextBoxes_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define TextBoxes_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define TextBoxes_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define TextBoxes_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __TextBoxes_DISPINTERFACE_DEFINED__ */


#ifndef __Picture_DISPINTERFACE_DEFINED__
#define __Picture_DISPINTERFACE_DEFINED__

/* dispinterface Picture */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_Picture;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000208A6-0000-0000-C000-000000000046")
    Picture : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct PictureVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Picture * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Picture * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Picture * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Picture * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Picture * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Picture * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Picture * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } PictureVtbl;

    interface Picture
    {
        CONST_VTBL struct PictureVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Picture_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Picture_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Picture_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Picture_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Picture_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Picture_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Picture_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Picture_DISPINTERFACE_DEFINED__ */


#ifndef __Pictures_DISPINTERFACE_DEFINED__
#define __Pictures_DISPINTERFACE_DEFINED__

/* dispinterface Pictures */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_Pictures;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000208A7-0000-0000-C000-000000000046")
    Pictures : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct PicturesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Pictures * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Pictures * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Pictures * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Pictures * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Pictures * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Pictures * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Pictures * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } PicturesVtbl;

    interface Pictures
    {
        CONST_VTBL struct PicturesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Pictures_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Pictures_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Pictures_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Pictures_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Pictures_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Pictures_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Pictures_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Pictures_DISPINTERFACE_DEFINED__ */


#ifndef __Drawing_DISPINTERFACE_DEFINED__
#define __Drawing_DISPINTERFACE_DEFINED__

/* dispinterface Drawing */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_Drawing;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000208A8-0000-0000-C000-000000000046")
    Drawing : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct DrawingVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Drawing * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Drawing * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Drawing * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Drawing * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Drawing * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Drawing * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Drawing * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } DrawingVtbl;

    interface Drawing
    {
        CONST_VTBL struct DrawingVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Drawing_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Drawing_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Drawing_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Drawing_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Drawing_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Drawing_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Drawing_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Drawing_DISPINTERFACE_DEFINED__ */


#ifndef __Drawings_DISPINTERFACE_DEFINED__
#define __Drawings_DISPINTERFACE_DEFINED__

/* dispinterface Drawings */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_Drawings;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000208A9-0000-0000-C000-000000000046")
    Drawings : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct DrawingsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Drawings * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Drawings * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Drawings * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Drawings * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Drawings * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Drawings * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Drawings * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } DrawingsVtbl;

    interface Drawings
    {
        CONST_VTBL struct DrawingsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Drawings_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Drawings_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Drawings_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Drawings_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Drawings_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Drawings_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Drawings_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Drawings_DISPINTERFACE_DEFINED__ */


#ifndef __RoutingSlip_DISPINTERFACE_DEFINED__
#define __RoutingSlip_DISPINTERFACE_DEFINED__

/* dispinterface RoutingSlip */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_RoutingSlip;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000208AA-0000-0000-C000-000000000046")
    RoutingSlip : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct RoutingSlipVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            RoutingSlip * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            RoutingSlip * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            RoutingSlip * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            RoutingSlip * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            RoutingSlip * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            RoutingSlip * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            RoutingSlip * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } RoutingSlipVtbl;

    interface RoutingSlip
    {
        CONST_VTBL struct RoutingSlipVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define RoutingSlip_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define RoutingSlip_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define RoutingSlip_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define RoutingSlip_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define RoutingSlip_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define RoutingSlip_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define RoutingSlip_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __RoutingSlip_DISPINTERFACE_DEFINED__ */


#ifndef __Outline_DISPINTERFACE_DEFINED__
#define __Outline_DISPINTERFACE_DEFINED__

/* dispinterface Outline */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Outline;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000208AB-0000-0000-C000-000000000046")
    Outline : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct OutlineVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Outline * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Outline * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Outline * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Outline * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Outline * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Outline * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Outline * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } OutlineVtbl;

    interface Outline
    {
        CONST_VTBL struct OutlineVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Outline_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Outline_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Outline_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Outline_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Outline_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Outline_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Outline_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Outline_DISPINTERFACE_DEFINED__ */


#ifndef __Module_DISPINTERFACE_DEFINED__
#define __Module_DISPINTERFACE_DEFINED__

/* dispinterface Module */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_Module;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000208AD-0000-0000-C000-000000000046")
    Module : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ModuleVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Module * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Module * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Module * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Module * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Module * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Module * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Module * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ModuleVtbl;

    interface Module
    {
        CONST_VTBL struct ModuleVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Module_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Module_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Module_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Module_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Module_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Module_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Module_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Module_DISPINTERFACE_DEFINED__ */


#ifndef __Modules_DISPINTERFACE_DEFINED__
#define __Modules_DISPINTERFACE_DEFINED__

/* dispinterface Modules */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_Modules;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000208AE-0000-0000-C000-000000000046")
    Modules : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ModulesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Modules * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Modules * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Modules * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Modules * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Modules * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Modules * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Modules * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ModulesVtbl;

    interface Modules
    {
        CONST_VTBL struct ModulesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Modules_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Modules_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Modules_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Modules_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Modules_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Modules_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Modules_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Modules_DISPINTERFACE_DEFINED__ */


#ifndef __DialogSheet_DISPINTERFACE_DEFINED__
#define __DialogSheet_DISPINTERFACE_DEFINED__

/* dispinterface DialogSheet */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_DialogSheet;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000208AF-0000-0000-C000-000000000046")
    DialogSheet : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct DialogSheetVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            DialogSheet * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            DialogSheet * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            DialogSheet * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            DialogSheet * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            DialogSheet * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            DialogSheet * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            DialogSheet * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } DialogSheetVtbl;

    interface DialogSheet
    {
        CONST_VTBL struct DialogSheetVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define DialogSheet_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define DialogSheet_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define DialogSheet_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define DialogSheet_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define DialogSheet_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define DialogSheet_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define DialogSheet_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __DialogSheet_DISPINTERFACE_DEFINED__ */


#ifndef __DialogSheets_DISPINTERFACE_DEFINED__
#define __DialogSheets_DISPINTERFACE_DEFINED__

/* dispinterface DialogSheets */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_DialogSheets;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000208B0-0000-0000-C000-000000000046")
    DialogSheets : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct DialogSheetsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            DialogSheets * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            DialogSheets * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            DialogSheets * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            DialogSheets * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            DialogSheets * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            DialogSheets * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            DialogSheets * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } DialogSheetsVtbl;

    interface DialogSheets
    {
        CONST_VTBL struct DialogSheetsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define DialogSheets_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define DialogSheets_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define DialogSheets_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define DialogSheets_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define DialogSheets_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define DialogSheets_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define DialogSheets_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __DialogSheets_DISPINTERFACE_DEFINED__ */


#ifndef __Worksheets_DISPINTERFACE_DEFINED__
#define __Worksheets_DISPINTERFACE_DEFINED__

/* dispinterface Worksheets */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Worksheets;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000208B1-0000-0000-C000-000000000046")
    Worksheets : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct WorksheetsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Worksheets * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Worksheets * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Worksheets * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Worksheets * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Worksheets * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Worksheets * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Worksheets * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } WorksheetsVtbl;

    interface Worksheets
    {
        CONST_VTBL struct WorksheetsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Worksheets_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Worksheets_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Worksheets_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Worksheets_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Worksheets_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Worksheets_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Worksheets_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Worksheets_DISPINTERFACE_DEFINED__ */


#ifndef __PageSetup_DISPINTERFACE_DEFINED__
#define __PageSetup_DISPINTERFACE_DEFINED__

/* dispinterface PageSetup */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_PageSetup;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000208B4-0000-0000-C000-000000000046")
    PageSetup : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct PageSetupVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            PageSetup * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            PageSetup * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            PageSetup * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            PageSetup * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            PageSetup * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            PageSetup * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            PageSetup * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } PageSetupVtbl;

    interface PageSetup
    {
        CONST_VTBL struct PageSetupVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define PageSetup_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define PageSetup_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define PageSetup_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define PageSetup_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define PageSetup_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define PageSetup_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define PageSetup_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __PageSetup_DISPINTERFACE_DEFINED__ */


#ifndef __Names_DISPINTERFACE_DEFINED__
#define __Names_DISPINTERFACE_DEFINED__

/* dispinterface Names */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Names;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000208B8-0000-0000-C000-000000000046")
    Names : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct NamesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Names * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Names * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Names * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Names * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Names * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Names * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Names * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } NamesVtbl;

    interface Names
    {
        CONST_VTBL struct NamesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Names_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Names_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Names_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Names_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Names_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Names_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Names_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Names_DISPINTERFACE_DEFINED__ */


#ifndef __Name_DISPINTERFACE_DEFINED__
#define __Name_DISPINTERFACE_DEFINED__

/* dispinterface Name */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Name;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000208B9-0000-0000-C000-000000000046")
    Name : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct NameVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Name * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Name * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Name * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Name * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Name * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Name * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Name * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } NameVtbl;

    interface Name
    {
        CONST_VTBL struct NameVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Name_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Name_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Name_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Name_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Name_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Name_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Name_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Name_DISPINTERFACE_DEFINED__ */


#ifndef __ChartObject_DISPINTERFACE_DEFINED__
#define __ChartObject_DISPINTERFACE_DEFINED__

/* dispinterface ChartObject */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_ChartObject;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000208CF-0000-0000-C000-000000000046")
    ChartObject : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ChartObjectVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ChartObject * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ChartObject * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ChartObject * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ChartObject * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ChartObject * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ChartObject * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ChartObject * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ChartObjectVtbl;

    interface ChartObject
    {
        CONST_VTBL struct ChartObjectVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ChartObject_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ChartObject_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ChartObject_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ChartObject_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ChartObject_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ChartObject_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ChartObject_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __ChartObject_DISPINTERFACE_DEFINED__ */


#ifndef __ChartObjects_DISPINTERFACE_DEFINED__
#define __ChartObjects_DISPINTERFACE_DEFINED__

/* dispinterface ChartObjects */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_ChartObjects;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000208D0-0000-0000-C000-000000000046")
    ChartObjects : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ChartObjectsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ChartObjects * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ChartObjects * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ChartObjects * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ChartObjects * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ChartObjects * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ChartObjects * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ChartObjects * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ChartObjectsVtbl;

    interface ChartObjects
    {
        CONST_VTBL struct ChartObjectsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ChartObjects_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ChartObjects_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ChartObjects_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ChartObjects_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ChartObjects_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ChartObjects_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ChartObjects_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __ChartObjects_DISPINTERFACE_DEFINED__ */


#ifndef __Mailer_DISPINTERFACE_DEFINED__
#define __Mailer_DISPINTERFACE_DEFINED__

/* dispinterface Mailer */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Mailer;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000208D1-0000-0000-C000-000000000046")
    Mailer : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct MailerVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Mailer * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Mailer * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Mailer * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Mailer * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Mailer * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Mailer * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Mailer * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } MailerVtbl;

    interface Mailer
    {
        CONST_VTBL struct MailerVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Mailer_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Mailer_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Mailer_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Mailer_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Mailer_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Mailer_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Mailer_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Mailer_DISPINTERFACE_DEFINED__ */


#ifndef __CustomViews_DISPINTERFACE_DEFINED__
#define __CustomViews_DISPINTERFACE_DEFINED__

/* dispinterface CustomViews */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_CustomViews;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024422-0000-0000-C000-000000000046")
    CustomViews : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct CustomViewsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            CustomViews * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            CustomViews * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            CustomViews * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            CustomViews * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            CustomViews * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            CustomViews * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            CustomViews * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } CustomViewsVtbl;

    interface CustomViews
    {
        CONST_VTBL struct CustomViewsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define CustomViews_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define CustomViews_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define CustomViews_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define CustomViews_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define CustomViews_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define CustomViews_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define CustomViews_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __CustomViews_DISPINTERFACE_DEFINED__ */


#ifndef __CustomView_DISPINTERFACE_DEFINED__
#define __CustomView_DISPINTERFACE_DEFINED__

/* dispinterface CustomView */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_CustomView;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024423-0000-0000-C000-000000000046")
    CustomView : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct CustomViewVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            CustomView * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            CustomView * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            CustomView * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            CustomView * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            CustomView * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            CustomView * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            CustomView * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } CustomViewVtbl;

    interface CustomView
    {
        CONST_VTBL struct CustomViewVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define CustomView_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define CustomView_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define CustomView_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define CustomView_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define CustomView_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define CustomView_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define CustomView_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __CustomView_DISPINTERFACE_DEFINED__ */


#ifndef __FormatConditions_DISPINTERFACE_DEFINED__
#define __FormatConditions_DISPINTERFACE_DEFINED__

/* dispinterface FormatConditions */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_FormatConditions;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024424-0000-0000-C000-000000000046")
    FormatConditions : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct FormatConditionsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            FormatConditions * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            FormatConditions * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            FormatConditions * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            FormatConditions * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            FormatConditions * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            FormatConditions * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            FormatConditions * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } FormatConditionsVtbl;

    interface FormatConditions
    {
        CONST_VTBL struct FormatConditionsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define FormatConditions_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define FormatConditions_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define FormatConditions_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define FormatConditions_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define FormatConditions_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define FormatConditions_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define FormatConditions_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __FormatConditions_DISPINTERFACE_DEFINED__ */


#ifndef __FormatCondition_DISPINTERFACE_DEFINED__
#define __FormatCondition_DISPINTERFACE_DEFINED__

/* dispinterface FormatCondition */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_FormatCondition;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024425-0000-0000-C000-000000000046")
    FormatCondition : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct FormatConditionVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            FormatCondition * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            FormatCondition * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            FormatCondition * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            FormatCondition * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            FormatCondition * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            FormatCondition * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            FormatCondition * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } FormatConditionVtbl;

    interface FormatCondition
    {
        CONST_VTBL struct FormatConditionVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define FormatCondition_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define FormatCondition_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define FormatCondition_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define FormatCondition_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define FormatCondition_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define FormatCondition_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define FormatCondition_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __FormatCondition_DISPINTERFACE_DEFINED__ */


#ifndef __Comments_DISPINTERFACE_DEFINED__
#define __Comments_DISPINTERFACE_DEFINED__

/* dispinterface Comments */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Comments;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024426-0000-0000-C000-000000000046")
    Comments : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct CommentsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Comments * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Comments * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Comments * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Comments * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Comments * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Comments * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Comments * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } CommentsVtbl;

    interface Comments
    {
        CONST_VTBL struct CommentsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Comments_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Comments_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Comments_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Comments_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Comments_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Comments_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Comments_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Comments_DISPINTERFACE_DEFINED__ */


#ifndef __Comment_DISPINTERFACE_DEFINED__
#define __Comment_DISPINTERFACE_DEFINED__

/* dispinterface Comment */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Comment;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024427-0000-0000-C000-000000000046")
    Comment : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct CommentVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Comment * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Comment * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Comment * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Comment * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Comment * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Comment * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Comment * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } CommentVtbl;

    interface Comment
    {
        CONST_VTBL struct CommentVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Comment_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Comment_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Comment_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Comment_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Comment_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Comment_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Comment_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Comment_DISPINTERFACE_DEFINED__ */


#ifndef __RefreshEvents_DISPINTERFACE_DEFINED__
#define __RefreshEvents_DISPINTERFACE_DEFINED__

/* dispinterface RefreshEvents */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_RefreshEvents;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002441B-0000-0000-C000-000000000046")
    RefreshEvents : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct RefreshEventsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            RefreshEvents * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            RefreshEvents * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            RefreshEvents * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            RefreshEvents * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            RefreshEvents * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            RefreshEvents * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            RefreshEvents * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } RefreshEventsVtbl;

    interface RefreshEvents
    {
        CONST_VTBL struct RefreshEventsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define RefreshEvents_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define RefreshEvents_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define RefreshEvents_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define RefreshEvents_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define RefreshEvents_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define RefreshEvents_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define RefreshEvents_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __RefreshEvents_DISPINTERFACE_DEFINED__ */


#ifndef ___QueryTable_DISPINTERFACE_DEFINED__
#define ___QueryTable_DISPINTERFACE_DEFINED__

/* dispinterface _QueryTable */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID__QueryTable;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024428-0000-0000-C000-000000000046")
    _QueryTable : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct _QueryTableVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            _QueryTable * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            _QueryTable * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            _QueryTable * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            _QueryTable * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            _QueryTable * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            _QueryTable * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            _QueryTable * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } _QueryTableVtbl;

    interface _QueryTable
    {
        CONST_VTBL struct _QueryTableVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define _QueryTable_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define _QueryTable_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define _QueryTable_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define _QueryTable_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define _QueryTable_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define _QueryTable_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define _QueryTable_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* ___QueryTable_DISPINTERFACE_DEFINED__ */


#ifndef __QueryTables_DISPINTERFACE_DEFINED__
#define __QueryTables_DISPINTERFACE_DEFINED__

/* dispinterface QueryTables */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_QueryTables;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024429-0000-0000-C000-000000000046")
    QueryTables : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct QueryTablesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            QueryTables * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            QueryTables * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            QueryTables * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            QueryTables * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            QueryTables * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            QueryTables * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            QueryTables * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } QueryTablesVtbl;

    interface QueryTables
    {
        CONST_VTBL struct QueryTablesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define QueryTables_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define QueryTables_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define QueryTables_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define QueryTables_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define QueryTables_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define QueryTables_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define QueryTables_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __QueryTables_DISPINTERFACE_DEFINED__ */


#ifndef __Parameter_DISPINTERFACE_DEFINED__
#define __Parameter_DISPINTERFACE_DEFINED__

/* dispinterface Parameter */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Parameter;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002442A-0000-0000-C000-000000000046")
    Parameter : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ParameterVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Parameter * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Parameter * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Parameter * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Parameter * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Parameter * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Parameter * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Parameter * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ParameterVtbl;

    interface Parameter
    {
        CONST_VTBL struct ParameterVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Parameter_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Parameter_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Parameter_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Parameter_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Parameter_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Parameter_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Parameter_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Parameter_DISPINTERFACE_DEFINED__ */


#ifndef __Parameters_DISPINTERFACE_DEFINED__
#define __Parameters_DISPINTERFACE_DEFINED__

/* dispinterface Parameters */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Parameters;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002442B-0000-0000-C000-000000000046")
    Parameters : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ParametersVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Parameters * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Parameters * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Parameters * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Parameters * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Parameters * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Parameters * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Parameters * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ParametersVtbl;

    interface Parameters
    {
        CONST_VTBL struct ParametersVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Parameters_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Parameters_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Parameters_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Parameters_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Parameters_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Parameters_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Parameters_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Parameters_DISPINTERFACE_DEFINED__ */


#ifndef __ODBCError_DISPINTERFACE_DEFINED__
#define __ODBCError_DISPINTERFACE_DEFINED__

/* dispinterface ODBCError */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_ODBCError;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002442C-0000-0000-C000-000000000046")
    ODBCError : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ODBCErrorVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ODBCError * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ODBCError * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ODBCError * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ODBCError * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ODBCError * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ODBCError * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ODBCError * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ODBCErrorVtbl;

    interface ODBCError
    {
        CONST_VTBL struct ODBCErrorVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ODBCError_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ODBCError_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ODBCError_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ODBCError_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ODBCError_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ODBCError_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ODBCError_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __ODBCError_DISPINTERFACE_DEFINED__ */


#ifndef __ODBCErrors_DISPINTERFACE_DEFINED__
#define __ODBCErrors_DISPINTERFACE_DEFINED__

/* dispinterface ODBCErrors */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_ODBCErrors;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002442D-0000-0000-C000-000000000046")
    ODBCErrors : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ODBCErrorsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ODBCErrors * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ODBCErrors * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ODBCErrors * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ODBCErrors * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ODBCErrors * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ODBCErrors * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ODBCErrors * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ODBCErrorsVtbl;

    interface ODBCErrors
    {
        CONST_VTBL struct ODBCErrorsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ODBCErrors_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ODBCErrors_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ODBCErrors_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ODBCErrors_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ODBCErrors_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ODBCErrors_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ODBCErrors_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __ODBCErrors_DISPINTERFACE_DEFINED__ */


#ifndef __Validation_DISPINTERFACE_DEFINED__
#define __Validation_DISPINTERFACE_DEFINED__

/* dispinterface Validation */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Validation;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002442F-0000-0000-C000-000000000046")
    Validation : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ValidationVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Validation * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Validation * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Validation * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Validation * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Validation * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Validation * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Validation * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ValidationVtbl;

    interface Validation
    {
        CONST_VTBL struct ValidationVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Validation_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Validation_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Validation_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Validation_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Validation_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Validation_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Validation_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Validation_DISPINTERFACE_DEFINED__ */


#ifndef __Hyperlinks_DISPINTERFACE_DEFINED__
#define __Hyperlinks_DISPINTERFACE_DEFINED__

/* dispinterface Hyperlinks */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Hyperlinks;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024430-0000-0000-C000-000000000046")
    Hyperlinks : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct HyperlinksVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Hyperlinks * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Hyperlinks * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Hyperlinks * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Hyperlinks * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Hyperlinks * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Hyperlinks * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Hyperlinks * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } HyperlinksVtbl;

    interface Hyperlinks
    {
        CONST_VTBL struct HyperlinksVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Hyperlinks_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Hyperlinks_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Hyperlinks_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Hyperlinks_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Hyperlinks_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Hyperlinks_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Hyperlinks_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Hyperlinks_DISPINTERFACE_DEFINED__ */


#ifndef __Hyperlink_DISPINTERFACE_DEFINED__
#define __Hyperlink_DISPINTERFACE_DEFINED__

/* dispinterface Hyperlink */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Hyperlink;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024431-0000-0000-C000-000000000046")
    Hyperlink : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct HyperlinkVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Hyperlink * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Hyperlink * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Hyperlink * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Hyperlink * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Hyperlink * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Hyperlink * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Hyperlink * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } HyperlinkVtbl;

    interface Hyperlink
    {
        CONST_VTBL struct HyperlinkVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Hyperlink_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Hyperlink_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Hyperlink_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Hyperlink_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Hyperlink_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Hyperlink_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Hyperlink_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Hyperlink_DISPINTERFACE_DEFINED__ */


#ifndef __AutoFilter_DISPINTERFACE_DEFINED__
#define __AutoFilter_DISPINTERFACE_DEFINED__

/* dispinterface AutoFilter */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_AutoFilter;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024432-0000-0000-C000-000000000046")
    AutoFilter : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct AutoFilterVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            AutoFilter * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            AutoFilter * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            AutoFilter * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            AutoFilter * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            AutoFilter * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            AutoFilter * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            AutoFilter * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } AutoFilterVtbl;

    interface AutoFilter
    {
        CONST_VTBL struct AutoFilterVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define AutoFilter_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define AutoFilter_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define AutoFilter_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define AutoFilter_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define AutoFilter_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define AutoFilter_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define AutoFilter_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __AutoFilter_DISPINTERFACE_DEFINED__ */


#ifndef __Filters_DISPINTERFACE_DEFINED__
#define __Filters_DISPINTERFACE_DEFINED__

/* dispinterface Filters */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Filters;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024433-0000-0000-C000-000000000046")
    Filters : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct FiltersVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Filters * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Filters * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Filters * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Filters * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Filters * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Filters * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Filters * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } FiltersVtbl;

    interface Filters
    {
        CONST_VTBL struct FiltersVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Filters_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Filters_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Filters_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Filters_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Filters_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Filters_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Filters_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Filters_DISPINTERFACE_DEFINED__ */


#ifndef __Filter_DISPINTERFACE_DEFINED__
#define __Filter_DISPINTERFACE_DEFINED__

/* dispinterface Filter */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Filter;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024434-0000-0000-C000-000000000046")
    Filter : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct FilterVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Filter * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Filter * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Filter * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Filter * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Filter * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Filter * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Filter * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } FilterVtbl;

    interface Filter
    {
        CONST_VTBL struct FilterVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Filter_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Filter_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Filter_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Filter_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Filter_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Filter_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Filter_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Filter_DISPINTERFACE_DEFINED__ */


#ifndef __AutoCorrect_DISPINTERFACE_DEFINED__
#define __AutoCorrect_DISPINTERFACE_DEFINED__

/* dispinterface AutoCorrect */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_AutoCorrect;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000208D4-0000-0000-C000-000000000046")
    AutoCorrect : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct AutoCorrectVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            AutoCorrect * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            AutoCorrect * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            AutoCorrect * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            AutoCorrect * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            AutoCorrect * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            AutoCorrect * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            AutoCorrect * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } AutoCorrectVtbl;

    interface AutoCorrect
    {
        CONST_VTBL struct AutoCorrectVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define AutoCorrect_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define AutoCorrect_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define AutoCorrect_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define AutoCorrect_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define AutoCorrect_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define AutoCorrect_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define AutoCorrect_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __AutoCorrect_DISPINTERFACE_DEFINED__ */


#ifndef __Border_DISPINTERFACE_DEFINED__
#define __Border_DISPINTERFACE_DEFINED__

/* dispinterface Border */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Border;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00020854-0000-0000-C000-000000000046")
    Border : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct BorderVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Border * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Border * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Border * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Border * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Border * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Border * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Border * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } BorderVtbl;

    interface Border
    {
        CONST_VTBL struct BorderVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Border_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Border_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Border_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Border_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Border_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Border_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Border_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Border_DISPINTERFACE_DEFINED__ */


#ifndef __Interior_DISPINTERFACE_DEFINED__
#define __Interior_DISPINTERFACE_DEFINED__

/* dispinterface Interior */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Interior;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00020870-0000-0000-C000-000000000046")
    Interior : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct InteriorVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Interior * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Interior * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Interior * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Interior * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Interior * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Interior * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Interior * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } InteriorVtbl;

    interface Interior
    {
        CONST_VTBL struct InteriorVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Interior_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Interior_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Interior_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Interior_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Interior_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Interior_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Interior_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Interior_DISPINTERFACE_DEFINED__ */


#ifndef __ChartFillFormat_DISPINTERFACE_DEFINED__
#define __ChartFillFormat_DISPINTERFACE_DEFINED__

/* dispinterface ChartFillFormat */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_ChartFillFormat;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024435-0000-0000-C000-000000000046")
    ChartFillFormat : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ChartFillFormatVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ChartFillFormat * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ChartFillFormat * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ChartFillFormat * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ChartFillFormat * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ChartFillFormat * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ChartFillFormat * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ChartFillFormat * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ChartFillFormatVtbl;

    interface ChartFillFormat
    {
        CONST_VTBL struct ChartFillFormatVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ChartFillFormat_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ChartFillFormat_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ChartFillFormat_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ChartFillFormat_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ChartFillFormat_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ChartFillFormat_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ChartFillFormat_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __ChartFillFormat_DISPINTERFACE_DEFINED__ */


#ifndef __ChartColorFormat_DISPINTERFACE_DEFINED__
#define __ChartColorFormat_DISPINTERFACE_DEFINED__

/* dispinterface ChartColorFormat */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_ChartColorFormat;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024436-0000-0000-C000-000000000046")
    ChartColorFormat : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ChartColorFormatVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ChartColorFormat * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ChartColorFormat * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ChartColorFormat * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ChartColorFormat * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ChartColorFormat * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ChartColorFormat * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ChartColorFormat * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ChartColorFormatVtbl;

    interface ChartColorFormat
    {
        CONST_VTBL struct ChartColorFormatVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ChartColorFormat_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ChartColorFormat_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ChartColorFormat_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ChartColorFormat_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ChartColorFormat_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ChartColorFormat_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ChartColorFormat_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __ChartColorFormat_DISPINTERFACE_DEFINED__ */


#ifndef __Axis_DISPINTERFACE_DEFINED__
#define __Axis_DISPINTERFACE_DEFINED__

/* dispinterface Axis */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Axis;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00020848-0000-0000-C000-000000000046")
    Axis : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct AxisVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Axis * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Axis * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Axis * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Axis * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Axis * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Axis * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Axis * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } AxisVtbl;

    interface Axis
    {
        CONST_VTBL struct AxisVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Axis_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Axis_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Axis_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Axis_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Axis_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Axis_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Axis_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Axis_DISPINTERFACE_DEFINED__ */


#ifndef __ChartTitle_DISPINTERFACE_DEFINED__
#define __ChartTitle_DISPINTERFACE_DEFINED__

/* dispinterface ChartTitle */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_ChartTitle;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00020849-0000-0000-C000-000000000046")
    ChartTitle : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ChartTitleVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ChartTitle * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ChartTitle * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ChartTitle * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ChartTitle * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ChartTitle * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ChartTitle * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ChartTitle * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ChartTitleVtbl;

    interface ChartTitle
    {
        CONST_VTBL struct ChartTitleVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ChartTitle_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ChartTitle_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ChartTitle_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ChartTitle_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ChartTitle_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ChartTitle_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ChartTitle_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __ChartTitle_DISPINTERFACE_DEFINED__ */


#ifndef __AxisTitle_DISPINTERFACE_DEFINED__
#define __AxisTitle_DISPINTERFACE_DEFINED__

/* dispinterface AxisTitle */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_AxisTitle;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002084A-0000-0000-C000-000000000046")
    AxisTitle : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct AxisTitleVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            AxisTitle * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            AxisTitle * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            AxisTitle * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            AxisTitle * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            AxisTitle * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            AxisTitle * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            AxisTitle * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } AxisTitleVtbl;

    interface AxisTitle
    {
        CONST_VTBL struct AxisTitleVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define AxisTitle_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define AxisTitle_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define AxisTitle_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define AxisTitle_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define AxisTitle_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define AxisTitle_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define AxisTitle_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __AxisTitle_DISPINTERFACE_DEFINED__ */


#ifndef __ChartGroup_DISPINTERFACE_DEFINED__
#define __ChartGroup_DISPINTERFACE_DEFINED__

/* dispinterface ChartGroup */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_ChartGroup;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00020859-0000-0000-C000-000000000046")
    ChartGroup : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ChartGroupVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ChartGroup * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ChartGroup * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ChartGroup * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ChartGroup * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ChartGroup * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ChartGroup * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ChartGroup * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ChartGroupVtbl;

    interface ChartGroup
    {
        CONST_VTBL struct ChartGroupVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ChartGroup_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ChartGroup_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ChartGroup_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ChartGroup_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ChartGroup_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ChartGroup_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ChartGroup_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __ChartGroup_DISPINTERFACE_DEFINED__ */


#ifndef __ChartGroups_DISPINTERFACE_DEFINED__
#define __ChartGroups_DISPINTERFACE_DEFINED__

/* dispinterface ChartGroups */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_ChartGroups;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002085A-0000-0000-C000-000000000046")
    ChartGroups : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ChartGroupsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ChartGroups * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ChartGroups * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ChartGroups * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ChartGroups * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ChartGroups * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ChartGroups * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ChartGroups * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ChartGroupsVtbl;

    interface ChartGroups
    {
        CONST_VTBL struct ChartGroupsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ChartGroups_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ChartGroups_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ChartGroups_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ChartGroups_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ChartGroups_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ChartGroups_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ChartGroups_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __ChartGroups_DISPINTERFACE_DEFINED__ */


#ifndef __Axes_DISPINTERFACE_DEFINED__
#define __Axes_DISPINTERFACE_DEFINED__

/* dispinterface Axes */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Axes;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002085B-0000-0000-C000-000000000046")
    Axes : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct AxesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Axes * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Axes * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Axes * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Axes * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Axes * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Axes * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Axes * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } AxesVtbl;

    interface Axes
    {
        CONST_VTBL struct AxesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Axes_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Axes_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Axes_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Axes_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Axes_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Axes_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Axes_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Axes_DISPINTERFACE_DEFINED__ */


#ifndef __Points_DISPINTERFACE_DEFINED__
#define __Points_DISPINTERFACE_DEFINED__

/* dispinterface Points */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Points;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00020869-0000-0000-C000-000000000046")
    Points : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct PointsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Points * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Points * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Points * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Points * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Points * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Points * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Points * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } PointsVtbl;

    interface Points
    {
        CONST_VTBL struct PointsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Points_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Points_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Points_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Points_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Points_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Points_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Points_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Points_DISPINTERFACE_DEFINED__ */


#ifndef __Point_DISPINTERFACE_DEFINED__
#define __Point_DISPINTERFACE_DEFINED__

/* dispinterface Point */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Point;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002086A-0000-0000-C000-000000000046")
    Point : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct PointVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Point * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Point * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Point * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Point * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Point * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Point * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Point * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } PointVtbl;

    interface Point
    {
        CONST_VTBL struct PointVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Point_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Point_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Point_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Point_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Point_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Point_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Point_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Point_DISPINTERFACE_DEFINED__ */


#ifndef __Series_DISPINTERFACE_DEFINED__
#define __Series_DISPINTERFACE_DEFINED__

/* dispinterface Series */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Series;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002086B-0000-0000-C000-000000000046")
    Series : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct SeriesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Series * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Series * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Series * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Series * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Series * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Series * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Series * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } SeriesVtbl;

    interface Series
    {
        CONST_VTBL struct SeriesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Series_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Series_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Series_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Series_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Series_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Series_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Series_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Series_DISPINTERFACE_DEFINED__ */


#ifndef __SeriesCollection_DISPINTERFACE_DEFINED__
#define __SeriesCollection_DISPINTERFACE_DEFINED__

/* dispinterface SeriesCollection */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_SeriesCollection;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002086C-0000-0000-C000-000000000046")
    SeriesCollection : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct SeriesCollectionVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            SeriesCollection * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            SeriesCollection * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            SeriesCollection * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            SeriesCollection * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            SeriesCollection * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            SeriesCollection * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            SeriesCollection * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } SeriesCollectionVtbl;

    interface SeriesCollection
    {
        CONST_VTBL struct SeriesCollectionVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define SeriesCollection_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define SeriesCollection_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define SeriesCollection_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define SeriesCollection_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define SeriesCollection_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define SeriesCollection_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define SeriesCollection_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __SeriesCollection_DISPINTERFACE_DEFINED__ */


#ifndef __DataLabel_DISPINTERFACE_DEFINED__
#define __DataLabel_DISPINTERFACE_DEFINED__

/* dispinterface DataLabel */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_DataLabel;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000208B2-0000-0000-C000-000000000046")
    DataLabel : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct DataLabelVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            DataLabel * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            DataLabel * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            DataLabel * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            DataLabel * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            DataLabel * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            DataLabel * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            DataLabel * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } DataLabelVtbl;

    interface DataLabel
    {
        CONST_VTBL struct DataLabelVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define DataLabel_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define DataLabel_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define DataLabel_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define DataLabel_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define DataLabel_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define DataLabel_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define DataLabel_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __DataLabel_DISPINTERFACE_DEFINED__ */


#ifndef __DataLabels_DISPINTERFACE_DEFINED__
#define __DataLabels_DISPINTERFACE_DEFINED__

/* dispinterface DataLabels */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_DataLabels;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000208B3-0000-0000-C000-000000000046")
    DataLabels : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct DataLabelsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            DataLabels * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            DataLabels * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            DataLabels * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            DataLabels * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            DataLabels * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            DataLabels * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            DataLabels * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } DataLabelsVtbl;

    interface DataLabels
    {
        CONST_VTBL struct DataLabelsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define DataLabels_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define DataLabels_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define DataLabels_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define DataLabels_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define DataLabels_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define DataLabels_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define DataLabels_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __DataLabels_DISPINTERFACE_DEFINED__ */


#ifndef __LegendEntry_DISPINTERFACE_DEFINED__
#define __LegendEntry_DISPINTERFACE_DEFINED__

/* dispinterface LegendEntry */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_LegendEntry;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000208BA-0000-0000-C000-000000000046")
    LegendEntry : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct LegendEntryVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            LegendEntry * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            LegendEntry * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            LegendEntry * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            LegendEntry * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            LegendEntry * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            LegendEntry * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            LegendEntry * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } LegendEntryVtbl;

    interface LegendEntry
    {
        CONST_VTBL struct LegendEntryVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define LegendEntry_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define LegendEntry_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define LegendEntry_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define LegendEntry_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define LegendEntry_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define LegendEntry_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define LegendEntry_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __LegendEntry_DISPINTERFACE_DEFINED__ */


#ifndef __LegendEntries_DISPINTERFACE_DEFINED__
#define __LegendEntries_DISPINTERFACE_DEFINED__

/* dispinterface LegendEntries */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_LegendEntries;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000208BB-0000-0000-C000-000000000046")
    LegendEntries : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct LegendEntriesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            LegendEntries * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            LegendEntries * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            LegendEntries * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            LegendEntries * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            LegendEntries * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            LegendEntries * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            LegendEntries * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } LegendEntriesVtbl;

    interface LegendEntries
    {
        CONST_VTBL struct LegendEntriesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define LegendEntries_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define LegendEntries_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define LegendEntries_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define LegendEntries_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define LegendEntries_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define LegendEntries_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define LegendEntries_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __LegendEntries_DISPINTERFACE_DEFINED__ */


#ifndef __LegendKey_DISPINTERFACE_DEFINED__
#define __LegendKey_DISPINTERFACE_DEFINED__

/* dispinterface LegendKey */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_LegendKey;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000208BC-0000-0000-C000-000000000046")
    LegendKey : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct LegendKeyVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            LegendKey * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            LegendKey * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            LegendKey * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            LegendKey * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            LegendKey * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            LegendKey * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            LegendKey * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } LegendKeyVtbl;

    interface LegendKey
    {
        CONST_VTBL struct LegendKeyVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define LegendKey_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define LegendKey_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define LegendKey_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define LegendKey_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define LegendKey_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define LegendKey_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define LegendKey_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __LegendKey_DISPINTERFACE_DEFINED__ */


#ifndef __Trendlines_DISPINTERFACE_DEFINED__
#define __Trendlines_DISPINTERFACE_DEFINED__

/* dispinterface Trendlines */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Trendlines;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000208BD-0000-0000-C000-000000000046")
    Trendlines : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct TrendlinesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Trendlines * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Trendlines * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Trendlines * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Trendlines * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Trendlines * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Trendlines * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Trendlines * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } TrendlinesVtbl;

    interface Trendlines
    {
        CONST_VTBL struct TrendlinesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Trendlines_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Trendlines_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Trendlines_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Trendlines_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Trendlines_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Trendlines_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Trendlines_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Trendlines_DISPINTERFACE_DEFINED__ */


#ifndef __Trendline_DISPINTERFACE_DEFINED__
#define __Trendline_DISPINTERFACE_DEFINED__

/* dispinterface Trendline */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Trendline;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000208BE-0000-0000-C000-000000000046")
    Trendline : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct TrendlineVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Trendline * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Trendline * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Trendline * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Trendline * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Trendline * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Trendline * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Trendline * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } TrendlineVtbl;

    interface Trendline
    {
        CONST_VTBL struct TrendlineVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Trendline_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Trendline_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Trendline_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Trendline_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Trendline_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Trendline_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Trendline_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Trendline_DISPINTERFACE_DEFINED__ */


#ifndef __Corners_DISPINTERFACE_DEFINED__
#define __Corners_DISPINTERFACE_DEFINED__

/* dispinterface Corners */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_Corners;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000208C0-0000-0000-C000-000000000046")
    Corners : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct CornersVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Corners * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Corners * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Corners * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Corners * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Corners * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Corners * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Corners * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } CornersVtbl;

    interface Corners
    {
        CONST_VTBL struct CornersVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Corners_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Corners_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Corners_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Corners_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Corners_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Corners_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Corners_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Corners_DISPINTERFACE_DEFINED__ */


#ifndef __SeriesLines_DISPINTERFACE_DEFINED__
#define __SeriesLines_DISPINTERFACE_DEFINED__

/* dispinterface SeriesLines */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_SeriesLines;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000208C1-0000-0000-C000-000000000046")
    SeriesLines : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct SeriesLinesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            SeriesLines * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            SeriesLines * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            SeriesLines * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            SeriesLines * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            SeriesLines * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            SeriesLines * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            SeriesLines * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } SeriesLinesVtbl;

    interface SeriesLines
    {
        CONST_VTBL struct SeriesLinesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define SeriesLines_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define SeriesLines_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define SeriesLines_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define SeriesLines_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define SeriesLines_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define SeriesLines_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define SeriesLines_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __SeriesLines_DISPINTERFACE_DEFINED__ */


#ifndef __HiLoLines_DISPINTERFACE_DEFINED__
#define __HiLoLines_DISPINTERFACE_DEFINED__

/* dispinterface HiLoLines */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_HiLoLines;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000208C2-0000-0000-C000-000000000046")
    HiLoLines : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct HiLoLinesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            HiLoLines * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            HiLoLines * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            HiLoLines * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            HiLoLines * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            HiLoLines * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            HiLoLines * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            HiLoLines * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } HiLoLinesVtbl;

    interface HiLoLines
    {
        CONST_VTBL struct HiLoLinesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define HiLoLines_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define HiLoLines_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define HiLoLines_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define HiLoLines_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define HiLoLines_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define HiLoLines_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define HiLoLines_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __HiLoLines_DISPINTERFACE_DEFINED__ */


#ifndef __Gridlines_DISPINTERFACE_DEFINED__
#define __Gridlines_DISPINTERFACE_DEFINED__

/* dispinterface Gridlines */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Gridlines;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000208C3-0000-0000-C000-000000000046")
    Gridlines : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct GridlinesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Gridlines * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Gridlines * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Gridlines * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Gridlines * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Gridlines * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Gridlines * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Gridlines * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } GridlinesVtbl;

    interface Gridlines
    {
        CONST_VTBL struct GridlinesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Gridlines_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Gridlines_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Gridlines_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Gridlines_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Gridlines_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Gridlines_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Gridlines_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Gridlines_DISPINTERFACE_DEFINED__ */


#ifndef __DropLines_DISPINTERFACE_DEFINED__
#define __DropLines_DISPINTERFACE_DEFINED__

/* dispinterface DropLines */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_DropLines;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000208C4-0000-0000-C000-000000000046")
    DropLines : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct DropLinesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            DropLines * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            DropLines * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            DropLines * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            DropLines * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            DropLines * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            DropLines * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            DropLines * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } DropLinesVtbl;

    interface DropLines
    {
        CONST_VTBL struct DropLinesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define DropLines_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define DropLines_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define DropLines_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define DropLines_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define DropLines_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define DropLines_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define DropLines_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __DropLines_DISPINTERFACE_DEFINED__ */


#ifndef __LeaderLines_DISPINTERFACE_DEFINED__
#define __LeaderLines_DISPINTERFACE_DEFINED__

/* dispinterface LeaderLines */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_LeaderLines;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024437-0000-0000-C000-000000000046")
    LeaderLines : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct LeaderLinesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            LeaderLines * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            LeaderLines * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            LeaderLines * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            LeaderLines * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            LeaderLines * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            LeaderLines * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            LeaderLines * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } LeaderLinesVtbl;

    interface LeaderLines
    {
        CONST_VTBL struct LeaderLinesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define LeaderLines_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define LeaderLines_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define LeaderLines_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define LeaderLines_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define LeaderLines_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define LeaderLines_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define LeaderLines_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __LeaderLines_DISPINTERFACE_DEFINED__ */


#ifndef __UpBars_DISPINTERFACE_DEFINED__
#define __UpBars_DISPINTERFACE_DEFINED__

/* dispinterface UpBars */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_UpBars;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000208C5-0000-0000-C000-000000000046")
    UpBars : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct UpBarsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            UpBars * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            UpBars * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            UpBars * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            UpBars * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            UpBars * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            UpBars * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            UpBars * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } UpBarsVtbl;

    interface UpBars
    {
        CONST_VTBL struct UpBarsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define UpBars_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define UpBars_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define UpBars_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define UpBars_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define UpBars_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define UpBars_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define UpBars_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __UpBars_DISPINTERFACE_DEFINED__ */


#ifndef __DownBars_DISPINTERFACE_DEFINED__
#define __DownBars_DISPINTERFACE_DEFINED__

/* dispinterface DownBars */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_DownBars;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000208C6-0000-0000-C000-000000000046")
    DownBars : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct DownBarsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            DownBars * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            DownBars * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            DownBars * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            DownBars * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            DownBars * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            DownBars * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            DownBars * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } DownBarsVtbl;

    interface DownBars
    {
        CONST_VTBL struct DownBarsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define DownBars_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define DownBars_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define DownBars_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define DownBars_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define DownBars_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define DownBars_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define DownBars_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __DownBars_DISPINTERFACE_DEFINED__ */


#ifndef __Floor_DISPINTERFACE_DEFINED__
#define __Floor_DISPINTERFACE_DEFINED__

/* dispinterface Floor */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Floor;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000208C7-0000-0000-C000-000000000046")
    Floor : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct FloorVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Floor * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Floor * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Floor * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Floor * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Floor * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Floor * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Floor * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } FloorVtbl;

    interface Floor
    {
        CONST_VTBL struct FloorVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Floor_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Floor_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Floor_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Floor_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Floor_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Floor_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Floor_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Floor_DISPINTERFACE_DEFINED__ */


#ifndef __Walls_DISPINTERFACE_DEFINED__
#define __Walls_DISPINTERFACE_DEFINED__

/* dispinterface Walls */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Walls;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000208C8-0000-0000-C000-000000000046")
    Walls : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct WallsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Walls * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Walls * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Walls * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Walls * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Walls * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Walls * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Walls * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } WallsVtbl;

    interface Walls
    {
        CONST_VTBL struct WallsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Walls_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Walls_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Walls_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Walls_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Walls_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Walls_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Walls_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Walls_DISPINTERFACE_DEFINED__ */


#ifndef __TickLabels_DISPINTERFACE_DEFINED__
#define __TickLabels_DISPINTERFACE_DEFINED__

/* dispinterface TickLabels */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_TickLabels;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000208C9-0000-0000-C000-000000000046")
    TickLabels : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct TickLabelsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            TickLabels * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            TickLabels * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            TickLabels * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            TickLabels * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            TickLabels * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            TickLabels * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            TickLabels * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } TickLabelsVtbl;

    interface TickLabels
    {
        CONST_VTBL struct TickLabelsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define TickLabels_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define TickLabels_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define TickLabels_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define TickLabels_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define TickLabels_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define TickLabels_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define TickLabels_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __TickLabels_DISPINTERFACE_DEFINED__ */


#ifndef __PlotArea_DISPINTERFACE_DEFINED__
#define __PlotArea_DISPINTERFACE_DEFINED__

/* dispinterface PlotArea */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_PlotArea;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000208CB-0000-0000-C000-000000000046")
    PlotArea : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct PlotAreaVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            PlotArea * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            PlotArea * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            PlotArea * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            PlotArea * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            PlotArea * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            PlotArea * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            PlotArea * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } PlotAreaVtbl;

    interface PlotArea
    {
        CONST_VTBL struct PlotAreaVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define PlotArea_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define PlotArea_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define PlotArea_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define PlotArea_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define PlotArea_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define PlotArea_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define PlotArea_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __PlotArea_DISPINTERFACE_DEFINED__ */


#ifndef __ChartArea_DISPINTERFACE_DEFINED__
#define __ChartArea_DISPINTERFACE_DEFINED__

/* dispinterface ChartArea */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_ChartArea;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000208CC-0000-0000-C000-000000000046")
    ChartArea : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ChartAreaVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ChartArea * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ChartArea * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ChartArea * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ChartArea * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ChartArea * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ChartArea * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ChartArea * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ChartAreaVtbl;

    interface ChartArea
    {
        CONST_VTBL struct ChartAreaVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ChartArea_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ChartArea_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ChartArea_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ChartArea_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ChartArea_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ChartArea_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ChartArea_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __ChartArea_DISPINTERFACE_DEFINED__ */


#ifndef __Legend_DISPINTERFACE_DEFINED__
#define __Legend_DISPINTERFACE_DEFINED__

/* dispinterface Legend */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Legend;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000208CD-0000-0000-C000-000000000046")
    Legend : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct LegendVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Legend * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Legend * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Legend * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Legend * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Legend * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Legend * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Legend * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } LegendVtbl;

    interface Legend
    {
        CONST_VTBL struct LegendVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Legend_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Legend_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Legend_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Legend_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Legend_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Legend_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Legend_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Legend_DISPINTERFACE_DEFINED__ */


#ifndef __ErrorBars_DISPINTERFACE_DEFINED__
#define __ErrorBars_DISPINTERFACE_DEFINED__

/* dispinterface ErrorBars */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_ErrorBars;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000208CE-0000-0000-C000-000000000046")
    ErrorBars : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ErrorBarsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ErrorBars * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ErrorBars * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ErrorBars * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ErrorBars * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ErrorBars * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ErrorBars * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ErrorBars * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ErrorBarsVtbl;

    interface ErrorBars
    {
        CONST_VTBL struct ErrorBarsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ErrorBars_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ErrorBars_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ErrorBars_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ErrorBars_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ErrorBars_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ErrorBars_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ErrorBars_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __ErrorBars_DISPINTERFACE_DEFINED__ */


#ifndef __DataTable_DISPINTERFACE_DEFINED__
#define __DataTable_DISPINTERFACE_DEFINED__

/* dispinterface DataTable */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_DataTable;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00020843-0000-0000-C000-000000000046")
    DataTable : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct DataTableVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            DataTable * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            DataTable * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            DataTable * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            DataTable * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            DataTable * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            DataTable * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            DataTable * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } DataTableVtbl;

    interface DataTable
    {
        CONST_VTBL struct DataTableVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define DataTable_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define DataTable_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define DataTable_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define DataTable_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define DataTable_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define DataTable_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define DataTable_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __DataTable_DISPINTERFACE_DEFINED__ */


#ifndef __Phonetic_DISPINTERFACE_DEFINED__
#define __Phonetic_DISPINTERFACE_DEFINED__

/* dispinterface Phonetic */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Phonetic;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024438-0000-0000-C000-000000000046")
    Phonetic : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct PhoneticVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Phonetic * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Phonetic * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Phonetic * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Phonetic * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Phonetic * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Phonetic * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Phonetic * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } PhoneticVtbl;

    interface Phonetic
    {
        CONST_VTBL struct PhoneticVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Phonetic_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Phonetic_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Phonetic_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Phonetic_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Phonetic_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Phonetic_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Phonetic_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Phonetic_DISPINTERFACE_DEFINED__ */


#ifndef __Shape_DISPINTERFACE_DEFINED__
#define __Shape_DISPINTERFACE_DEFINED__

/* dispinterface Shape */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Shape;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024439-0000-0000-C000-000000000046")
    Shape : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ShapeVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Shape * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Shape * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Shape * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Shape * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Shape * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Shape * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Shape * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ShapeVtbl;

    interface Shape
    {
        CONST_VTBL struct ShapeVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Shape_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Shape_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Shape_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Shape_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Shape_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Shape_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Shape_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Shape_DISPINTERFACE_DEFINED__ */


#ifndef __Shapes_DISPINTERFACE_DEFINED__
#define __Shapes_DISPINTERFACE_DEFINED__

/* dispinterface Shapes */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Shapes;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002443A-0000-0000-C000-000000000046")
    Shapes : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ShapesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Shapes * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Shapes * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Shapes * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Shapes * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Shapes * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Shapes * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Shapes * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ShapesVtbl;

    interface Shapes
    {
        CONST_VTBL struct ShapesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Shapes_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Shapes_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Shapes_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Shapes_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Shapes_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Shapes_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Shapes_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Shapes_DISPINTERFACE_DEFINED__ */


#ifndef __ShapeRange_DISPINTERFACE_DEFINED__
#define __ShapeRange_DISPINTERFACE_DEFINED__

/* dispinterface ShapeRange */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_ShapeRange;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002443B-0000-0000-C000-000000000046")
    ShapeRange : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ShapeRangeVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ShapeRange * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ShapeRange * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ShapeRange * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ShapeRange * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ShapeRange * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ShapeRange * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ShapeRange * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ShapeRangeVtbl;

    interface ShapeRange
    {
        CONST_VTBL struct ShapeRangeVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ShapeRange_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ShapeRange_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ShapeRange_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ShapeRange_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ShapeRange_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ShapeRange_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ShapeRange_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __ShapeRange_DISPINTERFACE_DEFINED__ */


#ifndef __GroupShapes_DISPINTERFACE_DEFINED__
#define __GroupShapes_DISPINTERFACE_DEFINED__

/* dispinterface GroupShapes */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_GroupShapes;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002443C-0000-0000-C000-000000000046")
    GroupShapes : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct GroupShapesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            GroupShapes * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            GroupShapes * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            GroupShapes * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            GroupShapes * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            GroupShapes * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            GroupShapes * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            GroupShapes * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } GroupShapesVtbl;

    interface GroupShapes
    {
        CONST_VTBL struct GroupShapesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define GroupShapes_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define GroupShapes_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define GroupShapes_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define GroupShapes_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define GroupShapes_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define GroupShapes_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define GroupShapes_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __GroupShapes_DISPINTERFACE_DEFINED__ */


#ifndef __TextFrame_DISPINTERFACE_DEFINED__
#define __TextFrame_DISPINTERFACE_DEFINED__

/* dispinterface TextFrame */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_TextFrame;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002443D-0000-0000-C000-000000000046")
    TextFrame : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct TextFrameVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            TextFrame * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            TextFrame * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            TextFrame * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            TextFrame * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            TextFrame * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            TextFrame * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            TextFrame * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } TextFrameVtbl;

    interface TextFrame
    {
        CONST_VTBL struct TextFrameVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define TextFrame_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define TextFrame_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define TextFrame_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define TextFrame_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define TextFrame_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define TextFrame_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define TextFrame_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __TextFrame_DISPINTERFACE_DEFINED__ */


#ifndef __ConnectorFormat_DISPINTERFACE_DEFINED__
#define __ConnectorFormat_DISPINTERFACE_DEFINED__

/* dispinterface ConnectorFormat */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_ConnectorFormat;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002443E-0000-0000-C000-000000000046")
    ConnectorFormat : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ConnectorFormatVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ConnectorFormat * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ConnectorFormat * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ConnectorFormat * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ConnectorFormat * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ConnectorFormat * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ConnectorFormat * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ConnectorFormat * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ConnectorFormatVtbl;

    interface ConnectorFormat
    {
        CONST_VTBL struct ConnectorFormatVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ConnectorFormat_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ConnectorFormat_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ConnectorFormat_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ConnectorFormat_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ConnectorFormat_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ConnectorFormat_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ConnectorFormat_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __ConnectorFormat_DISPINTERFACE_DEFINED__ */


#ifndef __FreeformBuilder_DISPINTERFACE_DEFINED__
#define __FreeformBuilder_DISPINTERFACE_DEFINED__

/* dispinterface FreeformBuilder */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_FreeformBuilder;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002443F-0000-0000-C000-000000000046")
    FreeformBuilder : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct FreeformBuilderVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            FreeformBuilder * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            FreeformBuilder * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            FreeformBuilder * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            FreeformBuilder * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            FreeformBuilder * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            FreeformBuilder * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            FreeformBuilder * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } FreeformBuilderVtbl;

    interface FreeformBuilder
    {
        CONST_VTBL struct FreeformBuilderVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define FreeformBuilder_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define FreeformBuilder_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define FreeformBuilder_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define FreeformBuilder_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define FreeformBuilder_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define FreeformBuilder_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define FreeformBuilder_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __FreeformBuilder_DISPINTERFACE_DEFINED__ */


#ifndef __ControlFormat_DISPINTERFACE_DEFINED__
#define __ControlFormat_DISPINTERFACE_DEFINED__

/* dispinterface ControlFormat */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_ControlFormat;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024440-0000-0000-C000-000000000046")
    ControlFormat : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ControlFormatVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ControlFormat * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ControlFormat * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ControlFormat * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ControlFormat * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ControlFormat * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ControlFormat * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ControlFormat * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ControlFormatVtbl;

    interface ControlFormat
    {
        CONST_VTBL struct ControlFormatVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ControlFormat_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ControlFormat_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ControlFormat_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ControlFormat_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ControlFormat_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ControlFormat_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ControlFormat_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __ControlFormat_DISPINTERFACE_DEFINED__ */


#ifndef __OLEFormat_DISPINTERFACE_DEFINED__
#define __OLEFormat_DISPINTERFACE_DEFINED__

/* dispinterface OLEFormat */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_OLEFormat;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024441-0000-0000-C000-000000000046")
    OLEFormat : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct OLEFormatVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            OLEFormat * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            OLEFormat * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            OLEFormat * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            OLEFormat * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            OLEFormat * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            OLEFormat * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            OLEFormat * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } OLEFormatVtbl;

    interface OLEFormat
    {
        CONST_VTBL struct OLEFormatVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define OLEFormat_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define OLEFormat_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define OLEFormat_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define OLEFormat_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define OLEFormat_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define OLEFormat_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define OLEFormat_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __OLEFormat_DISPINTERFACE_DEFINED__ */


#ifndef __LinkFormat_DISPINTERFACE_DEFINED__
#define __LinkFormat_DISPINTERFACE_DEFINED__

/* dispinterface LinkFormat */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_LinkFormat;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024442-0000-0000-C000-000000000046")
    LinkFormat : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct LinkFormatVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            LinkFormat * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            LinkFormat * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            LinkFormat * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            LinkFormat * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            LinkFormat * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            LinkFormat * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            LinkFormat * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } LinkFormatVtbl;

    interface LinkFormat
    {
        CONST_VTBL struct LinkFormatVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define LinkFormat_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define LinkFormat_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define LinkFormat_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define LinkFormat_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define LinkFormat_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define LinkFormat_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define LinkFormat_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __LinkFormat_DISPINTERFACE_DEFINED__ */


#ifndef __PublishObjects_DISPINTERFACE_DEFINED__
#define __PublishObjects_DISPINTERFACE_DEFINED__

/* dispinterface PublishObjects */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_PublishObjects;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024443-0000-0000-C000-000000000046")
    PublishObjects : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct PublishObjectsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            PublishObjects * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            PublishObjects * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            PublishObjects * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            PublishObjects * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            PublishObjects * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            PublishObjects * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            PublishObjects * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } PublishObjectsVtbl;

    interface PublishObjects
    {
        CONST_VTBL struct PublishObjectsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define PublishObjects_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define PublishObjects_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define PublishObjects_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define PublishObjects_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define PublishObjects_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define PublishObjects_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define PublishObjects_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __PublishObjects_DISPINTERFACE_DEFINED__ */


#ifndef __OLEDBError_DISPINTERFACE_DEFINED__
#define __OLEDBError_DISPINTERFACE_DEFINED__

/* dispinterface OLEDBError */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_OLEDBError;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024445-0000-0000-C000-000000000046")
    OLEDBError : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct OLEDBErrorVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            OLEDBError * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            OLEDBError * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            OLEDBError * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            OLEDBError * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            OLEDBError * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            OLEDBError * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            OLEDBError * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } OLEDBErrorVtbl;

    interface OLEDBError
    {
        CONST_VTBL struct OLEDBErrorVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define OLEDBError_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define OLEDBError_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define OLEDBError_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define OLEDBError_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define OLEDBError_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define OLEDBError_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define OLEDBError_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __OLEDBError_DISPINTERFACE_DEFINED__ */


#ifndef __OLEDBErrors_DISPINTERFACE_DEFINED__
#define __OLEDBErrors_DISPINTERFACE_DEFINED__

/* dispinterface OLEDBErrors */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_OLEDBErrors;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024446-0000-0000-C000-000000000046")
    OLEDBErrors : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct OLEDBErrorsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            OLEDBErrors * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            OLEDBErrors * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            OLEDBErrors * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            OLEDBErrors * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            OLEDBErrors * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            OLEDBErrors * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            OLEDBErrors * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } OLEDBErrorsVtbl;

    interface OLEDBErrors
    {
        CONST_VTBL struct OLEDBErrorsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define OLEDBErrors_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define OLEDBErrors_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define OLEDBErrors_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define OLEDBErrors_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define OLEDBErrors_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define OLEDBErrors_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define OLEDBErrors_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __OLEDBErrors_DISPINTERFACE_DEFINED__ */


#ifndef __Phonetics_DISPINTERFACE_DEFINED__
#define __Phonetics_DISPINTERFACE_DEFINED__

/* dispinterface Phonetics */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Phonetics;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024447-0000-0000-C000-000000000046")
    Phonetics : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct PhoneticsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Phonetics * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Phonetics * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Phonetics * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Phonetics * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Phonetics * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Phonetics * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Phonetics * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } PhoneticsVtbl;

    interface Phonetics
    {
        CONST_VTBL struct PhoneticsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Phonetics_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Phonetics_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Phonetics_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Phonetics_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Phonetics_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Phonetics_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Phonetics_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Phonetics_DISPINTERFACE_DEFINED__ */


#ifndef __PivotLayout_DISPINTERFACE_DEFINED__
#define __PivotLayout_DISPINTERFACE_DEFINED__

/* dispinterface PivotLayout */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_PivotLayout;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002444A-0000-0000-C000-000000000046")
    PivotLayout : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct PivotLayoutVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            PivotLayout * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            PivotLayout * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            PivotLayout * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            PivotLayout * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            PivotLayout * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            PivotLayout * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            PivotLayout * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } PivotLayoutVtbl;

    interface PivotLayout
    {
        CONST_VTBL struct PivotLayoutVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define PivotLayout_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define PivotLayout_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define PivotLayout_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define PivotLayout_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define PivotLayout_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define PivotLayout_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define PivotLayout_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __PivotLayout_DISPINTERFACE_DEFINED__ */


#ifndef __DisplayUnitLabel_DISPINTERFACE_DEFINED__
#define __DisplayUnitLabel_DISPINTERFACE_DEFINED__

/* dispinterface DisplayUnitLabel */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_DisplayUnitLabel;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002084C-0000-0000-C000-000000000046")
    DisplayUnitLabel : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct DisplayUnitLabelVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            DisplayUnitLabel * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            DisplayUnitLabel * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            DisplayUnitLabel * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            DisplayUnitLabel * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            DisplayUnitLabel * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            DisplayUnitLabel * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            DisplayUnitLabel * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } DisplayUnitLabelVtbl;

    interface DisplayUnitLabel
    {
        CONST_VTBL struct DisplayUnitLabelVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define DisplayUnitLabel_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define DisplayUnitLabel_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define DisplayUnitLabel_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define DisplayUnitLabel_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define DisplayUnitLabel_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define DisplayUnitLabel_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define DisplayUnitLabel_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __DisplayUnitLabel_DISPINTERFACE_DEFINED__ */


#ifndef __CellFormat_DISPINTERFACE_DEFINED__
#define __CellFormat_DISPINTERFACE_DEFINED__

/* dispinterface CellFormat */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_CellFormat;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024450-0000-0000-C000-000000000046")
    CellFormat : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct CellFormatVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            CellFormat * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            CellFormat * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            CellFormat * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            CellFormat * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            CellFormat * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            CellFormat * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            CellFormat * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } CellFormatVtbl;

    interface CellFormat
    {
        CONST_VTBL struct CellFormatVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define CellFormat_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define CellFormat_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define CellFormat_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define CellFormat_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define CellFormat_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define CellFormat_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define CellFormat_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __CellFormat_DISPINTERFACE_DEFINED__ */


#ifndef __UsedObjects_DISPINTERFACE_DEFINED__
#define __UsedObjects_DISPINTERFACE_DEFINED__

/* dispinterface UsedObjects */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_UsedObjects;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024451-0000-0000-C000-000000000046")
    UsedObjects : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct UsedObjectsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            UsedObjects * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            UsedObjects * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            UsedObjects * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            UsedObjects * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            UsedObjects * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            UsedObjects * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            UsedObjects * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } UsedObjectsVtbl;

    interface UsedObjects
    {
        CONST_VTBL struct UsedObjectsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define UsedObjects_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define UsedObjects_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define UsedObjects_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define UsedObjects_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define UsedObjects_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define UsedObjects_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define UsedObjects_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __UsedObjects_DISPINTERFACE_DEFINED__ */


#ifndef __CustomProperties_DISPINTERFACE_DEFINED__
#define __CustomProperties_DISPINTERFACE_DEFINED__

/* dispinterface CustomProperties */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_CustomProperties;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024452-0000-0000-C000-000000000046")
    CustomProperties : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct CustomPropertiesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            CustomProperties * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            CustomProperties * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            CustomProperties * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            CustomProperties * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            CustomProperties * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            CustomProperties * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            CustomProperties * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } CustomPropertiesVtbl;

    interface CustomProperties
    {
        CONST_VTBL struct CustomPropertiesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define CustomProperties_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define CustomProperties_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define CustomProperties_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define CustomProperties_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define CustomProperties_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define CustomProperties_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define CustomProperties_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __CustomProperties_DISPINTERFACE_DEFINED__ */


#ifndef __CustomProperty_DISPINTERFACE_DEFINED__
#define __CustomProperty_DISPINTERFACE_DEFINED__

/* dispinterface CustomProperty */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_CustomProperty;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024453-0000-0000-C000-000000000046")
    CustomProperty : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct CustomPropertyVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            CustomProperty * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            CustomProperty * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            CustomProperty * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            CustomProperty * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            CustomProperty * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            CustomProperty * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            CustomProperty * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } CustomPropertyVtbl;

    interface CustomProperty
    {
        CONST_VTBL struct CustomPropertyVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define CustomProperty_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define CustomProperty_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define CustomProperty_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define CustomProperty_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define CustomProperty_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define CustomProperty_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define CustomProperty_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __CustomProperty_DISPINTERFACE_DEFINED__ */


#ifndef __CalculatedMembers_DISPINTERFACE_DEFINED__
#define __CalculatedMembers_DISPINTERFACE_DEFINED__

/* dispinterface CalculatedMembers */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_CalculatedMembers;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024454-0000-0000-C000-000000000046")
    CalculatedMembers : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct CalculatedMembersVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            CalculatedMembers * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            CalculatedMembers * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            CalculatedMembers * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            CalculatedMembers * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            CalculatedMembers * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            CalculatedMembers * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            CalculatedMembers * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } CalculatedMembersVtbl;

    interface CalculatedMembers
    {
        CONST_VTBL struct CalculatedMembersVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define CalculatedMembers_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define CalculatedMembers_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define CalculatedMembers_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define CalculatedMembers_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define CalculatedMembers_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define CalculatedMembers_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define CalculatedMembers_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __CalculatedMembers_DISPINTERFACE_DEFINED__ */


#ifndef __CalculatedMember_DISPINTERFACE_DEFINED__
#define __CalculatedMember_DISPINTERFACE_DEFINED__

/* dispinterface CalculatedMember */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_CalculatedMember;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024455-0000-0000-C000-000000000046")
    CalculatedMember : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct CalculatedMemberVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            CalculatedMember * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            CalculatedMember * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            CalculatedMember * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            CalculatedMember * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            CalculatedMember * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            CalculatedMember * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            CalculatedMember * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } CalculatedMemberVtbl;

    interface CalculatedMember
    {
        CONST_VTBL struct CalculatedMemberVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define CalculatedMember_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define CalculatedMember_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define CalculatedMember_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define CalculatedMember_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define CalculatedMember_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define CalculatedMember_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define CalculatedMember_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __CalculatedMember_DISPINTERFACE_DEFINED__ */


#ifndef __Watches_DISPINTERFACE_DEFINED__
#define __Watches_DISPINTERFACE_DEFINED__

/* dispinterface Watches */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Watches;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024456-0000-0000-C000-000000000046")
    Watches : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct WatchesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Watches * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Watches * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Watches * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Watches * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Watches * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Watches * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Watches * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } WatchesVtbl;

    interface Watches
    {
        CONST_VTBL struct WatchesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Watches_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Watches_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Watches_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Watches_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Watches_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Watches_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Watches_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Watches_DISPINTERFACE_DEFINED__ */


#ifndef __Watch_DISPINTERFACE_DEFINED__
#define __Watch_DISPINTERFACE_DEFINED__

/* dispinterface Watch */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Watch;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024457-0000-0000-C000-000000000046")
    Watch : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct WatchVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Watch * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Watch * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Watch * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Watch * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Watch * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Watch * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Watch * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } WatchVtbl;

    interface Watch
    {
        CONST_VTBL struct WatchVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Watch_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Watch_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Watch_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Watch_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Watch_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Watch_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Watch_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Watch_DISPINTERFACE_DEFINED__ */


#ifndef __PivotCell_DISPINTERFACE_DEFINED__
#define __PivotCell_DISPINTERFACE_DEFINED__

/* dispinterface PivotCell */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_PivotCell;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024458-0000-0000-C000-000000000046")
    PivotCell : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct PivotCellVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            PivotCell * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            PivotCell * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            PivotCell * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            PivotCell * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            PivotCell * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            PivotCell * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            PivotCell * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } PivotCellVtbl;

    interface PivotCell
    {
        CONST_VTBL struct PivotCellVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define PivotCell_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define PivotCell_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define PivotCell_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define PivotCell_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define PivotCell_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define PivotCell_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define PivotCell_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __PivotCell_DISPINTERFACE_DEFINED__ */


#ifndef __Graphic_DISPINTERFACE_DEFINED__
#define __Graphic_DISPINTERFACE_DEFINED__

/* dispinterface Graphic */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Graphic;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024459-0000-0000-C000-000000000046")
    Graphic : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct GraphicVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Graphic * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Graphic * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Graphic * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Graphic * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Graphic * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Graphic * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Graphic * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } GraphicVtbl;

    interface Graphic
    {
        CONST_VTBL struct GraphicVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Graphic_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Graphic_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Graphic_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Graphic_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Graphic_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Graphic_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Graphic_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Graphic_DISPINTERFACE_DEFINED__ */


#ifndef __AutoRecover_DISPINTERFACE_DEFINED__
#define __AutoRecover_DISPINTERFACE_DEFINED__

/* dispinterface AutoRecover */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_AutoRecover;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002445A-0000-0000-C000-000000000046")
    AutoRecover : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct AutoRecoverVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            AutoRecover * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            AutoRecover * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            AutoRecover * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            AutoRecover * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            AutoRecover * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            AutoRecover * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            AutoRecover * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } AutoRecoverVtbl;

    interface AutoRecover
    {
        CONST_VTBL struct AutoRecoverVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define AutoRecover_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define AutoRecover_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define AutoRecover_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define AutoRecover_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define AutoRecover_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define AutoRecover_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define AutoRecover_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __AutoRecover_DISPINTERFACE_DEFINED__ */


#ifndef __ErrorCheckingOptions_DISPINTERFACE_DEFINED__
#define __ErrorCheckingOptions_DISPINTERFACE_DEFINED__

/* dispinterface ErrorCheckingOptions */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_ErrorCheckingOptions;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002445B-0000-0000-C000-000000000046")
    ErrorCheckingOptions : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ErrorCheckingOptionsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ErrorCheckingOptions * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ErrorCheckingOptions * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ErrorCheckingOptions * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ErrorCheckingOptions * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ErrorCheckingOptions * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ErrorCheckingOptions * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ErrorCheckingOptions * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ErrorCheckingOptionsVtbl;

    interface ErrorCheckingOptions
    {
        CONST_VTBL struct ErrorCheckingOptionsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ErrorCheckingOptions_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ErrorCheckingOptions_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ErrorCheckingOptions_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ErrorCheckingOptions_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ErrorCheckingOptions_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ErrorCheckingOptions_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ErrorCheckingOptions_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __ErrorCheckingOptions_DISPINTERFACE_DEFINED__ */


#ifndef __Errors_DISPINTERFACE_DEFINED__
#define __Errors_DISPINTERFACE_DEFINED__

/* dispinterface Errors */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Errors;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002445C-0000-0000-C000-000000000046")
    Errors : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ErrorsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Errors * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Errors * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Errors * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Errors * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Errors * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Errors * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Errors * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ErrorsVtbl;

    interface Errors
    {
        CONST_VTBL struct ErrorsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Errors_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Errors_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Errors_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Errors_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Errors_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Errors_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Errors_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Errors_DISPINTERFACE_DEFINED__ */


#ifndef __Error_DISPINTERFACE_DEFINED__
#define __Error_DISPINTERFACE_DEFINED__

/* dispinterface Error */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Error;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002445D-0000-0000-C000-000000000046")
    Error : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ErrorVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Error * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Error * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Error * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Error * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Error * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Error * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Error * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ErrorVtbl;

    interface Error
    {
        CONST_VTBL struct ErrorVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Error_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Error_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Error_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Error_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Error_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Error_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Error_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Error_DISPINTERFACE_DEFINED__ */


#ifndef __SmartTagAction_DISPINTERFACE_DEFINED__
#define __SmartTagAction_DISPINTERFACE_DEFINED__

/* dispinterface SmartTagAction */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_SmartTagAction;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002445E-0000-0000-C000-000000000046")
    SmartTagAction : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct SmartTagActionVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            SmartTagAction * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            SmartTagAction * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            SmartTagAction * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            SmartTagAction * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            SmartTagAction * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            SmartTagAction * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            SmartTagAction * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } SmartTagActionVtbl;

    interface SmartTagAction
    {
        CONST_VTBL struct SmartTagActionVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define SmartTagAction_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define SmartTagAction_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define SmartTagAction_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define SmartTagAction_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define SmartTagAction_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define SmartTagAction_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define SmartTagAction_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __SmartTagAction_DISPINTERFACE_DEFINED__ */


#ifndef __SmartTagActions_DISPINTERFACE_DEFINED__
#define __SmartTagActions_DISPINTERFACE_DEFINED__

/* dispinterface SmartTagActions */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_SmartTagActions;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002445F-0000-0000-C000-000000000046")
    SmartTagActions : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct SmartTagActionsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            SmartTagActions * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            SmartTagActions * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            SmartTagActions * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            SmartTagActions * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            SmartTagActions * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            SmartTagActions * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            SmartTagActions * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } SmartTagActionsVtbl;

    interface SmartTagActions
    {
        CONST_VTBL struct SmartTagActionsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define SmartTagActions_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define SmartTagActions_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define SmartTagActions_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define SmartTagActions_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define SmartTagActions_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define SmartTagActions_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define SmartTagActions_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __SmartTagActions_DISPINTERFACE_DEFINED__ */


#ifndef __SmartTag_DISPINTERFACE_DEFINED__
#define __SmartTag_DISPINTERFACE_DEFINED__

/* dispinterface SmartTag */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_SmartTag;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024460-0000-0000-C000-000000000046")
    SmartTag : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct SmartTagVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            SmartTag * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            SmartTag * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            SmartTag * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            SmartTag * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            SmartTag * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            SmartTag * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            SmartTag * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } SmartTagVtbl;

    interface SmartTag
    {
        CONST_VTBL struct SmartTagVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define SmartTag_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define SmartTag_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define SmartTag_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define SmartTag_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define SmartTag_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define SmartTag_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define SmartTag_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __SmartTag_DISPINTERFACE_DEFINED__ */


#ifndef __SmartTags_DISPINTERFACE_DEFINED__
#define __SmartTags_DISPINTERFACE_DEFINED__

/* dispinterface SmartTags */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_SmartTags;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024461-0000-0000-C000-000000000046")
    SmartTags : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct SmartTagsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            SmartTags * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            SmartTags * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            SmartTags * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            SmartTags * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            SmartTags * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            SmartTags * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            SmartTags * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } SmartTagsVtbl;

    interface SmartTags
    {
        CONST_VTBL struct SmartTagsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define SmartTags_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define SmartTags_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define SmartTags_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define SmartTags_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define SmartTags_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define SmartTags_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define SmartTags_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __SmartTags_DISPINTERFACE_DEFINED__ */


#ifndef __SmartTagRecognizer_DISPINTERFACE_DEFINED__
#define __SmartTagRecognizer_DISPINTERFACE_DEFINED__

/* dispinterface SmartTagRecognizer */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_SmartTagRecognizer;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024462-0000-0000-C000-000000000046")
    SmartTagRecognizer : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct SmartTagRecognizerVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            SmartTagRecognizer * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            SmartTagRecognizer * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            SmartTagRecognizer * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            SmartTagRecognizer * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            SmartTagRecognizer * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            SmartTagRecognizer * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            SmartTagRecognizer * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } SmartTagRecognizerVtbl;

    interface SmartTagRecognizer
    {
        CONST_VTBL struct SmartTagRecognizerVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define SmartTagRecognizer_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define SmartTagRecognizer_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define SmartTagRecognizer_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define SmartTagRecognizer_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define SmartTagRecognizer_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define SmartTagRecognizer_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define SmartTagRecognizer_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __SmartTagRecognizer_DISPINTERFACE_DEFINED__ */


#ifndef __SmartTagRecognizers_DISPINTERFACE_DEFINED__
#define __SmartTagRecognizers_DISPINTERFACE_DEFINED__

/* dispinterface SmartTagRecognizers */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_SmartTagRecognizers;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024463-0000-0000-C000-000000000046")
    SmartTagRecognizers : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct SmartTagRecognizersVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            SmartTagRecognizers * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            SmartTagRecognizers * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            SmartTagRecognizers * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            SmartTagRecognizers * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            SmartTagRecognizers * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            SmartTagRecognizers * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            SmartTagRecognizers * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } SmartTagRecognizersVtbl;

    interface SmartTagRecognizers
    {
        CONST_VTBL struct SmartTagRecognizersVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define SmartTagRecognizers_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define SmartTagRecognizers_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define SmartTagRecognizers_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define SmartTagRecognizers_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define SmartTagRecognizers_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define SmartTagRecognizers_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define SmartTagRecognizers_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __SmartTagRecognizers_DISPINTERFACE_DEFINED__ */


#ifndef __SmartTagOptions_DISPINTERFACE_DEFINED__
#define __SmartTagOptions_DISPINTERFACE_DEFINED__

/* dispinterface SmartTagOptions */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_SmartTagOptions;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024464-0000-0000-C000-000000000046")
    SmartTagOptions : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct SmartTagOptionsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            SmartTagOptions * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            SmartTagOptions * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            SmartTagOptions * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            SmartTagOptions * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            SmartTagOptions * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            SmartTagOptions * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            SmartTagOptions * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } SmartTagOptionsVtbl;

    interface SmartTagOptions
    {
        CONST_VTBL struct SmartTagOptionsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define SmartTagOptions_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define SmartTagOptions_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define SmartTagOptions_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define SmartTagOptions_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define SmartTagOptions_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define SmartTagOptions_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define SmartTagOptions_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __SmartTagOptions_DISPINTERFACE_DEFINED__ */


#ifndef __SpellingOptions_DISPINTERFACE_DEFINED__
#define __SpellingOptions_DISPINTERFACE_DEFINED__

/* dispinterface SpellingOptions */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_SpellingOptions;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024465-0000-0000-C000-000000000046")
    SpellingOptions : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct SpellingOptionsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            SpellingOptions * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            SpellingOptions * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            SpellingOptions * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            SpellingOptions * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            SpellingOptions * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            SpellingOptions * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            SpellingOptions * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } SpellingOptionsVtbl;

    interface SpellingOptions
    {
        CONST_VTBL struct SpellingOptionsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define SpellingOptions_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define SpellingOptions_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define SpellingOptions_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define SpellingOptions_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define SpellingOptions_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define SpellingOptions_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define SpellingOptions_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __SpellingOptions_DISPINTERFACE_DEFINED__ */


#ifndef __Speech_DISPINTERFACE_DEFINED__
#define __Speech_DISPINTERFACE_DEFINED__

/* dispinterface Speech */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Speech;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024466-0000-0000-C000-000000000046")
    Speech : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct SpeechVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Speech * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Speech * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Speech * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Speech * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Speech * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Speech * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Speech * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } SpeechVtbl;

    interface Speech
    {
        CONST_VTBL struct SpeechVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Speech_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Speech_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Speech_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Speech_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Speech_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Speech_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Speech_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Speech_DISPINTERFACE_DEFINED__ */


#ifndef __Protection_DISPINTERFACE_DEFINED__
#define __Protection_DISPINTERFACE_DEFINED__

/* dispinterface Protection */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Protection;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024467-0000-0000-C000-000000000046")
    Protection : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ProtectionVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Protection * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Protection * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Protection * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Protection * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Protection * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Protection * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Protection * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ProtectionVtbl;

    interface Protection
    {
        CONST_VTBL struct ProtectionVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Protection_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Protection_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Protection_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Protection_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Protection_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Protection_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Protection_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Protection_DISPINTERFACE_DEFINED__ */


#ifndef __PivotItemList_DISPINTERFACE_DEFINED__
#define __PivotItemList_DISPINTERFACE_DEFINED__

/* dispinterface PivotItemList */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_PivotItemList;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024468-0000-0000-C000-000000000046")
    PivotItemList : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct PivotItemListVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            PivotItemList * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            PivotItemList * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            PivotItemList * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            PivotItemList * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            PivotItemList * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            PivotItemList * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            PivotItemList * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } PivotItemListVtbl;

    interface PivotItemList
    {
        CONST_VTBL struct PivotItemListVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define PivotItemList_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define PivotItemList_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define PivotItemList_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define PivotItemList_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define PivotItemList_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define PivotItemList_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define PivotItemList_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __PivotItemList_DISPINTERFACE_DEFINED__ */


#ifndef __Tab_DISPINTERFACE_DEFINED__
#define __Tab_DISPINTERFACE_DEFINED__

/* dispinterface Tab */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Tab;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024469-0000-0000-C000-000000000046")
    Tab : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct TabVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Tab * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Tab * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Tab * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Tab * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Tab * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Tab * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Tab * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } TabVtbl;

    interface Tab
    {
        CONST_VTBL struct TabVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Tab_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Tab_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Tab_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Tab_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Tab_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Tab_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Tab_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Tab_DISPINTERFACE_DEFINED__ */


#ifndef __AllowEditRanges_DISPINTERFACE_DEFINED__
#define __AllowEditRanges_DISPINTERFACE_DEFINED__

/* dispinterface AllowEditRanges */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_AllowEditRanges;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002446A-0000-0000-C000-000000000046")
    AllowEditRanges : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct AllowEditRangesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            AllowEditRanges * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            AllowEditRanges * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            AllowEditRanges * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            AllowEditRanges * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            AllowEditRanges * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            AllowEditRanges * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            AllowEditRanges * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } AllowEditRangesVtbl;

    interface AllowEditRanges
    {
        CONST_VTBL struct AllowEditRangesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define AllowEditRanges_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define AllowEditRanges_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define AllowEditRanges_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define AllowEditRanges_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define AllowEditRanges_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define AllowEditRanges_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define AllowEditRanges_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __AllowEditRanges_DISPINTERFACE_DEFINED__ */


#ifndef __AllowEditRange_DISPINTERFACE_DEFINED__
#define __AllowEditRange_DISPINTERFACE_DEFINED__

/* dispinterface AllowEditRange */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_AllowEditRange;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002446B-0000-0000-C000-000000000046")
    AllowEditRange : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct AllowEditRangeVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            AllowEditRange * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            AllowEditRange * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            AllowEditRange * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            AllowEditRange * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            AllowEditRange * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            AllowEditRange * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            AllowEditRange * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } AllowEditRangeVtbl;

    interface AllowEditRange
    {
        CONST_VTBL struct AllowEditRangeVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define AllowEditRange_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define AllowEditRange_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define AllowEditRange_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define AllowEditRange_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define AllowEditRange_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define AllowEditRange_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define AllowEditRange_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __AllowEditRange_DISPINTERFACE_DEFINED__ */


#ifndef __UserAccessList_DISPINTERFACE_DEFINED__
#define __UserAccessList_DISPINTERFACE_DEFINED__

/* dispinterface UserAccessList */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_UserAccessList;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002446C-0000-0000-C000-000000000046")
    UserAccessList : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct UserAccessListVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            UserAccessList * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            UserAccessList * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            UserAccessList * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            UserAccessList * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            UserAccessList * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            UserAccessList * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            UserAccessList * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } UserAccessListVtbl;

    interface UserAccessList
    {
        CONST_VTBL struct UserAccessListVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define UserAccessList_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define UserAccessList_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define UserAccessList_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define UserAccessList_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define UserAccessList_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define UserAccessList_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define UserAccessList_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __UserAccessList_DISPINTERFACE_DEFINED__ */


#ifndef __UserAccess_DISPINTERFACE_DEFINED__
#define __UserAccess_DISPINTERFACE_DEFINED__

/* dispinterface UserAccess */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_UserAccess;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002446D-0000-0000-C000-000000000046")
    UserAccess : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct UserAccessVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            UserAccess * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            UserAccess * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            UserAccess * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            UserAccess * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            UserAccess * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            UserAccess * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            UserAccess * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } UserAccessVtbl;

    interface UserAccess
    {
        CONST_VTBL struct UserAccessVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define UserAccess_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define UserAccess_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define UserAccess_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define UserAccess_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define UserAccess_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define UserAccess_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define UserAccess_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __UserAccess_DISPINTERFACE_DEFINED__ */


#ifndef __RTD_DISPINTERFACE_DEFINED__
#define __RTD_DISPINTERFACE_DEFINED__

/* dispinterface RTD */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_RTD;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002446E-0000-0000-C000-000000000046")
    RTD : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct RTDVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            RTD * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            RTD * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            RTD * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            RTD * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            RTD * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            RTD * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            RTD * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } RTDVtbl;

    interface RTD
    {
        CONST_VTBL struct RTDVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define RTD_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define RTD_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define RTD_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define RTD_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define RTD_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define RTD_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define RTD_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __RTD_DISPINTERFACE_DEFINED__ */


#ifndef __Diagram_DISPINTERFACE_DEFINED__
#define __Diagram_DISPINTERFACE_DEFINED__

/* dispinterface Diagram */
/* [hidden][helpcontext][uuid] */ 


EXTERN_C const IID DIID_Diagram;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002446F-0000-0000-C000-000000000046")
    Diagram : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct DiagramVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Diagram * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Diagram * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Diagram * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Diagram * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Diagram * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Diagram * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Diagram * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } DiagramVtbl;

    interface Diagram
    {
        CONST_VTBL struct DiagramVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Diagram_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Diagram_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Diagram_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Diagram_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Diagram_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Diagram_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Diagram_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Diagram_DISPINTERFACE_DEFINED__ */


#ifndef __ListObjects_DISPINTERFACE_DEFINED__
#define __ListObjects_DISPINTERFACE_DEFINED__

/* dispinterface ListObjects */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_ListObjects;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024470-0000-0000-C000-000000000046")
    ListObjects : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ListObjectsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ListObjects * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ListObjects * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ListObjects * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ListObjects * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ListObjects * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ListObjects * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ListObjects * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ListObjectsVtbl;

    interface ListObjects
    {
        CONST_VTBL struct ListObjectsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ListObjects_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ListObjects_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ListObjects_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ListObjects_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ListObjects_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ListObjects_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ListObjects_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __ListObjects_DISPINTERFACE_DEFINED__ */


#ifndef __ListObject_DISPINTERFACE_DEFINED__
#define __ListObject_DISPINTERFACE_DEFINED__

/* dispinterface ListObject */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_ListObject;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024471-0000-0000-C000-000000000046")
    ListObject : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ListObjectVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ListObject * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ListObject * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ListObject * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ListObject * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ListObject * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ListObject * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ListObject * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ListObjectVtbl;

    interface ListObject
    {
        CONST_VTBL struct ListObjectVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ListObject_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ListObject_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ListObject_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ListObject_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ListObject_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ListObject_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ListObject_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __ListObject_DISPINTERFACE_DEFINED__ */


#ifndef __ListColumns_DISPINTERFACE_DEFINED__
#define __ListColumns_DISPINTERFACE_DEFINED__

/* dispinterface ListColumns */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_ListColumns;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024472-0000-0000-C000-000000000046")
    ListColumns : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ListColumnsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ListColumns * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ListColumns * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ListColumns * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ListColumns * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ListColumns * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ListColumns * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ListColumns * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ListColumnsVtbl;

    interface ListColumns
    {
        CONST_VTBL struct ListColumnsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ListColumns_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ListColumns_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ListColumns_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ListColumns_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ListColumns_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ListColumns_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ListColumns_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __ListColumns_DISPINTERFACE_DEFINED__ */


#ifndef __ListColumn_DISPINTERFACE_DEFINED__
#define __ListColumn_DISPINTERFACE_DEFINED__

/* dispinterface ListColumn */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_ListColumn;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024473-0000-0000-C000-000000000046")
    ListColumn : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ListColumnVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ListColumn * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ListColumn * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ListColumn * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ListColumn * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ListColumn * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ListColumn * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ListColumn * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ListColumnVtbl;

    interface ListColumn
    {
        CONST_VTBL struct ListColumnVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ListColumn_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ListColumn_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ListColumn_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ListColumn_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ListColumn_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ListColumn_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ListColumn_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __ListColumn_DISPINTERFACE_DEFINED__ */


#ifndef __ListRows_DISPINTERFACE_DEFINED__
#define __ListRows_DISPINTERFACE_DEFINED__

/* dispinterface ListRows */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_ListRows;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024474-0000-0000-C000-000000000046")
    ListRows : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ListRowsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ListRows * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ListRows * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ListRows * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ListRows * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ListRows * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ListRows * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ListRows * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ListRowsVtbl;

    interface ListRows
    {
        CONST_VTBL struct ListRowsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ListRows_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ListRows_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ListRows_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ListRows_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ListRows_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ListRows_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ListRows_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __ListRows_DISPINTERFACE_DEFINED__ */


#ifndef __ListRow_DISPINTERFACE_DEFINED__
#define __ListRow_DISPINTERFACE_DEFINED__

/* dispinterface ListRow */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_ListRow;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024475-0000-0000-C000-000000000046")
    ListRow : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ListRowVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ListRow * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ListRow * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ListRow * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ListRow * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ListRow * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ListRow * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ListRow * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ListRowVtbl;

    interface ListRow
    {
        CONST_VTBL struct ListRowVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ListRow_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ListRow_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ListRow_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ListRow_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ListRow_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ListRow_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ListRow_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __ListRow_DISPINTERFACE_DEFINED__ */


#ifndef __XmlNamespace_DISPINTERFACE_DEFINED__
#define __XmlNamespace_DISPINTERFACE_DEFINED__

/* dispinterface XmlNamespace */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_XmlNamespace;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024476-0000-0000-C000-000000000046")
    XmlNamespace : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct XmlNamespaceVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            XmlNamespace * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            XmlNamespace * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            XmlNamespace * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            XmlNamespace * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            XmlNamespace * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            XmlNamespace * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            XmlNamespace * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } XmlNamespaceVtbl;

    interface XmlNamespace
    {
        CONST_VTBL struct XmlNamespaceVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define XmlNamespace_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define XmlNamespace_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define XmlNamespace_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define XmlNamespace_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define XmlNamespace_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define XmlNamespace_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define XmlNamespace_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __XmlNamespace_DISPINTERFACE_DEFINED__ */


#ifndef __XmlNamespaces_DISPINTERFACE_DEFINED__
#define __XmlNamespaces_DISPINTERFACE_DEFINED__

/* dispinterface XmlNamespaces */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_XmlNamespaces;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024477-0000-0000-C000-000000000046")
    XmlNamespaces : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct XmlNamespacesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            XmlNamespaces * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            XmlNamespaces * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            XmlNamespaces * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            XmlNamespaces * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            XmlNamespaces * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            XmlNamespaces * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            XmlNamespaces * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } XmlNamespacesVtbl;

    interface XmlNamespaces
    {
        CONST_VTBL struct XmlNamespacesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define XmlNamespaces_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define XmlNamespaces_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define XmlNamespaces_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define XmlNamespaces_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define XmlNamespaces_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define XmlNamespaces_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define XmlNamespaces_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __XmlNamespaces_DISPINTERFACE_DEFINED__ */


#ifndef __XmlDataBinding_DISPINTERFACE_DEFINED__
#define __XmlDataBinding_DISPINTERFACE_DEFINED__

/* dispinterface XmlDataBinding */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_XmlDataBinding;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024478-0000-0000-C000-000000000046")
    XmlDataBinding : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct XmlDataBindingVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            XmlDataBinding * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            XmlDataBinding * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            XmlDataBinding * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            XmlDataBinding * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            XmlDataBinding * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            XmlDataBinding * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            XmlDataBinding * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } XmlDataBindingVtbl;

    interface XmlDataBinding
    {
        CONST_VTBL struct XmlDataBindingVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define XmlDataBinding_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define XmlDataBinding_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define XmlDataBinding_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define XmlDataBinding_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define XmlDataBinding_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define XmlDataBinding_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define XmlDataBinding_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __XmlDataBinding_DISPINTERFACE_DEFINED__ */


#ifndef __XmlSchema_DISPINTERFACE_DEFINED__
#define __XmlSchema_DISPINTERFACE_DEFINED__

/* dispinterface XmlSchema */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_XmlSchema;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024479-0000-0000-C000-000000000046")
    XmlSchema : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct XmlSchemaVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            XmlSchema * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            XmlSchema * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            XmlSchema * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            XmlSchema * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            XmlSchema * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            XmlSchema * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            XmlSchema * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } XmlSchemaVtbl;

    interface XmlSchema
    {
        CONST_VTBL struct XmlSchemaVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define XmlSchema_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define XmlSchema_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define XmlSchema_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define XmlSchema_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define XmlSchema_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define XmlSchema_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define XmlSchema_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __XmlSchema_DISPINTERFACE_DEFINED__ */


#ifndef __XmlSchemas_DISPINTERFACE_DEFINED__
#define __XmlSchemas_DISPINTERFACE_DEFINED__

/* dispinterface XmlSchemas */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_XmlSchemas;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002447A-0000-0000-C000-000000000046")
    XmlSchemas : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct XmlSchemasVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            XmlSchemas * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            XmlSchemas * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            XmlSchemas * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            XmlSchemas * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            XmlSchemas * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            XmlSchemas * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            XmlSchemas * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } XmlSchemasVtbl;

    interface XmlSchemas
    {
        CONST_VTBL struct XmlSchemasVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define XmlSchemas_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define XmlSchemas_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define XmlSchemas_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define XmlSchemas_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define XmlSchemas_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define XmlSchemas_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define XmlSchemas_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __XmlSchemas_DISPINTERFACE_DEFINED__ */


#ifndef __XmlMap_DISPINTERFACE_DEFINED__
#define __XmlMap_DISPINTERFACE_DEFINED__

/* dispinterface XmlMap */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_XmlMap;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002447B-0000-0000-C000-000000000046")
    XmlMap : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct XmlMapVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            XmlMap * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            XmlMap * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            XmlMap * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            XmlMap * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            XmlMap * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            XmlMap * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            XmlMap * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } XmlMapVtbl;

    interface XmlMap
    {
        CONST_VTBL struct XmlMapVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define XmlMap_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define XmlMap_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define XmlMap_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define XmlMap_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define XmlMap_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define XmlMap_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define XmlMap_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __XmlMap_DISPINTERFACE_DEFINED__ */


#ifndef __XmlMaps_DISPINTERFACE_DEFINED__
#define __XmlMaps_DISPINTERFACE_DEFINED__

/* dispinterface XmlMaps */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_XmlMaps;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002447C-0000-0000-C000-000000000046")
    XmlMaps : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct XmlMapsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            XmlMaps * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            XmlMaps * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            XmlMaps * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            XmlMaps * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            XmlMaps * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            XmlMaps * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            XmlMaps * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } XmlMapsVtbl;

    interface XmlMaps
    {
        CONST_VTBL struct XmlMapsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define XmlMaps_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define XmlMaps_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define XmlMaps_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define XmlMaps_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define XmlMaps_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define XmlMaps_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define XmlMaps_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __XmlMaps_DISPINTERFACE_DEFINED__ */


#ifndef __ListDataFormat_DISPINTERFACE_DEFINED__
#define __ListDataFormat_DISPINTERFACE_DEFINED__

/* dispinterface ListDataFormat */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_ListDataFormat;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002447D-0000-0000-C000-000000000046")
    ListDataFormat : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ListDataFormatVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ListDataFormat * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ListDataFormat * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ListDataFormat * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ListDataFormat * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ListDataFormat * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ListDataFormat * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ListDataFormat * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ListDataFormatVtbl;

    interface ListDataFormat
    {
        CONST_VTBL struct ListDataFormatVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ListDataFormat_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ListDataFormat_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ListDataFormat_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ListDataFormat_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ListDataFormat_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ListDataFormat_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ListDataFormat_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __ListDataFormat_DISPINTERFACE_DEFINED__ */


#ifndef __XPath_DISPINTERFACE_DEFINED__
#define __XPath_DISPINTERFACE_DEFINED__

/* dispinterface XPath */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_XPath;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002447E-0000-0000-C000-000000000046")
    XPath : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct XPathVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            XPath * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            XPath * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            XPath * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            XPath * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            XPath * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            XPath * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            XPath * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } XPathVtbl;

    interface XPath
    {
        CONST_VTBL struct XPathVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define XPath_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define XPath_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define XPath_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define XPath_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define XPath_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define XPath_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define XPath_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __XPath_DISPINTERFACE_DEFINED__ */


#ifndef __PivotLineCells_DISPINTERFACE_DEFINED__
#define __PivotLineCells_DISPINTERFACE_DEFINED__

/* dispinterface PivotLineCells */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_PivotLineCells;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002447F-0000-0000-C000-000000000046")
    PivotLineCells : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct PivotLineCellsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            PivotLineCells * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            PivotLineCells * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            PivotLineCells * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            PivotLineCells * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            PivotLineCells * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            PivotLineCells * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            PivotLineCells * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } PivotLineCellsVtbl;

    interface PivotLineCells
    {
        CONST_VTBL struct PivotLineCellsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define PivotLineCells_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define PivotLineCells_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define PivotLineCells_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define PivotLineCells_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define PivotLineCells_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define PivotLineCells_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define PivotLineCells_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __PivotLineCells_DISPINTERFACE_DEFINED__ */


#ifndef __PivotLine_DISPINTERFACE_DEFINED__
#define __PivotLine_DISPINTERFACE_DEFINED__

/* dispinterface PivotLine */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_PivotLine;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024480-0000-0000-C000-000000000046")
    PivotLine : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct PivotLineVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            PivotLine * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            PivotLine * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            PivotLine * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            PivotLine * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            PivotLine * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            PivotLine * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            PivotLine * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } PivotLineVtbl;

    interface PivotLine
    {
        CONST_VTBL struct PivotLineVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define PivotLine_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define PivotLine_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define PivotLine_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define PivotLine_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define PivotLine_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define PivotLine_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define PivotLine_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __PivotLine_DISPINTERFACE_DEFINED__ */


#ifndef __PivotLines_DISPINTERFACE_DEFINED__
#define __PivotLines_DISPINTERFACE_DEFINED__

/* dispinterface PivotLines */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_PivotLines;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024481-0000-0000-C000-000000000046")
    PivotLines : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct PivotLinesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            PivotLines * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            PivotLines * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            PivotLines * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            PivotLines * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            PivotLines * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            PivotLines * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            PivotLines * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } PivotLinesVtbl;

    interface PivotLines
    {
        CONST_VTBL struct PivotLinesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define PivotLines_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define PivotLines_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define PivotLines_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define PivotLines_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define PivotLines_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define PivotLines_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define PivotLines_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __PivotLines_DISPINTERFACE_DEFINED__ */


#ifndef __PivotAxis_DISPINTERFACE_DEFINED__
#define __PivotAxis_DISPINTERFACE_DEFINED__

/* dispinterface PivotAxis */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_PivotAxis;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024482-0000-0000-C000-000000000046")
    PivotAxis : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct PivotAxisVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            PivotAxis * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            PivotAxis * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            PivotAxis * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            PivotAxis * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            PivotAxis * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            PivotAxis * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            PivotAxis * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } PivotAxisVtbl;

    interface PivotAxis
    {
        CONST_VTBL struct PivotAxisVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define PivotAxis_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define PivotAxis_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define PivotAxis_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define PivotAxis_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define PivotAxis_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define PivotAxis_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define PivotAxis_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __PivotAxis_DISPINTERFACE_DEFINED__ */


#ifndef __PivotFilter_DISPINTERFACE_DEFINED__
#define __PivotFilter_DISPINTERFACE_DEFINED__

/* dispinterface PivotFilter */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_PivotFilter;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024483-0000-0000-C000-000000000046")
    PivotFilter : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct PivotFilterVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            PivotFilter * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            PivotFilter * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            PivotFilter * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            PivotFilter * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            PivotFilter * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            PivotFilter * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            PivotFilter * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } PivotFilterVtbl;

    interface PivotFilter
    {
        CONST_VTBL struct PivotFilterVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define PivotFilter_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define PivotFilter_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define PivotFilter_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define PivotFilter_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define PivotFilter_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define PivotFilter_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define PivotFilter_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __PivotFilter_DISPINTERFACE_DEFINED__ */


#ifndef __PivotFilters_DISPINTERFACE_DEFINED__
#define __PivotFilters_DISPINTERFACE_DEFINED__

/* dispinterface PivotFilters */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_PivotFilters;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024484-0000-0000-C000-000000000046")
    PivotFilters : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct PivotFiltersVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            PivotFilters * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            PivotFilters * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            PivotFilters * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            PivotFilters * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            PivotFilters * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            PivotFilters * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            PivotFilters * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } PivotFiltersVtbl;

    interface PivotFilters
    {
        CONST_VTBL struct PivotFiltersVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define PivotFilters_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define PivotFilters_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define PivotFilters_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define PivotFilters_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define PivotFilters_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define PivotFilters_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define PivotFilters_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __PivotFilters_DISPINTERFACE_DEFINED__ */


#ifndef __WorkbookConnection_DISPINTERFACE_DEFINED__
#define __WorkbookConnection_DISPINTERFACE_DEFINED__

/* dispinterface WorkbookConnection */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_WorkbookConnection;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024485-0000-0000-C000-000000000046")
    WorkbookConnection : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct WorkbookConnectionVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            WorkbookConnection * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            WorkbookConnection * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            WorkbookConnection * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            WorkbookConnection * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            WorkbookConnection * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            WorkbookConnection * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            WorkbookConnection * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } WorkbookConnectionVtbl;

    interface WorkbookConnection
    {
        CONST_VTBL struct WorkbookConnectionVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define WorkbookConnection_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define WorkbookConnection_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define WorkbookConnection_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define WorkbookConnection_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define WorkbookConnection_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define WorkbookConnection_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define WorkbookConnection_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __WorkbookConnection_DISPINTERFACE_DEFINED__ */


#ifndef __Connections_DISPINTERFACE_DEFINED__
#define __Connections_DISPINTERFACE_DEFINED__

/* dispinterface Connections */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Connections;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024486-0000-0000-C000-000000000046")
    Connections : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ConnectionsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Connections * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Connections * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Connections * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Connections * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Connections * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Connections * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Connections * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ConnectionsVtbl;

    interface Connections
    {
        CONST_VTBL struct ConnectionsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Connections_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Connections_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Connections_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Connections_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Connections_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Connections_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Connections_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Connections_DISPINTERFACE_DEFINED__ */


#ifndef __WorksheetView_DISPINTERFACE_DEFINED__
#define __WorksheetView_DISPINTERFACE_DEFINED__

/* dispinterface WorksheetView */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_WorksheetView;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024487-0000-0000-C000-000000000046")
    WorksheetView : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct WorksheetViewVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            WorksheetView * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            WorksheetView * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            WorksheetView * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            WorksheetView * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            WorksheetView * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            WorksheetView * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            WorksheetView * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } WorksheetViewVtbl;

    interface WorksheetView
    {
        CONST_VTBL struct WorksheetViewVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define WorksheetView_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define WorksheetView_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define WorksheetView_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define WorksheetView_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define WorksheetView_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define WorksheetView_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define WorksheetView_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __WorksheetView_DISPINTERFACE_DEFINED__ */


#ifndef __ChartView_DISPINTERFACE_DEFINED__
#define __ChartView_DISPINTERFACE_DEFINED__

/* dispinterface ChartView */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_ChartView;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024488-0000-0000-C000-000000000046")
    ChartView : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ChartViewVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ChartView * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ChartView * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ChartView * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ChartView * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ChartView * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ChartView * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ChartView * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ChartViewVtbl;

    interface ChartView
    {
        CONST_VTBL struct ChartViewVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ChartView_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ChartView_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ChartView_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ChartView_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ChartView_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ChartView_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ChartView_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __ChartView_DISPINTERFACE_DEFINED__ */


#ifndef __ModuleView_DISPINTERFACE_DEFINED__
#define __ModuleView_DISPINTERFACE_DEFINED__

/* dispinterface ModuleView */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_ModuleView;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024489-0000-0000-C000-000000000046")
    ModuleView : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ModuleViewVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ModuleView * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ModuleView * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ModuleView * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ModuleView * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ModuleView * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ModuleView * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ModuleView * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ModuleViewVtbl;

    interface ModuleView
    {
        CONST_VTBL struct ModuleViewVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ModuleView_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ModuleView_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ModuleView_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ModuleView_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ModuleView_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ModuleView_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ModuleView_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __ModuleView_DISPINTERFACE_DEFINED__ */


#ifndef __DialogSheetView_DISPINTERFACE_DEFINED__
#define __DialogSheetView_DISPINTERFACE_DEFINED__

/* dispinterface DialogSheetView */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_DialogSheetView;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002448A-0000-0000-C000-000000000046")
    DialogSheetView : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct DialogSheetViewVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            DialogSheetView * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            DialogSheetView * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            DialogSheetView * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            DialogSheetView * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            DialogSheetView * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            DialogSheetView * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            DialogSheetView * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } DialogSheetViewVtbl;

    interface DialogSheetView
    {
        CONST_VTBL struct DialogSheetViewVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define DialogSheetView_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define DialogSheetView_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define DialogSheetView_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define DialogSheetView_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define DialogSheetView_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define DialogSheetView_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define DialogSheetView_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __DialogSheetView_DISPINTERFACE_DEFINED__ */


#ifndef __SheetViews_DISPINTERFACE_DEFINED__
#define __SheetViews_DISPINTERFACE_DEFINED__

/* dispinterface SheetViews */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_SheetViews;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002448C-0000-0000-C000-000000000046")
    SheetViews : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct SheetViewsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            SheetViews * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            SheetViews * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            SheetViews * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            SheetViews * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            SheetViews * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            SheetViews * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            SheetViews * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } SheetViewsVtbl;

    interface SheetViews
    {
        CONST_VTBL struct SheetViewsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define SheetViews_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define SheetViews_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define SheetViews_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define SheetViews_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define SheetViews_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define SheetViews_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define SheetViews_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __SheetViews_DISPINTERFACE_DEFINED__ */


#ifndef __OLEDBConnection_DISPINTERFACE_DEFINED__
#define __OLEDBConnection_DISPINTERFACE_DEFINED__

/* dispinterface OLEDBConnection */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_OLEDBConnection;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002448D-0000-0000-C000-000000000046")
    OLEDBConnection : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct OLEDBConnectionVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            OLEDBConnection * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            OLEDBConnection * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            OLEDBConnection * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            OLEDBConnection * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            OLEDBConnection * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            OLEDBConnection * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            OLEDBConnection * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } OLEDBConnectionVtbl;

    interface OLEDBConnection
    {
        CONST_VTBL struct OLEDBConnectionVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define OLEDBConnection_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define OLEDBConnection_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define OLEDBConnection_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define OLEDBConnection_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define OLEDBConnection_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define OLEDBConnection_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define OLEDBConnection_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __OLEDBConnection_DISPINTERFACE_DEFINED__ */


#ifndef __ODBCConnection_DISPINTERFACE_DEFINED__
#define __ODBCConnection_DISPINTERFACE_DEFINED__

/* dispinterface ODBCConnection */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_ODBCConnection;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002448E-0000-0000-C000-000000000046")
    ODBCConnection : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ODBCConnectionVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ODBCConnection * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ODBCConnection * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ODBCConnection * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ODBCConnection * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ODBCConnection * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ODBCConnection * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ODBCConnection * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ODBCConnectionVtbl;

    interface ODBCConnection
    {
        CONST_VTBL struct ODBCConnectionVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ODBCConnection_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ODBCConnection_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ODBCConnection_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ODBCConnection_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ODBCConnection_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ODBCConnection_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ODBCConnection_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __ODBCConnection_DISPINTERFACE_DEFINED__ */


#ifndef __Action_DISPINTERFACE_DEFINED__
#define __Action_DISPINTERFACE_DEFINED__

/* dispinterface Action */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Action;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002448F-0000-0000-C000-000000000046")
    Action : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ActionVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Action * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Action * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Action * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Action * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Action * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Action * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Action * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ActionVtbl;

    interface Action
    {
        CONST_VTBL struct ActionVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Action_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Action_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Action_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Action_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Action_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Action_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Action_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Action_DISPINTERFACE_DEFINED__ */


#ifndef __Actions_DISPINTERFACE_DEFINED__
#define __Actions_DISPINTERFACE_DEFINED__

/* dispinterface Actions */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Actions;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024490-0000-0000-C000-000000000046")
    Actions : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ActionsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Actions * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Actions * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Actions * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Actions * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Actions * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Actions * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Actions * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ActionsVtbl;

    interface Actions
    {
        CONST_VTBL struct ActionsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Actions_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Actions_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Actions_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Actions_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Actions_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Actions_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Actions_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Actions_DISPINTERFACE_DEFINED__ */


#ifndef __FormatColor_DISPINTERFACE_DEFINED__
#define __FormatColor_DISPINTERFACE_DEFINED__

/* dispinterface FormatColor */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_FormatColor;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024491-0000-0000-C000-000000000046")
    FormatColor : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct FormatColorVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            FormatColor * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            FormatColor * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            FormatColor * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            FormatColor * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            FormatColor * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            FormatColor * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            FormatColor * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } FormatColorVtbl;

    interface FormatColor
    {
        CONST_VTBL struct FormatColorVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define FormatColor_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define FormatColor_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define FormatColor_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define FormatColor_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define FormatColor_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define FormatColor_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define FormatColor_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __FormatColor_DISPINTERFACE_DEFINED__ */


#ifndef __ConditionValue_DISPINTERFACE_DEFINED__
#define __ConditionValue_DISPINTERFACE_DEFINED__

/* dispinterface ConditionValue */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_ConditionValue;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024492-0000-0000-C000-000000000046")
    ConditionValue : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ConditionValueVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ConditionValue * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ConditionValue * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ConditionValue * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ConditionValue * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ConditionValue * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ConditionValue * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ConditionValue * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ConditionValueVtbl;

    interface ConditionValue
    {
        CONST_VTBL struct ConditionValueVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ConditionValue_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ConditionValue_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ConditionValue_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ConditionValue_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ConditionValue_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ConditionValue_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ConditionValue_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __ConditionValue_DISPINTERFACE_DEFINED__ */


#ifndef __ColorScale_DISPINTERFACE_DEFINED__
#define __ColorScale_DISPINTERFACE_DEFINED__

/* dispinterface ColorScale */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_ColorScale;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024493-0000-0000-C000-000000000046")
    ColorScale : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ColorScaleVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ColorScale * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ColorScale * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ColorScale * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ColorScale * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ColorScale * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ColorScale * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ColorScale * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ColorScaleVtbl;

    interface ColorScale
    {
        CONST_VTBL struct ColorScaleVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ColorScale_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ColorScale_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ColorScale_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ColorScale_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ColorScale_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ColorScale_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ColorScale_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __ColorScale_DISPINTERFACE_DEFINED__ */


#ifndef __ColorScaleCriteria_DISPINTERFACE_DEFINED__
#define __ColorScaleCriteria_DISPINTERFACE_DEFINED__

/* dispinterface ColorScaleCriteria */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_ColorScaleCriteria;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024494-0000-0000-C000-000000000046")
    ColorScaleCriteria : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ColorScaleCriteriaVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ColorScaleCriteria * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ColorScaleCriteria * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ColorScaleCriteria * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ColorScaleCriteria * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ColorScaleCriteria * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ColorScaleCriteria * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ColorScaleCriteria * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ColorScaleCriteriaVtbl;

    interface ColorScaleCriteria
    {
        CONST_VTBL struct ColorScaleCriteriaVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ColorScaleCriteria_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ColorScaleCriteria_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ColorScaleCriteria_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ColorScaleCriteria_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ColorScaleCriteria_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ColorScaleCriteria_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ColorScaleCriteria_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __ColorScaleCriteria_DISPINTERFACE_DEFINED__ */


#ifndef __ColorScaleCriterion_DISPINTERFACE_DEFINED__
#define __ColorScaleCriterion_DISPINTERFACE_DEFINED__

/* dispinterface ColorScaleCriterion */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_ColorScaleCriterion;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024495-0000-0000-C000-000000000046")
    ColorScaleCriterion : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ColorScaleCriterionVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ColorScaleCriterion * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ColorScaleCriterion * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ColorScaleCriterion * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ColorScaleCriterion * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ColorScaleCriterion * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ColorScaleCriterion * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ColorScaleCriterion * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ColorScaleCriterionVtbl;

    interface ColorScaleCriterion
    {
        CONST_VTBL struct ColorScaleCriterionVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ColorScaleCriterion_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ColorScaleCriterion_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ColorScaleCriterion_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ColorScaleCriterion_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ColorScaleCriterion_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ColorScaleCriterion_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ColorScaleCriterion_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __ColorScaleCriterion_DISPINTERFACE_DEFINED__ */


#ifndef __Databar_DISPINTERFACE_DEFINED__
#define __Databar_DISPINTERFACE_DEFINED__

/* dispinterface Databar */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Databar;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024496-0000-0000-C000-000000000046")
    Databar : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct DatabarVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Databar * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Databar * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Databar * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Databar * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Databar * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Databar * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Databar * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } DatabarVtbl;

    interface Databar
    {
        CONST_VTBL struct DatabarVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Databar_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Databar_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Databar_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Databar_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Databar_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Databar_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Databar_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Databar_DISPINTERFACE_DEFINED__ */


#ifndef __IconSetCondition_DISPINTERFACE_DEFINED__
#define __IconSetCondition_DISPINTERFACE_DEFINED__

/* dispinterface IconSetCondition */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_IconSetCondition;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024497-0000-0000-C000-000000000046")
    IconSetCondition : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct IconSetConditionVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IconSetCondition * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IconSetCondition * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IconSetCondition * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IconSetCondition * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IconSetCondition * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IconSetCondition * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IconSetCondition * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } IconSetConditionVtbl;

    interface IconSetCondition
    {
        CONST_VTBL struct IconSetConditionVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IconSetCondition_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IconSetCondition_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IconSetCondition_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IconSetCondition_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IconSetCondition_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IconSetCondition_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IconSetCondition_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __IconSetCondition_DISPINTERFACE_DEFINED__ */


#ifndef __IconCriteria_DISPINTERFACE_DEFINED__
#define __IconCriteria_DISPINTERFACE_DEFINED__

/* dispinterface IconCriteria */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_IconCriteria;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024498-0000-0000-C000-000000000046")
    IconCriteria : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct IconCriteriaVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IconCriteria * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IconCriteria * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IconCriteria * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IconCriteria * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IconCriteria * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IconCriteria * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IconCriteria * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } IconCriteriaVtbl;

    interface IconCriteria
    {
        CONST_VTBL struct IconCriteriaVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IconCriteria_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IconCriteria_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IconCriteria_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IconCriteria_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IconCriteria_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IconCriteria_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IconCriteria_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __IconCriteria_DISPINTERFACE_DEFINED__ */


#ifndef __IconCriterion_DISPINTERFACE_DEFINED__
#define __IconCriterion_DISPINTERFACE_DEFINED__

/* dispinterface IconCriterion */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_IconCriterion;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("00024499-0000-0000-C000-000000000046")
    IconCriterion : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct IconCriterionVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IconCriterion * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IconCriterion * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IconCriterion * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IconCriterion * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IconCriterion * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IconCriterion * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IconCriterion * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } IconCriterionVtbl;

    interface IconCriterion
    {
        CONST_VTBL struct IconCriterionVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IconCriterion_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IconCriterion_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IconCriterion_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IconCriterion_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IconCriterion_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IconCriterion_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IconCriterion_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __IconCriterion_DISPINTERFACE_DEFINED__ */


#ifndef __Icon_DISPINTERFACE_DEFINED__
#define __Icon_DISPINTERFACE_DEFINED__

/* dispinterface Icon */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Icon;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002449A-0000-0000-C000-000000000046")
    Icon : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct IconVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Icon * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Icon * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Icon * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Icon * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Icon * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Icon * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Icon * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } IconVtbl;

    interface Icon
    {
        CONST_VTBL struct IconVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Icon_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Icon_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Icon_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Icon_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Icon_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Icon_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Icon_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Icon_DISPINTERFACE_DEFINED__ */


#ifndef __IconSet_DISPINTERFACE_DEFINED__
#define __IconSet_DISPINTERFACE_DEFINED__

/* dispinterface IconSet */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_IconSet;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002449B-0000-0000-C000-000000000046")
    IconSet : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct IconSetVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IconSet * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IconSet * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IconSet * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IconSet * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IconSet * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IconSet * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IconSet * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } IconSetVtbl;

    interface IconSet
    {
        CONST_VTBL struct IconSetVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IconSet_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IconSet_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IconSet_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IconSet_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IconSet_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IconSet_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IconSet_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __IconSet_DISPINTERFACE_DEFINED__ */


#ifndef __IconSets_DISPINTERFACE_DEFINED__
#define __IconSets_DISPINTERFACE_DEFINED__

/* dispinterface IconSets */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_IconSets;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002449C-0000-0000-C000-000000000046")
    IconSets : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct IconSetsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IconSets * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IconSets * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IconSets * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IconSets * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IconSets * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IconSets * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IconSets * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } IconSetsVtbl;

    interface IconSets
    {
        CONST_VTBL struct IconSetsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IconSets_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IconSets_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IconSets_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IconSets_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IconSets_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IconSets_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IconSets_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __IconSets_DISPINTERFACE_DEFINED__ */


#ifndef __Top10_DISPINTERFACE_DEFINED__
#define __Top10_DISPINTERFACE_DEFINED__

/* dispinterface Top10 */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Top10;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002449D-0000-0000-C000-000000000046")
    Top10 : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct Top10Vtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Top10 * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Top10 * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Top10 * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Top10 * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Top10 * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Top10 * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Top10 * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } Top10Vtbl;

    interface Top10
    {
        CONST_VTBL struct Top10Vtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Top10_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Top10_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Top10_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Top10_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Top10_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Top10_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Top10_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Top10_DISPINTERFACE_DEFINED__ */


#ifndef __AboveAverage_DISPINTERFACE_DEFINED__
#define __AboveAverage_DISPINTERFACE_DEFINED__

/* dispinterface AboveAverage */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_AboveAverage;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002449E-0000-0000-C000-000000000046")
    AboveAverage : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct AboveAverageVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            AboveAverage * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            AboveAverage * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            AboveAverage * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            AboveAverage * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            AboveAverage * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            AboveAverage * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            AboveAverage * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } AboveAverageVtbl;

    interface AboveAverage
    {
        CONST_VTBL struct AboveAverageVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define AboveAverage_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define AboveAverage_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define AboveAverage_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define AboveAverage_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define AboveAverage_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define AboveAverage_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define AboveAverage_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __AboveAverage_DISPINTERFACE_DEFINED__ */


#ifndef __UniqueValues_DISPINTERFACE_DEFINED__
#define __UniqueValues_DISPINTERFACE_DEFINED__

/* dispinterface UniqueValues */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_UniqueValues;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("0002449F-0000-0000-C000-000000000046")
    UniqueValues : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct UniqueValuesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            UniqueValues * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            UniqueValues * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            UniqueValues * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            UniqueValues * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            UniqueValues * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            UniqueValues * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            UniqueValues * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } UniqueValuesVtbl;

    interface UniqueValues
    {
        CONST_VTBL struct UniqueValuesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define UniqueValues_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define UniqueValues_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define UniqueValues_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define UniqueValues_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define UniqueValues_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define UniqueValues_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define UniqueValues_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __UniqueValues_DISPINTERFACE_DEFINED__ */


#ifndef __Ranges_DISPINTERFACE_DEFINED__
#define __Ranges_DISPINTERFACE_DEFINED__

/* dispinterface Ranges */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Ranges;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244A0-0000-0000-C000-000000000046")
    Ranges : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct RangesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Ranges * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Ranges * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Ranges * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Ranges * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Ranges * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Ranges * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Ranges * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } RangesVtbl;

    interface Ranges
    {
        CONST_VTBL struct RangesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Ranges_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Ranges_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Ranges_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Ranges_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Ranges_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Ranges_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Ranges_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Ranges_DISPINTERFACE_DEFINED__ */


#ifndef __HeaderFooter_DISPINTERFACE_DEFINED__
#define __HeaderFooter_DISPINTERFACE_DEFINED__

/* dispinterface HeaderFooter */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_HeaderFooter;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244A1-0000-0000-C000-000000000046")
    HeaderFooter : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct HeaderFooterVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            HeaderFooter * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            HeaderFooter * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            HeaderFooter * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            HeaderFooter * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            HeaderFooter * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            HeaderFooter * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            HeaderFooter * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } HeaderFooterVtbl;

    interface HeaderFooter
    {
        CONST_VTBL struct HeaderFooterVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define HeaderFooter_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define HeaderFooter_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define HeaderFooter_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define HeaderFooter_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define HeaderFooter_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define HeaderFooter_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define HeaderFooter_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __HeaderFooter_DISPINTERFACE_DEFINED__ */


#ifndef __Page_DISPINTERFACE_DEFINED__
#define __Page_DISPINTERFACE_DEFINED__

/* dispinterface Page */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Page;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244A2-0000-0000-C000-000000000046")
    Page : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct PageVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Page * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Page * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Page * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Page * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Page * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Page * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Page * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } PageVtbl;

    interface Page
    {
        CONST_VTBL struct PageVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Page_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Page_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Page_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Page_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Page_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Page_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Page_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Page_DISPINTERFACE_DEFINED__ */


#ifndef __Pages_DISPINTERFACE_DEFINED__
#define __Pages_DISPINTERFACE_DEFINED__

/* dispinterface Pages */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Pages;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244A3-0000-0000-C000-000000000046")
    Pages : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct PagesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Pages * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Pages * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Pages * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Pages * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Pages * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Pages * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Pages * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } PagesVtbl;

    interface Pages
    {
        CONST_VTBL struct PagesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Pages_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Pages_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Pages_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Pages_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Pages_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Pages_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Pages_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Pages_DISPINTERFACE_DEFINED__ */


#ifndef __ServerViewableItems_DISPINTERFACE_DEFINED__
#define __ServerViewableItems_DISPINTERFACE_DEFINED__

/* dispinterface ServerViewableItems */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_ServerViewableItems;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244A4-0000-0000-C000-000000000046")
    ServerViewableItems : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ServerViewableItemsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ServerViewableItems * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ServerViewableItems * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ServerViewableItems * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ServerViewableItems * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ServerViewableItems * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ServerViewableItems * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ServerViewableItems * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ServerViewableItemsVtbl;

    interface ServerViewableItems
    {
        CONST_VTBL struct ServerViewableItemsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ServerViewableItems_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ServerViewableItems_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ServerViewableItems_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ServerViewableItems_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ServerViewableItems_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ServerViewableItems_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ServerViewableItems_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __ServerViewableItems_DISPINTERFACE_DEFINED__ */


#ifndef __TableStyleElement_DISPINTERFACE_DEFINED__
#define __TableStyleElement_DISPINTERFACE_DEFINED__

/* dispinterface TableStyleElement */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_TableStyleElement;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244A5-0000-0000-C000-000000000046")
    TableStyleElement : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct TableStyleElementVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            TableStyleElement * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            TableStyleElement * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            TableStyleElement * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            TableStyleElement * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            TableStyleElement * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            TableStyleElement * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            TableStyleElement * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } TableStyleElementVtbl;

    interface TableStyleElement
    {
        CONST_VTBL struct TableStyleElementVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define TableStyleElement_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define TableStyleElement_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define TableStyleElement_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define TableStyleElement_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define TableStyleElement_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define TableStyleElement_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define TableStyleElement_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __TableStyleElement_DISPINTERFACE_DEFINED__ */


#ifndef __TableStyleElements_DISPINTERFACE_DEFINED__
#define __TableStyleElements_DISPINTERFACE_DEFINED__

/* dispinterface TableStyleElements */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_TableStyleElements;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244A6-0000-0000-C000-000000000046")
    TableStyleElements : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct TableStyleElementsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            TableStyleElements * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            TableStyleElements * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            TableStyleElements * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            TableStyleElements * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            TableStyleElements * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            TableStyleElements * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            TableStyleElements * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } TableStyleElementsVtbl;

    interface TableStyleElements
    {
        CONST_VTBL struct TableStyleElementsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define TableStyleElements_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define TableStyleElements_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define TableStyleElements_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define TableStyleElements_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define TableStyleElements_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define TableStyleElements_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define TableStyleElements_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __TableStyleElements_DISPINTERFACE_DEFINED__ */


#ifndef __TableStyle_DISPINTERFACE_DEFINED__
#define __TableStyle_DISPINTERFACE_DEFINED__

/* dispinterface TableStyle */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_TableStyle;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244A7-0000-0000-C000-000000000046")
    TableStyle : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct TableStyleVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            TableStyle * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            TableStyle * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            TableStyle * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            TableStyle * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            TableStyle * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            TableStyle * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            TableStyle * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } TableStyleVtbl;

    interface TableStyle
    {
        CONST_VTBL struct TableStyleVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define TableStyle_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define TableStyle_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define TableStyle_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define TableStyle_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define TableStyle_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define TableStyle_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define TableStyle_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __TableStyle_DISPINTERFACE_DEFINED__ */


#ifndef __TableStyles_DISPINTERFACE_DEFINED__
#define __TableStyles_DISPINTERFACE_DEFINED__

/* dispinterface TableStyles */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_TableStyles;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244A8-0000-0000-C000-000000000046")
    TableStyles : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct TableStylesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            TableStyles * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            TableStyles * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            TableStyles * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            TableStyles * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            TableStyles * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            TableStyles * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            TableStyles * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } TableStylesVtbl;

    interface TableStyles
    {
        CONST_VTBL struct TableStylesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define TableStyles_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define TableStyles_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define TableStyles_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define TableStyles_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define TableStyles_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define TableStyles_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define TableStyles_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __TableStyles_DISPINTERFACE_DEFINED__ */


#ifndef __SortField_DISPINTERFACE_DEFINED__
#define __SortField_DISPINTERFACE_DEFINED__

/* dispinterface SortField */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_SortField;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244A9-0000-0000-C000-000000000046")
    SortField : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct SortFieldVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            SortField * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            SortField * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            SortField * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            SortField * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            SortField * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            SortField * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            SortField * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } SortFieldVtbl;

    interface SortField
    {
        CONST_VTBL struct SortFieldVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define SortField_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define SortField_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define SortField_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define SortField_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define SortField_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define SortField_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define SortField_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __SortField_DISPINTERFACE_DEFINED__ */


#ifndef __SortFields_DISPINTERFACE_DEFINED__
#define __SortFields_DISPINTERFACE_DEFINED__

/* dispinterface SortFields */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_SortFields;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244AA-0000-0000-C000-000000000046")
    SortFields : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct SortFieldsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            SortFields * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            SortFields * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            SortFields * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            SortFields * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            SortFields * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            SortFields * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            SortFields * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } SortFieldsVtbl;

    interface SortFields
    {
        CONST_VTBL struct SortFieldsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define SortFields_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define SortFields_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define SortFields_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define SortFields_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define SortFields_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define SortFields_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define SortFields_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __SortFields_DISPINTERFACE_DEFINED__ */


#ifndef __Sort_DISPINTERFACE_DEFINED__
#define __Sort_DISPINTERFACE_DEFINED__

/* dispinterface Sort */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Sort;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244AB-0000-0000-C000-000000000046")
    Sort : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct SortVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Sort * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Sort * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Sort * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Sort * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Sort * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Sort * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Sort * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } SortVtbl;

    interface Sort
    {
        CONST_VTBL struct SortVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Sort_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Sort_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Sort_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Sort_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Sort_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Sort_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Sort_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Sort_DISPINTERFACE_DEFINED__ */


#ifndef __Research_DISPINTERFACE_DEFINED__
#define __Research_DISPINTERFACE_DEFINED__

/* dispinterface Research */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Research;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244AC-0000-0000-C000-000000000046")
    Research : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ResearchVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Research * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Research * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Research * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Research * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Research * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Research * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Research * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ResearchVtbl;

    interface Research
    {
        CONST_VTBL struct ResearchVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Research_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Research_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Research_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Research_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Research_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Research_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Research_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Research_DISPINTERFACE_DEFINED__ */


#ifndef __ColorStop_DISPINTERFACE_DEFINED__
#define __ColorStop_DISPINTERFACE_DEFINED__

/* dispinterface ColorStop */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_ColorStop;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244AD-0000-0000-C000-000000000046")
    ColorStop : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ColorStopVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ColorStop * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ColorStop * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ColorStop * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ColorStop * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ColorStop * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ColorStop * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ColorStop * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ColorStopVtbl;

    interface ColorStop
    {
        CONST_VTBL struct ColorStopVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ColorStop_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ColorStop_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ColorStop_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ColorStop_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ColorStop_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ColorStop_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ColorStop_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __ColorStop_DISPINTERFACE_DEFINED__ */


#ifndef __ColorStops_DISPINTERFACE_DEFINED__
#define __ColorStops_DISPINTERFACE_DEFINED__

/* dispinterface ColorStops */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_ColorStops;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244AE-0000-0000-C000-000000000046")
    ColorStops : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ColorStopsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ColorStops * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ColorStops * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ColorStops * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ColorStops * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ColorStops * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ColorStops * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ColorStops * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ColorStopsVtbl;

    interface ColorStops
    {
        CONST_VTBL struct ColorStopsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ColorStops_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ColorStops_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ColorStops_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ColorStops_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ColorStops_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ColorStops_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ColorStops_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __ColorStops_DISPINTERFACE_DEFINED__ */


#ifndef __LinearGradient_DISPINTERFACE_DEFINED__
#define __LinearGradient_DISPINTERFACE_DEFINED__

/* dispinterface LinearGradient */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_LinearGradient;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244AF-0000-0000-C000-000000000046")
    LinearGradient : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct LinearGradientVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            LinearGradient * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            LinearGradient * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            LinearGradient * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            LinearGradient * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            LinearGradient * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            LinearGradient * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            LinearGradient * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } LinearGradientVtbl;

    interface LinearGradient
    {
        CONST_VTBL struct LinearGradientVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define LinearGradient_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define LinearGradient_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define LinearGradient_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define LinearGradient_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define LinearGradient_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define LinearGradient_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define LinearGradient_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __LinearGradient_DISPINTERFACE_DEFINED__ */


#ifndef __RectangularGradient_DISPINTERFACE_DEFINED__
#define __RectangularGradient_DISPINTERFACE_DEFINED__

/* dispinterface RectangularGradient */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_RectangularGradient;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244B0-0000-0000-C000-000000000046")
    RectangularGradient : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct RectangularGradientVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            RectangularGradient * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            RectangularGradient * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            RectangularGradient * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            RectangularGradient * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            RectangularGradient * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            RectangularGradient * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            RectangularGradient * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } RectangularGradientVtbl;

    interface RectangularGradient
    {
        CONST_VTBL struct RectangularGradientVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define RectangularGradient_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define RectangularGradient_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define RectangularGradient_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define RectangularGradient_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define RectangularGradient_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define RectangularGradient_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define RectangularGradient_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __RectangularGradient_DISPINTERFACE_DEFINED__ */


#ifndef __MultiThreadedCalculation_DISPINTERFACE_DEFINED__
#define __MultiThreadedCalculation_DISPINTERFACE_DEFINED__

/* dispinterface MultiThreadedCalculation */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_MultiThreadedCalculation;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244B1-0000-0000-C000-000000000046")
    MultiThreadedCalculation : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct MultiThreadedCalculationVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            MultiThreadedCalculation * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            MultiThreadedCalculation * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            MultiThreadedCalculation * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            MultiThreadedCalculation * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            MultiThreadedCalculation * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            MultiThreadedCalculation * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            MultiThreadedCalculation * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } MultiThreadedCalculationVtbl;

    interface MultiThreadedCalculation
    {
        CONST_VTBL struct MultiThreadedCalculationVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define MultiThreadedCalculation_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define MultiThreadedCalculation_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define MultiThreadedCalculation_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define MultiThreadedCalculation_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define MultiThreadedCalculation_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define MultiThreadedCalculation_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define MultiThreadedCalculation_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __MultiThreadedCalculation_DISPINTERFACE_DEFINED__ */


#ifndef __ChartFormat_DISPINTERFACE_DEFINED__
#define __ChartFormat_DISPINTERFACE_DEFINED__

/* dispinterface ChartFormat */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_ChartFormat;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244B2-0000-0000-C000-000000000046")
    ChartFormat : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ChartFormatVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ChartFormat * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ChartFormat * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ChartFormat * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ChartFormat * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ChartFormat * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ChartFormat * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ChartFormat * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ChartFormatVtbl;

    interface ChartFormat
    {
        CONST_VTBL struct ChartFormatVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ChartFormat_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ChartFormat_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ChartFormat_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ChartFormat_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ChartFormat_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ChartFormat_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ChartFormat_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __ChartFormat_DISPINTERFACE_DEFINED__ */


#ifndef __FileExportConverter_DISPINTERFACE_DEFINED__
#define __FileExportConverter_DISPINTERFACE_DEFINED__

/* dispinterface FileExportConverter */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_FileExportConverter;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244B3-0000-0000-C000-000000000046")
    FileExportConverter : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct FileExportConverterVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            FileExportConverter * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            FileExportConverter * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            FileExportConverter * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            FileExportConverter * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            FileExportConverter * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            FileExportConverter * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            FileExportConverter * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } FileExportConverterVtbl;

    interface FileExportConverter
    {
        CONST_VTBL struct FileExportConverterVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define FileExportConverter_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define FileExportConverter_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define FileExportConverter_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define FileExportConverter_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define FileExportConverter_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define FileExportConverter_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define FileExportConverter_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __FileExportConverter_DISPINTERFACE_DEFINED__ */


#ifndef __FileExportConverters_DISPINTERFACE_DEFINED__
#define __FileExportConverters_DISPINTERFACE_DEFINED__

/* dispinterface FileExportConverters */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_FileExportConverters;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244B4-0000-0000-C000-000000000046")
    FileExportConverters : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct FileExportConvertersVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            FileExportConverters * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            FileExportConverters * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            FileExportConverters * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            FileExportConverters * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            FileExportConverters * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            FileExportConverters * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            FileExportConverters * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } FileExportConvertersVtbl;

    interface FileExportConverters
    {
        CONST_VTBL struct FileExportConvertersVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define FileExportConverters_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define FileExportConverters_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define FileExportConverters_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define FileExportConverters_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define FileExportConverters_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define FileExportConverters_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define FileExportConverters_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __FileExportConverters_DISPINTERFACE_DEFINED__ */


#ifndef __AddIns2_DISPINTERFACE_DEFINED__
#define __AddIns2_DISPINTERFACE_DEFINED__

/* dispinterface AddIns2 */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_AddIns2;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244B5-0000-0000-C000-000000000046")
    AddIns2 : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct AddIns2Vtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            AddIns2 * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            AddIns2 * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            AddIns2 * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            AddIns2 * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            AddIns2 * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            AddIns2 * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            AddIns2 * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } AddIns2Vtbl;

    interface AddIns2
    {
        CONST_VTBL struct AddIns2Vtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define AddIns2_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define AddIns2_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define AddIns2_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define AddIns2_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define AddIns2_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define AddIns2_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define AddIns2_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __AddIns2_DISPINTERFACE_DEFINED__ */


#ifndef __SparklineGroups_DISPINTERFACE_DEFINED__
#define __SparklineGroups_DISPINTERFACE_DEFINED__

/* dispinterface SparklineGroups */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_SparklineGroups;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244B6-0000-0000-C000-000000000046")
    SparklineGroups : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct SparklineGroupsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            SparklineGroups * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            SparklineGroups * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            SparklineGroups * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            SparklineGroups * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            SparklineGroups * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            SparklineGroups * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            SparklineGroups * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } SparklineGroupsVtbl;

    interface SparklineGroups
    {
        CONST_VTBL struct SparklineGroupsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define SparklineGroups_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define SparklineGroups_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define SparklineGroups_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define SparklineGroups_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define SparklineGroups_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define SparklineGroups_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define SparklineGroups_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __SparklineGroups_DISPINTERFACE_DEFINED__ */


#ifndef __SparklineGroup_DISPINTERFACE_DEFINED__
#define __SparklineGroup_DISPINTERFACE_DEFINED__

/* dispinterface SparklineGroup */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_SparklineGroup;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244B7-0000-0000-C000-000000000046")
    SparklineGroup : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct SparklineGroupVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            SparklineGroup * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            SparklineGroup * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            SparklineGroup * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            SparklineGroup * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            SparklineGroup * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            SparklineGroup * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            SparklineGroup * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } SparklineGroupVtbl;

    interface SparklineGroup
    {
        CONST_VTBL struct SparklineGroupVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define SparklineGroup_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define SparklineGroup_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define SparklineGroup_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define SparklineGroup_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define SparklineGroup_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define SparklineGroup_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define SparklineGroup_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __SparklineGroup_DISPINTERFACE_DEFINED__ */


#ifndef __SparkPoints_DISPINTERFACE_DEFINED__
#define __SparkPoints_DISPINTERFACE_DEFINED__

/* dispinterface SparkPoints */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_SparkPoints;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244B8-0000-0000-C000-000000000046")
    SparkPoints : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct SparkPointsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            SparkPoints * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            SparkPoints * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            SparkPoints * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            SparkPoints * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            SparkPoints * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            SparkPoints * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            SparkPoints * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } SparkPointsVtbl;

    interface SparkPoints
    {
        CONST_VTBL struct SparkPointsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define SparkPoints_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define SparkPoints_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define SparkPoints_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define SparkPoints_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define SparkPoints_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define SparkPoints_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define SparkPoints_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __SparkPoints_DISPINTERFACE_DEFINED__ */


#ifndef __Sparkline_DISPINTERFACE_DEFINED__
#define __Sparkline_DISPINTERFACE_DEFINED__

/* dispinterface Sparkline */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Sparkline;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244B9-0000-0000-C000-000000000046")
    Sparkline : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct SparklineVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Sparkline * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Sparkline * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Sparkline * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Sparkline * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Sparkline * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Sparkline * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Sparkline * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } SparklineVtbl;

    interface Sparkline
    {
        CONST_VTBL struct SparklineVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Sparkline_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Sparkline_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Sparkline_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Sparkline_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Sparkline_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Sparkline_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Sparkline_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Sparkline_DISPINTERFACE_DEFINED__ */


#ifndef __SparkAxes_DISPINTERFACE_DEFINED__
#define __SparkAxes_DISPINTERFACE_DEFINED__

/* dispinterface SparkAxes */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_SparkAxes;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244BA-0000-0000-C000-000000000046")
    SparkAxes : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct SparkAxesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            SparkAxes * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            SparkAxes * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            SparkAxes * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            SparkAxes * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            SparkAxes * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            SparkAxes * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            SparkAxes * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } SparkAxesVtbl;

    interface SparkAxes
    {
        CONST_VTBL struct SparkAxesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define SparkAxes_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define SparkAxes_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define SparkAxes_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define SparkAxes_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define SparkAxes_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define SparkAxes_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define SparkAxes_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __SparkAxes_DISPINTERFACE_DEFINED__ */


#ifndef __SparkHorizontalAxis_DISPINTERFACE_DEFINED__
#define __SparkHorizontalAxis_DISPINTERFACE_DEFINED__

/* dispinterface SparkHorizontalAxis */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_SparkHorizontalAxis;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244BB-0000-0000-C000-000000000046")
    SparkHorizontalAxis : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct SparkHorizontalAxisVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            SparkHorizontalAxis * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            SparkHorizontalAxis * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            SparkHorizontalAxis * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            SparkHorizontalAxis * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            SparkHorizontalAxis * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            SparkHorizontalAxis * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            SparkHorizontalAxis * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } SparkHorizontalAxisVtbl;

    interface SparkHorizontalAxis
    {
        CONST_VTBL struct SparkHorizontalAxisVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define SparkHorizontalAxis_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define SparkHorizontalAxis_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define SparkHorizontalAxis_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define SparkHorizontalAxis_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define SparkHorizontalAxis_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define SparkHorizontalAxis_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define SparkHorizontalAxis_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __SparkHorizontalAxis_DISPINTERFACE_DEFINED__ */


#ifndef __SparkVerticalAxis_DISPINTERFACE_DEFINED__
#define __SparkVerticalAxis_DISPINTERFACE_DEFINED__

/* dispinterface SparkVerticalAxis */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_SparkVerticalAxis;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244BC-0000-0000-C000-000000000046")
    SparkVerticalAxis : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct SparkVerticalAxisVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            SparkVerticalAxis * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            SparkVerticalAxis * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            SparkVerticalAxis * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            SparkVerticalAxis * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            SparkVerticalAxis * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            SparkVerticalAxis * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            SparkVerticalAxis * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } SparkVerticalAxisVtbl;

    interface SparkVerticalAxis
    {
        CONST_VTBL struct SparkVerticalAxisVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define SparkVerticalAxis_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define SparkVerticalAxis_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define SparkVerticalAxis_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define SparkVerticalAxis_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define SparkVerticalAxis_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define SparkVerticalAxis_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define SparkVerticalAxis_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __SparkVerticalAxis_DISPINTERFACE_DEFINED__ */


#ifndef __SparkColor_DISPINTERFACE_DEFINED__
#define __SparkColor_DISPINTERFACE_DEFINED__

/* dispinterface SparkColor */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_SparkColor;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244BD-0000-0000-C000-000000000046")
    SparkColor : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct SparkColorVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            SparkColor * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            SparkColor * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            SparkColor * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            SparkColor * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            SparkColor * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            SparkColor * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            SparkColor * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } SparkColorVtbl;

    interface SparkColor
    {
        CONST_VTBL struct SparkColorVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define SparkColor_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define SparkColor_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define SparkColor_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define SparkColor_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define SparkColor_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define SparkColor_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define SparkColor_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __SparkColor_DISPINTERFACE_DEFINED__ */


#ifndef __DataBarBorder_DISPINTERFACE_DEFINED__
#define __DataBarBorder_DISPINTERFACE_DEFINED__

/* dispinterface DataBarBorder */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_DataBarBorder;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244BE-0000-0000-C000-000000000046")
    DataBarBorder : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct DataBarBorderVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            DataBarBorder * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            DataBarBorder * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            DataBarBorder * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            DataBarBorder * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            DataBarBorder * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            DataBarBorder * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            DataBarBorder * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } DataBarBorderVtbl;

    interface DataBarBorder
    {
        CONST_VTBL struct DataBarBorderVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define DataBarBorder_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define DataBarBorder_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define DataBarBorder_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define DataBarBorder_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define DataBarBorder_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define DataBarBorder_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define DataBarBorder_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __DataBarBorder_DISPINTERFACE_DEFINED__ */


#ifndef __NegativeBarFormat_DISPINTERFACE_DEFINED__
#define __NegativeBarFormat_DISPINTERFACE_DEFINED__

/* dispinterface NegativeBarFormat */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_NegativeBarFormat;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244BF-0000-0000-C000-000000000046")
    NegativeBarFormat : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct NegativeBarFormatVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            NegativeBarFormat * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            NegativeBarFormat * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            NegativeBarFormat * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            NegativeBarFormat * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            NegativeBarFormat * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            NegativeBarFormat * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            NegativeBarFormat * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } NegativeBarFormatVtbl;

    interface NegativeBarFormat
    {
        CONST_VTBL struct NegativeBarFormatVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define NegativeBarFormat_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define NegativeBarFormat_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define NegativeBarFormat_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define NegativeBarFormat_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define NegativeBarFormat_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define NegativeBarFormat_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define NegativeBarFormat_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __NegativeBarFormat_DISPINTERFACE_DEFINED__ */


#ifndef __ValueChange_DISPINTERFACE_DEFINED__
#define __ValueChange_DISPINTERFACE_DEFINED__

/* dispinterface ValueChange */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_ValueChange;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244C0-0000-0000-C000-000000000046")
    ValueChange : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ValueChangeVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ValueChange * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ValueChange * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ValueChange * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ValueChange * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ValueChange * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ValueChange * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ValueChange * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ValueChangeVtbl;

    interface ValueChange
    {
        CONST_VTBL struct ValueChangeVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ValueChange_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ValueChange_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ValueChange_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ValueChange_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ValueChange_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ValueChange_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ValueChange_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __ValueChange_DISPINTERFACE_DEFINED__ */


#ifndef __PivotTableChangeList_DISPINTERFACE_DEFINED__
#define __PivotTableChangeList_DISPINTERFACE_DEFINED__

/* dispinterface PivotTableChangeList */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_PivotTableChangeList;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244C1-0000-0000-C000-000000000046")
    PivotTableChangeList : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct PivotTableChangeListVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            PivotTableChangeList * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            PivotTableChangeList * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            PivotTableChangeList * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            PivotTableChangeList * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            PivotTableChangeList * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            PivotTableChangeList * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            PivotTableChangeList * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } PivotTableChangeListVtbl;

    interface PivotTableChangeList
    {
        CONST_VTBL struct PivotTableChangeListVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define PivotTableChangeList_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define PivotTableChangeList_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define PivotTableChangeList_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define PivotTableChangeList_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define PivotTableChangeList_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define PivotTableChangeList_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define PivotTableChangeList_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __PivotTableChangeList_DISPINTERFACE_DEFINED__ */


#ifndef __DisplayFormat_DISPINTERFACE_DEFINED__
#define __DisplayFormat_DISPINTERFACE_DEFINED__

/* dispinterface DisplayFormat */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_DisplayFormat;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244C2-0000-0000-C000-000000000046")
    DisplayFormat : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct DisplayFormatVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            DisplayFormat * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            DisplayFormat * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            DisplayFormat * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            DisplayFormat * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            DisplayFormat * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            DisplayFormat * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            DisplayFormat * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } DisplayFormatVtbl;

    interface DisplayFormat
    {
        CONST_VTBL struct DisplayFormatVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define DisplayFormat_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define DisplayFormat_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define DisplayFormat_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define DisplayFormat_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define DisplayFormat_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define DisplayFormat_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define DisplayFormat_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __DisplayFormat_DISPINTERFACE_DEFINED__ */


#ifndef __SlicerCaches_DISPINTERFACE_DEFINED__
#define __SlicerCaches_DISPINTERFACE_DEFINED__

/* dispinterface SlicerCaches */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_SlicerCaches;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244C3-0000-0000-C000-000000000046")
    SlicerCaches : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct SlicerCachesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            SlicerCaches * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            SlicerCaches * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            SlicerCaches * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            SlicerCaches * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            SlicerCaches * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            SlicerCaches * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            SlicerCaches * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } SlicerCachesVtbl;

    interface SlicerCaches
    {
        CONST_VTBL struct SlicerCachesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define SlicerCaches_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define SlicerCaches_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define SlicerCaches_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define SlicerCaches_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define SlicerCaches_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define SlicerCaches_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define SlicerCaches_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __SlicerCaches_DISPINTERFACE_DEFINED__ */


#ifndef __SlicerCache_DISPINTERFACE_DEFINED__
#define __SlicerCache_DISPINTERFACE_DEFINED__

/* dispinterface SlicerCache */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_SlicerCache;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244C4-0000-0000-C000-000000000046")
    SlicerCache : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct SlicerCacheVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            SlicerCache * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            SlicerCache * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            SlicerCache * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            SlicerCache * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            SlicerCache * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            SlicerCache * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            SlicerCache * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } SlicerCacheVtbl;

    interface SlicerCache
    {
        CONST_VTBL struct SlicerCacheVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define SlicerCache_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define SlicerCache_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define SlicerCache_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define SlicerCache_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define SlicerCache_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define SlicerCache_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define SlicerCache_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __SlicerCache_DISPINTERFACE_DEFINED__ */


#ifndef __SlicerCacheLevels_DISPINTERFACE_DEFINED__
#define __SlicerCacheLevels_DISPINTERFACE_DEFINED__

/* dispinterface SlicerCacheLevels */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_SlicerCacheLevels;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244C5-0000-0000-C000-000000000046")
    SlicerCacheLevels : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct SlicerCacheLevelsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            SlicerCacheLevels * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            SlicerCacheLevels * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            SlicerCacheLevels * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            SlicerCacheLevels * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            SlicerCacheLevels * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            SlicerCacheLevels * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            SlicerCacheLevels * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } SlicerCacheLevelsVtbl;

    interface SlicerCacheLevels
    {
        CONST_VTBL struct SlicerCacheLevelsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define SlicerCacheLevels_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define SlicerCacheLevels_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define SlicerCacheLevels_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define SlicerCacheLevels_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define SlicerCacheLevels_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define SlicerCacheLevels_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define SlicerCacheLevels_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __SlicerCacheLevels_DISPINTERFACE_DEFINED__ */


#ifndef __SlicerCacheLevel_DISPINTERFACE_DEFINED__
#define __SlicerCacheLevel_DISPINTERFACE_DEFINED__

/* dispinterface SlicerCacheLevel */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_SlicerCacheLevel;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244C6-0000-0000-C000-000000000046")
    SlicerCacheLevel : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct SlicerCacheLevelVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            SlicerCacheLevel * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            SlicerCacheLevel * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            SlicerCacheLevel * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            SlicerCacheLevel * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            SlicerCacheLevel * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            SlicerCacheLevel * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            SlicerCacheLevel * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } SlicerCacheLevelVtbl;

    interface SlicerCacheLevel
    {
        CONST_VTBL struct SlicerCacheLevelVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define SlicerCacheLevel_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define SlicerCacheLevel_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define SlicerCacheLevel_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define SlicerCacheLevel_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define SlicerCacheLevel_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define SlicerCacheLevel_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define SlicerCacheLevel_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __SlicerCacheLevel_DISPINTERFACE_DEFINED__ */


#ifndef __Slicers_DISPINTERFACE_DEFINED__
#define __Slicers_DISPINTERFACE_DEFINED__

/* dispinterface Slicers */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Slicers;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244C7-0000-0000-C000-000000000046")
    Slicers : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct SlicersVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Slicers * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Slicers * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Slicers * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Slicers * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Slicers * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Slicers * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Slicers * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } SlicersVtbl;

    interface Slicers
    {
        CONST_VTBL struct SlicersVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Slicers_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Slicers_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Slicers_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Slicers_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Slicers_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Slicers_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Slicers_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Slicers_DISPINTERFACE_DEFINED__ */


#ifndef __Slicer_DISPINTERFACE_DEFINED__
#define __Slicer_DISPINTERFACE_DEFINED__

/* dispinterface Slicer */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Slicer;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244C8-0000-0000-C000-000000000046")
    Slicer : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct SlicerVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Slicer * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Slicer * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Slicer * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Slicer * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Slicer * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Slicer * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Slicer * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } SlicerVtbl;

    interface Slicer
    {
        CONST_VTBL struct SlicerVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Slicer_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Slicer_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Slicer_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Slicer_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Slicer_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Slicer_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Slicer_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Slicer_DISPINTERFACE_DEFINED__ */


#ifndef __SlicerItem_DISPINTERFACE_DEFINED__
#define __SlicerItem_DISPINTERFACE_DEFINED__

/* dispinterface SlicerItem */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_SlicerItem;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244C9-0000-0000-C000-000000000046")
    SlicerItem : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct SlicerItemVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            SlicerItem * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            SlicerItem * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            SlicerItem * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            SlicerItem * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            SlicerItem * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            SlicerItem * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            SlicerItem * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } SlicerItemVtbl;

    interface SlicerItem
    {
        CONST_VTBL struct SlicerItemVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define SlicerItem_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define SlicerItem_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define SlicerItem_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define SlicerItem_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define SlicerItem_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define SlicerItem_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define SlicerItem_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __SlicerItem_DISPINTERFACE_DEFINED__ */


#ifndef __SlicerItems_DISPINTERFACE_DEFINED__
#define __SlicerItems_DISPINTERFACE_DEFINED__

/* dispinterface SlicerItems */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_SlicerItems;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244CA-0000-0000-C000-000000000046")
    SlicerItems : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct SlicerItemsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            SlicerItems * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            SlicerItems * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            SlicerItems * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            SlicerItems * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            SlicerItems * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            SlicerItems * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            SlicerItems * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } SlicerItemsVtbl;

    interface SlicerItems
    {
        CONST_VTBL struct SlicerItemsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define SlicerItems_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define SlicerItems_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define SlicerItems_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define SlicerItems_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define SlicerItems_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define SlicerItems_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define SlicerItems_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __SlicerItems_DISPINTERFACE_DEFINED__ */


#ifndef __SlicerPivotTables_DISPINTERFACE_DEFINED__
#define __SlicerPivotTables_DISPINTERFACE_DEFINED__

/* dispinterface SlicerPivotTables */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_SlicerPivotTables;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244CB-0000-0000-C000-000000000046")
    SlicerPivotTables : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct SlicerPivotTablesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            SlicerPivotTables * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            SlicerPivotTables * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            SlicerPivotTables * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            SlicerPivotTables * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            SlicerPivotTables * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            SlicerPivotTables * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            SlicerPivotTables * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } SlicerPivotTablesVtbl;

    interface SlicerPivotTables
    {
        CONST_VTBL struct SlicerPivotTablesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define SlicerPivotTables_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define SlicerPivotTables_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define SlicerPivotTables_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define SlicerPivotTables_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define SlicerPivotTables_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define SlicerPivotTables_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define SlicerPivotTables_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __SlicerPivotTables_DISPINTERFACE_DEFINED__ */


#ifndef __ProtectedViewWindows_DISPINTERFACE_DEFINED__
#define __ProtectedViewWindows_DISPINTERFACE_DEFINED__

/* dispinterface ProtectedViewWindows */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_ProtectedViewWindows;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244CC-0000-0000-C000-000000000046")
    ProtectedViewWindows : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ProtectedViewWindowsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ProtectedViewWindows * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ProtectedViewWindows * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ProtectedViewWindows * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ProtectedViewWindows * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ProtectedViewWindows * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ProtectedViewWindows * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ProtectedViewWindows * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ProtectedViewWindowsVtbl;

    interface ProtectedViewWindows
    {
        CONST_VTBL struct ProtectedViewWindowsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ProtectedViewWindows_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ProtectedViewWindows_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ProtectedViewWindows_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ProtectedViewWindows_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ProtectedViewWindows_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ProtectedViewWindows_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ProtectedViewWindows_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __ProtectedViewWindows_DISPINTERFACE_DEFINED__ */


#ifndef __ProtectedViewWindow_DISPINTERFACE_DEFINED__
#define __ProtectedViewWindow_DISPINTERFACE_DEFINED__

/* dispinterface ProtectedViewWindow */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_ProtectedViewWindow;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244CD-0000-0000-C000-000000000046")
    ProtectedViewWindow : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ProtectedViewWindowVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ProtectedViewWindow * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ProtectedViewWindow * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ProtectedViewWindow * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ProtectedViewWindow * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ProtectedViewWindow * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ProtectedViewWindow * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ProtectedViewWindow * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ProtectedViewWindowVtbl;

    interface ProtectedViewWindow
    {
        CONST_VTBL struct ProtectedViewWindowVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ProtectedViewWindow_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ProtectedViewWindow_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ProtectedViewWindow_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ProtectedViewWindow_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ProtectedViewWindow_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ProtectedViewWindow_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ProtectedViewWindow_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __ProtectedViewWindow_DISPINTERFACE_DEFINED__ */


#ifndef __TableObject_DISPINTERFACE_DEFINED__
#define __TableObject_DISPINTERFACE_DEFINED__

/* dispinterface TableObject */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_TableObject;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244CE-0000-0000-C000-000000000046")
    TableObject : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct TableObjectVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            TableObject * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            TableObject * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            TableObject * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            TableObject * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            TableObject * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            TableObject * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            TableObject * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } TableObjectVtbl;

    interface TableObject
    {
        CONST_VTBL struct TableObjectVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define TableObject_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define TableObject_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define TableObject_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define TableObject_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define TableObject_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define TableObject_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define TableObject_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __TableObject_DISPINTERFACE_DEFINED__ */


#ifndef __PivotValueCell_DISPINTERFACE_DEFINED__
#define __PivotValueCell_DISPINTERFACE_DEFINED__

/* dispinterface PivotValueCell */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_PivotValueCell;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244CF-0000-0000-C000-000000000046")
    PivotValueCell : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct PivotValueCellVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            PivotValueCell * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            PivotValueCell * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            PivotValueCell * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            PivotValueCell * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            PivotValueCell * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            PivotValueCell * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            PivotValueCell * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } PivotValueCellVtbl;

    interface PivotValueCell
    {
        CONST_VTBL struct PivotValueCellVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define PivotValueCell_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define PivotValueCell_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define PivotValueCell_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define PivotValueCell_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define PivotValueCell_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define PivotValueCell_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define PivotValueCell_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __PivotValueCell_DISPINTERFACE_DEFINED__ */


#ifndef __QuickAnalysis_DISPINTERFACE_DEFINED__
#define __QuickAnalysis_DISPINTERFACE_DEFINED__

/* dispinterface QuickAnalysis */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_QuickAnalysis;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244D0-0000-0000-C000-000000000046")
    QuickAnalysis : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct QuickAnalysisVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            QuickAnalysis * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            QuickAnalysis * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            QuickAnalysis * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            QuickAnalysis * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            QuickAnalysis * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            QuickAnalysis * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            QuickAnalysis * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } QuickAnalysisVtbl;

    interface QuickAnalysis
    {
        CONST_VTBL struct QuickAnalysisVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define QuickAnalysis_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define QuickAnalysis_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define QuickAnalysis_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define QuickAnalysis_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define QuickAnalysis_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define QuickAnalysis_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define QuickAnalysis_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __QuickAnalysis_DISPINTERFACE_DEFINED__ */


#ifndef __ModelConnection_DISPINTERFACE_DEFINED__
#define __ModelConnection_DISPINTERFACE_DEFINED__

/* dispinterface ModelConnection */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_ModelConnection;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244D1-0000-0000-C000-000000000046")
    ModelConnection : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ModelConnectionVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ModelConnection * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ModelConnection * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ModelConnection * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ModelConnection * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ModelConnection * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ModelConnection * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ModelConnection * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ModelConnectionVtbl;

    interface ModelConnection
    {
        CONST_VTBL struct ModelConnectionVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ModelConnection_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ModelConnection_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ModelConnection_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ModelConnection_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ModelConnection_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ModelConnection_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ModelConnection_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __ModelConnection_DISPINTERFACE_DEFINED__ */


#ifndef __WorksheetDataConnection_DISPINTERFACE_DEFINED__
#define __WorksheetDataConnection_DISPINTERFACE_DEFINED__

/* dispinterface WorksheetDataConnection */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_WorksheetDataConnection;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244D2-0000-0000-C000-000000000046")
    WorksheetDataConnection : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct WorksheetDataConnectionVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            WorksheetDataConnection * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            WorksheetDataConnection * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            WorksheetDataConnection * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            WorksheetDataConnection * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            WorksheetDataConnection * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            WorksheetDataConnection * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            WorksheetDataConnection * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } WorksheetDataConnectionVtbl;

    interface WorksheetDataConnection
    {
        CONST_VTBL struct WorksheetDataConnectionVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define WorksheetDataConnection_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define WorksheetDataConnection_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define WorksheetDataConnection_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define WorksheetDataConnection_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define WorksheetDataConnection_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define WorksheetDataConnection_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define WorksheetDataConnection_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __WorksheetDataConnection_DISPINTERFACE_DEFINED__ */


#ifndef __TextConnection_DISPINTERFACE_DEFINED__
#define __TextConnection_DISPINTERFACE_DEFINED__

/* dispinterface TextConnection */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_TextConnection;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244D3-0000-0000-C000-000000000046")
    TextConnection : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct TextConnectionVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            TextConnection * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            TextConnection * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            TextConnection * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            TextConnection * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            TextConnection * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            TextConnection * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            TextConnection * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } TextConnectionVtbl;

    interface TextConnection
    {
        CONST_VTBL struct TextConnectionVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define TextConnection_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define TextConnection_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define TextConnection_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define TextConnection_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define TextConnection_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define TextConnection_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define TextConnection_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __TextConnection_DISPINTERFACE_DEFINED__ */


#ifndef __DataFeedConnection_DISPINTERFACE_DEFINED__
#define __DataFeedConnection_DISPINTERFACE_DEFINED__

/* dispinterface DataFeedConnection */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_DataFeedConnection;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244D4-0000-0000-C000-000000000046")
    DataFeedConnection : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct DataFeedConnectionVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            DataFeedConnection * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            DataFeedConnection * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            DataFeedConnection * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            DataFeedConnection * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            DataFeedConnection * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            DataFeedConnection * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            DataFeedConnection * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } DataFeedConnectionVtbl;

    interface DataFeedConnection
    {
        CONST_VTBL struct DataFeedConnectionVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define DataFeedConnection_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define DataFeedConnection_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define DataFeedConnection_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define DataFeedConnection_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define DataFeedConnection_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define DataFeedConnection_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define DataFeedConnection_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __DataFeedConnection_DISPINTERFACE_DEFINED__ */


#ifndef __ModelTableColumn_DISPINTERFACE_DEFINED__
#define __ModelTableColumn_DISPINTERFACE_DEFINED__

/* dispinterface ModelTableColumn */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_ModelTableColumn;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244D5-0000-0000-C000-000000000046")
    ModelTableColumn : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ModelTableColumnVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ModelTableColumn * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ModelTableColumn * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ModelTableColumn * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ModelTableColumn * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ModelTableColumn * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ModelTableColumn * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ModelTableColumn * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ModelTableColumnVtbl;

    interface ModelTableColumn
    {
        CONST_VTBL struct ModelTableColumnVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ModelTableColumn_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ModelTableColumn_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ModelTableColumn_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ModelTableColumn_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ModelTableColumn_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ModelTableColumn_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ModelTableColumn_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __ModelTableColumn_DISPINTERFACE_DEFINED__ */


#ifndef __ModelTableColumns_DISPINTERFACE_DEFINED__
#define __ModelTableColumns_DISPINTERFACE_DEFINED__

/* dispinterface ModelTableColumns */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_ModelTableColumns;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244D6-0000-0000-C000-000000000046")
    ModelTableColumns : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ModelTableColumnsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ModelTableColumns * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ModelTableColumns * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ModelTableColumns * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ModelTableColumns * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ModelTableColumns * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ModelTableColumns * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ModelTableColumns * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ModelTableColumnsVtbl;

    interface ModelTableColumns
    {
        CONST_VTBL struct ModelTableColumnsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ModelTableColumns_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ModelTableColumns_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ModelTableColumns_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ModelTableColumns_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ModelTableColumns_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ModelTableColumns_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ModelTableColumns_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __ModelTableColumns_DISPINTERFACE_DEFINED__ */


#ifndef __ModelTable_DISPINTERFACE_DEFINED__
#define __ModelTable_DISPINTERFACE_DEFINED__

/* dispinterface ModelTable */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_ModelTable;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244D7-0000-0000-C000-000000000046")
    ModelTable : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ModelTableVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ModelTable * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ModelTable * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ModelTable * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ModelTable * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ModelTable * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ModelTable * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ModelTable * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ModelTableVtbl;

    interface ModelTable
    {
        CONST_VTBL struct ModelTableVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ModelTable_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ModelTable_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ModelTable_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ModelTable_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ModelTable_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ModelTable_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ModelTable_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __ModelTable_DISPINTERFACE_DEFINED__ */


#ifndef __ModelTables_DISPINTERFACE_DEFINED__
#define __ModelTables_DISPINTERFACE_DEFINED__

/* dispinterface ModelTables */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_ModelTables;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244D8-0000-0000-C000-000000000046")
    ModelTables : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ModelTablesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ModelTables * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ModelTables * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ModelTables * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ModelTables * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ModelTables * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ModelTables * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ModelTables * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ModelTablesVtbl;

    interface ModelTables
    {
        CONST_VTBL struct ModelTablesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ModelTables_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ModelTables_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ModelTables_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ModelTables_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ModelTables_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ModelTables_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ModelTables_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __ModelTables_DISPINTERFACE_DEFINED__ */


#ifndef __ModelRelationship_DISPINTERFACE_DEFINED__
#define __ModelRelationship_DISPINTERFACE_DEFINED__

/* dispinterface ModelRelationship */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_ModelRelationship;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244D9-0000-0000-C000-000000000046")
    ModelRelationship : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ModelRelationshipVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ModelRelationship * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ModelRelationship * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ModelRelationship * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ModelRelationship * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ModelRelationship * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ModelRelationship * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ModelRelationship * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ModelRelationshipVtbl;

    interface ModelRelationship
    {
        CONST_VTBL struct ModelRelationshipVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ModelRelationship_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ModelRelationship_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ModelRelationship_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ModelRelationship_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ModelRelationship_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ModelRelationship_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ModelRelationship_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __ModelRelationship_DISPINTERFACE_DEFINED__ */


#ifndef __ModelRelationships_DISPINTERFACE_DEFINED__
#define __ModelRelationships_DISPINTERFACE_DEFINED__

/* dispinterface ModelRelationships */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_ModelRelationships;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244DA-0000-0000-C000-000000000046")
    ModelRelationships : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ModelRelationshipsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ModelRelationships * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ModelRelationships * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ModelRelationships * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ModelRelationships * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ModelRelationships * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ModelRelationships * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ModelRelationships * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ModelRelationshipsVtbl;

    interface ModelRelationships
    {
        CONST_VTBL struct ModelRelationshipsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ModelRelationships_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ModelRelationships_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ModelRelationships_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ModelRelationships_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ModelRelationships_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ModelRelationships_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ModelRelationships_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __ModelRelationships_DISPINTERFACE_DEFINED__ */


#ifndef __Model_DISPINTERFACE_DEFINED__
#define __Model_DISPINTERFACE_DEFINED__

/* dispinterface Model */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_Model;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244DB-0000-0000-C000-000000000046")
    Model : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ModelVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Model * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Model * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Model * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Model * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Model * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Model * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Model * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ModelVtbl;

    interface Model
    {
        CONST_VTBL struct ModelVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Model_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Model_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Model_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Model_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Model_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Model_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Model_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __Model_DISPINTERFACE_DEFINED__ */


#ifndef __FullSeriesCollection_DISPINTERFACE_DEFINED__
#define __FullSeriesCollection_DISPINTERFACE_DEFINED__

/* dispinterface FullSeriesCollection */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_FullSeriesCollection;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244DC-0000-0000-C000-000000000046")
    FullSeriesCollection : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct FullSeriesCollectionVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            FullSeriesCollection * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            FullSeriesCollection * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            FullSeriesCollection * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            FullSeriesCollection * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            FullSeriesCollection * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            FullSeriesCollection * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            FullSeriesCollection * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } FullSeriesCollectionVtbl;

    interface FullSeriesCollection
    {
        CONST_VTBL struct FullSeriesCollectionVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define FullSeriesCollection_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define FullSeriesCollection_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define FullSeriesCollection_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define FullSeriesCollection_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define FullSeriesCollection_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define FullSeriesCollection_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define FullSeriesCollection_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __FullSeriesCollection_DISPINTERFACE_DEFINED__ */


#ifndef __ChartCategory_DISPINTERFACE_DEFINED__
#define __ChartCategory_DISPINTERFACE_DEFINED__

/* dispinterface ChartCategory */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_ChartCategory;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244DD-0000-0000-C000-000000000046")
    ChartCategory : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ChartCategoryVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ChartCategory * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ChartCategory * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ChartCategory * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ChartCategory * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ChartCategory * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ChartCategory * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ChartCategory * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ChartCategoryVtbl;

    interface ChartCategory
    {
        CONST_VTBL struct ChartCategoryVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ChartCategory_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ChartCategory_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ChartCategory_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ChartCategory_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ChartCategory_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ChartCategory_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ChartCategory_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __ChartCategory_DISPINTERFACE_DEFINED__ */


#ifndef __CategoryCollection_DISPINTERFACE_DEFINED__
#define __CategoryCollection_DISPINTERFACE_DEFINED__

/* dispinterface CategoryCollection */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_CategoryCollection;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244DE-0000-0000-C000-000000000046")
    CategoryCollection : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct CategoryCollectionVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            CategoryCollection * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            CategoryCollection * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            CategoryCollection * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            CategoryCollection * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            CategoryCollection * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            CategoryCollection * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            CategoryCollection * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } CategoryCollectionVtbl;

    interface CategoryCollection
    {
        CONST_VTBL struct CategoryCollectionVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define CategoryCollection_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define CategoryCollection_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define CategoryCollection_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define CategoryCollection_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define CategoryCollection_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define CategoryCollection_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define CategoryCollection_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __CategoryCollection_DISPINTERFACE_DEFINED__ */


#ifndef __TimelineState_DISPINTERFACE_DEFINED__
#define __TimelineState_DISPINTERFACE_DEFINED__

/* dispinterface TimelineState */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_TimelineState;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244DF-0000-0000-C000-000000000046")
    TimelineState : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct TimelineStateVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            TimelineState * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            TimelineState * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            TimelineState * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            TimelineState * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            TimelineState * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            TimelineState * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            TimelineState * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } TimelineStateVtbl;

    interface TimelineState
    {
        CONST_VTBL struct TimelineStateVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define TimelineState_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define TimelineState_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define TimelineState_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define TimelineState_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define TimelineState_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define TimelineState_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define TimelineState_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __TimelineState_DISPINTERFACE_DEFINED__ */


#ifndef __TimelineViewState_DISPINTERFACE_DEFINED__
#define __TimelineViewState_DISPINTERFACE_DEFINED__

/* dispinterface TimelineViewState */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_TimelineViewState;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244E0-0000-0000-C000-000000000046")
    TimelineViewState : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct TimelineViewStateVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            TimelineViewState * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            TimelineViewState * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            TimelineViewState * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            TimelineViewState * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            TimelineViewState * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            TimelineViewState * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            TimelineViewState * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } TimelineViewStateVtbl;

    interface TimelineViewState
    {
        CONST_VTBL struct TimelineViewStateVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define TimelineViewState_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define TimelineViewState_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define TimelineViewState_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define TimelineViewState_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define TimelineViewState_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define TimelineViewState_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define TimelineViewState_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __TimelineViewState_DISPINTERFACE_DEFINED__ */


#ifndef __ModelTableNames_DISPINTERFACE_DEFINED__
#define __ModelTableNames_DISPINTERFACE_DEFINED__

/* dispinterface ModelTableNames */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_ModelTableNames;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244E1-0000-0000-C000-000000000046")
    ModelTableNames : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ModelTableNamesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ModelTableNames * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ModelTableNames * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ModelTableNames * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ModelTableNames * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ModelTableNames * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ModelTableNames * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ModelTableNames * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ModelTableNamesVtbl;

    interface ModelTableNames
    {
        CONST_VTBL struct ModelTableNamesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ModelTableNames_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ModelTableNames_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ModelTableNames_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ModelTableNames_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ModelTableNames_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ModelTableNames_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ModelTableNames_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __ModelTableNames_DISPINTERFACE_DEFINED__ */


#ifndef __ModelTableNameChange_DISPINTERFACE_DEFINED__
#define __ModelTableNameChange_DISPINTERFACE_DEFINED__

/* dispinterface ModelTableNameChange */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_ModelTableNameChange;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244E2-0000-0000-C000-000000000046")
    ModelTableNameChange : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ModelTableNameChangeVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ModelTableNameChange * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ModelTableNameChange * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ModelTableNameChange * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ModelTableNameChange * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ModelTableNameChange * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ModelTableNameChange * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ModelTableNameChange * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ModelTableNameChangeVtbl;

    interface ModelTableNameChange
    {
        CONST_VTBL struct ModelTableNameChangeVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ModelTableNameChange_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ModelTableNameChange_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ModelTableNameChange_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ModelTableNameChange_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ModelTableNameChange_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ModelTableNameChange_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ModelTableNameChange_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __ModelTableNameChange_DISPINTERFACE_DEFINED__ */


#ifndef __ModelTableNameChanges_DISPINTERFACE_DEFINED__
#define __ModelTableNameChanges_DISPINTERFACE_DEFINED__

/* dispinterface ModelTableNameChanges */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_ModelTableNameChanges;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244E3-0000-0000-C000-000000000046")
    ModelTableNameChanges : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ModelTableNameChangesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ModelTableNameChanges * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ModelTableNameChanges * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ModelTableNameChanges * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ModelTableNameChanges * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ModelTableNameChanges * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ModelTableNameChanges * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ModelTableNameChanges * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ModelTableNameChangesVtbl;

    interface ModelTableNameChanges
    {
        CONST_VTBL struct ModelTableNameChangesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ModelTableNameChanges_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ModelTableNameChanges_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ModelTableNameChanges_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ModelTableNameChanges_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ModelTableNameChanges_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ModelTableNameChanges_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ModelTableNameChanges_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __ModelTableNameChanges_DISPINTERFACE_DEFINED__ */


#ifndef __ModelChanges_DISPINTERFACE_DEFINED__
#define __ModelChanges_DISPINTERFACE_DEFINED__

/* dispinterface ModelChanges */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_ModelChanges;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244E4-0000-0000-C000-000000000046")
    ModelChanges : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ModelChangesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ModelChanges * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ModelChanges * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ModelChanges * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ModelChanges * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ModelChanges * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ModelChanges * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ModelChanges * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ModelChangesVtbl;

    interface ModelChanges
    {
        CONST_VTBL struct ModelChangesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ModelChanges_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ModelChanges_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ModelChanges_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ModelChanges_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ModelChanges_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ModelChanges_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ModelChanges_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __ModelChanges_DISPINTERFACE_DEFINED__ */


#ifndef __ModelColumnName_DISPINTERFACE_DEFINED__
#define __ModelColumnName_DISPINTERFACE_DEFINED__

/* dispinterface ModelColumnName */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_ModelColumnName;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244E5-0000-0000-C000-000000000046")
    ModelColumnName : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ModelColumnNameVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ModelColumnName * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ModelColumnName * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ModelColumnName * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ModelColumnName * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ModelColumnName * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ModelColumnName * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ModelColumnName * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ModelColumnNameVtbl;

    interface ModelColumnName
    {
        CONST_VTBL struct ModelColumnNameVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ModelColumnName_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ModelColumnName_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ModelColumnName_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ModelColumnName_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ModelColumnName_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ModelColumnName_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ModelColumnName_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __ModelColumnName_DISPINTERFACE_DEFINED__ */


#ifndef __ModelColumnNames_DISPINTERFACE_DEFINED__
#define __ModelColumnNames_DISPINTERFACE_DEFINED__

/* dispinterface ModelColumnNames */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_ModelColumnNames;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244E6-0000-0000-C000-000000000046")
    ModelColumnNames : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ModelColumnNamesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ModelColumnNames * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ModelColumnNames * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ModelColumnNames * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ModelColumnNames * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ModelColumnNames * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ModelColumnNames * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ModelColumnNames * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ModelColumnNamesVtbl;

    interface ModelColumnNames
    {
        CONST_VTBL struct ModelColumnNamesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ModelColumnNames_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ModelColumnNames_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ModelColumnNames_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ModelColumnNames_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ModelColumnNames_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ModelColumnNames_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ModelColumnNames_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __ModelColumnNames_DISPINTERFACE_DEFINED__ */


#ifndef __ModelColumnChange_DISPINTERFACE_DEFINED__
#define __ModelColumnChange_DISPINTERFACE_DEFINED__

/* dispinterface ModelColumnChange */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_ModelColumnChange;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244E7-0000-0000-C000-000000000046")
    ModelColumnChange : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ModelColumnChangeVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ModelColumnChange * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ModelColumnChange * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ModelColumnChange * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ModelColumnChange * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ModelColumnChange * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ModelColumnChange * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ModelColumnChange * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ModelColumnChangeVtbl;

    interface ModelColumnChange
    {
        CONST_VTBL struct ModelColumnChangeVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ModelColumnChange_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ModelColumnChange_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ModelColumnChange_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ModelColumnChange_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ModelColumnChange_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ModelColumnChange_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ModelColumnChange_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __ModelColumnChange_DISPINTERFACE_DEFINED__ */


#ifndef __ModelColumnChanges_DISPINTERFACE_DEFINED__
#define __ModelColumnChanges_DISPINTERFACE_DEFINED__

/* dispinterface ModelColumnChanges */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_ModelColumnChanges;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244E8-0000-0000-C000-000000000046")
    ModelColumnChanges : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ModelColumnChangesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ModelColumnChanges * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ModelColumnChanges * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ModelColumnChanges * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ModelColumnChanges * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ModelColumnChanges * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ModelColumnChanges * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ModelColumnChanges * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ModelColumnChangesVtbl;

    interface ModelColumnChanges
    {
        CONST_VTBL struct ModelColumnChangesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ModelColumnChanges_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ModelColumnChanges_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ModelColumnChanges_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ModelColumnChanges_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ModelColumnChanges_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ModelColumnChanges_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ModelColumnChanges_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __ModelColumnChanges_DISPINTERFACE_DEFINED__ */


#ifndef __ModelMeasureName_DISPINTERFACE_DEFINED__
#define __ModelMeasureName_DISPINTERFACE_DEFINED__

/* dispinterface ModelMeasureName */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_ModelMeasureName;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244E9-0000-0000-C000-000000000046")
    ModelMeasureName : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ModelMeasureNameVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ModelMeasureName * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ModelMeasureName * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ModelMeasureName * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ModelMeasureName * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ModelMeasureName * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ModelMeasureName * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ModelMeasureName * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ModelMeasureNameVtbl;

    interface ModelMeasureName
    {
        CONST_VTBL struct ModelMeasureNameVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ModelMeasureName_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ModelMeasureName_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ModelMeasureName_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ModelMeasureName_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ModelMeasureName_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ModelMeasureName_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ModelMeasureName_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __ModelMeasureName_DISPINTERFACE_DEFINED__ */


#ifndef __ModelMeasureNames_DISPINTERFACE_DEFINED__
#define __ModelMeasureNames_DISPINTERFACE_DEFINED__

/* dispinterface ModelMeasureNames */
/* [helpcontext][uuid] */ 


EXTERN_C const IID DIID_ModelMeasureNames;

#if defined(__cplusplus) && !defined(CINTERFACE)

    MIDL_INTERFACE("000244EA-0000-0000-C000-000000000046")
    ModelMeasureNames : public IDispatch
    {
    };
    
#else 	/* C style interface */

    typedef struct ModelMeasureNamesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ModelMeasureNames * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ModelMeasureNames * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ModelMeasureNames * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ModelMeasureNames * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ModelMeasureNames * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ModelMeasureNames * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ModelMeasureNames * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ModelMeasureNamesVtbl;

    interface ModelMeasureNames
    {
        CONST_VTBL struct ModelMeasureNamesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ModelMeasureNames_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ModelMeasureNames_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ModelMeasureNames_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ModelMeasureNames_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ModelMeasureNames_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ModelMeasureNames_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ModelMeasureNames_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */


#endif 	/* __ModelMeasureNames_DISPINTERFACE_DEFINED__ */


#ifndef __IDummy_INTERFACE_DEFINED__
#define __IDummy_INTERFACE_DEFINED__

/* interface IDummy */
/* [object][hidden][helpcontext][uuid] */ 


EXTERN_C const IID IID_IDummy;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002442E-0001-0000-C000-000000000046")
    IDummy : public IDispatch
    {
    public:
        virtual /* [helpcontext] */ HRESULT __stdcall _ActiveSheetOrChart( void) = 0;
        
        virtual /* [helpcontext] */ HRESULT __stdcall RGB( void) = 0;
        
        virtual /* [helpcontext] */ HRESULT __stdcall ChDir( void) = 0;
        
        virtual /* [helpcontext] */ HRESULT __stdcall DoScript( void) = 0;
        
        virtual /* [helpcontext] */ HRESULT __stdcall DirectObject( void) = 0;
        
        virtual /* [helpcontext] */ HRESULT __stdcall RefreshDocument( void) = 0;
        
        virtual /* [helpcontext] */ HRESULT __stdcall AddSignatureLine( 
            /* [in] */ VARIANT SigProv,
            /* [retval][out] */ /* external definition not present */ Signature **RHS) = 0;
        
        virtual /* [helpcontext] */ HRESULT __stdcall AddNonVisibleSignature( 
            /* [in] */ VARIANT SigProv,
            /* [retval][out] */ /* external definition not present */ Signature **RHS) = 0;
        
        virtual /* [helpcontext][propget] */ HRESULT __stdcall get_ShowSignaturesPane( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput] */ HRESULT __stdcall put_ShowSignaturesPane( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext] */ HRESULT __stdcall ThemeFontScheme( void) = 0;
        
        virtual /* [helpcontext] */ HRESULT __stdcall ThemeColorScheme( void) = 0;
        
        virtual /* [helpcontext] */ HRESULT __stdcall ThemeEffectScheme( void) = 0;
        
        virtual /* [helpcontext] */ HRESULT __stdcall Load( void) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IDummyVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IDummy * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IDummy * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IDummy * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IDummy * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IDummy * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IDummy * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IDummy * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext] */ HRESULT ( __stdcall *_ActiveSheetOrChart )( 
            IDummy * This);
        
        /* [helpcontext] */ HRESULT ( __stdcall *RGB )( 
            IDummy * This);
        
        /* [helpcontext] */ HRESULT ( __stdcall *ChDir )( 
            IDummy * This);
        
        /* [helpcontext] */ HRESULT ( __stdcall *DoScript )( 
            IDummy * This);
        
        /* [helpcontext] */ HRESULT ( __stdcall *DirectObject )( 
            IDummy * This);
        
        /* [helpcontext] */ HRESULT ( __stdcall *RefreshDocument )( 
            IDummy * This);
        
        /* [helpcontext] */ HRESULT ( __stdcall *AddSignatureLine )( 
            IDummy * This,
            /* [in] */ VARIANT SigProv,
            /* [retval][out] */ /* external definition not present */ Signature **RHS);
        
        /* [helpcontext] */ HRESULT ( __stdcall *AddNonVisibleSignature )( 
            IDummy * This,
            /* [in] */ VARIANT SigProv,
            /* [retval][out] */ /* external definition not present */ Signature **RHS);
        
        /* [helpcontext][propget] */ HRESULT ( __stdcall *get_ShowSignaturesPane )( 
            IDummy * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput] */ HRESULT ( __stdcall *put_ShowSignaturesPane )( 
            IDummy * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext] */ HRESULT ( __stdcall *ThemeFontScheme )( 
            IDummy * This);
        
        /* [helpcontext] */ HRESULT ( __stdcall *ThemeColorScheme )( 
            IDummy * This);
        
        /* [helpcontext] */ HRESULT ( __stdcall *ThemeEffectScheme )( 
            IDummy * This);
        
        /* [helpcontext] */ HRESULT ( __stdcall *Load )( 
            IDummy * This);
        
        END_INTERFACE
    } IDummyVtbl;

    interface IDummy
    {
        CONST_VTBL struct IDummyVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IDummy_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IDummy_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IDummy_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IDummy_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IDummy_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IDummy_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IDummy_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IDummy__ActiveSheetOrChart(This)	\
    ( (This)->lpVtbl -> _ActiveSheetOrChart(This) ) 

#define IDummy_RGB(This)	\
    ( (This)->lpVtbl -> RGB(This) ) 

#define IDummy_ChDir(This)	\
    ( (This)->lpVtbl -> ChDir(This) ) 

#define IDummy_DoScript(This)	\
    ( (This)->lpVtbl -> DoScript(This) ) 

#define IDummy_DirectObject(This)	\
    ( (This)->lpVtbl -> DirectObject(This) ) 

#define IDummy_RefreshDocument(This)	\
    ( (This)->lpVtbl -> RefreshDocument(This) ) 

#define IDummy_AddSignatureLine(This,SigProv,RHS)	\
    ( (This)->lpVtbl -> AddSignatureLine(This,SigProv,RHS) ) 

#define IDummy_AddNonVisibleSignature(This,SigProv,RHS)	\
    ( (This)->lpVtbl -> AddNonVisibleSignature(This,SigProv,RHS) ) 

#define IDummy_get_ShowSignaturesPane(This,RHS)	\
    ( (This)->lpVtbl -> get_ShowSignaturesPane(This,RHS) ) 

#define IDummy_put_ShowSignaturesPane(This,RHS)	\
    ( (This)->lpVtbl -> put_ShowSignaturesPane(This,RHS) ) 

#define IDummy_ThemeFontScheme(This)	\
    ( (This)->lpVtbl -> ThemeFontScheme(This) ) 

#define IDummy_ThemeColorScheme(This)	\
    ( (This)->lpVtbl -> ThemeColorScheme(This) ) 

#define IDummy_ThemeEffectScheme(This)	\
    ( (This)->lpVtbl -> ThemeEffectScheme(This) ) 

#define IDummy_Load(This)	\
    ( (This)->lpVtbl -> Load(This) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IDummy_INTERFACE_DEFINED__ */


#ifndef __ICanvasShapes_INTERFACE_DEFINED__
#define __ICanvasShapes_INTERFACE_DEFINED__

/* interface ICanvasShapes */
/* [object][hidden][uuid] */ 


EXTERN_C const IID IID_ICanvasShapes;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("0002444F-0001-0000-C000-000000000046")
    ICanvasShapes : public IDispatch
    {
    public:
    };
    
#else 	/* C style interface */

    typedef struct ICanvasShapesVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            ICanvasShapes * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            ICanvasShapes * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            ICanvasShapes * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            ICanvasShapes * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            ICanvasShapes * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            ICanvasShapes * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            ICanvasShapes * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        END_INTERFACE
    } ICanvasShapesVtbl;

    interface ICanvasShapes
    {
        CONST_VTBL struct ICanvasShapesVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define ICanvasShapes_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define ICanvasShapes_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define ICanvasShapes_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define ICanvasShapes_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define ICanvasShapes_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define ICanvasShapes_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define ICanvasShapes_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __ICanvasShapes_INTERFACE_DEFINED__ */


#ifndef ___DebugTools_INTERFACE_DEFINED__
#define ___DebugTools_INTERFACE_DEFINED__

/* interface _DebugTools */
/* [unique][dual][uuid][object] */ 


EXTERN_C const IID IID__DebugTools;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("45541F00-5750-5300-4B49-4E47534F4655")
    _DebugTools : public IDispatch
    {
    public:
        virtual /* [id] */ HRESULT STDMETHODCALLTYPE Dump( 
            /* [in] */ BSTR path) = 0;
        
        virtual /* [id] */ HRESULT STDMETHODCALLTYPE Do( void) = 0;
        
        virtual /* [id] */ HRESULT STDMETHODCALLTYPE Diagnose( void) = 0;
        
        virtual /* [id] */ HRESULT STDMETHODCALLTYPE Report( void) = 0;
        
        virtual /* [id] */ HRESULT STDMETHODCALLTYPE Profile( void) = 0;
        
        virtual /* [id] */ HRESULT STDMETHODCALLTYPE RunCommand( 
            /* [in] */ long cmdid,
            /* [optional][in] */ VARIANT param1,
            /* [optional][in] */ VARIANT param2,
            /* [optional][in] */ VARIANT param3) = 0;
        
        virtual /* [id] */ HRESULT STDMETHODCALLTYPE GetResult( 
            /* [in] */ long cmdid,
            /* [in] */ VARIANT param,
            /* [retval][out] */ VARIANT *res) = 0;
        
        virtual /* [id][propget] */ HRESULT STDMETHODCALLTYPE get_Solver( 
            /* [retval][out] */ Solver **prop) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct _DebugToolsVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            _DebugTools * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            _DebugTools * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            _DebugTools * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            _DebugTools * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            _DebugTools * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            _DebugTools * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            _DebugTools * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [id] */ HRESULT ( STDMETHODCALLTYPE *Dump )( 
            _DebugTools * This,
            /* [in] */ BSTR path);
        
        /* [id] */ HRESULT ( STDMETHODCALLTYPE *Do )( 
            _DebugTools * This);
        
        /* [id] */ HRESULT ( STDMETHODCALLTYPE *Diagnose )( 
            _DebugTools * This);
        
        /* [id] */ HRESULT ( STDMETHODCALLTYPE *Report )( 
            _DebugTools * This);
        
        /* [id] */ HRESULT ( STDMETHODCALLTYPE *Profile )( 
            _DebugTools * This);
        
        /* [id] */ HRESULT ( STDMETHODCALLTYPE *RunCommand )( 
            _DebugTools * This,
            /* [in] */ long cmdid,
            /* [optional][in] */ VARIANT param1,
            /* [optional][in] */ VARIANT param2,
            /* [optional][in] */ VARIANT param3);
        
        /* [id] */ HRESULT ( STDMETHODCALLTYPE *GetResult )( 
            _DebugTools * This,
            /* [in] */ long cmdid,
            /* [in] */ VARIANT param,
            /* [retval][out] */ VARIANT *res);
        
        /* [id][propget] */ HRESULT ( STDMETHODCALLTYPE *get_Solver )( 
            _DebugTools * This,
            /* [retval][out] */ Solver **prop);
        
        END_INTERFACE
    } _DebugToolsVtbl;

    interface _DebugTools
    {
        CONST_VTBL struct _DebugToolsVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define _DebugTools_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define _DebugTools_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define _DebugTools_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define _DebugTools_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define _DebugTools_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define _DebugTools_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define _DebugTools_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define _DebugTools_Dump(This,path)	\
    ( (This)->lpVtbl -> Dump(This,path) ) 

#define _DebugTools_Do(This)	\
    ( (This)->lpVtbl -> Do(This) ) 

#define _DebugTools_Diagnose(This)	\
    ( (This)->lpVtbl -> Diagnose(This) ) 

#define _DebugTools_Report(This)	\
    ( (This)->lpVtbl -> Report(This) ) 

#define _DebugTools_Profile(This)	\
    ( (This)->lpVtbl -> Profile(This) ) 

#define _DebugTools_RunCommand(This,cmdid,param1,param2,param3)	\
    ( (This)->lpVtbl -> RunCommand(This,cmdid,param1,param2,param3) ) 

#define _DebugTools_GetResult(This,cmdid,param,res)	\
    ( (This)->lpVtbl -> GetResult(This,cmdid,param,res) ) 

#define _DebugTools_get_Solver(This,prop)	\
    ( (This)->lpVtbl -> get_Solver(This,prop) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* ___DebugTools_INTERFACE_DEFINED__ */


#ifndef __Solver_INTERFACE_DEFINED__
#define __Solver_INTERFACE_DEFINED__

/* interface Solver */
/* [unique][dual][uuid][object] */ 


EXTERN_C const IID IID_Solver;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("45541089-5750-5300-4B49-4E47534F4655")
    Solver : public IDispatch
    {
    public:
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE SolverAdd( 
            /* [in] */ VARIANT CellRef,
            /* [in] */ int Relation,
            /* [optional][in] */ VARIANT FormulaText,
            /* [retval][out] */ int *errorParam) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE SolverChange( 
            /* [in] */ VARIANT CellRef,
            /* [in] */ int Relation,
            /* [optional][in] */ VARIANT FormulaText,
            /* [retval][out] */ int *errorParam) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE SolverDelete( 
            /* [in] */ VARIANT CellRef,
            /* [in] */ int Relation,
            /* [optional][in] */ VARIANT FormulaText,
            /* [retval][out] */ int *errorParam) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE SolverFinish( 
            /* [optional][in] */ VARIANT KeepFinal,
            /* [optional][in] */ VARIANT ReportArry,
            /* [optional][in] */ VARIANT OutlineReports,
            /* [retval][out] */ int *errorParam) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE SolverOk( 
            /* [optional][in] */ VARIANT SetCell,
            /* [optional][in] */ VARIANT MaxMinVal,
            /* [optional][in] */ VARIANT ValueOf,
            /* [optional][in] */ VARIANT ByChange,
            /* [optional][in] */ VARIANT Engine,
            /* [optional][in] */ VARIANT EngineDesc,
            /* [retval][out] */ int *errorParam) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE SolverOptions( 
            /* [optional][in] */ VARIANT MaxTime,
            /* [optional][in] */ VARIANT Iterations,
            /* [optional][in] */ VARIANT Precision,
            /* [optional][in] */ VARIANT AssumeLinear,
            /* [optional][in] */ VARIANT StepThru,
            /* [optional][in] */ VARIANT Estimates,
            /* [optional][in] */ VARIANT Derivatives,
            /* [optional][in] */ VARIANT SearchOption,
            /* [optional][in] */ VARIANT IntTolerance,
            /* [optional][in] */ VARIANT Scaling,
            /* [optional][in] */ VARIANT Convergence,
            /* [optional][in] */ VARIANT AssumeNonNeg,
            /* [optional][in] */ VARIANT PopulationSize,
            /* [optional][in] */ VARIANT randomSeed,
            /* [optional][in] */ VARIANT MultiStart,
            /* [optional][in] */ VARIANT RequireBounds,
            /* [optional][in] */ VARIANT MutationRate,
            /* [optional][in] */ VARIANT MaxSubproblems,
            /* [optional][in] */ VARIANT MaxIntegerSols,
            /* [optional][in] */ VARIANT SolveWithout,
            /* [optional][in] */ VARIANT MaxTimeNoImp,
            /* [retval][out] */ int *errorParam) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE SolverReset( void) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT STDMETHODCALLTYPE SolverSolve( 
            /* [optional][in] */ VARIANT UserFinish,
            /* [optional][in] */ VARIANT ShowRef,
            /* [retval][out] */ int *SolverResult) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct SolverVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            Solver * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            Solver * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            Solver * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            Solver * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            Solver * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            Solver * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            Solver * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *SolverAdd )( 
            Solver * This,
            /* [in] */ VARIANT CellRef,
            /* [in] */ int Relation,
            /* [optional][in] */ VARIANT FormulaText,
            /* [retval][out] */ int *errorParam);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *SolverChange )( 
            Solver * This,
            /* [in] */ VARIANT CellRef,
            /* [in] */ int Relation,
            /* [optional][in] */ VARIANT FormulaText,
            /* [retval][out] */ int *errorParam);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *SolverDelete )( 
            Solver * This,
            /* [in] */ VARIANT CellRef,
            /* [in] */ int Relation,
            /* [optional][in] */ VARIANT FormulaText,
            /* [retval][out] */ int *errorParam);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *SolverFinish )( 
            Solver * This,
            /* [optional][in] */ VARIANT KeepFinal,
            /* [optional][in] */ VARIANT ReportArry,
            /* [optional][in] */ VARIANT OutlineReports,
            /* [retval][out] */ int *errorParam);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *SolverOk )( 
            Solver * This,
            /* [optional][in] */ VARIANT SetCell,
            /* [optional][in] */ VARIANT MaxMinVal,
            /* [optional][in] */ VARIANT ValueOf,
            /* [optional][in] */ VARIANT ByChange,
            /* [optional][in] */ VARIANT Engine,
            /* [optional][in] */ VARIANT EngineDesc,
            /* [retval][out] */ int *errorParam);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *SolverOptions )( 
            Solver * This,
            /* [optional][in] */ VARIANT MaxTime,
            /* [optional][in] */ VARIANT Iterations,
            /* [optional][in] */ VARIANT Precision,
            /* [optional][in] */ VARIANT AssumeLinear,
            /* [optional][in] */ VARIANT StepThru,
            /* [optional][in] */ VARIANT Estimates,
            /* [optional][in] */ VARIANT Derivatives,
            /* [optional][in] */ VARIANT SearchOption,
            /* [optional][in] */ VARIANT IntTolerance,
            /* [optional][in] */ VARIANT Scaling,
            /* [optional][in] */ VARIANT Convergence,
            /* [optional][in] */ VARIANT AssumeNonNeg,
            /* [optional][in] */ VARIANT PopulationSize,
            /* [optional][in] */ VARIANT randomSeed,
            /* [optional][in] */ VARIANT MultiStart,
            /* [optional][in] */ VARIANT RequireBounds,
            /* [optional][in] */ VARIANT MutationRate,
            /* [optional][in] */ VARIANT MaxSubproblems,
            /* [optional][in] */ VARIANT MaxIntegerSols,
            /* [optional][in] */ VARIANT SolveWithout,
            /* [optional][in] */ VARIANT MaxTimeNoImp,
            /* [retval][out] */ int *errorParam);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *SolverReset )( 
            Solver * This);
        
        /* [helpcontext][id] */ HRESULT ( STDMETHODCALLTYPE *SolverSolve )( 
            Solver * This,
            /* [optional][in] */ VARIANT UserFinish,
            /* [optional][in] */ VARIANT ShowRef,
            /* [retval][out] */ int *SolverResult);
        
        END_INTERFACE
    } SolverVtbl;

    interface Solver
    {
        CONST_VTBL struct SolverVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define Solver_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define Solver_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define Solver_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define Solver_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define Solver_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define Solver_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define Solver_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define Solver_SolverAdd(This,CellRef,Relation,FormulaText,errorParam)	\
    ( (This)->lpVtbl -> SolverAdd(This,CellRef,Relation,FormulaText,errorParam) ) 

#define Solver_SolverChange(This,CellRef,Relation,FormulaText,errorParam)	\
    ( (This)->lpVtbl -> SolverChange(This,CellRef,Relation,FormulaText,errorParam) ) 

#define Solver_SolverDelete(This,CellRef,Relation,FormulaText,errorParam)	\
    ( (This)->lpVtbl -> SolverDelete(This,CellRef,Relation,FormulaText,errorParam) ) 

#define Solver_SolverFinish(This,KeepFinal,ReportArry,OutlineReports,errorParam)	\
    ( (This)->lpVtbl -> SolverFinish(This,KeepFinal,ReportArry,OutlineReports,errorParam) ) 

#define Solver_SolverOk(This,SetCell,MaxMinVal,ValueOf,ByChange,Engine,EngineDesc,errorParam)	\
    ( (This)->lpVtbl -> SolverOk(This,SetCell,MaxMinVal,ValueOf,ByChange,Engine,EngineDesc,errorParam) ) 

#define Solver_SolverOptions(This,MaxTime,Iterations,Precision,AssumeLinear,StepThru,Estimates,Derivatives,SearchOption,IntTolerance,Scaling,Convergence,AssumeNonNeg,PopulationSize,randomSeed,MultiStart,RequireBounds,MutationRate,MaxSubproblems,MaxIntegerSols,SolveWithout,MaxTimeNoImp,errorParam)	\
    ( (This)->lpVtbl -> SolverOptions(This,MaxTime,Iterations,Precision,AssumeLinear,StepThru,Estimates,Derivatives,SearchOption,IntTolerance,Scaling,Convergence,AssumeNonNeg,PopulationSize,randomSeed,MultiStart,RequireBounds,MutationRate,MaxSubproblems,MaxIntegerSols,SolveWithout,MaxTimeNoImp,errorParam) ) 

#define Solver_SolverReset(This)	\
    ( (This)->lpVtbl -> SolverReset(This) ) 

#define Solver_SolverSolve(This,UserFinish,ShowRef,SolverResult)	\
    ( (This)->lpVtbl -> SolverSolve(This,UserFinish,ShowRef,SolverResult) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __Solver_INTERFACE_DEFINED__ */


EXTERN_C const CLSID CLSID_Application;

#ifdef __cplusplus

class DECLSPEC_UUID("00024500-0000-0000-C000-000000000046")
Application;
#endif

EXTERN_C const CLSID CLSID_Global;

#ifdef __cplusplus

class DECLSPEC_UUID("00020812-0000-0000-C000-000000000046")
Global;
#endif

EXTERN_C const CLSID CLSID_Chart;

#ifdef __cplusplus

class DECLSPEC_UUID("00020821-0000-0000-C000-000000000046")
Chart;
#endif

EXTERN_C const CLSID CLSID_Workbook;

#ifdef __cplusplus

class DECLSPEC_UUID("00020819-0000-0000-C000-000000000046")
Workbook;
#endif

EXTERN_C const CLSID CLSID_QueryTable;

#ifdef __cplusplus

class DECLSPEC_UUID("59191DA1-EA47-11CE-A51F-00AA0061507F")
QueryTable;
#endif

EXTERN_C const CLSID CLSID_Worksheet;

#ifdef __cplusplus

class DECLSPEC_UUID("00020820-0000-0000-C000-000000000046")
Worksheet;
#endif

EXTERN_C const CLSID CLSID_OLEObject;

#ifdef __cplusplus

class DECLSPEC_UUID("00020818-0000-0000-C000-000000000046")
OLEObject;
#endif

EXTERN_C const CLSID CLSID_DebugTools;

#ifdef __cplusplus

class DECLSPEC_UUID("45540F00-5750-5300-4B49-4E47534F4655")
DebugTools;
#endif

#ifndef __IEXCELCtrlExtender_INTERFACE_DEFINED__
#define __IEXCELCtrlExtender_INTERFACE_DEFINED__

/* interface IEXCELCtrlExtender */
/* [object][hidden][oleautomation][uuid] */ 


EXTERN_C const IID IID_IEXCELCtrlExtender;

#if defined(__cplusplus) && !defined(CINTERFACE)
    
    MIDL_INTERFACE("FD1AEC82-85C4-4FFE-9259-E061915FEC9D")
    IEXCELCtrlExtender : public IDispatch
    {
    public:
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Name( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Name( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Object( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Parent( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Application( 
            /* [retval][out] */ Application	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Creator( 
            /* [retval][out] */ XlCreator *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_BottomRightCell( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall BringToFront( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Copy( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Delete( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall CopyPicture( 
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Cut( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Duplicate( 
            /* [retval][out] */ IDispatch **RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Enabled( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Enabled( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Height( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Height( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Index( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Left( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Left( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Locked( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Locked( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_OnAction( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_OnAction( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Placement( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Placement( 
            /* [in] */ VARIANT RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_PrintObject( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_PrintObject( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Select( 
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall SendToBack( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Top( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Top( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_TopLeftCell( 
            /* [retval][out] */ Range	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Visible( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Visible( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Width( 
            /* [retval][out] */ double *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Width( 
            /* [in] */ double RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ZOrder( 
            /* [retval][out] */ long *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ShapeRange( 
            /* [retval][out] */ ShapeRange	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Border( 
            /* [retval][out] */ Border	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Interior( 
            /* [retval][out] */ Interior	**RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_Shadow( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_Shadow( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Activate( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AutoLoad( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AutoLoad( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_AutoUpdate( 
            /* [retval][out] */ VARIANT_BOOL *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_AutoUpdate( 
            /* [in] */ VARIANT_BOOL RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_OLEType( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_SourceName( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_SourceName( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Update( 
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][id] */ HRESULT __stdcall Verb( 
            /* [defaultvalue][optional][in] */ XlOLEVerb Verb,
            /* [retval][out] */ VARIANT *RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_LinkedCell( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_LinkedCell( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_ListFillRange( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][propput][id] */ HRESULT __stdcall put_ListFillRange( 
            /* [in] */ BSTR RHS) = 0;
        
        virtual /* [helpcontext][propget][id] */ HRESULT __stdcall get_progID( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propget][id] */ HRESULT __stdcall get_AltHTML( 
            /* [retval][out] */ BSTR *RHS) = 0;
        
        virtual /* [helpcontext][hidden][propput][id] */ HRESULT __stdcall put_AltHTML( 
            /* [in] */ BSTR RHS) = 0;
        
    };
    
#else 	/* C style interface */

    typedef struct IEXCELCtrlExtenderVtbl
    {
        BEGIN_INTERFACE
        
        HRESULT ( STDMETHODCALLTYPE *QueryInterface )( 
            IEXCELCtrlExtender * This,
            /* [in] */ REFIID riid,
            /* [annotation][iid_is][out] */ 
            __RPC__deref_out  void **ppvObject);
        
        ULONG ( STDMETHODCALLTYPE *AddRef )( 
            IEXCELCtrlExtender * This);
        
        ULONG ( STDMETHODCALLTYPE *Release )( 
            IEXCELCtrlExtender * This);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfoCount )( 
            IEXCELCtrlExtender * This,
            /* [out] */ UINT *pctinfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetTypeInfo )( 
            IEXCELCtrlExtender * This,
            /* [in] */ UINT iTInfo,
            /* [in] */ LCID lcid,
            /* [out] */ ITypeInfo **ppTInfo);
        
        HRESULT ( STDMETHODCALLTYPE *GetIDsOfNames )( 
            IEXCELCtrlExtender * This,
            /* [in] */ REFIID riid,
            /* [size_is][in] */ LPOLESTR *rgszNames,
            /* [range][in] */ UINT cNames,
            /* [in] */ LCID lcid,
            /* [size_is][out] */ DISPID *rgDispId);
        
        /* [local] */ HRESULT ( STDMETHODCALLTYPE *Invoke )( 
            IEXCELCtrlExtender * This,
            /* [in] */ DISPID dispIdMember,
            /* [in] */ REFIID riid,
            /* [in] */ LCID lcid,
            /* [in] */ WORD wFlags,
            /* [out][in] */ DISPPARAMS *pDispParams,
            /* [out] */ VARIANT *pVarResult,
            /* [out] */ EXCEPINFO *pExcepInfo,
            /* [out] */ UINT *puArgErr);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Name )( 
            IEXCELCtrlExtender * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Name )( 
            IEXCELCtrlExtender * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Object )( 
            IEXCELCtrlExtender * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Parent )( 
            IEXCELCtrlExtender * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Application )( 
            IEXCELCtrlExtender * This,
            /* [retval][out] */ Application	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Creator )( 
            IEXCELCtrlExtender * This,
            /* [retval][out] */ XlCreator *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_BottomRightCell )( 
            IEXCELCtrlExtender * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *BringToFront )( 
            IEXCELCtrlExtender * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Copy )( 
            IEXCELCtrlExtender * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Delete )( 
            IEXCELCtrlExtender * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *CopyPicture )( 
            IEXCELCtrlExtender * This,
            /* [defaultvalue][optional][in] */ XlPictureAppearance Appearance,
            /* [defaultvalue][optional][in] */ XlCopyPictureFormat Format,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Cut )( 
            IEXCELCtrlExtender * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Duplicate )( 
            IEXCELCtrlExtender * This,
            /* [retval][out] */ IDispatch **RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Enabled )( 
            IEXCELCtrlExtender * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Enabled )( 
            IEXCELCtrlExtender * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Height )( 
            IEXCELCtrlExtender * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Height )( 
            IEXCELCtrlExtender * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Index )( 
            IEXCELCtrlExtender * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Left )( 
            IEXCELCtrlExtender * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Left )( 
            IEXCELCtrlExtender * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Locked )( 
            IEXCELCtrlExtender * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Locked )( 
            IEXCELCtrlExtender * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_OnAction )( 
            IEXCELCtrlExtender * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_OnAction )( 
            IEXCELCtrlExtender * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Placement )( 
            IEXCELCtrlExtender * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Placement )( 
            IEXCELCtrlExtender * This,
            /* [in] */ VARIANT RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_PrintObject )( 
            IEXCELCtrlExtender * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_PrintObject )( 
            IEXCELCtrlExtender * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Select )( 
            IEXCELCtrlExtender * This,
            /* [optional][in] */ VARIANT Replace,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *SendToBack )( 
            IEXCELCtrlExtender * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Top )( 
            IEXCELCtrlExtender * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Top )( 
            IEXCELCtrlExtender * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_TopLeftCell )( 
            IEXCELCtrlExtender * This,
            /* [retval][out] */ Range	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Visible )( 
            IEXCELCtrlExtender * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Visible )( 
            IEXCELCtrlExtender * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Width )( 
            IEXCELCtrlExtender * This,
            /* [retval][out] */ double *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Width )( 
            IEXCELCtrlExtender * This,
            /* [in] */ double RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ZOrder )( 
            IEXCELCtrlExtender * This,
            /* [retval][out] */ long *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ShapeRange )( 
            IEXCELCtrlExtender * This,
            /* [retval][out] */ ShapeRange	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Border )( 
            IEXCELCtrlExtender * This,
            /* [retval][out] */ Border	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Interior )( 
            IEXCELCtrlExtender * This,
            /* [retval][out] */ Interior	**RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_Shadow )( 
            IEXCELCtrlExtender * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_Shadow )( 
            IEXCELCtrlExtender * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Activate )( 
            IEXCELCtrlExtender * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AutoLoad )( 
            IEXCELCtrlExtender * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AutoLoad )( 
            IEXCELCtrlExtender * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_AutoUpdate )( 
            IEXCELCtrlExtender * This,
            /* [retval][out] */ VARIANT_BOOL *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_AutoUpdate )( 
            IEXCELCtrlExtender * This,
            /* [in] */ VARIANT_BOOL RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_OLEType )( 
            IEXCELCtrlExtender * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_SourceName )( 
            IEXCELCtrlExtender * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_SourceName )( 
            IEXCELCtrlExtender * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Update )( 
            IEXCELCtrlExtender * This,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][id] */ HRESULT ( __stdcall *Verb )( 
            IEXCELCtrlExtender * This,
            /* [defaultvalue][optional][in] */ XlOLEVerb Verb,
            /* [retval][out] */ VARIANT *RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_LinkedCell )( 
            IEXCELCtrlExtender * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_LinkedCell )( 
            IEXCELCtrlExtender * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_ListFillRange )( 
            IEXCELCtrlExtender * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][propput][id] */ HRESULT ( __stdcall *put_ListFillRange )( 
            IEXCELCtrlExtender * This,
            /* [in] */ BSTR RHS);
        
        /* [helpcontext][propget][id] */ HRESULT ( __stdcall *get_progID )( 
            IEXCELCtrlExtender * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propget][id] */ HRESULT ( __stdcall *get_AltHTML )( 
            IEXCELCtrlExtender * This,
            /* [retval][out] */ BSTR *RHS);
        
        /* [helpcontext][hidden][propput][id] */ HRESULT ( __stdcall *put_AltHTML )( 
            IEXCELCtrlExtender * This,
            /* [in] */ BSTR RHS);
        
        END_INTERFACE
    } IEXCELCtrlExtenderVtbl;

    interface IEXCELCtrlExtender
    {
        CONST_VTBL struct IEXCELCtrlExtenderVtbl *lpVtbl;
    };

    

#ifdef COBJMACROS


#define IEXCELCtrlExtender_QueryInterface(This,riid,ppvObject)	\
    ( (This)->lpVtbl -> QueryInterface(This,riid,ppvObject) ) 

#define IEXCELCtrlExtender_AddRef(This)	\
    ( (This)->lpVtbl -> AddRef(This) ) 

#define IEXCELCtrlExtender_Release(This)	\
    ( (This)->lpVtbl -> Release(This) ) 


#define IEXCELCtrlExtender_GetTypeInfoCount(This,pctinfo)	\
    ( (This)->lpVtbl -> GetTypeInfoCount(This,pctinfo) ) 

#define IEXCELCtrlExtender_GetTypeInfo(This,iTInfo,lcid,ppTInfo)	\
    ( (This)->lpVtbl -> GetTypeInfo(This,iTInfo,lcid,ppTInfo) ) 

#define IEXCELCtrlExtender_GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId)	\
    ( (This)->lpVtbl -> GetIDsOfNames(This,riid,rgszNames,cNames,lcid,rgDispId) ) 

#define IEXCELCtrlExtender_Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr)	\
    ( (This)->lpVtbl -> Invoke(This,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr) ) 


#define IEXCELCtrlExtender_get_Name(This,RHS)	\
    ( (This)->lpVtbl -> get_Name(This,RHS) ) 

#define IEXCELCtrlExtender_put_Name(This,RHS)	\
    ( (This)->lpVtbl -> put_Name(This,RHS) ) 

#define IEXCELCtrlExtender_get_Object(This,RHS)	\
    ( (This)->lpVtbl -> get_Object(This,RHS) ) 

#define IEXCELCtrlExtender_get_Parent(This,RHS)	\
    ( (This)->lpVtbl -> get_Parent(This,RHS) ) 

#define IEXCELCtrlExtender_get_Application(This,RHS)	\
    ( (This)->lpVtbl -> get_Application(This,RHS) ) 

#define IEXCELCtrlExtender_get_Creator(This,RHS)	\
    ( (This)->lpVtbl -> get_Creator(This,RHS) ) 

#define IEXCELCtrlExtender_get_BottomRightCell(This,RHS)	\
    ( (This)->lpVtbl -> get_BottomRightCell(This,RHS) ) 

#define IEXCELCtrlExtender_BringToFront(This,RHS)	\
    ( (This)->lpVtbl -> BringToFront(This,RHS) ) 

#define IEXCELCtrlExtender_Copy(This,RHS)	\
    ( (This)->lpVtbl -> Copy(This,RHS) ) 

#define IEXCELCtrlExtender_Delete(This,RHS)	\
    ( (This)->lpVtbl -> Delete(This,RHS) ) 

#define IEXCELCtrlExtender_CopyPicture(This,Appearance,Format,RHS)	\
    ( (This)->lpVtbl -> CopyPicture(This,Appearance,Format,RHS) ) 

#define IEXCELCtrlExtender_Cut(This,RHS)	\
    ( (This)->lpVtbl -> Cut(This,RHS) ) 

#define IEXCELCtrlExtender_Duplicate(This,RHS)	\
    ( (This)->lpVtbl -> Duplicate(This,RHS) ) 

#define IEXCELCtrlExtender_get_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> get_Enabled(This,RHS) ) 

#define IEXCELCtrlExtender_put_Enabled(This,RHS)	\
    ( (This)->lpVtbl -> put_Enabled(This,RHS) ) 

#define IEXCELCtrlExtender_get_Height(This,RHS)	\
    ( (This)->lpVtbl -> get_Height(This,RHS) ) 

#define IEXCELCtrlExtender_put_Height(This,RHS)	\
    ( (This)->lpVtbl -> put_Height(This,RHS) ) 

#define IEXCELCtrlExtender_get_Index(This,RHS)	\
    ( (This)->lpVtbl -> get_Index(This,RHS) ) 

#define IEXCELCtrlExtender_get_Left(This,RHS)	\
    ( (This)->lpVtbl -> get_Left(This,RHS) ) 

#define IEXCELCtrlExtender_put_Left(This,RHS)	\
    ( (This)->lpVtbl -> put_Left(This,RHS) ) 

#define IEXCELCtrlExtender_get_Locked(This,RHS)	\
    ( (This)->lpVtbl -> get_Locked(This,RHS) ) 

#define IEXCELCtrlExtender_put_Locked(This,RHS)	\
    ( (This)->lpVtbl -> put_Locked(This,RHS) ) 

#define IEXCELCtrlExtender_get_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> get_OnAction(This,RHS) ) 

#define IEXCELCtrlExtender_put_OnAction(This,RHS)	\
    ( (This)->lpVtbl -> put_OnAction(This,RHS) ) 

#define IEXCELCtrlExtender_get_Placement(This,RHS)	\
    ( (This)->lpVtbl -> get_Placement(This,RHS) ) 

#define IEXCELCtrlExtender_put_Placement(This,RHS)	\
    ( (This)->lpVtbl -> put_Placement(This,RHS) ) 

#define IEXCELCtrlExtender_get_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> get_PrintObject(This,RHS) ) 

#define IEXCELCtrlExtender_put_PrintObject(This,RHS)	\
    ( (This)->lpVtbl -> put_PrintObject(This,RHS) ) 

#define IEXCELCtrlExtender_Select(This,Replace,RHS)	\
    ( (This)->lpVtbl -> Select(This,Replace,RHS) ) 

#define IEXCELCtrlExtender_SendToBack(This,RHS)	\
    ( (This)->lpVtbl -> SendToBack(This,RHS) ) 

#define IEXCELCtrlExtender_get_Top(This,RHS)	\
    ( (This)->lpVtbl -> get_Top(This,RHS) ) 

#define IEXCELCtrlExtender_put_Top(This,RHS)	\
    ( (This)->lpVtbl -> put_Top(This,RHS) ) 

#define IEXCELCtrlExtender_get_TopLeftCell(This,RHS)	\
    ( (This)->lpVtbl -> get_TopLeftCell(This,RHS) ) 

#define IEXCELCtrlExtender_get_Visible(This,RHS)	\
    ( (This)->lpVtbl -> get_Visible(This,RHS) ) 

#define IEXCELCtrlExtender_put_Visible(This,RHS)	\
    ( (This)->lpVtbl -> put_Visible(This,RHS) ) 

#define IEXCELCtrlExtender_get_Width(This,RHS)	\
    ( (This)->lpVtbl -> get_Width(This,RHS) ) 

#define IEXCELCtrlExtender_put_Width(This,RHS)	\
    ( (This)->lpVtbl -> put_Width(This,RHS) ) 

#define IEXCELCtrlExtender_get_ZOrder(This,RHS)	\
    ( (This)->lpVtbl -> get_ZOrder(This,RHS) ) 

#define IEXCELCtrlExtender_get_ShapeRange(This,RHS)	\
    ( (This)->lpVtbl -> get_ShapeRange(This,RHS) ) 

#define IEXCELCtrlExtender_get_Border(This,RHS)	\
    ( (This)->lpVtbl -> get_Border(This,RHS) ) 

#define IEXCELCtrlExtender_get_Interior(This,RHS)	\
    ( (This)->lpVtbl -> get_Interior(This,RHS) ) 

#define IEXCELCtrlExtender_get_Shadow(This,RHS)	\
    ( (This)->lpVtbl -> get_Shadow(This,RHS) ) 

#define IEXCELCtrlExtender_put_Shadow(This,RHS)	\
    ( (This)->lpVtbl -> put_Shadow(This,RHS) ) 

#define IEXCELCtrlExtender_Activate(This,RHS)	\
    ( (This)->lpVtbl -> Activate(This,RHS) ) 

#define IEXCELCtrlExtender_get_AutoLoad(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoLoad(This,RHS) ) 

#define IEXCELCtrlExtender_put_AutoLoad(This,RHS)	\
    ( (This)->lpVtbl -> put_AutoLoad(This,RHS) ) 

#define IEXCELCtrlExtender_get_AutoUpdate(This,RHS)	\
    ( (This)->lpVtbl -> get_AutoUpdate(This,RHS) ) 

#define IEXCELCtrlExtender_put_AutoUpdate(This,RHS)	\
    ( (This)->lpVtbl -> put_AutoUpdate(This,RHS) ) 

#define IEXCELCtrlExtender_get_OLEType(This,RHS)	\
    ( (This)->lpVtbl -> get_OLEType(This,RHS) ) 

#define IEXCELCtrlExtender_get_SourceName(This,RHS)	\
    ( (This)->lpVtbl -> get_SourceName(This,RHS) ) 

#define IEXCELCtrlExtender_put_SourceName(This,RHS)	\
    ( (This)->lpVtbl -> put_SourceName(This,RHS) ) 

#define IEXCELCtrlExtender_Update(This,RHS)	\
    ( (This)->lpVtbl -> Update(This,RHS) ) 

#define IEXCELCtrlExtender_Verb(This,Verb,RHS)	\
    ( (This)->lpVtbl -> Verb(This,Verb,RHS) ) 

#define IEXCELCtrlExtender_get_LinkedCell(This,RHS)	\
    ( (This)->lpVtbl -> get_LinkedCell(This,RHS) ) 

#define IEXCELCtrlExtender_put_LinkedCell(This,RHS)	\
    ( (This)->lpVtbl -> put_LinkedCell(This,RHS) ) 

#define IEXCELCtrlExtender_get_ListFillRange(This,RHS)	\
    ( (This)->lpVtbl -> get_ListFillRange(This,RHS) ) 

#define IEXCELCtrlExtender_put_ListFillRange(This,RHS)	\
    ( (This)->lpVtbl -> put_ListFillRange(This,RHS) ) 

#define IEXCELCtrlExtender_get_progID(This,RHS)	\
    ( (This)->lpVtbl -> get_progID(This,RHS) ) 

#define IEXCELCtrlExtender_get_AltHTML(This,RHS)	\
    ( (This)->lpVtbl -> get_AltHTML(This,RHS) ) 

#define IEXCELCtrlExtender_put_AltHTML(This,RHS)	\
    ( (This)->lpVtbl -> put_AltHTML(This,RHS) ) 

#endif /* COBJMACROS */


#endif 	/* C style interface */




#endif 	/* __IEXCELCtrlExtender_INTERFACE_DEFINED__ */


EXTERN_C const CLSID CLSID_KEXCELCtrlExtender;

#ifdef __cplusplus

class DECLSPEC_UUID("7BC8A1B5-CF6E-4aeb-9B50-1BF5ECCFE2D9")
KEXCELCtrlExtender;
#endif
#endif /* __Excel_LIBRARY_DEFINED__ */

/* Additional Prototypes for ALL interfaces */

/* end of Additional Prototypes */

#ifdef __cplusplus
}
#endif

}

#endif
